@@ -6,6 +6,26 @@ Development script of the ChemEnv utility to get the optimized explicit permutat
 identified with the separation plane algorithms (typically with coordination numbers >= 6)
 """
 
+import itertools
+import json
+import os
+import time
+from math import factorial
+from optparse import OptionParser
+from random import shuffle
+
+import numpy as np
+import tabulate
+
+from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import (
+    AllCoordinationGeometries,
+)
+from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import (
+    AbstractGeometry,
+    LocalGeometryFinder,
+)
+from pymatgen.analysis.chemenv.utils.coordination_geometry_utils import Plane
+
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "2.0"
@@ -13,22 +33,6 @@ __maintainer__ = "David Waroquiers"
 __email__ = "david.waroquiers@gmail.com"
 __date__ = "Feb 20, 2016"
 
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import AbstractGeometry
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import LocalGeometryFinder
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import AllCoordinationGeometries
-from pymatgen.analysis.chemenv.utils.coordination_geometry_utils import Plane
-from math import factorial
-
-import numpy as np
-import itertools
-from random import shuffle
-import json
-import os
-import tabulate
-import time
-
-from optparse import OptionParser
-
 
 # Printing functions depending on the printing volume option
 def prt1(string, printing_volume):
@@ -43,7 +47,7 @@ def prt2(string, printing_volume):
 
 # Iterator function for the random permutations
 def random_permutations_iterator(initial_permutation, npermutations):
-    for ii in range(npermutations):
+    for _ in range(npermutations):
         shuffle(initial_permutation)
         yield initial_permutation
 
@@ -109,35 +113,35 @@ if __name__ == "__main__":
             raise ValueError("Wrong command line option for permutations_setup")
 
     # Class containing all the coordination geometries
-    allcg = AllCoordinationGeometries()
+    all_cg = AllCoordinationGeometries()
 
-    sepplane_cgs = []
+    sep_plane_cgs = []
     for coordination in range(1, 21):
-        symbol_name_mapping = allcg.get_symbol_name_mapping(coordination=coordination)
-        for symbol, name in symbol_name_mapping.items():
-            cg = allcg[symbol]
+        symbol_name_mapping = all_cg.get_symbol_name_mapping(coordination=coordination)
+        for symbol in symbol_name_mapping:
+            cg = all_cg[symbol]
             if cg.points is None:
                 continue
             if cg.algorithms[0].algorithm_type != "EXPLICIT_PERMUTATIONS":
-                sepplane_cgs.append(symbol)
+                sep_plane_cgs.append(symbol)
                 continue
     ncols = 5
-    nlines = int(np.ceil(float(len(sepplane_cgs)) / ncols))
-    sepplane_cgs_grid = []
-    for iline in range(nlines):
-        sepplane_cgs_grid.append([""] * ncols)
+    nlines = int(np.ceil(float(len(sep_plane_cgs)) / ncols))
+    sep_plane_cgs_grid = []
+    for _ in range(nlines):
+        sep_plane_cgs_grid.append([""] * ncols)
     for iline in range(nlines):
         for icol in range(ncols):
             ii = iline * ncols + icol
-            if ii >= len(sepplane_cgs):
+            if ii >= len(sep_plane_cgs):
                 break
-            sepplane_cgs_grid[iline][icol] = sepplane_cgs[ii]
+            sep_plane_cgs_grid[iline][icol] = sep_plane_cgs[ii]
 
     while True:
         # Printing all symbols
         print("Coordination geometries using a separation plane algorithm :")
-        print(tabulate.tabulate(sepplane_cgs_grid, tablefmt="grid"))
-        print("")
+        print(tabulate.tabulate(sep_plane_cgs_grid, tablefmt="grid"))
+        print()
 
         # Define the coordination geometry
         cg_symbol = input(
@@ -145,11 +149,11 @@ if __name__ == "__main__":
         )
         if cg_symbol == "q":
             break
-        if cg_symbol not in sepplane_cgs:
+        if cg_symbol not in sep_plane_cgs:
             print("Wrong geometry, try again ...")
             continue
 
-        cg = allcg[cg_symbol]
+        cg = all_cg[cg_symbol]
 
         print(f'Getting explicit permutations for geometry "{cg.name}" (symbol : "{cg_symbol}")\n')
 
@@ -177,20 +181,16 @@ if __name__ == "__main__":
             else:
                 eop = str(len(algo.explicit_optimized_permutations))
             print(
-                "For ialgo {:d}, plane_points are {}, "
-                "side_0 is {} and "
-                "side_1 is {}.".format(
-                    ialgo,
-                    "[{}]".format(", ".join([str(pp) for pp in algo.plane_points])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[0]])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[1]])),
-                )
+                f"For ialgo {ialgo,:d}, plane_points are "
+                f"[{', '.join(map(str, algo.plane_points))}], "
+                f"side_0 is [{', '.join(map(str, algo.point_groups[0]))}] and "
+                f"side_1 is [{', '.join(map(str, algo.point_groups[1]))}]."
             )
             original_nexplicit_perms.append(len(algo.explicit_permutations))
             original_nexplicit_optimized_perms.append(eop)
             print(
-                "  For this algorithm, there are {} optimized permutations and "
-                "{:d} explicit permutations".format(eop, len(algo.explicit_permutations))
+                f"  For this algorithm, there are {eop} optimized permutations and "
+                f"{len(algo.explicit_permutations):d} explicit permutations"
             )
             if algo.other_plane_points is None:
                 input("Multiplicity and other plane points is not defined for this algorithm !")
@@ -211,7 +211,7 @@ if __name__ == "__main__":
             explicit_permutations_per_plane = []
             for iplane, plane_point_indices in enumerate(all_planes_point_indices):
                 prt1(
-                    string="In plane {:d} ({})".format(iplane, "-".join(str(pp) for pp in plane_point_indices)),
+                    string=f"In plane {iplane:d} ({'-'.join(str(pp) for pp in plane_point_indices)})",
                     printing_volume=printing_volume,
                 )
 
@@ -221,7 +221,7 @@ if __name__ == "__main__":
                 # Actual test of the permutations
                 csms, perms, algos, sep_perms = lgf._cg_csm_separation_plane(
                     coordination_geometry=cg,
-                    sepplane=algo,
+                    sep_plane=algo,
                     local_plane=local_plane,
                     plane_separations=[],
                     dist_tolerances=[0.05, 0.1, 0.2, 0.3, 0.5],
@@ -242,9 +242,7 @@ if __name__ == "__main__":
                             break
                     if not found:
                         prt1(
-                            string=" permutation {} : {}".format(
-                                "-".join([str(ii) for ii in sep_perms[icsm]]), str(csm["symmetry_measure"])
-                            ),
+                            string=f" permutation {'-'.join(map(str, sep_perms[icsm]))} : {csm['symmetry_measure']}",
                             printing_volume=printing_volume,
                         )
                         csms_with_recorded_permutation.append(csm)
@@ -268,14 +266,14 @@ if __name__ == "__main__":
             algo.explicit_permutations = np.array(algo.explicit_permutations)
             print(f"Explicit permutations found ({len(algo.explicit_permutations):d})")
             print(algo.explicit_permutations)
-            print("")
+            print()
             # Setup the permutations for the next optimization
             algo._permutations = algo.explicit_permutations
 
         while True:
             test = input(
-                'Get the explicit optimized permutations for geometry "{}" (symbol : "{}") ? '
-                '("y" to confirm, "q" to quit)\n'.format(cg.name, cg_symbol)
+                f'Get the explicit optimized permutations for geometry "{cg.name}" (symbol : '
+                f'"{cg_symbol}") ? ("y" to confirm, "q" to quit)\n'
             )
             if test not in ["y", "q"]:
                 print("Wrong key, try again")
@@ -292,14 +290,10 @@ if __name__ == "__main__":
         for ialgo, algo in enumerate(cg.algorithms):
             perms_used = {}
             print(
-                "In ialgo {:d} (plane_points : {}, "
-                "side_0 : {} and "
-                "side_1 : {})".format(
-                    ialgo,
-                    "[{}]".format(", ".join([str(pp) for pp in algo.plane_points])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[0]])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[1]])),
-                )
+                f"In ialgo {ialgo:d} (plane_points : "
+                f"[{', '.join(map(str, algo.plane_points))}], "
+                f"side_0 : [{', '.join(map(str, algo.point_groups[0]))}] and "
+                f"side_1 : [{', '.join(map(str, algo.point_groups[1]))}])"
             )
             if algo.algorithm_type == "EXPLICIT_PERMUTATIONS":
                 raise ValueError("Do something for the explicit ones ... (these should anyway be by far ok!)")
@@ -342,9 +336,9 @@ if __name__ == "__main__":
             for indices_perm in perms_iterator:
 
                 prt1(
-                    string="Perm # {:d}/{:d} : {} (est. rem. time : {} sec)".format(
-                        iperm, npermutations, "-".join([str(ii) for ii in indices_perm]), timeleft
-                    ),
+                    string=f"Perm # {iperm:d}/{npermutations:d} : "
+                    f"{'-'.join(map(str, indices_perm))} "
+                    f"(est. rem. time : {timeleft} sec)",
                     printing_volume=printing_volume,
                 )
                 # Setup of the local and perfect geometries
@@ -358,7 +352,7 @@ if __name__ == "__main__":
                 separation_permutations = list()
                 for iplane, plane_point_indices in enumerate(all_planes_point_indices):
                     prt2(
-                        string="In plane {:d} ({})".format(iplane, "-".join(str(pp) for pp in plane_point_indices)),
+                        string=f"In plane {iplane:d} ({'-'.join(str(pp) for pp in plane_point_indices)})",
                         printing_volume=printing_volume,
                     )
 
@@ -371,7 +365,7 @@ if __name__ == "__main__":
                     # Get the results for this algorithm and plane
                     csms, perms, algos, sep_perms = lgf._cg_csm_separation_plane(
                         coordination_geometry=cg,
-                        sepplane=algo,
+                        sep_plane=algo,
                         local_plane=local_plane,
                         plane_separations=[],
                         dist_tolerances=[0.05, 0.1, 0.2, 0.3, 0.5],
@@ -391,9 +385,7 @@ if __name__ == "__main__":
                             mincsm_indices.append(icsm)
                     this_plane_sep_perm = tuple(sep_perms[imin])
                     prt2(
-                        string="  permutation {} gives csm={:.6f}".format(
-                            "-".join(str(pp) for pp in this_plane_sep_perm), mycsms[imin]
-                        ),
+                        string=f"  permutation {'-'.join(map(str, this_plane_sep_perm))} gives csm={mycsms[imin]:.6f}",
                         printing_volume=printing_volume,
                     )
 
@@ -408,49 +400,34 @@ if __name__ == "__main__":
                 timeleft = f"{timeleft:.1f}"
                 iperm += 1
             print(
-                "Optimized permutations {:d}/{:d}"
-                "(old : {}/{}) : ".format(
-                    len(perms_used),
-                    len(algo.permutations),
-                    str(original_nexplicit_optimized_perms[ialgo]),
-                    str(original_nexplicit_perms[ialgo]),
-                )
+                f"Optimized permutations {len(perms_used):d}/{len(algo.permutations):d}"
+                f"(old : {original_nexplicit_optimized_perms[ialgo]}/{original_nexplicit_perms[ialgo]}) : "
             )
             for perm, number in perms_used.items():
-                print(" - permutation {} : {:d}".format("-".join([str(pp) for pp in perm]), number))
+                print(f" - permutation {'-'.join(map(str, perm))} : {number:d}")
             print(
-                "For ialgo {:d} (plane_points : {}, "
-                "side_0 : {} and "
-                "side_1 : {}),\n"
-                "Optimized perturbations {:d}/{:d} (old : {}/{}) "
-                "are :".format(
-                    ialgo,
-                    "[{}]".format(", ".join([str(pp) for pp in algo.plane_points])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[0]])),
-                    "[{}]".format(", ".join([str(pp) for pp in algo.point_groups[1]])),
-                    len(perms_used),
-                    len(algo.permutations),
-                    str(original_nexplicit_optimized_perms[ialgo]),
-                    str(original_nexplicit_perms[ialgo]),
-                )
+                f"For ialgo {ialgo} (plane_points : [{', '.join(map(str, algo.plane_points))}], "
+                f"side_0 : [{', '.join(map(str, algo.point_groups[0]))}] and "
+                f"side_1 : [{', '.join(map(str, algo.point_groups[1]))}]),\n"
+                f"Optimized perturbations {len(perms_used)}/{len(algo.permutations)} (old : "
+                f"{original_nexplicit_optimized_perms[ialgo]}/{original_nexplicit_perms[ialgo]}) are :"
             )
             # print('Optimized permutations ({:d}/{:d}) : '.format(len(perms_used), len(algo.permutations)))
-            explicit_optimized_permutations = [list(perm) for perm in perms_used.keys()]
+            explicit_optimized_permutations = [list(perm) for perm in perms_used]
             explicit_optimized_permutations.sort()
             print(explicit_optimized_permutations)
-            print("")
+            print()
             test = input(f'Set optimized permutations for algorithm {ialgo:d} ? ("y" to confirm)')
             if test == "y":
                 algo.explicit_optimized_permutations = np.array(explicit_optimized_permutations)
 
         test = input(
-            'Save coordination geometry "{}" (symbol "{}") and new explicit and optimized permutations ? '
-            '("y" to confirm)'.format(cg.name, cg_symbol)
+            f'Save coordination geometry "{cg.name}" (symbol "{cg_symbol}") and new explicit and optimized '
+            'permutations ? ("y" to confirm)'
         )
         if test == "y":
             newgeom_dir = "new_geometry_files"
             if not os.path.exists(newgeom_dir):
                 os.makedirs(newgeom_dir)
-            f = open(f"{newgeom_dir}/{cg_symbol}.json", "w")
-            json.dump(cg.as_dict(), f)
-            f.close()
+            with open(f"{newgeom_dir}/{cg_symbol}.json", "w") as f:
+                json.dump(cg.as_dict(), f)
