@@ -5,6 +5,8 @@
 Module for BondDissociationEnergies.
 """
 
+from __future__ import annotations
+
 import logging
 
 import networkx as nx
@@ -56,9 +58,7 @@ class BondDissociationEnergies(MSONable):
                                                        among fragments. Defaults to False. See the definition
                                                        of self.expected_charges below for more specific information.
             multibreak (bool): If True, additionally attempt to break pairs of bonds. Defaults to False.
-
         """
-
         self.molecule_entry = molecule_entry
         self.filter_fragment_entries(fragment_entries)
         print(str(len(self.filtered_entries)) + " filtered entries")
@@ -187,7 +187,7 @@ class BondDissociationEnergies(MSONable):
                             + smiles
                         )
                     elif len(good_entries) == 1:
-                        # If we have only one good entry, format it and addd it to the list that will eventually return:
+                        # If we have only one good entry, format it and add it to the list that will eventually return:
                         self.bond_dissociation_energies += [self.build_new_entry(good_entries, bonds)]
                     else:
                         # We shouldn't ever encounter more than one good entry.
@@ -275,7 +275,7 @@ class BondDissociationEnergies(MSONable):
         """
         Search all fragment entries for those isomorphic to the given fragment.
         We distinguish between entries where both initial and final molgraphs are isomorphic to the
-        given fragment (entries) vs those where only the intial molgraph is isomorphic to the given
+        given fragment (entries) vs those where only the initial molgraph is isomorphic to the given
         fragment (initial_entries) vs those where only the final molgraph is isomorphic (final_entries)
 
         Args:
@@ -326,7 +326,7 @@ class BondDissociationEnergies(MSONable):
             entry["final_molgraph"] = MoleculeGraph.with_local_env_strategy(
                 Molecule.from_dict(entry["final_molecule"]), OpenBabelNN()
             )
-            # Classify any potential structural change that occured during optimization:
+            # Classify any potential structural change that occurred during optimization:
             if entry["initial_molgraph"].isomorphic_to(entry["final_molgraph"]):
                 entry["structure_change"] = "no_change"
             else:
