@@ -197,7 +197,7 @@ class BVAnalyzer:
                 sigma = data["std"]
                 # Calculate posterior probability. Note that constant
                 # factors are ignored. They have no effect on the results.
-                prob[sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2)) / sigma * PRIOR_PROB[sp]
+                prob[sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma**2)) / sigma * PRIOR_PROB[sp]
         # Normalize the probabilities
         try:
             prob = {k: v / sum(prob.values()) for k, v in prob.items()}
@@ -208,7 +208,7 @@ class BVAnalyzer:
     def _calc_site_probabilities_unordered(self, site, nn):
         bv_sum = calculate_bv_sum_unordered(site, nn, scale_factor=self.dist_scale_factor)
         prob = {}
-        for specie, occu in site.species.items():
+        for specie in site.species:
             el = specie.symbol
 
             prob[el] = {}
@@ -218,7 +218,7 @@ class BVAnalyzer:
                     sigma = data["std"]
                     # Calculate posterior probability. Note that constant
                     # factors are ignored. They have no effect on the results.
-                    prob[el][sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2)) / sigma * PRIOR_PROB[sp]
+                    prob[el][sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma**2)) / sigma * PRIOR_PROB[sp]
             # Normalize the probabilities
             try:
                 prob[el] = {k: v / sum(prob[el].values()) for k, v in prob[el].items()}
@@ -246,7 +246,7 @@ class BVAnalyzer:
         """
         els = [Element(el.symbol) for el in structure.composition.elements]
 
-        if not set(els).issubset(set(BV_PARAMS.keys())):
+        if not set(els).issubset(set(BV_PARAMS)):
             raise ValueError("Structure contains elements not in set of BV parameters!")
 
         # Perform symmetry determination and get sites grouped by symmetry.
@@ -270,7 +270,7 @@ class BVAnalyzer:
                 nn = structure.get_neighbors(test_site, self.max_radius)
                 prob = self._calc_site_probabilities(test_site, nn)
                 all_prob.append(prob)
-                val = list(prob.keys())
+                val = list(prob)
                 # Sort valences in order of decreasing probability.
                 val = sorted(val, key=lambda v: -prob[v])
                 # Retain probabilities that are at least 1/100 of highest prob.
@@ -284,8 +284,8 @@ class BVAnalyzer:
                 all_prob.append(prob)
                 full_all_prob.extend(prob.values())
                 vals = []
-                for (elsp, occ) in get_z_ordered_elmap(test_site.species):
-                    val = list(prob[elsp.symbol].keys())
+                for (elsp, _) in get_z_ordered_elmap(test_site.species):
+                    val = list(prob[elsp.symbol])
                     # Sort valences in order of decreasing probability.
                     val = sorted(val, key=lambda v: -prob[elsp.symbol][v])
                     # Retain probabilities that are at least 1/100 of highest
@@ -322,11 +322,13 @@ class BVAnalyzer:
                     self._best_vset = v_set
                     self._best_score = score
 
-            def _recurse(assigned=[]):
+            def _recurse(assigned=None):
                 # recurses to find permutations of valences based on whether a
                 # charge balanced assignment can still be found
                 if self._n > self.max_permutations:
                     return None
+                if assigned is None:
+                    assigned = []
 
                 i = len(assigned)
                 highest = vmax.copy()
@@ -357,7 +359,7 @@ class BVAnalyzer:
             tmp = []
             attrib = []
             for insite, nsite in enumerate(nsites):
-                for val in valences[insite]:
+                for _ in valences[insite]:
                     tmp.append(nsite)
                     attrib.append(insite)
             new_nsites = np.array(tmp)
@@ -382,8 +384,8 @@ class BVAnalyzer:
             def evaluate_assignment(v_set):
                 el_oxi = collections.defaultdict(list)
                 jj = 0
-                for i, sites in enumerate(equi_sites):
-                    for specie, occu in get_z_ordered_elmap(sites[0].species):
+                for sites in equi_sites:
+                    for specie, _ in get_z_ordered_elmap(sites[0].species):
                         el_oxi[specie.symbol].append(v_set[jj])
                         jj += 1
                 max_diff = max(max(v) - min(v) for v in el_oxi.values())
@@ -398,11 +400,13 @@ class BVAnalyzer:
                     self._best_vset = v_set
                     self._best_score = score
 
-            def _recurse(assigned=[]):
+            def _recurse(assigned=None):
                 # recurses to find permutations of valences based on whether a
                 # charge balanced assignment can still be found
                 if self._n > self.max_permutations:
                     return None
+                if assigned is None:
+                    assigned = []
 
                 i = len(assigned)
                 highest = vmax.copy()
@@ -444,7 +448,7 @@ class BVAnalyzer:
                 return [int(assigned[site]) for site in structure]
             assigned = {}
             new_best_vset = []
-            for ii in range(len(equi_sites)):
+            for _ in equi_sites:
                 new_best_vset.append([])
             for ival, val in enumerate(self._best_vset):
                 new_best_vset[attrib[ival]].append(val)
@@ -492,7 +496,7 @@ def get_z_ordered_elmap(comp):
     Cr4+, Cr3+, Ni3+, Ni4+, Zn2+ ... or
     Cr4+, Cr3+, Ni4+, Ni3+, Zn2+
     """
-    return sorted((elsp, comp[elsp]) for elsp in comp.keys())
+    return sorted((elsp, comp[elsp]) for elsp in comp)
 
 
 def add_oxidation_state_by_site_fraction(structure, oxidation_states):
