@@ -76,7 +76,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                     patchA=n1,
                     patchB=n2,
                     arrowstyle="-|>",
-                    connectionstyle="arc3,rad=%s" % rad,
+                    connectionstyle=f"arc3,rad={rad}",
                     mutation_scale=15.0,
                     lw=2,
                     alpha=alpha,
@@ -90,7 +90,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                     patchA=n1,
                     patchB=n2,
                     arrowstyle="-|>",
-                    connectionstyle="arc3,rad=%s" % rad,
+                    connectionstyle=f"arc3,rad={rad}",
                     mutation_scale=10.0,
                     lw=2,
                     alpha=alpha,
@@ -104,7 +104,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                 patchA=n1,
                 patchB=n2,
                 arrowstyle="-|>",
-                connectionstyle="arc3,rad=%s" % rad,
+                connectionstyle=f"arc3,rad={rad}",
                 mutation_scale=10.0,
                 lw=2,
                 alpha=alpha,
@@ -357,7 +357,7 @@ class ConnectedComponent(MSONable):
             new_ends = []
             for current_node_end, current_delta_end in current_ends:
                 for nb in self._connected_subgraph.neighbors(current_node_end):
-                    for iedge, edata in self._connected_subgraph[current_node_end][nb].items():
+                    for edata in self._connected_subgraph[current_node_end][nb].values():
                         new_delta = current_delta_end + get_delta(current_node_end, nb, edata)
                         if (nb.isite, *new_delta) not in visited:
                             new_ends.append((nb, new_delta))
@@ -383,12 +383,10 @@ class ConnectedComponent(MSONable):
 
     def compute_periodicity(self, algorithm="all_simple_paths"):
         """
-
         Args:
             algorithm ():
 
         Returns:
-
         """
         if algorithm == "all_simple_paths":
             self.compute_periodicity_all_simple_paths_algorithm()
@@ -400,9 +398,7 @@ class ConnectedComponent(MSONable):
 
     def compute_periodicity_all_simple_paths_algorithm(self):
         """
-
         Returns:
-
         """
         self_loop_nodes = list(nx.nodes_with_selfloops(self._connected_subgraph))
         all_nodes_independent_cell_image_vectors = []
@@ -411,7 +407,7 @@ class ConnectedComponent(MSONable):
             # TODO: do we need to go through all test nodes ?
             this_node_cell_img_vectors = []
             if test_node in self_loop_nodes:
-                for key, edge_data in self._connected_subgraph[test_node][test_node].items():
+                for edge_data in self._connected_subgraph[test_node][test_node].values():
                     if edge_data["delta"] == (0, 0, 0):
                         raise ValueError("There should not be self loops with delta image = (0, 0, 0).")
                     this_node_cell_img_vectors.append(edge_data["delta"])
@@ -458,10 +454,10 @@ class ConnectedComponent(MSONable):
                     path.append(test_node)
                     # TODO: there are some paths that appears twice for cycles, and there are some paths that should
                     # probably not be considered
-                    this_path_deltas = [np.zeros(3, np.int_)]
+                    this_path_deltas = [np.zeros(3, int)]
                     for (node1, node2) in [(node1, path[inode1 + 1]) for inode1, node1 in enumerate(path[:-1])]:
                         this_path_deltas_new = []
-                        for key, edge_data in self._connected_subgraph[node1][node2].items():
+                        for edge_data in self._connected_subgraph[node1][node2].values():
                             delta = get_delta(node1, node2, edge_data)
                             for current_delta in this_path_deltas:
                                 this_path_deltas_new.append(current_delta + delta)
@@ -489,9 +485,7 @@ class ConnectedComponent(MSONable):
 
     def compute_periodicity_cycle_basis(self):
         """
-
         Returns:
-
         """
         my_simple_graph = nx.Graph(self._connected_subgraph)
         cycles = nx.cycle_basis(my_simple_graph)
@@ -499,10 +493,10 @@ class ConnectedComponent(MSONable):
         for cyc in cycles:
             mycyc = list(cyc)
             mycyc.append(cyc[0])
-            this_cycle_deltas = [np.zeros(3, np.int_)]
+            this_cycle_deltas = [np.zeros(3, int)]
             for (node1, node2) in [(node1, mycyc[inode1 + 1]) for inode1, node1 in enumerate(mycyc[:-1])]:
                 this_cycle_deltas_new = []
-                for key, edge_data in self._connected_subgraph[node1][node2].items():
+                for edge_data in self._connected_subgraph[node1][node2].values():
                     delta = get_delta(node1, node2, edge_data)
                     for current_delta in this_cycle_deltas:
                         this_cycle_deltas_new.append(current_delta + delta)
@@ -537,19 +531,16 @@ class ConnectedComponent(MSONable):
 
     def make_supergraph(self, multiplicity):
         """
-
         Args:
             multiplicity ():
 
         Returns:
-
         """
         supergraph = make_supergraph(self._connected_subgraph, multiplicity, self._periodicity_vectors)
         return supergraph
 
     def show_graph(self, graph=None, save_file=None, drawing_type="internal", pltshow=True):
         """
-
         Args:
             graph ():
             save_file ():
@@ -557,7 +548,6 @@ class ConnectedComponent(MSONable):
             pltshow ():
 
         Returns:
-
         """
         import matplotlib.pyplot as plt
 
@@ -602,18 +592,14 @@ class ConnectedComponent(MSONable):
     @property
     def is_periodic(self):
         """
-
         Returns:
-
         """
         return not self.is_0d
 
     @property
     def is_0d(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -622,9 +608,7 @@ class ConnectedComponent(MSONable):
     @property
     def is_1d(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -633,9 +617,7 @@ class ConnectedComponent(MSONable):
     @property
     def is_2d(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -644,9 +626,7 @@ class ConnectedComponent(MSONable):
     @property
     def is_3d(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -683,9 +663,7 @@ class ConnectedComponent(MSONable):
     @property
     def periodicity_vectors(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -694,9 +672,7 @@ class ConnectedComponent(MSONable):
     @property
     def periodicity(self):
         """
-
         Returns:
-
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
@@ -704,12 +680,10 @@ class ConnectedComponent(MSONable):
 
     def elastic_centered_graph(self, start_node=None):
         """
-
         Args:
             start_node ():
 
         Returns:
-
         """
         logging.info("In elastic centering")
         # Loop on start_nodes, sometimes some nodes cannot be elastically taken
@@ -736,23 +710,18 @@ class ConnectedComponent(MSONable):
             # Loop on nodes in this level of the tree
             for node in current_nodes:
                 inode += 1
-                logging.debug(f"  In node #{inode:d}/{len(current_nodes):d} in level {tree_level:d} ({str(node)})")
+                logging.debug(f"  In node #{inode:d}/{len(current_nodes):d} in level {tree_level:d} ({node})")
                 node_neighbors = list(tree.neighbors(n=node))
                 node_edges = centered_connected_subgraph.edges(nbunch=[node], data=True, keys=True)
                 # Loop on neighbors of a node (from the tree used)
                 for inode_neighbor, node_neighbor in enumerate(node_neighbors):
                     logging.debug(
-                        "    Testing neighbor #{:d}/{:d} ({}) of node #{:d} ({})".format(
-                            inode_neighbor,
-                            len(node_neighbors),
-                            node_neighbor,
-                            inode,
-                            node,
-                        )
+                        f"    Testing neighbor #{inode_neighbor:d}/{len(node_neighbors):d} ({node_neighbor}) of "
+                        f"node #{inode:d} ({node})"
                     )
                     already_inside = False
                     ddeltas = []
-                    for n1, n2, key, edata in node_edges:
+                    for n1, n2, _key, edata in node_edges:
                         if (n1 == node and n2 == node_neighbor) or (n2 == node and n1 == node_neighbor):
                             if edata["delta"] == (0, 0, 0):
                                 already_inside = True
@@ -766,9 +735,7 @@ class ConnectedComponent(MSONable):
                                     raise ValueError("Should not be here ...")
                             ddeltas.append(thisdelta)
                     logging.debug(
-                        "        ddeltas : {}".format(
-                            ", ".join(["({})".format(", ".join(str(ddd) for ddd in dd)) for dd in ddeltas])
-                        )
+                        "        ddeltas : " + ", ".join([f"({', '.join(str(ddd) for ddd in dd)})" for dd in ddeltas])
                     )
                     if ddeltas.count((0, 0, 0)) > 1:
                         raise ValueError("Should not have more than one 000 delta ...")
@@ -778,17 +745,13 @@ class ConnectedComponent(MSONable):
                     logging.debug("          Edge outside the cell ... getting neighbor back inside")
                     if (0, 0, 0) in ddeltas:
                         ddeltas.remove((0, 0, 0))
-                    myddelta = np.array(ddeltas[0], np.int_)
+                    myddelta = np.array(ddeltas[0], int)
                     node_neighbor_edges = centered_connected_subgraph.edges(
                         nbunch=[node_neighbor], data=True, keys=True
                     )
                     logging.debug(
-                        "            Delta image from node {} to neighbor {} : "
-                        "{}".format(
-                            str(node),
-                            str(node_neighbor),
-                            "({})".format(", ".join([str(iii) for iii in myddelta])),
-                        )
+                        f"            Delta image from node {str(node)} to neighbor {str(node_neighbor)} : "
+                        f"({', '.join([str(iii) for iii in myddelta])})"
                     )
                     # Loop on the edges of this neighbor
                     for n1, n2, key, edata in node_neighbor_edges:
@@ -797,21 +760,17 @@ class ConnectedComponent(MSONable):
                         ):
                             if edata["start"] == node_neighbor.isite and edata["end"] != node_neighbor.isite:
                                 centered_connected_subgraph[n1][n2][key]["delta"] = tuple(
-                                    np.array(edata["delta"], np.int_) + myddelta
+                                    np.array(edata["delta"], int) + myddelta
                                 )
                             elif edata["end"] == node_neighbor.isite:
                                 centered_connected_subgraph[n1][n2][key]["delta"] = tuple(
-                                    np.array(edata["delta"], np.int_) - myddelta
+                                    np.array(edata["delta"], int) - myddelta
                                 )
                             else:
                                 raise ValueError("DUHH")
                             logging.debug(
-                                "                  {} to node {} now has delta "
-                                "{}".format(
-                                    str(n1),
-                                    str(n2),
-                                    str(centered_connected_subgraph[n1][n2][key]["delta"]),
-                                )
+                                f"                  {n1} to node {n2} now has delta "
+                                f"{centered_connected_subgraph[n1][n2][key]['delta']}"
                             )
                 new_current_nodes.extend(node_neighbors)
                 nodes_traversed.extend(node_neighbors)
@@ -871,7 +830,7 @@ class ConnectedComponent(MSONable):
             edata (dict): Edge data dictionary with possibly the above tuples as lists.
 
         Returns:
-            dict: Edge data dictionary with the lists tranformed back into tuples when applicable.
+            dict: Edge data dictionary with the lists transformed back into tuples when applicable.
         """
         edata["delta"] = tuple(edata["delta"])
         edata["ligands"] = [tuple([lig[0], tuple(lig[1]), tuple(lig[2])]) for lig in edata["ligands"]]
@@ -898,8 +857,8 @@ class ConnectedComponent(MSONable):
                     ied = self._edgekey_to_edgedictkey(ie)
                     new_dict_of_dicts[in1][in2][ied] = jsanitize(edge_data)
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "nodes": {strindex: (node.as_dict(), data) for strindex, (node, data) in nodes.items()},
             "graph": new_dict_of_dicts,
         }
@@ -945,19 +904,17 @@ class ConnectedComponent(MSONable):
 
     def description(self, full=False):
         """
-
         Args:
             full ():
 
         Returns:
-
         """
         out = ["Connected component with environment nodes :"]
         if not full:
             out.extend([str(en) for en in sorted(self.graph.nodes())])
             return "\n".join(out)
         for en in sorted(self.graph.nodes()):
-            out.append(f"{str(en)}, connected to :")
+            out.append(f"{en}, connected to :")
             en_neighbs = nx.neighbors(self.graph, en)
             for en_neighb in sorted(en_neighbs):
                 out.append(f"  - {en_neighb} with delta image cells")
