@@ -1,15 +1,18 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module contains the main object used to identify the coordination environments in a given structure.
 If you use this module, please cite the following:
 David Waroquiers, Xavier Gonze, Gian-Marco Rignanese, Cathrin Welker-Nieuwoudt, Frank Rosowski,
 Michael Goebel, Stephan Schenk, Peter Degelmann, Rute Andre, Robert Glaum, and Geoffroy Hautier,
 "Statistical analysis of coordination environments in oxides",
-Chem. Mater., 2017, 29 (19), pp 8346–8360,
+Chem. Mater., 2017, 29 (19), pp 8346-8360,
 DOI: 10.1021/acs.chemmater.7b02766
+D. Waroquiers, J. George, M. Horton, S. Schenk, K. A. Persson, G.-M. Rignanese, X. Gonze, G. Hautier
+"ChemEnv: a fast and robust coordination environment identification tool",
+Acta Cryst. B 2020, 76, pp 683-695,
+DOI: 10.1107/S2052520620007994
 """
 
 __author__ = "David Waroquiers"
@@ -23,7 +26,6 @@ __date__ = "Feb 20, 2016"
 import itertools
 import logging
 import time
-from collections import OrderedDict
 from random import shuffle
 
 import numpy as np
@@ -158,26 +160,25 @@ class AbstractGeometry:
                 outs.append(
                     "Points are referenced to the central site for coordination numbers < 5"
                     " and to the centroid (calculated with the central site) for coordination"
-                    " numbers >= 5 : {c}\n".format(c=self.centre)
+                    f" numbers >= 5 : {self.centre}\n"
                 )
             else:
                 outs.append(
                     "Points are referenced to the central site for coordination numbers < 5"
                     " and to the centroid (calculated without the central site) for coordination"
-                    " numbers >= 5 : {c}\n".format(c=self.centre)
+                    f" numbers >= 5 : {self.centre}\n"
                 )
         elif self.centering_type == "central_site":
             outs.append(f"Points are referenced to the central site : {self.centre}\n")
         elif self.centering_type == "centroid":
             if self.include_central_site_in_centroid:
                 outs.append(
-                    "Points are referenced to the centroid "
-                    "(calculated with the central site) :\n  {c}\n".format(c=self.centre)
+                    f"Points are referenced to the centroid (calculated with the central site) :\n  {self.centre}\n"
                 )
             else:
                 outs.append(
-                    "Points are referenced to the centroid"
-                    " (calculated without the central site) :\n  {c}\n".format(c=self.centre)
+                    "Points are referenced to the centroid (calculated without the central site)"
+                    f" :\n  {self.centre}\n"
                 )
         return "\n".join(outs)
 
@@ -373,17 +374,20 @@ class LocalGeometryFinder:
 
     def __init__(
         self,
-        permutations_safe_override=False,
-        plane_ordering_override=True,
-        debug_level=None,
-        plane_safe_permutations=False,
+        permutations_safe_override: bool = False,
+        plane_ordering_override: bool = True,
+        plane_safe_permutations: bool = False,
         only_symbols=None,
+        print_citation: bool = False,
     ):
         """
-        Constructor for the LocalGeometryFinder, initializes the list of coordination geometries
-        :param permutations_safe_override: If set to True, all permutations are tested (very time-consuming for large
+        Args:
+            permutations_safe_override: If set to True, all permutations are tested (very time-consuming for large
             coordination numbers!)
-        :param plane_ordering_override: If set to False, the ordering of the points in the plane is disabled
+            plane_ordering_override: If set to False, the ordering of the points in the plane is disabled
+            plane_safe_permutations: Whether to use safe permutations.
+            only_symbols: Whether to restrict the list of environments to be identified.
+            print_citation: If True, the ChemEnv citation will be printed
         """
         self.allcg = AllCoordinationGeometries(
             permutations_safe_override=permutations_safe_override,
@@ -398,7 +402,8 @@ class LocalGeometryFinder:
             bva_distance_scale_factor=None,
             structure_refinement=self.STRUCTURE_REFINEMENT_NONE,
         )
-        print(chemenv_citations())
+        if print_citation:
+            print(chemenv_citations())
 
     def setup_parameters(
         self,
@@ -482,14 +487,14 @@ class LocalGeometryFinder:
         """
         return self.structure
 
-    def set_structure(self, lattice, species, coords, coords_are_cartesian):
+    def set_structure(self, lattice: Lattice, species, coords, coords_are_cartesian):
         """
         Sets up the pymatgen structure for which the coordination geometries have to be identified starting from the
         lattice, the species and the coordinates
         :param lattice: The lattice of the structure
         :param species: The species on the sites
         :param coords: The coordinates of the sites
-        :param coords_are_cartesian: If set to True, the coordinates are given in cartesian coordinates
+        :param coords_are_cartesian: If set to True, the coordinates are given in Cartesian coordinates
         """
         self.setup_structure(Structure(lattice, species, coords, coords_are_cartesian))
 
@@ -522,8 +527,11 @@ class LocalGeometryFinder:
             if valences == "undefined":
                 vals = valences
             else:
-                if len(valences) != len(structure):
-                    raise ValueError("Valences do not match the number of sites in the structure")
+                len_vals, len_sites = len(valences), len(structure)
+                if len_vals != len_sites:
+                    raise ValueError(
+                        f"Valences ({len_vals}) do not match the number of sites in the structure ({len_sites})"
+                    )
                 vals = valences
         # TODO: add something to compute only the neighbors sets needed for the strategy.
         se = self.compute_structure_environments(
@@ -554,6 +562,7 @@ class LocalGeometryFinder:
         get_from_hints=False,
         voronoi_normalized_distance_tolerance=PRESETS["DEFAULT"]["voronoi_normalized_distance_tolerance"],
         voronoi_normalized_angle_tolerance=PRESETS["DEFAULT"]["voronoi_normalized_angle_tolerance"],
+        voronoi_distance_cutoff=None,
         recompute=None,
         optimization=PRESETS["DEFAULT"]["optimization"],
     ):
@@ -583,6 +592,8 @@ class LocalGeometryFinder:
             neighbors sets
         :param voronoi_normalized_angle_tolerance: tolerance for the normalized angle used to distinguish
             neighbors sets
+        :param voronoi_distance_cutoff: determines distance of considered neighbors. Especially important to increase it
+            for molecules in a box.
         :param recompute: whether to recompute the sites already computed (when initial_structure_environments
             is not None)
         :param optimization: optimization algorithm
@@ -664,6 +675,8 @@ class LocalGeometryFinder:
             normalized_angle_tolerance = DetailedVoronoiContainer.default_normalized_angle_tolerance
         else:
             normalized_angle_tolerance = voronoi_normalized_angle_tolerance
+        if voronoi_distance_cutoff is None:
+            voronoi_distance_cutoff = DetailedVoronoiContainer.default_voronoi_cutoff
         self.detailed_voronoi = DetailedVoronoiContainer(
             self.structure,
             isites=sites_indices,
@@ -673,6 +686,7 @@ class LocalGeometryFinder:
             additional_conditions=additional_conditions,
             normalized_distance_tolerance=normalized_distance_tolerance,
             normalized_angle_tolerance=normalized_angle_tolerance,
+            voronoi_cutoff=voronoi_distance_cutoff,
         )
         logging.debug("DetailedVoronoiContainer has been set up")
 
@@ -727,14 +741,13 @@ class LocalGeometryFinder:
                 continue
             if breakit:
                 logging.debug(
-                    " ... in site #{:d}/{:d} ({}) : "
-                    "skipped (timelimit)".format(isite, len(self.structure), site.species_string)
+                    f" ... in site #{isite}/{len(self.structure)} ({site.species_string}) : skipped (timelimit)"
                 )
                 continue
             logging.debug(f" ... in site #{isite:d}/{len(self.structure):d} ({site.species_string})")
             t1 = time.process_time()
             if optimization > 0:
-                self.detailed_voronoi.local_planes[isite] = OrderedDict()
+                self.detailed_voronoi.local_planes[isite] = {}
                 self.detailed_voronoi.separations[isite] = {}
             se.init_neighbors_sets(
                 isite=isite,
@@ -823,10 +836,7 @@ class LocalGeometryFinder:
                 cn_new_nb_set = missing_nb_set_to_add["cn_new_nb_set"]
                 new_nb_set = missing_nb_set_to_add["new_nb_set"]
                 inew_nb_set = se.neighbors_sets[isite_new_nb_set][cn_new_nb_set].index(new_nb_set)
-                logging.debug(
-                    "    ... getting environments for nb_set ({:d}, {:d}) - "
-                    "from hints".format(cn_new_nb_set, inew_nb_set)
-                )
+                logging.debug(f"    ... getting environments for nb_set ({cn_new_nb_set}, {inew_nb_set}) - from hints")
                 tnbset1 = time.process_time()
                 self.update_nb_set_environments(
                     se=se,
@@ -875,7 +885,7 @@ class LocalGeometryFinder:
         self.setup_local_geometry(isite, coords=neighb_coords, optimization=optimization)
         if optimization > 0:
             logging.debug("Getting StructureEnvironments with optimized algorithm")
-            nb_set.local_planes = OrderedDict()
+            nb_set.local_planes = {}
             nb_set.separations = {}
             cncgsm = self.get_coordination_symmetry_measures_optim(nb_set=nb_set, optimization=optimization)
         else:
@@ -1092,14 +1102,8 @@ class LocalGeometryFinder:
         aa = 0.4
         bb = -0.2
         coords = []
-        for ii in range(coordination + 1):
-            coords.append(
-                aa
-                * np.random.random_sample(
-                    3,
-                )
-                + bb
-            )
+        for _ in range(coordination + 1):
+            coords.append(aa * np.random.random_sample(3) + bb)
         self.set_structure(
             lattice=np.array([[10, 0, 0], [0, 10, 0], [0, 0, 10]], np.float_),
             species=["Si"] * (coordination + 1),
@@ -1284,7 +1288,7 @@ class LocalGeometryFinder:
             logging.log(
                 level=5,
                 msg="Getting Continuous Symmetry Measure with Separation Plane "
-                'algorithm for geometry "{}"'.format(geometry.ce_symbol),
+                f'algorithm for geometry "{geometry.ce_symbol}"',
             )
             self.perfect_geometry = AbstractGeometry.from_cg(
                 cg=geometry,
@@ -1588,12 +1592,14 @@ class LocalGeometryFinder:
         """
         Returns the symmetry measures of the given coordination geometry "coordination_geometry" using separation
         facets to reduce the complexity of the system. Caller to the refined 2POINTS, 3POINTS and other ...
+
         Args:
             coordination_geometry: The coordination geometry to be investigated.
             separation_plane_algo: Separation Plane algorithm used.
             points_perfect: Points corresponding to the perfect geometry.
             nb_set: Neighbor set for this set of points. (used to store already computed separation planes)
             optimization: Optimization level (1 or 2).
+
         Returns:
             tuple: Continuous symmetry measures for the given coordination geometry for each plane and permutation
                    investigated, corresponding permutations, corresponding algorithms,
@@ -1617,7 +1623,7 @@ class LocalGeometryFinder:
         local2perfect_maps = []
 
         if separation_plane_algo.separation in nb_set.separations:
-            for sep_indices, (local_plane, npsep) in nb_set.separations[separation_plane_algo.separation].items():
+            for local_plane, npsep in nb_set.separations[separation_plane_algo.separation].values():
                 cgsm = cgcsmoptim(
                     coordination_geometry=coordination_geometry,
                     sepplane=separation_plane_algo,
@@ -1700,7 +1706,7 @@ class LocalGeometryFinder:
                         continue
                     if sep not in nb_set.separations:
                         nb_set.separations[sep] = {}
-                    mysep = [np.array(ss, dtype=np.int8) for ss in separation]
+                    mysep = [np.array(ss, dtype=int) for ss in separation]
                     nb_set.separations[sep][separation] = (plane, mysep)
                     if sep == separation_plane_algo.separation:
                         new_seps.append(mysep)
@@ -1816,7 +1822,7 @@ class LocalGeometryFinder:
 
             # plane_found = True
 
-            for i_sep_perm, sep_perm in enumerate(sep_perms):
+            for sep_perm in sep_perms:
                 perm1 = [separation_perm[ii] for ii in sep_perm]
                 pp = [perm1[ii] for ii in argref_separation]
                 # Skip permutations that have already been performed
@@ -1903,7 +1909,7 @@ class LocalGeometryFinder:
         else:
             sep_perms = sepplane.permutations
 
-        for i_sep_perm, sep_perm in enumerate(sep_perms):
+        for sep_perm in sep_perms:
             perm1 = [separation_perm[ii] for ii in sep_perm]
             pp = [perm1[ii] for ii in argref_separation]
 
@@ -1978,7 +1984,7 @@ class LocalGeometryFinder:
         else:
             sep_perms = sepplane.permutations
 
-        for i_sep_perm, sep_perm in enumerate(sep_perms):
+        for sep_perm in sep_perms:
             perm1 = separation_perm.take(sep_perm)
             pp = perm1.take(argref_separation)
 
