@@ -1,12 +1,9 @@
-#!/usr/bin/env python
-
-
-__author__ = "waroquiers"
-
 import json
 import os
 import unittest
 
+import pytest
+
 from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
     AngleNbSetWeight,
     CNBiasNbSetWeight,
@@ -22,6 +19,8 @@ from pymatgen.analysis.chemenv.coordination_environments.structure_environments
 )
 from pymatgen.util.testing import PymatgenTest
 
+__author__ = "waroquiers"
+
 se_files_dir = os.path.join(
     PymatgenTest.TEST_FILES_DIR,
     "chemenv",
@@ -36,8 +35,6 @@ class FakeNbSet:
     def __len__(self):
         return self.cn
 
-    pass
-
 
 class DummyStructureEnvironments:
     pass
@@ -62,36 +59,36 @@ class StrategyWeightsTest(PymatgenTest):
         ]
         angle_weight = AngleNbSetWeight(aa=1.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.9634354419021528, delta=1e-8)
+        assert abs(aw - 0.9634354419021528) < 1e-8
         angle_weight = AngleNbSetWeight(aa=2.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.92820785071319645, delta=1e-8)
+        assert abs(aw - 0.92820785071319645) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.98154747307613843, delta=1e-8)
+        assert abs(aw - 0.98154747307613843) < 1e-8
 
-        self.assertNotEqual(AngleNbSetWeight(1.0), AngleNbSetWeight(2.0))
+        assert AngleNbSetWeight(1.0) != AngleNbSetWeight(2.0)
 
         # nb_set with no neighbor
         fake_nb_set.angles = []
         angle_weight = AngleNbSetWeight(aa=1.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.0, delta=1e-8)
+        assert abs(aw - 0.0) < 1e-8
         angle_weight = AngleNbSetWeight(aa=2.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.0, delta=1e-8)
+        assert abs(aw - 0.0) < 1e-8
 
         # nb_set with one neighbor
         fake_nb_set.angles = [3.08570351705799]
         angle_weight = AngleNbSetWeight(aa=1.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.24555248382791284, delta=1e-8)
+        assert abs(aw - 0.24555248382791284) < 1e-8
         angle_weight = AngleNbSetWeight(aa=2.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.060296022314057396, delta=1e-8)
+        assert abs(aw - 0.060296022314057396) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 0.49553252549950022, delta=1e-8)
+        assert abs(aw - 0.49553252549950022) < 1e-8
 
         # nb_set with 6 neighbors (sum of the angles is 4*pi, i.e. the full sphere)
         fake_nb_set.angles = [
@@ -104,13 +101,13 @@ class StrategyWeightsTest(PymatgenTest):
         ]
         angle_weight = AngleNbSetWeight(aa=1.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 1.0, delta=1e-8)
+        assert abs(aw - 1.0) < 1e-8
         angle_weight = AngleNbSetWeight(aa=2.0)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 1.0, delta=1e-8)
+        assert abs(aw - 1.0) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(aw, 1.0, delta=1e-8)
+        assert abs(aw - 1.0) < 1e-8
 
     def test_normalized_angle_distance_weight(self):
         fake_nb_set = FakeNbSet()
@@ -128,12 +125,11 @@ class StrategyWeightsTest(PymatgenTest):
         nadw10 = NormalizedAngleDistanceNbSetWeight(average_type="arithmetic", aa=2, bb=2)
         nadw11 = NormalizedAngleDistanceNbSetWeight(average_type="geometric", aa=1, bb=2)
         nadw12 = NormalizedAngleDistanceNbSetWeight(average_type="geometric", aa=2, bb=1)
-        self.assertNotEqual(nadw11, nadw12)
-        with self.assertRaisesRegex(ValueError, "Both exponents are 0."):
+        assert nadw11 != nadw12
+        with pytest.raises(ValueError, match="Both exponents are 0."):
             NormalizedAngleDistanceNbSetWeight(average_type="arithmetic", aa=0, bb=0)
-        with self.assertRaisesRegex(
-            ValueError,
-            'Average type is "arithmetix" ' 'while it should be "geometric" or "arithmetic"',
+        with pytest.raises(
+            ValueError, match='Average type is "arithmetix" ' 'while it should be "geometric" or "arithmetic"'
         ):
             NormalizedAngleDistanceNbSetWeight(average_type="arithmetix", aa=1, bb=1)
 
@@ -152,35 +148,35 @@ class StrategyWeightsTest(PymatgenTest):
             0.7354996568248028,
         ]
         w1 = nadw1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w1, 0.67310887189488189, delta=1e-8)
+        assert abs(w1 - 0.67310887189488189) < 1e-8
         w2 = nadw2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w2, 0.69422258996523023, delta=1e-8)
+        assert abs(w2 - 0.69422258996523023) < 1e-8
         w3 = nadw3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w3, 0.8700949310182079, delta=1e-8)
+        assert abs(w3 - 0.8700949310182079) < 1e-8
         w4 = nadw4.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w4, 0.7847083661164217, delta=1e-8)
+        assert abs(w4 - 0.7847083661164217) < 1e-8
         w5 = nadw5.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w5, 0.96148050989126843, delta=1e-8)
+        assert abs(w5 - 0.96148050989126843) < 1e-8
         w6 = nadw6.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w6, 0.98621181678741754, delta=1e-8)
+        assert abs(w6 - 0.98621181678741754) < 1e-8
         w7 = nadw7.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w7, 0.97479580875402994, delta=1e-8)
+        assert abs(w7 - 0.97479580875402994) < 1e-8
         w8 = nadw8.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w8, 0.63348507114489783, delta=1e-8)
+        assert abs(w8 - 0.63348507114489783) < 1e-8
         w9 = nadw9.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w9, 0.7668954450583646, delta=1e-8)
+        assert abs(w9 - 0.7668954450583646) < 1e-8
         w10 = nadw10.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w10, 0.51313920014833292, delta=1e-8)
+        assert abs(w10 - 0.51313920014833292) < 1e-8
         w11 = nadw11.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w11, 0.585668617459, delta=1e-8)
+        assert abs(w11 - 0.585668617459) < 1e-8
         w12 = nadw12.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w12, 0.520719679281, delta=1e-8)
+        assert abs(w12 - 0.520719679281) < 1e-8
 
     def test_CN_bias_weight(self):
         fake_nb_set = FakeNbSet()
         dummy_se = DummyStructureEnvironments()
         bias_weight1 = CNBiasNbSetWeight.linearly_equidistant(weight_cn1=1.0, weight_cn13=13.0)
-        bias_weight2 = CNBiasNbSetWeight.geometrically_equidistant(weight_cn1=1.0, weight_cn13=1.1 ** 12)
+        bias_weight2 = CNBiasNbSetWeight.geometrically_equidistant(weight_cn1=1.0, weight_cn13=1.1**12)
         bias_weight3 = CNBiasNbSetWeight.explicit(
             cn_weights={
                 1: 1.0,
@@ -198,36 +194,36 @@ class StrategyWeightsTest(PymatgenTest):
                 13: 4.8,
             }
         )
-        with self.assertRaisesRegex(ValueError, "Weights should be provided for CN 1 to 13"):
+        with pytest.raises(ValueError, match="Weights should be provided for CN 1 to 13"):
             CNBiasNbSetWeight.explicit(cn_weights={1: 1.0, 13: 2.0})
 
         fake_nb_set.cn = 1
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w1, 1.0, delta=1e-8)
+        assert abs(w1 - 1.0) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w2, 1.0, delta=1e-8)
+        assert abs(w2 - 1.0) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w3, 1.0, delta=1e-8)
+        assert abs(w3 - 1.0) < 1e-8
         fake_nb_set.cn = 7
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w1, 7.0, delta=1e-8)
+        assert abs(w1 - 7.0) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w2, 1.1 ** 6, delta=1e-8)
+        assert abs(w2 - 1.1**6) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w3, 4.3, delta=1e-8)
+        assert abs(w3 - 4.3) < 1e-8
         fake_nb_set.cn = 13
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w1, 13.0, delta=1e-8)
+        assert abs(w1 - 13.0) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w2, 1.1 ** 12, delta=1e-8)
+        assert abs(w2 - 1.1**12) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        self.assertAlmostEqual(w3, 4.8, delta=1e-8)
+        assert abs(w3 - 4.8) < 1e-8
 
         bias_weight4 = CNBiasNbSetWeight.from_description(
             {"type": "linearly_equidistant", "weight_cn1": 2.0, "weight_cn13": 26.0}
         )
         for cn in range(1, 14):
-            self.assertAlmostEqual(bias_weight4.cn_weights[cn], 2.0 * cn)
+            assert round(abs(bias_weight4.cn_weights[cn] - 2.0 * cn), 7) == 0
 
         bias_weight5 = CNBiasNbSetWeight.from_description(
             {
@@ -236,25 +232,24 @@ class StrategyWeightsTest(PymatgenTest):
                 "weight_cn13": 13.0,
             }
         )
-        self.assertAlmostEqual(bias_weight5.cn_weights[1], 1.0)
-        self.assertAlmostEqual(bias_weight5.cn_weights[3], 1.5334062370163877)
-        self.assertAlmostEqual(bias_weight5.cn_weights[9], 5.5287748136788739)
-        self.assertAlmostEqual(bias_weight5.cn_weights[12], 10.498197520079623)
+        assert round(abs(bias_weight5.cn_weights[1] - 1.0), 7) == 0
+        assert round(abs(bias_weight5.cn_weights[3] - 1.5334062370163877), 7) == 0
+        assert round(abs(bias_weight5.cn_weights[9] - 5.5287748136788739), 7) == 0
+        assert round(abs(bias_weight5.cn_weights[12] - 10.498197520079623), 7) == 0
 
         cn_weights = {cn: 0.0 for cn in range(1, 14)}
         cn_weights[6] = 2.0
         cn_weights[4] = 1.0
         bias_weight6 = CNBiasNbSetWeight.from_description({"type": "explicit", "cn_weights": cn_weights})
 
-        self.assertAlmostEqual(bias_weight6.cn_weights[1], 0.0)
-        self.assertAlmostEqual(bias_weight6.cn_weights[4], 1.0)
-        self.assertAlmostEqual(bias_weight6.cn_weights[6], 2.0)
+        assert round(abs(bias_weight6.cn_weights[1] - 0.0), 7) == 0
+        assert round(abs(bias_weight6.cn_weights[4] - 1.0), 7) == 0
+        assert round(abs(bias_weight6.cn_weights[6] - 2.0), 7) == 0
 
     def test_self_csms_weight(self):
         # Get the StructureEnvironments for K2NaNb2Fe7Si8H4O31 (mp-743972)
-        f = open(os.path.join(se_files_dir, "se_mp-743972.json"))
-        dd = json.load(f)
-        f.close()
+        with open(os.path.join(se_files_dir, "se_mp-743972.json")) as f:
+            dd = json.load(f)
         se = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
@@ -284,7 +279,7 @@ class StrategyWeightsTest(PymatgenTest):
             weight_estimator=weight_estimator2,
             symmetry_measure_type=symmetry_measure_type,
         )
-        self.assertNotEqual(self_weight, self_weight2)
+        assert self_weight != self_weight2
 
         additional_info = {}
         cn_map = (12, 3)
@@ -294,7 +289,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.11671945916431022, delta=1e-8)
+        assert abs(self_w - 0.11671945916431022) < 1e-8
         cn_map = (12, 2)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
@@ -302,7 +297,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.0, delta=1e-8)
+        assert abs(self_w - 0.0) < 1e-8
         cn_map = (12, 0)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
@@ -310,7 +305,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.0, delta=1e-8)
+        assert abs(self_w - 0.0) < 1e-8
         cn_map = (12, 1)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
@@ -318,7 +313,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.0, delta=1e-8)
+        assert abs(self_w - 0.0) < 1e-8
         cn_map = (13, 2)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
@@ -326,12 +321,11 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.14204073172729198, delta=1e-8)
+        assert abs(self_w - 0.14204073172729198) < 1e-8
 
         # Get the StructureEnvironments for SiO2 (mp-7000)
-        f = open(os.path.join(se_files_dir, "se_mp-7000.json"))
-        dd = json.load(f)
-        f.close()
+        with open(os.path.join(se_files_dir, "se_mp-7000.json")) as f:
+            dd = json.load(f)
         se = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
@@ -362,7 +356,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.8143992162836029, delta=1e-8)
+        assert abs(self_w - 0.8143992162836029) < 1e-8
         cn_map = (4, 0)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
@@ -370,13 +364,12 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(self_w, 0.99629742352359496, delta=1e-8)
+        assert abs(self_w - 0.99629742352359496) < 1e-8
 
     def test_delta_csms_weight(self):
         # Get the StructureEnvironments for K2NaNb2Fe7Si8H4O31 (mp-743972)
-        f = open(os.path.join(se_files_dir, "se_mp-743972.json"))
-        dd = json.load(f)
-        f.close()
+        with open(os.path.join(se_files_dir, "se_mp-743972.json")) as f:
+            dd = json.load(f)
         se = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
@@ -406,7 +399,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (12, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -414,7 +407,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (12, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -422,7 +415,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (12, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -430,7 +423,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (13, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -438,7 +431,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 1.0, delta=1e-8)
+        assert abs(delta_w - 1.0) < 1e-8
         cn_map = (13, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -446,7 +439,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (13, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -454,7 +447,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
@@ -480,7 +473,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.040830741048481355, delta=1e-8)
+        assert abs(delta_w - 0.040830741048481355) < 1e-8
         cn_map = (13, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -488,7 +481,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 1.0, delta=1e-8)
+        assert abs(delta_w - 1.0) < 1e-8
         cn_map = (13, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -496,7 +489,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.103515625, delta=1e-8)
+        assert abs(delta_w - 0.103515625) < 1e-8
         cn_map = (13, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -504,12 +497,11 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.103515625, delta=1e-8)
+        assert abs(delta_w - 0.103515625) < 1e-8
 
         # Get the StructureEnvironments for SiO2 (mp-7000)
-        f = open(os.path.join(se_files_dir, "se_mp-7000.json"))
-        dd = json.load(f)
-        f.close()
+        with open(os.path.join(se_files_dir, "se_mp-7000.json")) as f:
+            dd = json.load(f)
         se = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
@@ -540,7 +532,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 0.0, delta=1e-8)
+        assert abs(delta_w - 0.0) < 1e-8
         cn_map = (4, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
@@ -548,7 +540,7 @@ class StrategyWeightsTest(PymatgenTest):
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        self.assertAlmostEqual(delta_w, 1.0, delta=1e-8)
+        assert abs(delta_w - 1.0) < 1e-8
 
     def test_dist_angle_area_weight(self):
 
@@ -566,33 +558,33 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         d1, d2, a1, a2 = 1.05, 1.15, 0.05, 0.08
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.05, 1.15, 0.1, 0.2
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.9, 1.95, 0.1, 0.2
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.05, 1.95, 0.05, 0.25
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.05, 1.95, 0.75, 0.9
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.1, 1.9, 0.1, 0.9
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.23, 1.77, 0.48, 0.52
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.23, 1.24, 0.48, 0.52
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.4, 1.6, 0.4, 0.6
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.6, 1.9, 0.7, 0.9
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.5, 1.6, 0.75, 0.78
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.5, 1.6, 0.75, 0.95
-        self.assertFalse(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert not da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.4, 1.6, 0.1, 0.9
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
         d1, d2, a1, a2 = 1.4, 1.6, 0.3, 0.7
-        self.assertTrue(da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2))
+        assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
 
     def test_dist_nb_set_weight(self):
 
@@ -679,26 +671,26 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map7 = (7, 0)
 
         myweight1 = dnbset_weight.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        self.assertAlmostEqual(myweight1, 0.0, delta=1e-8)
+        assert abs(myweight1 - 0.0) < 1e-8
         myweight2 = dnbset_weight.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        self.assertAlmostEqual(myweight2, 0.103515625, delta=1e-8)
+        assert abs(myweight2 - 0.103515625) < 1e-8
         myweight3 = dnbset_weight.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        self.assertAlmostEqual(myweight3, 0.5, delta=1e-8)
+        assert abs(myweight3 - 0.5) < 1e-8
         myweight4 = dnbset_weight.weight(fake_nb_set4, dummy_se, cn_map=cn_map4, additional_info=None)
-        self.assertAlmostEqual(myweight4, 0.896484375, delta=1e-8)
+        assert abs(myweight4 - 0.896484375) < 1e-8
         myweight5 = dnbset_weight.weight(fake_nb_set5, dummy_se, cn_map=cn_map5, additional_info=None)
-        self.assertAlmostEqual(myweight5, 1.0, delta=1e-8)
+        assert abs(myweight5 - 1.0) < 1e-8
         myweight5_m2 = dnbset_weight.weight(fake_nb_set5_m2, dummy_se, cn_map=cn_map5_m2, additional_info=None)
-        self.assertAlmostEqual(myweight5_m2, 0.103515625, delta=1e-8)
+        assert abs(myweight5_m2 - 0.103515625) < 1e-8
         myweight7 = dnbset_weight.weight(fake_nb_set7, dummy_se, cn_map=cn_map7, additional_info=None)
-        self.assertAlmostEqual(myweight7, 1.0, delta=1e-8)
+        assert abs(myweight7 - 1.0) < 1e-8
 
         myweight_2_3 = dnbset_weight2.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        self.assertAlmostEqual(myweight_2_3, 0.5, delta=1e-8)
+        assert abs(myweight_2_3 - 0.5) < 1e-8
         myweight_2_4 = dnbset_weight2.weight(fake_nb_set4, dummy_se, cn_map=cn_map4, additional_info=None)
-        self.assertAlmostEqual(myweight_2_4, 0.84375, delta=1e-8)
+        assert abs(myweight_2_4 - 0.84375) < 1e-8
         myweight_2_2 = dnbset_weight2.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        self.assertAlmostEqual(myweight_2_2, 0.15625, delta=1e-8)
+        assert abs(myweight_2_2 - 0.15625) < 1e-8
 
         dnbset_weight3 = DistanceNbSetWeight(
             weight_function={
@@ -716,9 +708,9 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweight_3_6 = dnbset_weight3.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        self.assertAlmostEqual(myweight_3_6, 1.0, delta=1e-8)
+        assert abs(myweight_3_6 - 1.0) < 1e-8
         myweight_4_6 = dnbset_weight4.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        self.assertAlmostEqual(myweight_4_6, 0.15625, delta=1e-8)
+        assert abs(myweight_4_6 - 0.15625) < 1e-8
 
         deltadnbset_weight = DeltaDistanceNbSetWeight(
             weight_function={
@@ -728,11 +720,11 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweightdelta1 = deltadnbset_weight.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        self.assertAlmostEqual(myweightdelta1, 1.0, delta=1e-8)
+        assert abs(myweightdelta1 - 1.0) < 1e-8
         myweightdelta2 = deltadnbset_weight.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        self.assertAlmostEqual(myweightdelta2, 0.0, delta=1e-8)
+        assert abs(myweightdelta2 - 0.0) < 1e-8
         myweightdelta3 = deltadnbset_weight.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        self.assertAlmostEqual(myweightdelta3, 0.0, delta=1e-8)
+        assert abs(myweightdelta3 - 0.0) < 1e-8
 
         deltadnbset_weight2 = DeltaDistanceNbSetWeight(
             weight_function={
@@ -742,11 +734,11 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweightdelta1 = deltadnbset_weight2.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        self.assertAlmostEqual(myweightdelta1, 0.5, delta=1e-8)
+        assert abs(myweightdelta1 - 0.5) < 1e-8
         myweightdelta2 = deltadnbset_weight2.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        self.assertAlmostEqual(myweightdelta2, 0.0, delta=1e-8)
+        assert abs(myweightdelta2 - 0.0) < 1e-8
         myweightdelta3 = deltadnbset_weight2.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        self.assertAlmostEqual(myweightdelta3, 0.0, delta=1e-8)
+        assert abs(myweightdelta3 - 0.0) < 1e-8
 
         deltadnbset_weight3 = DeltaDistanceNbSetWeight(
             weight_function={
@@ -756,9 +748,9 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweightdelta1 = deltadnbset_weight3.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        self.assertAlmostEqual(myweightdelta1, 0.15625, delta=1e-8)
+        assert abs(myweightdelta1 - 0.15625) < 1e-8
         myweightdelta6 = deltadnbset_weight3.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        self.assertAlmostEqual(myweightdelta6, 0.31640625, delta=1e-8)
+        assert abs(myweightdelta6 - 0.31640625) < 1e-8
 
         deltadnbset_weight4 = DeltaDistanceNbSetWeight(
             weight_function={
@@ -769,9 +761,9 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweightdelta1 = deltadnbset_weight4.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        self.assertAlmostEqual(myweightdelta1, 0.15625, delta=1e-8)
+        assert abs(myweightdelta1 - 0.15625) < 1e-8
         myweightdelta6 = deltadnbset_weight4.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        self.assertAlmostEqual(myweightdelta6, 1.0, delta=1e-8)
+        assert abs(myweightdelta6 - 1.0) < 1e-8
 
 
 if __name__ == "__main__":
