@@ -21,9 +21,9 @@ def get_delta(node1, node2, edge_data):
     :return:
     """
     if node1.isite == edge_data["start"] and node2.isite == edge_data["end"]:
-        return np.array(edge_data["delta"], dtype=np.int_)
+        return np.array(edge_data["delta"], dtype=int)
     if node2.isite == edge_data["start"] and node1.isite == edge_data["end"]:
-        return -np.array(edge_data["delta"], dtype=np.int_)
+        return -np.array(edge_data["delta"], dtype=int)
     raise ValueError("Trying to find a delta between two nodes with an edge that seems not to link these nodes.")
 
 
@@ -252,7 +252,9 @@ class SimpleGraphCycle(MSONable):
         out.extend([str(node) for node in self.nodes])
         return "\n".join(out)
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, SimpleGraphCycle):
+            return NotImplemented
         if not self.ordered or not other.ordered:
             raise RuntimeError("Simple cycles should be ordered in order to be compared.")
         return self.nodes == other.nodes
@@ -454,13 +456,15 @@ class MultiGraphCycle(MSONable):
         out = ["Multigraph cycle with nodes :"]
         cycle = []
         for inode, node1, node2 in zip(itertools.count(), self.nodes[:-1], self.nodes[1:]):
-            cycle.append(f"{str(node1)} -*{self.edge_indices[inode]:d}*- {str(node2)}")
-        cycle.append(f"{str(self.nodes[-1])} -*{self.edge_indices[-1]:d}*- {str(self.nodes[0])}")
+            cycle.append(f"{node1} -*{self.edge_indices[inode]:d}*- {node2}")
+        cycle.append(f"{self.nodes[-1]} -*{self.edge_indices[-1]:d}*- {self.nodes[0]}")
         # out.extend([str(node) for node in self.nodes])
         out.extend(cycle)
         return "\n".join(out)
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, MultiGraphCycle):
+            return NotImplemented
         if not self.ordered or not other.ordered:
             raise RuntimeError("Multigraph cycles should be ordered in order to be compared.")
         return self.nodes == other.nodes and self.edge_indices == other.edge_indices
@@ -490,7 +494,7 @@ def get_all_elementary_cycles(graph):
         all_edges_dict[(n2, n1)] = nedges
         index2edge.append((n1, n2))
         nedges += 1
-    cycles_matrix = np.zeros(shape=(len(cycle_basis), nedges), dtype=np.bool)
+    cycles_matrix = np.zeros(shape=(len(cycle_basis), nedges), dtype=bool)
     for icycle, cycle in enumerate(cycle_basis):
         for in1, n1 in enumerate(cycle):
             n2 = cycle[(in1 + 1) % len(cycle)]
@@ -502,7 +506,7 @@ def get_all_elementary_cycles(graph):
 
     for ncycles in range(1, len(cycle_basis) + 1):
         for cycles_combination in itertools.combinations(cycles_matrix, ncycles):
-            edges_counts = np.array(np.mod(np.sum(cycles_combination, axis=0), 2), dtype=np.bool)
+            edges_counts = np.array(np.mod(np.sum(cycles_combination, axis=0), 2), dtype=bool)
             myedges = [edge for iedge, edge in enumerate(index2edge) if edges_counts[iedge]]
             # print(myedges)
             try:
