@@ -1,6 +1,7 @@
 __author__ = "waroquiers"
 
 import numpy as np
+import pytest
 
 from pymatgen.analysis.chemenv.connectivity.environment_nodes import EnvironmentNode
 from pymatgen.analysis.chemenv.utils.graph_utils import (
@@ -20,7 +21,9 @@ class FakeNodeWithEqMethod:
     def __init__(self, isite):
         self.isite = isite
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
         return self.isite == other.isite
 
     def __hash__(self):
@@ -31,7 +34,9 @@ class FakeNodeWithEqLtMethods:
     def __init__(self, isite):
         self.isite = isite
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
         return self.isite == other.isite
 
     def __lt__(self, other):
@@ -52,7 +57,10 @@ class FakeNodeWithEqMethodWrongSortable:
     def __init__(self, isite):
         self.isite = isite
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
+
         return self.isite == other.isite
 
     def __hash__(self):
@@ -67,18 +75,18 @@ class GraphUtilsTest(PymatgenTest):
         n1 = FakeNode(3)
         n2 = FakeNode(7)
         edge_data = {"start": 3, "end": 7, "delta": [2, 6, 4]}
-        self.assertTrue(np.allclose(get_delta(n1, n2, edge_data), [2, 6, 4]))
+        assert np.allclose(get_delta(n1, n2, edge_data), [2, 6, 4])
         edge_data = {"start": 7, "end": 3, "delta": [2, 6, 4]}
-        self.assertTrue(np.allclose(get_delta(n1, n2, edge_data), [-2, -6, -4]))
-        with self.assertRaisesRegex(
+        assert np.allclose(get_delta(n1, n2, edge_data), [-2, -6, -4])
+        with pytest.raises(
             ValueError,
-            "Trying to find a delta between two nodes with an edge that seems not to link these nodes.",
+            match="Trying to find a delta between two nodes with an edge that seems not to link these nodes.",
         ):
             edge_data = {"start": 6, "end": 3, "delta": [2, 6, 4]}
             get_delta(n1, n2, edge_data)
-        with self.assertRaisesRegex(
+        with pytest.raises(
             ValueError,
-            "Trying to find a delta between two nodes with an edge that seems not to link these nodes.",
+            match="Trying to find a delta between two nodes with an edge that seems not to link these nodes.",
         ):
             edge_data = {"start": 7, "end": 2, "delta": [2, 6, 4]}
             get_delta(n1, n2, edge_data)
@@ -88,97 +96,91 @@ class GraphUtilsTest(PymatgenTest):
 
         # Test equality
         sg_cycle2 = SimpleGraphCycle([1, 2, 3, 0])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
         sg_cycle2 = SimpleGraphCycle([2, 3, 0, 1])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
         sg_cycle2 = SimpleGraphCycle([3, 0, 1, 2])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
 
         # Test reversed cycles
         sg_cycle2 = SimpleGraphCycle([0, 3, 2, 1])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
         sg_cycle2 = SimpleGraphCycle([3, 2, 1, 0])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
         sg_cycle2 = SimpleGraphCycle([2, 1, 0, 3])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
         sg_cycle2 = SimpleGraphCycle([1, 0, 3, 2])
-        self.assertEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 == sg_cycle2
 
         # Test different cycle lengths inequality
         sg_cycle2 = SimpleGraphCycle([0, 1, 2, 3, 4])
-        self.assertNotEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 != sg_cycle2
 
         # Test equality of self-loops
-        self.assertEqual(SimpleGraphCycle([0]), SimpleGraphCycle([0]))
-        self.assertNotEqual(SimpleGraphCycle([0]), SimpleGraphCycle([4]))
+        assert SimpleGraphCycle([0]) == SimpleGraphCycle([0])
+        assert SimpleGraphCycle([0]) != SimpleGraphCycle([4])
 
         # Test inequality inversing two nodes
         sg_cycle2 = SimpleGraphCycle([0, 1, 3, 2])
-        self.assertNotEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 != sg_cycle2
 
         # Test inequality with different nodes
         sg_cycle2 = SimpleGraphCycle([4, 1, 2, 3])
-        self.assertNotEqual(sg_cycle1, sg_cycle2)
+        assert sg_cycle1 != sg_cycle2
 
         # Test hashing function
-        self.assertEqual(hash(sg_cycle1), 4)
-        self.assertEqual(hash(SimpleGraphCycle([0])), 1)
-        self.assertEqual(hash(SimpleGraphCycle([0, 1, 3, 6])), 4)
-        self.assertEqual(hash(SimpleGraphCycle([0, 1, 2])), 3)
+        assert hash(sg_cycle1) == 4
+        assert hash(SimpleGraphCycle([0])) == 1
+        assert hash(SimpleGraphCycle([0, 1, 3, 6])) == 4
+        assert hash(SimpleGraphCycle([0, 1, 2])) == 3
 
         # Test from_edges function
         #   3-nodes cycle
         edges = [(0, 2), (4, 2), (0, 4)]
         sg_cycle = SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
-        self.assertEqual(sg_cycle, SimpleGraphCycle([4, 0, 2]))
+        assert sg_cycle == SimpleGraphCycle([4, 0, 2])
 
         #   Self-loop cycle
         edges = [(2, 2)]
         sg_cycle = SimpleGraphCycle.from_edges(edges=edges)
-        self.assertEqual(sg_cycle, SimpleGraphCycle([2]))
+        assert sg_cycle == SimpleGraphCycle([2])
 
         #   5-nodes cycle
         edges = [(0, 2), (4, 7), (2, 7), (4, 5), (5, 0)]
         sg_cycle = SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
-        self.assertEqual(sg_cycle, SimpleGraphCycle([2, 7, 4, 5, 0]))
+        assert sg_cycle == SimpleGraphCycle([2, 7, 4, 5, 0])
 
         #   two identical 3-nodes cycles
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : Duplicate nodes.",
-        ):
+        with pytest.raises(ValueError, match="SimpleGraphCycle is not valid : Duplicate nodes."):
             edges = [(0, 2), (4, 2), (0, 4), (0, 2), (4, 2), (0, 4)]
             SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
 
         #   two cycles in from_edges
-        with self.assertRaisesRegex(ValueError, expected_regex="Could not construct a cycle from edges."):
+        with pytest.raises(ValueError, match="Could not construct a cycle from edges."):
             edges = [(0, 2), (4, 2), (0, 4), (1, 3), (6, 7), (3, 6), (1, 7)]
             SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
 
-        with self.assertRaisesRegex(ValueError, expected_regex="Could not construct a cycle from edges."):
+        with pytest.raises(ValueError, match="Could not construct a cycle from edges."):
             edges = [(0, 2), (4, 6), (2, 7), (4, 5), (5, 0)]
             SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
 
-        with self.assertRaisesRegex(ValueError, expected_regex="Could not construct a cycle from edges."):
+        with pytest.raises(ValueError, match="Could not construct a cycle from edges."):
             edges = [(0, 2), (4, 7), (2, 7), (4, 10), (5, 0)]
             SimpleGraphCycle.from_edges(edges=edges, edges_are_ordered=False)
 
         # Test as_dict from_dict and len method
         sg_cycle = SimpleGraphCycle([0, 1, 2, 3])
-        self.assertEqual(sg_cycle, SimpleGraphCycle.from_dict(sg_cycle.as_dict()))
-        self.assertEqual(len(sg_cycle), 4)
+        assert sg_cycle == SimpleGraphCycle.from_dict(sg_cycle.as_dict())
+        assert len(sg_cycle) == 4
         sg_cycle = SimpleGraphCycle([4])
-        self.assertEqual(sg_cycle, SimpleGraphCycle.from_dict(sg_cycle.as_dict()))
-        self.assertEqual(len(sg_cycle), 1)
+        assert sg_cycle == SimpleGraphCycle.from_dict(sg_cycle.as_dict())
+        assert len(sg_cycle) == 1
         sg_cycle = SimpleGraphCycle([4, 2, 6, 7, 9, 3, 15])
-        self.assertEqual(sg_cycle, SimpleGraphCycle.from_dict(sg_cycle.as_dict()))
-        self.assertEqual(len(sg_cycle), 7)
+        assert sg_cycle == SimpleGraphCycle.from_dict(sg_cycle.as_dict())
+        assert len(sg_cycle) == 7
 
         # Check validation at instance creation time
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : Duplicate nodes.",
-        ):
+        with pytest.raises(ValueError, match="SimpleGraphCycle is not valid : Duplicate nodes."):
             SimpleGraphCycle([0, 2, 4, 6, 2])
 
         # Check the validate method
@@ -188,31 +190,21 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(sgc.ordered)
-        self.assertEqual(
-            sgc.nodes,
-            (FakeNodeWithEqMethod(1), FakeNodeWithEqMethod(0), FakeNodeWithEqMethod(2)),
-        )
+        assert not sgc.ordered
+        assert sgc.nodes == (FakeNodeWithEqMethod(1), FakeNodeWithEqMethod(0), FakeNodeWithEqMethod(2))
         sgc.validate(check_strict_ordering=False)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : The nodes are not sortable.",
-        ):
+        with pytest.raises(ValueError, match="SimpleGraphCycle is not valid : The nodes are not sortable."):
             sgc.validate(check_strict_ordering=True)
 
         # Empty cycle not valid
         sgc = SimpleGraphCycle([], validate=False, ordered=False)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : Empty cycle is not valid.",
-        ):
+        with pytest.raises(ValueError, match="SimpleGraphCycle is not valid : Empty cycle is not valid."):
             sgc.validate()
 
         # Simple graph cycle with 2 nodes not valid
         sgc = SimpleGraphCycle([1, 2], validate=False, ordered=False)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : Simple graph cycle with 2 nodes is not valid.",
+        with pytest.raises(
+            ValueError, match="SimpleGraphCycle is not valid : Simple graph cycle with 2 nodes is not valid."
         ):
             sgc.validate()
 
@@ -227,10 +219,9 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        with self.assertRaisesRegex(
+        with pytest.raises(
             ValueError,
-            expected_regex="SimpleGraphCycle is not valid : "
-            "The list of nodes in the cycle cannot be strictly ordered.",
+            match="SimpleGraphCycle is not valid : " "The list of nodes in the cycle cannot be strictly ordered.",
         ):
             sgc.validate(check_strict_ordering=True)
 
@@ -246,11 +237,10 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         sgc.order(raise_on_fail=False)
-        self.assertFalse(sgc.ordered)
-        with self.assertRaisesRegex(
+        assert not sgc.ordered
+        with pytest.raises(
             ValueError,
-            expected_regex="SimpleGraphCycle is not valid : "
-            "The list of nodes in the cycle cannot be strictly ordered.",
+            match="SimpleGraphCycle is not valid : " "The list of nodes in the cycle cannot be strictly ordered.",
         ):
             sgc.order(raise_on_fail=True)
 
@@ -265,11 +255,8 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         sgc.order(raise_on_fail=False)
-        self.assertFalse(sgc.ordered)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="SimpleGraphCycle is not valid : The nodes are not sortable.",
-        ):
+        assert not sgc.ordered
+        with pytest.raises(ValueError, match="SimpleGraphCycle is not valid : The nodes are not sortable."):
             sgc.order(raise_on_fail=True)
 
         sgc = SimpleGraphCycle(
@@ -283,15 +270,12 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         sgc.order(raise_on_fail=True)
-        self.assertTrue(sgc.ordered)
-        self.assertEqual(
-            sgc.nodes,
-            (
-                FakeNodeWithEqLtMethods(0),
-                FakeNodeWithEqLtMethods(6),
-                FakeNodeWithEqLtMethods(3),
-                FakeNodeWithEqLtMethods(8),
-            ),
+        assert sgc.ordered
+        assert sgc.nodes == (
+            FakeNodeWithEqLtMethods(0),
+            FakeNodeWithEqLtMethods(6),
+            FakeNodeWithEqLtMethods(3),
+            FakeNodeWithEqLtMethods(8),
         )
 
         sgc = SimpleGraphCycle(
@@ -305,27 +289,23 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         sgc.order(raise_on_fail=False)
-        self.assertFalse(sgc.ordered)
-        self.assertEqual(
-            sgc.nodes,
-            (
-                FakeNodeWithEqLtMethodsBis(8),
-                FakeNodeWithEqLtMethods(0),
-                FakeNodeWithEqLtMethods(6),
-                FakeNodeWithEqLtMethods(3),
-            ),
+        assert not sgc.ordered
+        assert sgc.nodes == (
+            FakeNodeWithEqLtMethodsBis(8),
+            FakeNodeWithEqLtMethods(0),
+            FakeNodeWithEqLtMethods(6),
+            FakeNodeWithEqLtMethods(3),
         )
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="Could not order simple graph cycle as the nodes are of different classes.",
+        with pytest.raises(
+            ValueError, match="Could not order simple graph cycle as the nodes are of different classes."
         ):
             sgc.order(raise_on_fail=True)
 
         sgc = SimpleGraphCycle([FakeNodeWithEqLtMethods(85)], validate=False, ordered=False)
-        self.assertFalse(sgc.ordered)
+        assert not sgc.ordered
         sgc.order()
-        self.assertTrue(sgc.ordered)
-        self.assertEqual(sgc.nodes, tuple([FakeNodeWithEqLtMethods(85)]))
+        assert sgc.ordered
+        assert sgc.nodes == tuple([FakeNodeWithEqLtMethods(85)])
 
         sgc = SimpleGraphCycle(
             [
@@ -341,29 +321,25 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(sgc.ordered)
+        assert not sgc.ordered
         sgc.order()
-        self.assertTrue(sgc.ordered)
-        self.assertEqual(
-            sgc.nodes,
-            tuple(
-                [
-                    FakeNodeWithEqLtMethods(1),
-                    FakeNodeWithEqLtMethods(4),
-                    FakeNodeWithEqLtMethods(3),
-                    FakeNodeWithEqLtMethods(6),
-                    FakeNodeWithEqLtMethods(2),
-                    FakeNodeWithEqLtMethods(8),
-                    FakeNodeWithEqLtMethods(32),
-                    FakeNodeWithEqLtMethods(64),
-                ]
-            ),
+        assert sgc.ordered
+        assert sgc.nodes == tuple(
+            [
+                FakeNodeWithEqLtMethods(1),
+                FakeNodeWithEqLtMethods(4),
+                FakeNodeWithEqLtMethods(3),
+                FakeNodeWithEqLtMethods(6),
+                FakeNodeWithEqLtMethods(2),
+                FakeNodeWithEqLtMethods(8),
+                FakeNodeWithEqLtMethods(32),
+                FakeNodeWithEqLtMethods(64),
+            ]
         )
 
         # Test str method
-        self.assertEqual(
-            str(sgc),
-            "Simple cycle with nodes :\n"
+        assert (
+            str(sgc) == "Simple cycle with nodes :\n"
             "FakeNode_1\n"
             "FakeNode_4\n"
             "FakeNode_3\n"
@@ -371,29 +347,25 @@ class GraphUtilsTest(PymatgenTest):
             "FakeNode_2\n"
             "FakeNode_8\n"
             "FakeNode_32\n"
-            "FakeNode_64",
+            "FakeNode_64"
         )
 
     def test_multigraph_cycle(self):
         mg_cycle1 = MultiGraphCycle([2, 4, 3, 5], [1, 0, 2, 0])
         # Check is_valid method
         is_valid, msg = MultiGraphCycle._is_valid(mg_cycle1)
-        self.assertTrue(is_valid)
-        self.assertEqual(msg, "")
-        with self.assertRaisesRegex(
+        assert is_valid
+        assert msg == ""
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "Number of nodes different from number of "
-            "edge indices.",
+            match="MultiGraphCycle is not valid : " "Number of nodes different from number of " "edge indices.",
         ):
             MultiGraphCycle([0, 2, 4], [0, 0])  # number of nodes is different from number of edge_indices
-        with self.assertRaisesRegex(ValueError, expected_regex="MultiGraphCycle is not valid : Duplicate nodes."):
+        with pytest.raises(ValueError, match="MultiGraphCycle is not valid : Duplicate nodes."):
             MultiGraphCycle([0, 2, 4, 3, 2], [0, 0, 0, 0, 0])  # duplicated nodes
-        with self.assertRaisesRegex(
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "Cycles with two nodes cannot use the same "
-            "edge for the cycle.",
+            match="MultiGraphCycle is not valid : " "Cycles with two nodes cannot use the same " "edge for the cycle.",
         ):
             MultiGraphCycle([3, 5], [1, 1])  # number of nodes is different from number of edge_indices
 
@@ -401,65 +373,65 @@ class GraphUtilsTest(PymatgenTest):
 
         #   Test different cycle lengths inequality
         mg_cycle2 = MultiGraphCycle([2, 3, 4, 5, 6], [1, 0, 2, 0, 0])
-        self.assertFalse(mg_cycle1 == mg_cycle2)
+        assert not mg_cycle1 == mg_cycle2
 
         #   Test equality
         mg_cycle2 = MultiGraphCycle([2, 4, 3, 5], [1, 0, 2, 0])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([4, 3, 5, 2], [0, 2, 0, 1])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([3, 5, 2, 4], [2, 0, 1, 0])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([5, 2, 4, 3], [0, 1, 0, 2])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         #   Test equality (reversed)
         mg_cycle2 = MultiGraphCycle([2, 5, 3, 4], [0, 2, 0, 1])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([5, 3, 4, 2], [2, 0, 1, 0])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([3, 4, 2, 5], [0, 1, 0, 2])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([4, 2, 5, 3], [1, 0, 2, 0])
-        self.assertTrue(mg_cycle1 == mg_cycle2)
+        assert mg_cycle1 == mg_cycle2
         #   Test inequality
         mg_cycle2 = MultiGraphCycle([2, 5, 3, 4], [0, 1, 0, 1])
-        self.assertFalse(mg_cycle1 == mg_cycle2)
+        assert not mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([2, 5, 3, 4], [1, 0, 2, 0])
-        self.assertFalse(mg_cycle1 == mg_cycle2)
+        assert not mg_cycle1 == mg_cycle2
         mg_cycle2 = MultiGraphCycle([3, 5, 2, 4], [1, 0, 2, 0])
-        self.assertFalse(mg_cycle1 == mg_cycle2)
+        assert not mg_cycle1 == mg_cycle2
 
         #   Test Self-loop case
-        self.assertTrue(MultiGraphCycle([2], [1]) == MultiGraphCycle([2], [1]))
-        self.assertFalse(MultiGraphCycle([1], [1]) == MultiGraphCycle([2], [1]))
-        self.assertFalse(MultiGraphCycle([2], [1]) == MultiGraphCycle([2], [0]))
-        self.assertFalse(MultiGraphCycle([2], [1]) == MultiGraphCycle([1], [1]))
-        self.assertFalse(MultiGraphCycle([2], [0]) == MultiGraphCycle([2], [1]))
+        assert MultiGraphCycle([2], [1]) == MultiGraphCycle([2], [1])
+        assert not MultiGraphCycle([1], [1]) == MultiGraphCycle([2], [1])
+        assert not MultiGraphCycle([2], [1]) == MultiGraphCycle([2], [0])
+        assert not MultiGraphCycle([2], [1]) == MultiGraphCycle([1], [1])
+        assert not MultiGraphCycle([2], [0]) == MultiGraphCycle([2], [1])
 
         #   Test special case with two nodes
-        self.assertTrue(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([2, 4], [1, 3]))
-        self.assertTrue(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([2, 4], [3, 1]))
-        self.assertTrue(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [3, 1]))
-        self.assertTrue(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [1, 3]))
-        self.assertFalse(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [1, 2]))
-        self.assertFalse(MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 0], [1, 3]))
+        assert MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([2, 4], [1, 3])
+        assert MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([2, 4], [3, 1])
+        assert MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [3, 1])
+        assert MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [1, 3])
+        assert not MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 2], [1, 2])
+        assert not MultiGraphCycle([2, 4], [1, 3]) == MultiGraphCycle([4, 0], [1, 3])
 
         # Test hashing function
-        self.assertEqual(hash(mg_cycle1), 4)
-        self.assertEqual(hash(MultiGraphCycle([0], [0])), 1)
-        self.assertEqual(hash(MultiGraphCycle([0, 3], [0, 1])), 2)
-        self.assertEqual(hash(MultiGraphCycle([0, 3, 5, 7, 8], [0, 1, 0, 0, 0])), 5)
+        assert hash(mg_cycle1) == 4
+        assert hash(MultiGraphCycle([0], [0])) == 1
+        assert hash(MultiGraphCycle([0, 3], [0, 1])) == 2
+        assert hash(MultiGraphCycle([0, 3, 5, 7, 8], [0, 1, 0, 0, 0])) == 5
 
         # Test as_dict from_dict and len method
         mg_cycle = MultiGraphCycle([0, 1, 2, 3], [1, 2, 0, 3])
-        self.assertTrue(mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict()))
-        self.assertEqual(len(mg_cycle), 4)
+        assert mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict())
+        assert len(mg_cycle) == 4
         mg_cycle = MultiGraphCycle([2, 5, 3, 4, 1, 0], [0, 0, 2, 0, 1, 0])
-        self.assertTrue(mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict()))
-        self.assertEqual(len(mg_cycle), 6)
+        assert mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict())
+        assert len(mg_cycle) == 6
         mg_cycle = MultiGraphCycle([8], [1])
-        self.assertTrue(mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict()))
-        self.assertEqual(len(mg_cycle), 1)
+        assert mg_cycle == MultiGraphCycle.from_dict(mg_cycle.as_dict())
+        assert len(mg_cycle) == 1
 
         # Check the validate method
         # Number of nodes and edges do not match
@@ -473,21 +445,16 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(mgc.ordered)
-        with self.assertRaisesRegex(
+        assert not mgc.ordered
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "Number of nodes different from "
-            "number of edge indices.",
+            match="MultiGraphCycle is not valid : " "Number of nodes different from " "number of edge indices.",
         ):
             mgc.validate(check_strict_ordering=False)
 
         # Empty cycle not valid
         mgc = MultiGraphCycle([], edge_indices=[], validate=False, ordered=False)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="MultiGraphCycle is not valid : Empty cycle is not valid.",
-        ):
+        with pytest.raises(ValueError, match="MultiGraphCycle is not valid : Empty cycle is not valid."):
             mgc.validate()
 
         # Multi graph cycle with duplicate nodes not valid
@@ -497,10 +464,7 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="MultiGraphCycle is not valid : Duplicate nodes.",
-        ):
+        with pytest.raises(ValueError, match="MultiGraphCycle is not valid : Duplicate nodes."):
             mgc.validate()
 
         # Multi graph cycle with two nodes cannot use the same edge
@@ -510,10 +474,9 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        with self.assertRaisesRegex(
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "Cycles with two nodes cannot use the same edge for the cycle.",
+            match="MultiGraphCycle is not valid : " "Cycles with two nodes cannot use the same edge for the cycle.",
         ):
             mgc.validate()
 
@@ -524,16 +487,10 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(mgc.ordered)
-        self.assertEqual(
-            mgc.nodes,
-            (FakeNodeWithEqMethod(1), FakeNodeWithEqMethod(0), FakeNodeWithEqMethod(2)),
-        )
+        assert not mgc.ordered
+        assert mgc.nodes == (FakeNodeWithEqMethod(1), FakeNodeWithEqMethod(0), FakeNodeWithEqMethod(2))
         mgc.validate(check_strict_ordering=False)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="MultiGraphCycle is not valid : The nodes are not sortable.",
-        ):
+        with pytest.raises(ValueError, match="MultiGraphCycle is not valid : The nodes are not sortable."):
             mgc.validate(check_strict_ordering=True)
 
         # Multi graph cycle with nodes that cannot be strictly ordered
@@ -548,10 +505,9 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        with self.assertRaisesRegex(
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "The list of nodes in the cycle cannot be strictly ordered.",
+            match="MultiGraphCycle is not valid : " "The list of nodes in the cycle cannot be strictly ordered.",
         ):
             mgc.validate(check_strict_ordering=True)
 
@@ -568,11 +524,10 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         mgc.order(raise_on_fail=False)
-        self.assertFalse(mgc.ordered)
-        with self.assertRaisesRegex(
+        assert not mgc.ordered
+        with pytest.raises(
             ValueError,
-            expected_regex="MultiGraphCycle is not valid : "
-            "The list of nodes in the cycle cannot be strictly ordered.",
+            match="MultiGraphCycle is not valid : " "The list of nodes in the cycle cannot be strictly ordered.",
         ):
             mgc.order(raise_on_fail=True)
 
@@ -588,11 +543,8 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         mgc.order(raise_on_fail=False)
-        self.assertFalse(mgc.ordered)
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="MultiGraphCycle is not valid : The nodes are not sortable.",
-        ):
+        assert not mgc.ordered
+        with pytest.raises(ValueError, match="MultiGraphCycle is not valid : The nodes are not sortable."):
             mgc.order(raise_on_fail=True)
 
         mgc = MultiGraphCycle(
@@ -607,17 +559,14 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         mgc.order(raise_on_fail=True)
-        self.assertTrue(mgc.ordered)
-        self.assertEqual(
-            mgc.nodes,
-            (
-                FakeNodeWithEqLtMethods(0),
-                FakeNodeWithEqLtMethods(6),
-                FakeNodeWithEqLtMethods(3),
-                FakeNodeWithEqLtMethods(8),
-            ),
+        assert mgc.ordered
+        assert mgc.nodes == (
+            FakeNodeWithEqLtMethods(0),
+            FakeNodeWithEqLtMethods(6),
+            FakeNodeWithEqLtMethods(3),
+            FakeNodeWithEqLtMethods(8),
         )
-        self.assertEqual(mgc.edge_indices, (5, 3, 7, 2))
+        assert mgc.edge_indices == (5, 3, 7, 2)
 
         mgc = MultiGraphCycle(
             [
@@ -631,20 +580,16 @@ class GraphUtilsTest(PymatgenTest):
             ordered=False,
         )
         mgc.order(raise_on_fail=False)
-        self.assertFalse(mgc.ordered)
-        self.assertEqual(
-            mgc.nodes,
-            (
-                FakeNodeWithEqLtMethodsBis(8),
-                FakeNodeWithEqLtMethods(0),
-                FakeNodeWithEqLtMethods(6),
-                FakeNodeWithEqLtMethods(3),
-            ),
+        assert not mgc.ordered
+        assert mgc.nodes == (
+            FakeNodeWithEqLtMethodsBis(8),
+            FakeNodeWithEqLtMethods(0),
+            FakeNodeWithEqLtMethods(6),
+            FakeNodeWithEqLtMethods(3),
         )
-        self.assertEqual(mgc.edge_indices, (2, 5, 3, 7))
-        with self.assertRaisesRegex(
-            ValueError,
-            expected_regex="Could not order simple graph cycle as the nodes are of different classes.",
+        assert mgc.edge_indices == (2, 5, 3, 7)
+        with pytest.raises(
+            ValueError, match="Could not order simple graph cycle as the nodes are of different classes."
         ):
             mgc.order(raise_on_fail=True)
 
@@ -654,11 +599,11 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(mgc.ordered)
+        assert not mgc.ordered
         mgc.order()
-        self.assertTrue(mgc.ordered)
-        self.assertEqual(mgc.nodes, tuple([FakeNodeWithEqLtMethods(85)]))
-        self.assertEqual(mgc.edge_indices, tuple([7]))
+        assert mgc.ordered
+        assert mgc.nodes == tuple([FakeNodeWithEqLtMethods(85)])
+        assert mgc.edge_indices == tuple([7])
 
         mgc = MultiGraphCycle(
             [
@@ -675,28 +620,25 @@ class GraphUtilsTest(PymatgenTest):
             validate=False,
             ordered=False,
         )
-        self.assertFalse(mgc.ordered)
+        assert not mgc.ordered
         mgc.order()
-        self.assertTrue(mgc.ordered)
-        self.assertEqual(
-            mgc.nodes,
-            tuple(
-                [
-                    FakeNodeWithEqLtMethods(1),
-                    FakeNodeWithEqLtMethods(4),
-                    FakeNodeWithEqLtMethods(3),
-                    FakeNodeWithEqLtMethods(6),
-                    FakeNodeWithEqLtMethods(2),
-                    FakeNodeWithEqLtMethods(8),
-                    FakeNodeWithEqLtMethods(32),
-                    FakeNodeWithEqLtMethods(64),
-                ]
-            ),
+        assert mgc.ordered
+        assert mgc.nodes == tuple(
+            [
+                FakeNodeWithEqLtMethods(1),
+                FakeNodeWithEqLtMethods(4),
+                FakeNodeWithEqLtMethods(3),
+                FakeNodeWithEqLtMethods(6),
+                FakeNodeWithEqLtMethods(2),
+                FakeNodeWithEqLtMethods(8),
+                FakeNodeWithEqLtMethods(32),
+                FakeNodeWithEqLtMethods(64),
+            ]
         )
-        self.assertEqual(mgc.edge_indices, tuple([0, 1, 4, 0, 2, 2, 5, 3]))
+        assert mgc.edge_indices == tuple([0, 1, 4, 0, 2, 2, 5, 3])
 
         # Testing all cases for a length-4 cycle
-        nodes_ref = tuple(FakeNodeWithEqLtMethods(inode) for inode in [0, 1, 2, 3])
+        nodes_ref = tuple(FakeNodeWithEqLtMethods(inode) for inode in range(4))
         edges_ref = (3, 6, 9, 12)
         for inodes, iedges in [
             ((0, 1, 2, 3), (3, 6, 9, 12)),
@@ -713,16 +655,8 @@ class GraphUtilsTest(PymatgenTest):
                 edge_indices=[iedge for iedge in iedges],
             )
             strnodes = ", ".join([str(i) for i in inodes])
-            self.assertEqual(
-                mgc.nodes,
-                nodes_ref,
-                msg="Nodes not equal for inodes = ({})".format(", ".join([str(i) for i in inodes])),
-            )
-            self.assertEqual(
-                mgc.edge_indices,
-                edges_ref,
-                msg=f"Edges not equal for inodes = ({strnodes})",
-            )
+            assert mgc.nodes == nodes_ref, f"Nodes not equal for inodes = ({', '.join([str(i) for i in inodes])})"
+            assert mgc.edge_indices == edges_ref, f"Edges not equal for inodes = ({strnodes})"
 
 
 class EnvironmentNodesGraphUtilsTest(PymatgenTest):
@@ -736,52 +670,52 @@ class EnvironmentNodesGraphUtilsTest(PymatgenTest):
         # Tests of SimpleGraphCycle with EnvironmentNodes
         c1 = SimpleGraphCycle([e2])
         c2 = SimpleGraphCycle([e2])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
 
         c1 = SimpleGraphCycle([e1])
         c2 = SimpleGraphCycle([e2])
-        self.assertNotEqual(c1, c2)
+        assert c1 != c2
 
         c1 = SimpleGraphCycle([e1, e2, e3])
         c2 = SimpleGraphCycle([e2, e1, e3])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = SimpleGraphCycle([e2, e3, e1])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
 
         c1 = SimpleGraphCycle([e3, e2, e4, e1, e5])
         c2 = SimpleGraphCycle([e1, e4, e2, e3, e5])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = SimpleGraphCycle([e2, e3, e5, e1, e4])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
 
         c1 = SimpleGraphCycle([e2, e3, e4, e1, e5])
         c2 = SimpleGraphCycle([e2, e3, e5, e1, e4])
-        self.assertNotEqual(c1, c2)
+        assert c1 != c2
 
         # Tests of MultiGraphCycle with EnvironmentNodes
         c1 = MultiGraphCycle([e1], [2])
         c2 = MultiGraphCycle([e1], [2])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = MultiGraphCycle([e1], [1])
-        self.assertNotEqual(c1, c2)
+        assert c1 != c2
         c2 = MultiGraphCycle([e2], [2])
-        self.assertNotEqual(c1, c2)
+        assert c1 != c2
 
         c1 = MultiGraphCycle([e1, e2], [0, 1])
         c2 = MultiGraphCycle([e1, e2], [1, 0])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = MultiGraphCycle([e2, e1], [1, 0])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = MultiGraphCycle([e2, e1], [0, 1])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = MultiGraphCycle([e2, e1], [2, 1])
-        self.assertNotEqual(c1, c2)
+        assert c1 != c2
 
         c1 = MultiGraphCycle([e1, e2, e3], [0, 1, 2])
         c2 = MultiGraphCycle([e2, e1, e3], [0, 2, 1])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
         c2 = MultiGraphCycle([e2, e3, e1], [1, 2, 0])
-        self.assertEqual(c1, c2)
+        assert c1 == c2
 
 
 if __name__ == "__main__":
