@@ -6,12 +6,14 @@
 This module implements a TEM pattern calculator.
 """
 
+from __future__ import annotations
+
 import json
 import os
 from collections import namedtuple
 from fractions import Fraction
 from functools import lru_cache
-from typing import Dict, List, Tuple, cast, Union
+from typing import List, Tuple, cast
 
 import numpy as np
 import pandas as pd
@@ -47,9 +49,9 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         self,
         symprec: float = None,
         voltage: float = 200,
-        beam_direction: Tuple[int, int, int] = (0, 0, 1),
+        beam_direction: tuple[int, int, int] = (0, 0, 1),
         camera_length: int = 160,
-        debye_waller_factors: Dict[str, float] = None,
+        debye_waller_factors: dict[str, float] = None,
         cs: float = 1,
     ) -> None:
         """
@@ -89,9 +91,9 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         wavelength_rel = (
             sc.h
             / np.sqrt(
-                2 * sc.m_e * sc.e * 1000 * self.voltage * (1 + (sc.e * 1000 * self.voltage) / (2 * sc.m_e * sc.c ** 2))
+                2 * sc.m_e * sc.e * 1000 * self.voltage * (1 + (sc.e * 1000 * self.voltage) / (2 * sc.m_e * sc.c**2))
             )
-            * (10 ** 10)
+            * (10**10)
         )
         return wavelength_rel
 
@@ -107,14 +109,14 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         points = [0, 0, 0]
         coord_values = np.arange(coord_left, coord_right + 1)
-        points[0], points[1], points[2] = np.meshgrid(coord_values, coord_values, coord_values)
+        points[0], points[1], points[2] = np.meshgrid(coord_values, coord_values, coord_values)  # type: ignore
         points_matrix = (np.ravel(points[i]) for i in range(0, 3))
         result = np.vstack(list(points_matrix)).transpose()
         return result
 
     def zone_axis_filter(
-        self, points: Union[List[Tuple[int, int, int]], np.ndarray], laue_zone: int = 0
-    ) -> Union[List[Tuple[int, int, int]]]:
+        self, points: list[tuple[int, int, int]] | np.ndarray, laue_zone: int = 0
+    ) -> list[tuple[int, int, int]]:
         """
         Filters out all points that exist within the specified Laue zone according to the zone axis rule.
         Args:
@@ -128,13 +130,13 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         if len(points) == 0:
             return []
         filtered = np.where(np.dot(np.array(self.beam_direction), np.transpose(points)) == laue_zone)
-        result = points[filtered]
+        result = points[filtered]  # type: ignore
         result_tuples = cast(List[Tuple[int, int, int]], [tuple(x) for x in result.tolist()])
         return result_tuples
 
     def get_interplanar_spacings(
-        self, structure: Structure, points: Union[List[Tuple[int, int, int]], np.ndarray]
-    ) -> Dict[Tuple[int, int, int], float]:
+        self, structure: Structure, points: list[tuple[int, int, int]] | np.ndarray
+    ) -> dict[tuple[int, int, int], float]:
         """
         Args:
             structure (Structure): the input structure.
@@ -150,8 +152,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return interplanar_spacings
 
     def bragg_angles(
-        self, interplanar_spacings: Dict[Tuple[int, int, int], float]
-    ) -> Dict[Tuple[int, int, int], float]:
+        self, interplanar_spacings: dict[tuple[int, int, int], float]
+    ) -> dict[tuple[int, int, int], float]:
         """
         Gets the Bragg angles for every hkl point passed in (where n = 1).
         Args:
@@ -159,36 +161,36 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         Returns:
             dict of hkl plane (3-tuple) to Bragg angle in radians (float)
         """
-        plane = list(interplanar_spacings.keys())
+        plane = list(interplanar_spacings)
         interplanar_spacings_val = np.array(list(interplanar_spacings.values()))
         bragg_angles_val = np.arcsin(self.wavelength_rel() / (2 * interplanar_spacings_val))
         bragg_angles = dict(zip(plane, bragg_angles_val))
         return bragg_angles
 
-    def get_s2(self, bragg_angles: Dict[Tuple[int, int, int], float]) -> Dict[Tuple[int, int, int], float]:
+    def get_s2(self, bragg_angles: dict[tuple[int, int, int], float]) -> dict[tuple[int, int, int], float]:
         """
         Calculates the s squared parameter (= square of sin theta over lambda) for each hkl plane.
         Args:
-            bragg_angles (Dict): The bragg angles for each hkl plane.
+            bragg_angles (dict): The bragg angles for each hkl plane.
         Returns:
             Dict of hkl plane to s2 parameter, calculates the s squared parameter
                 (= square of sin theta over lambda).
         """
-        plane = list(bragg_angles.keys())
+        plane = list(bragg_angles)
         bragg_angles_val = np.array(list(bragg_angles.values()))
         s2_val = (np.sin(bragg_angles_val) / self.wavelength_rel()) ** 2
         s2 = dict(zip(plane, s2_val))
         return s2
 
     def x_ray_factors(
-        self, structure: Structure, bragg_angles: Dict[Tuple[int, int, int], float]
-    ) -> Dict[str, Dict[Tuple[int, int, int], float]]:
+        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
+    ) -> dict[str, dict[tuple[int, int, int], float]]:
         """
         Calculates x-ray factors, which are required to calculate atomic scattering factors. Method partially inspired
         by the equivalent process in the xrd module.
         Args:
             structure (Structure): The input structure.
-            bragg_angles (Dict): Dictionary of hkl plane to Bragg angle.
+            bragg_angles (dict): Dictionary of hkl plane to Bragg angle.
         Returns:
             dict of atomic symbol to another dict of hkl plane to x-ray factor (in angstroms).
         """
@@ -200,7 +202,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
             coeffs = np.array(ATOMIC_SCATTERING_PARAMS[atom.symbol])
             for plane in bragg_angles:
                 scattering_factor_curr = atom.Z - 41.78214 * s2[plane] * np.sum(
-                    coeffs[:, 0] * np.exp(-coeffs[:, 1] * s2[plane]), axis=None
+                    coeffs[:, 0] * np.exp(-coeffs[:, 1] * s2[plane]), axis=None  # type: ignore
                 )
                 scattering_factors_for_atom[plane] = scattering_factor_curr
             x_ray_factors[atom.symbol] = scattering_factors_for_atom
@@ -208,8 +210,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return x_ray_factors
 
     def electron_scattering_factors(
-        self, structure: Structure, bragg_angles: Dict[Tuple[int, int, int], float]
-    ) -> Dict[str, Dict[Tuple[int, int, int], float]]:
+        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
+    ) -> dict[str, dict[tuple[int, int, int], float]]:
         """
         Calculates atomic scattering factors for electrons using the Mott-Bethe formula (1st order Born approximation).
         Args:
@@ -233,8 +235,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return electron_scattering_factors
 
     def cell_scattering_factors(
-        self, structure: Structure, bragg_angles: Dict[Tuple[int, int, int], float]
-    ) -> Dict[Tuple[int, int, int], int]:
+        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
+    ) -> dict[tuple[int, int, int], int]:
         """
         Calculates the scattering factor for the whole cell.
         Args:
@@ -248,7 +250,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         scattering_factor_curr = 0
         for plane in bragg_angles:
             for site in structure:
-                for sp, occu in site.species.items():
+                for sp in site.species:
                     g_dot_r = np.dot(np.array(plane), np.transpose(site.frac_coords))
                     scattering_factor_curr += electron_scattering_factors[sp.symbol][plane] * np.exp(
                         2j * np.pi * g_dot_r
@@ -258,8 +260,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return cell_scattering_factors
 
     def cell_intensity(
-        self, structure: Structure, bragg_angles: Dict[Tuple[int, int, int], float]
-    ) -> Dict[Tuple[int, int, int], float]:
+        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
+    ) -> dict[tuple[int, int, int], float]:
         """
         Calculates cell intensity for each hkl plane. For simplicity's sake, take I = |F|**2.
         Args:
@@ -279,7 +281,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         self,
         structure: Structure,
         scaled: bool = None,
-        two_theta_range: Tuple[float, float] = None,
+        two_theta_range: tuple[float, float] = None,
     ) -> pd.DataFrame:
         """
         Returns all relevant TEM DP info in a pandas dataframe.
@@ -305,10 +307,10 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         rows_list = []
         for dot in tem_dots:
             dict1 = {
-                "Pos": dot.position,
+                "Position": dot.position,
                 "(hkl)": dot.hkl,
-                "Intnsty (norm)": dot.intensity,
-                "Film rad": dot.film_radius,
+                "Intensity (norm)": dot.intensity,
+                "Film radius": dot.film_radius,
                 "Interplanar Spacing": dot.d_spacing,
             }
             rows_list.append(dict1)
@@ -316,8 +318,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return df
 
     def normalized_cell_intensity(
-        self, structure: Structure, bragg_angles: Dict[Tuple[int, int, int], float]
-    ) -> Dict[Tuple[int, int, int], float]:
+        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
+    ) -> dict[tuple[int, int, int], float]:
         """
         Normalizes the cell_intensity dict to 1, for use in plotting.
         Args:
@@ -337,8 +339,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def is_parallel(
         self,
         structure: Structure,
-        plane: Tuple[int, int, int],
-        other_plane: Tuple[int, int, int],
+        plane: tuple[int, int, int],
+        other_plane: tuple[int, int, int],
     ) -> bool:
         """
         Checks if two hkl planes are parallel in reciprocal space.
@@ -352,7 +354,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         phi = self.get_interplanar_angle(structure, plane, other_plane)
         return phi in (180, 0) or np.isnan(phi)
 
-    def get_first_point(self, structure: Structure, points: list) -> Dict[Tuple[int, int, int], float]:
+    def get_first_point(self, structure: Structure, points: list) -> dict[tuple[int, int, int], float]:
         """
         Gets the first point to be plotted in the 2D DP, corresponding to maximum d/minimum R.
         Args:
@@ -365,14 +367,14 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         max_d_plane = (0, 0, 1)
         points = self.zone_axis_filter(points)
         spacings = self.get_interplanar_spacings(structure, points)
-        for plane in sorted(spacings.keys()):
+        for plane in sorted(spacings):
             if spacings[plane] > max_d:
                 max_d_plane = plane
                 max_d = spacings[plane]
         return {max_d_plane: max_d}
 
     @staticmethod
-    def get_interplanar_angle(structure: Structure, p1: Tuple[int, int, int], p2: Tuple[int, int, int]) -> float:
+    def get_interplanar_angle(structure: Structure, p1: tuple[int, int, int], p2: tuple[int, int, int]) -> float:
         """
         Returns the interplanar angle (in degrees) between the normal of two crystal planes.
         Formulas from International Tables for Crystallography Volume C pp. 2-9.
@@ -397,25 +399,25 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         cos_beta_star = (np.cos(alpha) * np.cos(gamma) - np.cos(beta)) / (np.sin(alpha) * np.sin(gamma))
         cos_gamma_star = (np.cos(alpha) * np.cos(beta) - np.cos(gamma)) / (np.sin(alpha) * np.sin(beta))
         r1_norm = np.sqrt(
-            p1[0] ** 2 * a_star ** 2
-            + p1[1] ** 2 * b_star ** 2
-            + p1[2] ** 2 * c_star ** 2
+            p1[0] ** 2 * a_star**2
+            + p1[1] ** 2 * b_star**2
+            + p1[2] ** 2 * c_star**2
             + 2 * p1[0] * p1[1] * a_star * b_star * cos_gamma_star
             + 2 * p1[0] * p1[2] * a_star * c_star * cos_beta_star
             + 2 * p1[1] * p1[2] * b_star * c_star * cos_gamma_star
         )
         r2_norm = np.sqrt(
-            p2[0] ** 2 * a_star ** 2
-            + p2[1] ** 2 * b_star ** 2
-            + p2[2] ** 2 * c_star ** 2
+            p2[0] ** 2 * a_star**2
+            + p2[1] ** 2 * b_star**2
+            + p2[2] ** 2 * c_star**2
             + 2 * p2[0] * p2[1] * a_star * b_star * cos_gamma_star
             + 2 * p2[0] * p2[2] * a_star * c_star * cos_beta_star
             + 2 * p2[1] * p2[2] * b_star * c_star * cos_gamma_star
         )
         r1_dot_r2 = (
-            p1[0] * p2[0] * a_star ** 2
-            + p1[1] * p2[1] * b_star ** 2
-            + p1[2] * p2[2] * c_star ** 2
+            p1[0] * p2[0] * a_star**2
+            + p1[1] * p2[1] * b_star**2
+            + p1[2] * p2[2] * c_star**2
             + (p1[0] * p2[1] + p2[0] * p1[1]) * a_star * b_star * cos_gamma_star
             + (p1[0] * p2[2] + p2[0] * p1[1]) * a_star * c_star * cos_beta_star
             + (p1[1] * p2[2] + p2[1] * p1[2]) * b_star * c_star * cos_alpha_star
@@ -425,9 +427,9 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
 
     @staticmethod
     def get_plot_coeffs(
-        p1: Tuple[int, int, int],
-        p2: Tuple[int, int, int],
-        p3: Tuple[int, int, int],
+        p1: tuple[int, int, int],
+        p2: tuple[int, int, int],
+        p3: tuple[int, int, int],
     ) -> np.ndarray:
         """
         Calculates coefficients of the vector addition required to generate positions for each DP point
@@ -445,7 +447,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         x = np.dot(a_pinv, b)
         return np.ravel(x)
 
-    def get_positions(self, structure: Structure, points: list) -> Dict[Tuple[int, int, int], np.ndarray]:
+    def get_positions(self, structure: Structure, points: list) -> dict[tuple[int, int, int], np.ndarray]:
         """
         Calculates all the positions of each hkl point in the 2D diffraction pattern by vector addition.
         Distance in centimeters.
@@ -465,7 +467,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         spacings = self.get_interplanar_spacings(structure, points)
         # second is the first non-parallel-to-first-point vector when sorted.
         # note 000 is "parallel" to every plane vector.
-        for plane in sorted(spacings.keys()):
+        for plane in sorted(spacings):
             second_point, second_d = plane, spacings[plane]
             if not self.is_parallel(structure, first_point, second_point):
                 break
@@ -496,7 +498,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
 
         return positions
 
-    def tem_dots(self, structure: Structure, points) -> List:
+    def tem_dots(self, structure: Structure, points) -> list:
         """
         Generates all TEM_dot as named tuples that will appear on the 2D diffraction pattern.
         Args:
@@ -513,7 +515,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         for hkl, intensity in cell_intensity.items():
             dot = namedtuple("dot", ["position", "hkl", "intensity", "film_radius", "d_spacing"])
             position = positions[hkl]
-            film_radius = 0.91 * (10 ** -3 * self.cs * self.wavelength_rel() ** 3) ** Fraction("1/4")
+            film_radius = 0.91 * (10**-3 * self.cs * self.wavelength_rel() ** 3) ** Fraction("1/4")
             d_spacing = interplanar_spacings[hkl]
             tem_dot = dot(position, hkl, intensity, film_radius, d_spacing)
             dots.append(tem_dot)
