@@ -6,8 +6,9 @@ This module provides classes to store, generate, and manipulate material interfa
 """
 
 import warnings
-from pymatgen.core.interface import Interface  # noqa
-from pymatgen.analysis.interfaces import CoherentInterfaceBuilder  # noqa
+
+from pymatgen.analysis.interfaces import CoherentInterfaceBuilder  # noqa: F401
+from pymatgen.core.interface import Interface  # noqa: F401
 
 __author__ = "Eric Sivonxay, Shyam Dwaraknath, and Kyle Bystrom"
 __copyright__ = "Copyright 2019, The Materials Project"
