@@ -9,26 +9,25 @@ Please consider citing one or both of the following papers if you use this
 code in your own work.
 
 References:
-
     (1) Richards, W. D., Miara, L. J., Wang, Y., Kim, J. C., &amp; Ceder, G. (2015).
     Interface stability in solid-state batteries. Chemistry of Materials, 28(1),
-    266–273. https://doi.org/10.1021/acs.chemmater.5b04082
+    266-273. https://doi.org/10.1021/acs.chemmater.5b04082
 
     (2) Xiao, Y., Wang, Y., Bo, S.-H., Kim, J. C., Miara, L. J., &amp; Ceder, G. (2019).
     Understanding interface stability in solid-state batteries.
-    Nature Reviews Materials, 5(2), 105–126. https://doi.org/10.1038/s41578-019-0157-5
+    Nature Reviews Materials, 5(2), 105-126. https://doi.org/10.1038/s41578-019-0157-5
 
 """
 
+from __future__ import annotations
+
 import json
 import os
-import sys
 import warnings
-from typing import List, Tuple, Union
+from typing import Literal
 
 import matplotlib.pyplot as plt
 import numpy as np
-from monty.dev import deprecated
 from monty.json import MSONable
 from pandas import DataFrame
 from plotly.graph_objects import Figure, Scatter
@@ -39,11 +38,6 @@ from pymatgen.core.composition import Composition
 from pymatgen.util.plotting import pretty_plot
 from pymatgen.util.string import htmlify, latexify
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 __author__ = "Yihan Xiao, Matthew McDermott"
 __maintainer__ = "Matthew McDermott"
 __email__ = "mcdermott@lbl.gov"
@@ -67,11 +61,11 @@ class InterfacialReactivity(MSONable):
     References:
         Richards, W. D., Miara, L. J., Wang, Y., Kim, J. C., &amp; Ceder, G. (2015).
         Interface stability in solid-state batteries. Chemistry of Materials, 28(1),
-        266–273. https://doi.org/10.1021/acs.chemmater.5b04082
+        266-273. https://doi.org/10.1021/acs.chemmater.5b04082
 
         Xiao, Y., Wang, Y., Bo, S.-H., Kim, J. C., Miara, L. J., &amp; Ceder, G. (2019).
         Understanding interface stability in solid-state batteries.
-        Nature Reviews Materials, 5(2), 105–126.
+        Nature Reviews Materials, 5(2), 105-126.
         https://doi.org/10.1038/s41578-019-0157-5
     """
 
@@ -143,7 +137,7 @@ class InterfacialReactivity(MSONable):
                 self.e1 = self._get_entry_energy(self.pd, self.comp1)
                 self.e2 = self._get_entry_energy(self.pd, self.comp2)
 
-    def get_kinks(self) -> List[Tuple[int, float, float, Reaction, float]]:
+    def get_kinks(self) -> list[tuple[int, float, float, Reaction, float]]:
         """
         Finds all the kinks in mixing ratio where reaction products changes
         along the tie-line of composition self.c1 and composition self.c2.
@@ -178,7 +172,7 @@ class InterfacialReactivity(MSONable):
             for i in reversed(critical_comp):
                 # Gets mixing ratio x at kinks.
                 c = self.pd.pd_coords(i)
-                x = np.linalg.norm(c - c2_coord) / np.linalg.norm(c1_coord - c2_coord)
+                x = float(np.linalg.norm(c - c2_coord) / np.linalg.norm(c1_coord - c2_coord))
                 # Modifies mixing ratio in case compositions self.comp1 and
                 # self.comp2 are not normalized.
                 x = x * n2 / (n1 + x * (n2 - n1))
@@ -200,7 +194,7 @@ class InterfacialReactivity(MSONable):
 
         return list(zip(index_kink, x_kink, energy_kink, react_kink, energy_per_rxt_formula))
 
-    def plot(self, backend: Literal["plotly", "matplotlib"] = "plotly") -> Union[Figure, plt.Figure]:
+    def plot(self, backend: Literal["plotly", "matplotlib"] = "plotly") -> Figure | plt.Figure:
         """
         Plots reaction energy as a function of mixing ratio x in self.c1 - self.c2
         tie line.
@@ -212,7 +206,6 @@ class InterfacialReactivity(MSONable):
         Returns:
             Plot of reaction energies as a function of mixing ratio
         """
-
         if backend.lower() == "plotly":
             fig = self._get_plotly_figure()
         elif backend.lower() in ["matplotlib", "mpl", "plt"]:
@@ -291,7 +284,7 @@ class InterfacialReactivity(MSONable):
         """
         return self.pd.get_hull_energy(self.comp1 * x + self.comp2 * (1 - x)) - self.e1 * x - self.e2 * (1 - x)
 
-    def _get_reactants(self, x: float) -> List[Composition]:
+    def _get_reactants(self, x: float) -> list[Composition]:
         """Returns a list of relevant reactant compositions given an x coordinate"""
         # Uses original composition for reactants.
         if np.isclose(x, 0):
@@ -347,7 +340,7 @@ class InterfacialReactivity(MSONable):
 
     def _get_plotly_figure(self) -> Figure:
         """Returns a Plotly figure of reaction kinks diagram"""
-        kinks = map(list, zip(*self.get_kinks()))  # type: ignore
+        kinks = map(list, zip(*self.get_kinks()))
         _, x, energy, reactions, _ = kinks
 
         lines = Scatter(
@@ -368,7 +361,7 @@ class InterfacialReactivity(MSONable):
         rxn_min = reactions.pop(min_idx)
 
         labels = [
-            rf"{htmlify(str(r))} <br>" + "\u0394" + f"E<sub>rxn</sub> = {round(e, 3)} eV/atom"  # type: ignore
+            f"{htmlify(str(r))} <br>\u0394E<sub>rxn</sub> = {round(e, 3)} eV/atom"  # type: ignore
             for r, e in zip(reactions, energy)
         ]
 
@@ -388,9 +381,7 @@ class InterfacialReactivity(MSONable):
             hoverlabel=dict(bgcolor="navy"),
         )
 
-        min_label = (
-            rf"{htmlify(str(rxn_min))} <br>" + "\u0394" + f"E<sub>rxn</sub> = {round(e_min, 3)} eV/atom"  # type: ignore
-        )
+        min_label = f"{htmlify(str(rxn_min))} <br>\u0394E<sub>rxn</sub> = {round(e_min, 3)} eV/atom"  # type: ignore
 
         minimum = Scatter(
             x=[x_min],
@@ -416,7 +407,7 @@ class InterfacialReactivity(MSONable):
         pretty_plot(8, 5)
         plt.xlim([-0.05, 1.05])  # plot boundary is 5% wider on each side
 
-        kinks = list(zip(*self.get_kinks()))  # type: ignore
+        kinks = list(zip(*self.get_kinks()))
         _, x, energy, reactions, _ = kinks
 
         plt.plot(x, energy, "o-", markersize=8, c="navy", zorder=1)
@@ -424,11 +415,7 @@ class InterfacialReactivity(MSONable):
 
         for x_coord, y_coord, rxn in zip(x, energy, reactions):
             products = ", ".join(
-                [
-                    latexify(p.reduced_formula)
-                    for p in rxn.products  # type: ignore
-                    if not np.isclose(rxn.get_coeff(p), 0)  # type: ignore
-                ]
+                [latexify(p.reduced_formula) for p in rxn.products if not np.isclose(rxn.get_coeff(p), 0)]
             )
             plt.annotate(
                 products,
@@ -467,7 +454,7 @@ class InterfacialReactivity(MSONable):
         return title
 
     @staticmethod
-    def _get_plotly_annotations(x: List[float], y: List[float], reactions: List[Reaction]):
+    def _get_plotly_annotations(x: list[float], y: list[float], reactions: list[Reaction]):
         """Returns dictionary of annotations for the Plotly figure layout"""
         annotations = []
         for x_coord, y_coord, rxn in zip(x, y, reactions):
@@ -632,13 +619,6 @@ class InterfacialReactivity(MSONable):
             products = products.union({k.reduced_formula for k in react.products})
         return list(products)
 
-    @deprecated(products)
-    def get_products(self):
-        """
-        Deprecated method. Use the "products" property.
-        """
-        return self.products
-
 
 class GrandPotentialInterfacialReactivity(InterfacialReactivity):
     """
@@ -681,7 +661,6 @@ class GrandPotentialInterfacialReactivity(InterfacialReactivity):
                 composition, convex hull energy will be used associated with a
                 warning message.
         """
-
         if not isinstance(grand_pd, GrandPotentialPhaseDiagram):
             raise ValueError("Please use the InterfacialReactivity class if using a regular phase diagram!")
 
@@ -728,7 +707,7 @@ class GrandPotentialInterfacialReactivity(InterfacialReactivity):
             (f"{self.c2_original.reduced_formula} ({unit})", energy2),
         ]
 
-    def _get_reactants(self, x: float) -> List[Composition]:
+    def _get_reactants(self, x: float) -> list[Composition]:
         """Returns a list of relevant reactant compositions given an x coordinate"""
         reactants = super()._get_reactants(x)
         reactants += [Composition(e.symbol) for e, v in self.pd.chempots.items()]
