@@ -6,12 +6,14 @@ This module provides some useful functions for dealing with magnetic Structures
 (e.g. Structures with associated magmom tags).
 """
 
+from __future__ import annotations
+
 import logging
 import os
 import warnings
 from collections import namedtuple
 from enum import Enum, unique
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any
 
 import numpy as np
 from monty.serialization import loadfn
@@ -84,7 +86,7 @@ class CollinearMagneticStructureAnalyzer:
     def __init__(
         self,
         structure: Structure,
-        overwrite_magmom_mode: Union[OverwriteMagmomMode, str] = "none",
+        overwrite_magmom_mode: OverwriteMagmomMode | str = "none",
         round_magmoms: bool = False,
         detect_valences: bool = False,
         make_primitive: bool = True,
@@ -93,7 +95,7 @@ class CollinearMagneticStructureAnalyzer:
         threshold: float = 0.00,
         threshold_nonmag: float = 0.1,
     ):
-        r"""
+        """
         If magnetic moments are not defined, moments will be
         taken either from default_magmoms.yaml (similar to the
         default magmoms in MPRelaxSet, with a few extra definitions)
@@ -116,7 +118,7 @@ class CollinearMagneticStructureAnalyzer:
           no magmoms are defined in input structure, otherwise it will respect
           existing magmoms.
         * "normalize" will normalize magmoms to unity, but will respect sign
-          (used for comparing orderings), magmoms < theshold will be set to zero
+          (used for comparing orderings), magmoms < theshhold will be set to zero
 
         Args:
             structure: input Structure object
@@ -140,7 +142,6 @@ class CollinearMagneticStructureAnalyzer:
                 below which nonmagnetic ions (with no magmom specified
                 in default_magmoms) will be rounded to zero
         """
-
         if default_magmoms:
             self.default_magmoms = default_magmoms
         else:
@@ -167,7 +168,7 @@ class CollinearMagneticStructureAnalyzer:
 
         has_spin = False
         for comp in structure.species_and_occu:
-            for sp, occu in comp.items():
+            for sp in comp:
                 if getattr(sp, "spin", False):
                     has_spin = True
 
@@ -191,7 +192,7 @@ class CollinearMagneticStructureAnalyzer:
                     "site properties. Any 'None' magmoms have been "
                     "replaced with zero."
                 )
-            magmoms = [m if m else 0 for m in structure.site_properties["magmom"]]
+            magmoms = [m or 0 for m in structure.site_properties["magmom"]]
         elif has_spin:
             magmoms = [getattr(sp, "spin", 0) for sp in structure.species]
             structure.remove_spin()
@@ -301,12 +302,11 @@ class CollinearMagneticStructureAnalyzer:
         self.structure = structure
 
     @staticmethod
-    def _round_magmoms(magmoms: VectorLike, round_magmoms_mode: Union[int, float]) -> np.ndarray:
+    def _round_magmoms(magmoms: VectorLike, round_magmoms_mode: int | float) -> np.ndarray:
         """If round_magmoms_mode is an integer, simply round to that number
         of decimal places, else if set to a float will try and round
         intelligently by grouping magmoms.
         """
-
         if isinstance(round_magmoms_mode, int):
 
             # simple rounding to number of decimal places
@@ -348,7 +348,6 @@ class CollinearMagneticStructureAnalyzer:
         """Returns a Structure with species decorated with spin values instead
         of using magmom site properties.
         """
-
         structure = self.structure.copy()
         structure.add_spin_by_site(structure.site_properties["magmom"])
         structure.remove_site_property("magmom")
@@ -364,7 +363,6 @@ class CollinearMagneticStructureAnalyzer:
 
         Returns: Structure
         """
-
         sites = [site for site in self.structure if abs(site.properties["magmom"]) > 0]
 
         structure = Structure.from_sites(sites)
@@ -383,9 +381,7 @@ class CollinearMagneticStructureAnalyzer:
 
         Returns:
           Structure
-
         """
-
         structure = self.structure.copy()
         structure.remove_site_property("magmom")
 
@@ -404,9 +400,7 @@ class CollinearMagneticStructureAnalyzer:
 
         Returns:
           Structure
-
         """
-
         structure = self.structure.copy()
 
         structure.add_site_property("magmom", [abs(m) for m in self.magmoms])
@@ -430,12 +424,11 @@ class CollinearMagneticStructureAnalyzer:
     @property
     def types_of_magnetic_species(
         self,
-    ) -> Tuple[Union[Element, Species, DummySpecies], ...]:
+    ) -> tuple[Element | Species | DummySpecies, ...]:
         """Equivalent to Structure.types_of_specie but only returns
         magnetic species.
 
         Returns: types of Species as a list
-
         """
         if self.number_of_magnetic_sites > 0:
             structure = self.get_structure_with_only_magnetic_atoms()
@@ -445,24 +438,23 @@ class CollinearMagneticStructureAnalyzer:
     @property
     def types_of_magnetic_specie(
         self,
-    ) -> Tuple[Union[Element, Species, DummySpecies], ...]:
+    ) -> tuple[Element | Species | DummySpecies, ...]:
         """
         Specie->Species rename. Used to maintain backwards compatibility.
         """
         return self.types_of_magnetic_species
 
     @property
-    def magnetic_species_and_magmoms(self) -> Dict[str, Any]:
+    def magnetic_species_and_magmoms(self) -> dict[str, Any]:
         """Returns a dict of magnetic species and the magnitude of
         their associated magmoms. Will return a list if there are
         multiple magmoms per species.
 
         Returns: dict of magnetic species and magmoms
         """
-
         structure = self.get_ferromagnetic_structure()
 
-        magtypes: Dict = {str(site.specie): set() for site in structure if site.properties["magmom"] != 0}
+        magtypes: dict = {str(site.specie): set() for site in structure if site.properties["magmom"] != 0}
 
         for site in structure:
             if site.properties["magmom"] != 0:
@@ -483,16 +475,13 @@ class CollinearMagneticStructureAnalyzer:
 
     def number_of_unique_magnetic_sites(self, symprec: float = 1e-3, angle_tolerance: float = 5) -> int:
         """
-
         Args:
           symprec: same as in SpacegroupAnalyzer (Default value = 1e-3)
           angle_tolerance: same as in SpacegroupAnalyzer (Default value = 5)
 
         Returns: Number of symmetrically-distinct magnetic sites present
         in structure.
-
         """
-
         structure = self.get_nonmagnetic_structure()
 
         sga = SpacegroupAnalyzer(structure, symprec=symprec, angle_tolerance=angle_tolerance)
@@ -515,7 +504,6 @@ class CollinearMagneticStructureAnalyzer:
         Returns: Ordering Enum ('FiM' is used as the abbreviation for
         ferrimagnetic)
         """
-
         if not self.is_collinear:
             warnings.warn("Detecting ordering in non-collinear structures not yet implemented.")
             return Ordering.Unknown
@@ -541,7 +529,7 @@ class CollinearMagneticStructureAnalyzer:
             return Ordering.AFM
         return Ordering.NM
 
-    def get_exchange_group_info(self, symprec: float = 1e-2, angle_tolerance: float = 5.0) -> Tuple[str, int]:
+    def get_exchange_group_info(self, symprec: float = 1e-2, angle_tolerance: float = 5.0) -> tuple[str, int]:
         """Returns the information on the symmetry of the Hamiltonian
         describing the exchange energy of the system, taking into
         account relative direction of magnetic moments but not their
@@ -558,9 +546,7 @@ class CollinearMagneticStructureAnalyzer:
 
         Returns:
           spacegroup_symbol, international_number
-
         """
-
         structure = self.get_structure_with_spin()
 
         return structure.get_space_group_info(symprec=symprec, angle_tolerance=angle_tolerance)
@@ -573,7 +559,6 @@ class CollinearMagneticStructureAnalyzer:
 
         Returns: True or False
         """
-
         a = CollinearMagneticStructureAnalyzer(
             self.structure, overwrite_magmom_mode="normalize"
         ).get_structure_with_spin()
@@ -598,14 +583,13 @@ class CollinearMagneticStructureAnalyzer:
 
     def __str__(self):
         """
-        Sorts a Structure (by fractional co-ordinate), and
+        Sorts a Structure (by fractional coordinate), and
         prints sites with magnetic information. This is
         useful over Structure.__str__ because sites are in
         a consistent order, which makes visual comparison between
         two identical Structures with different magnetic orderings
         easier.
         """
-
         frac_coords = self.structure.frac_coords
         sorted_indices = np.lexsort((frac_coords[:, 2], frac_coords[:, 1], frac_coords[:, 0]))
         s = Structure.from_sites([self.structure[idx] for idx in sorted_indices])
@@ -615,7 +599,7 @@ class CollinearMagneticStructureAnalyzer:
         outs.append("Magmoms Sites")
         for site in s:
             if site.properties["magmom"] != 0:
-                prefix = "{:+.2f}   ".format(site.properties["magmom"])
+                prefix = f"{site.properties['magmom']:+.2f}   "
             else:
                 prefix = "        "
             outs.append(prefix + repr(site))
@@ -640,14 +624,15 @@ class MagneticStructureEnumerator:
     def __init__(
         self,
         structure: Structure,
-        default_magmoms: Optional[Dict[str, float]] = None,
-        strategies: Union[List[str], Tuple[str, ...]] = (
+        default_magmoms: dict[str, float] | None = None,
+        strategies: list[str]
+        | tuple[str, ...] = (
             "ferromagnetic",
             "antiferromagnetic",
         ),
         automatic: bool = True,
         truncate_by_symmetry: bool = True,
-        transformation_kwargs: Optional[Dict] = None,
+        transformation_kwargs: dict | None = None,
     ):
         """
         This class will try generated different collinear
@@ -675,8 +660,7 @@ class MagneticStructureEnumerator:
             transformation_kwargs: keyword arguments to pass to
                 MagOrderingTransformation, to change automatic cell size limits, etc.
         """
-
-        self.logger = logging.getLogger(self.__class__.__name__)
+        self.logger = logging.getLogger(type(self).__name__)
 
         self.structure = structure
 
@@ -708,8 +692,8 @@ class MagneticStructureEnumerator:
         # is be a list of strings in ("fm", "afm",
         # "ferrimagnetic_by_species", "ferrimagnetic_by_motif",
         # "afm_by_motif", "input_structure")
-        self.ordered_structures: List[Structure] = []
-        self.ordered_structure_origins: List[str] = []
+        self.ordered_structures: list[Structure] = []
+        self.ordered_structure_origins: list[str] = []
 
         formula = structure.composition.reduced_formula
 
@@ -749,9 +733,7 @@ class MagneticStructureEnumerator:
           input_structure: Structure
 
         Returns: Structure
-
         """
-
         input_structure = input_structure.copy()
 
         # remove any annotated spin
@@ -768,7 +750,7 @@ class MagneticStructureEnumerator:
 
         return input_structure
 
-    def _generate_transformations(self, structure: Structure) -> Dict[str, MagOrderingTransformation]:
+    def _generate_transformations(self, structure: Structure) -> dict[str, MagOrderingTransformation]:
         """The central problem with trying to enumerate magnetic orderings is
         that we have to enumerate orderings that might plausibly be magnetic
         ground states, while not enumerating orderings that are physically
@@ -785,11 +767,9 @@ class MagneticStructureEnumerator:
         enumeration strategy (keys)
 
         Returns: dict of Transformations keyed by strategy
-
         """
-
         formula = structure.composition.reduced_formula
-        transformations: Dict[str, MagOrderingTransformation] = {}
+        transformations: dict[str, MagOrderingTransformation] = {}
 
         # analyzer is used to obtain information on sanitized input
         analyzer = CollinearMagneticStructureAnalyzer(
@@ -828,7 +808,7 @@ class MagneticStructureEnumerator:
         if "max_cell_size" not in self.transformation_kwargs:
             # TODO: change to 8 / num_mag_sites ?
             self.transformation_kwargs["max_cell_size"] = max(1, int(4 / num_mag_sites))
-        self.logger.info("Max cell size set to {}".format(self.transformation_kwargs["max_cell_size"]))
+        self.logger.info(f"Max cell size set to {self.transformation_kwargs['max_cell_size']}")
 
         # when enumerating ferrimagnetic structures, it's useful to detect
         # symmetrically distinct magnetic sites, since different
@@ -887,7 +867,7 @@ class MagneticStructureEnumerator:
 
         # we store constraint(s) for each strategy first,
         # and then use each to perform a transformation later
-        all_constraints: Dict[str, Any] = {}
+        all_constraints: dict[str, Any] = {}
 
         # ...to which we can add simple AFM cases first...
         if "antiferromagnetic" in self.strategies:
@@ -973,7 +953,7 @@ class MagneticStructureEnumerator:
     def _generate_ordered_structures(
         self,
         sanitized_input_structure: Structure,
-        transformations: Dict[str, MagOrderingTransformation],
+        transformations: dict[str, MagOrderingTransformation],
     ):
         """Apply our input structure to our list of transformations and output a list
         of ordered structures that have been pruned for duplicates and for those
@@ -991,7 +971,6 @@ class MagneticStructureEnumerator:
 
         Returns: List of Structures
         """
-
         ordered_structures = self.ordered_structures
         ordered_structures_origins = self.ordered_structure_origins
 
@@ -1003,7 +982,6 @@ class MagneticStructureEnumerator:
             by the transformation.
             """
             if structures_to_add:
-                # type conversion
                 if isinstance(structures_to_add, Structure):
                     structures_to_add = [structures_to_add]
                 structures_to_add = [s["structure"] if isinstance(s, dict) else s for s in structures_to_add]
@@ -1027,7 +1005,7 @@ class MagneticStructureEnumerator:
 
         # in case we've introduced duplicates, let's remove them
         self.logger.info("Pruning duplicate structures.")
-        structures_to_remove: List[int] = []
+        structures_to_remove: list[int] = []
         for idx, ordered_structure in enumerate(ordered_structures):
             if idx not in structures_to_remove:
                 duplicate_checker = CollinearMagneticStructureAnalyzer(ordered_structure, overwrite_magmom_mode="none")
@@ -1036,7 +1014,7 @@ class MagneticStructureEnumerator:
                         if duplicate_checker.matches_ordering(check_structure):
                             structures_to_remove.append(check_idx)
 
-        if len(structures_to_remove):
+        if len(structures_to_remove) == 0:
             self.logger.info(f"Removing {len(structures_to_remove)} duplicate ordered structures")
             ordered_structures = [s for idx, s in enumerate(ordered_structures) if idx not in structures_to_remove]
             ordered_structures_origins = [
