@@ -17,10 +17,10 @@ import pandas as pd
 from monty.json import MSONable, jsanitize
 from monty.serialization import dumpfn
 
-from pymatgen.core.structure import Structure
 from pymatgen.analysis.graphs import StructureGraph
 from pymatgen.analysis.local_env import MinimumDistanceNN
 from pymatgen.analysis.magnetism import CollinearMagneticStructureAnalyzer, Ordering
+from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 __author__ = "ncfrey"
@@ -36,7 +36,7 @@ class HeisenbergMapper:
     Class to compute exchange parameters from low energy magnetic orderings.
     """
 
-    def __init__(self, ordered_structures, energies, cutoff=0.0, tol=0.02):
+    def __init__(self, ordered_structures, energies, cutoff=0.0, tol: float = 0.02):
         """
         Exchange parameters are computed by mapping to a classical Heisenberg
         model. Strategy is the scheme for generating neighbors. Currently only
@@ -59,22 +59,15 @@ class HeisenbergMapper:
                 being equal.
 
         Parameters:
-            strategy (object): Class from pymatgen.analysis.local_env for
-                constructing graphs.
+            strategy (object): Class from pymatgen.analysis.local_env for constructing graphs.
             sgraphs (list): StructureGraph objects.
-            unique_site_ids (dict): Maps each site to its unique numerical
-                identifier.
-            wyckoff_ids (dict): Maps unique numerical identifier to wyckoff
-                position.
-            nn_interacations (dict): {i: j} pairs of NN interactions
-                between unique sites.
+            unique_site_ids (dict): Maps each site to its unique numerical identifier.
+            wyckoff_ids (dict): Maps unique numerical identifier to wyckoff position.
+            nn_interactions (dict): {i: j} pairs of NN interactions between unique sites.
             dists (dict): NN, NNN, and NNNN interaction distances
-            ex_mat (DataFrame): Invertible Heisenberg Hamiltonian for each
-                graph.
+            ex_mat (DataFrame): Invertible Heisenberg Hamiltonian for each graph.
             ex_params (dict): Exchange parameter values (meV/atom)
-
         """
-
         # Save original copies of inputs
         self.ordered_structures_ = ordered_structures
         self.energies_ = energies
@@ -121,9 +114,7 @@ class HeisenbergMapper:
 
         Returns:
             sgraphs (list): StructureGraph objects.
-
         """
-
         # Strategy for finding neighbors
         if cutoff:
             strategy = MinimumDistanceNN(cutoff=cutoff, get_all_sites=True)
@@ -148,9 +139,7 @@ class HeisenbergMapper:
                 unique int identifier
             wyckoff_ids (dict): maps tuples of equivalent site indices to their
                 wyckoff symbols
-
         """
-
         # Get a nonmagnetic representation of the supercell geometry
         s0 = CollinearMagneticStructureAnalyzer(
             structure, make_primitive=False, threshold=0.0
@@ -185,9 +174,7 @@ class HeisenbergMapper:
 
         Returns:
             None: (sets self.nn_interactions and self.dists instance variables)
-
         """
-
         tol = self.tol  # tolerance on NN distances
         sgraph = self.sgraphs[0]
         unique_site_ids = self.unique_site_ids
@@ -262,9 +249,7 @@ class HeisenbergMapper:
 
         TODO:
             * Deal with large variance in |S| across configs
-
         """
-
         sgraphs = self.sgraphs
         tol = self.tol
         unique_site_ids = self.unique_site_ids
@@ -280,9 +265,9 @@ class HeisenbergMapper:
 
         # Get labels of unique NN interactions
         for k0, v0 in nn_interactions.items():
-            for i, j in v0.items():  # i and j indices
-                c = str(i) + "-" + str(j) + "-" + str(k0)
-                c_rev = str(j) + "-" + str(i) + "-" + str(k0)
+            for idx, j in v0.items():  # i and j indices
+                c = str(idx) + "-" + str(j) + "-" + str(k0)
+                c_rev = str(j) + "-" + str(idx) + "-" + str(k0)
                 if c not in columns and c_rev not in columns:
                     columns.append(c)
 
@@ -304,24 +289,24 @@ class HeisenbergMapper:
 
             # Loop over all sites in each graph and compute |S_i . S_j|
             # for n+1 unique graphs to compute n exchange params
-            for graph in sgraphs:
+            for _graph in sgraphs:
                 sgraph = sgraphs_copy.pop(0)
                 ex_row = pd.DataFrame(np.zeros((1, num_nn_j + 1)), index=[sgraph_index], columns=columns)
 
-                for i, node in enumerate(sgraph.graph.nodes):
+                for idx, _node in enumerate(sgraph.graph.nodes):
                     # s_i_sign = np.sign(sgraph.structure.site_properties['magmom'][i])
-                    s_i = sgraph.structure.site_properties["magmom"][i]
+                    s_i = sgraph.structure.site_properties["magmom"][idx]
 
                     for k, v in unique_site_ids.items():
-                        if i in k:
+                        if idx in k:
                             i_index = v
 
                     # Get all connections for ith site and compute |S_i . S_j|
-                    connections = sgraph.get_connected_sites(i)
+                    connections = sgraph.get_connected_sites(idx)
                     # dists = [round(cs[-1], 2) for cs in connections]  # i<->j distances
                     # dists = sorted(list(set(dists)))  # NN, NNN, NNNN, etc.
 
-                    for j, connection in enumerate(connections):
+                    for connection in connections:
                         j_site = connection[2]
                         dist = round(connection[-1], 2)  # i_j distance
 
@@ -382,9 +367,7 @@ class HeisenbergMapper:
 
         Returns:
             ex_params (dict): Exchange parameter values (meV/atom).
-
         """
-
         ex_mat = self.ex_mat
         # Solve the matrix equation for J_ij values
         E = ex_mat[["E"]]
@@ -400,7 +383,7 @@ class HeisenbergMapper:
             return ex_params
 
         # Solve eigenvalue problem for more than 1 NN interaction
-        H = ex_mat.loc[:, ex_mat.columns != "E"].values
+        H = np.array(ex_mat.loc[:, ex_mat.columns != "E"].values).astype("float64")
         H_inv = np.linalg.inv(H)
         j_ij = np.dot(H_inv, E)
 
@@ -422,9 +405,7 @@ class HeisenbergMapper:
             afm_struct (Structure): afm structure with 'magmom' site property
             fm_e (float): fm energy
             afm_e (float): afm energy
-
         """
-
         fm_struct, afm_struct = None, None
         mag_min = np.inf
         mag_max = 0.001
@@ -496,9 +477,7 @@ class HeisenbergMapper:
 
         Returns:
             j_avg (float): Average exchange parameter (meV/atom)
-
         """
-
         # Get low energy orderings if not supplied
         if any(arg is None for arg in [fm_struct, afm_struct, fm_e, afm_e]):
             fm_struct, afm_struct, fm_e, afm_e = self.get_low_energy_orderings()
@@ -509,7 +488,7 @@ class HeisenbergMapper:
         # fm_e = fm_e / len(magmoms)
         # afm_e = afm_e / len(afm_magmoms)
 
-        m_avg = np.mean([np.sqrt(m ** 2) for m in magmoms])
+        m_avg = np.mean([np.sqrt(m**2) for m in magmoms])
 
         # If m_avg for FM config is < 1 we won't get sensibile results.
         if m_avg < 1:
@@ -521,7 +500,7 @@ class HeisenbergMapper:
             logging.warning(iamthedanger)
 
         delta_e = afm_e - fm_e  # J > 0 -> FM
-        j_avg = delta_e / (m_avg ** 2)  # eV / magnetic ion
+        j_avg = delta_e / (m_avg**2)  # eV / magnetic ion
         j_avg *= 1000  # meV / ion
 
         return j_avg
@@ -537,9 +516,7 @@ class HeisenbergMapper:
 
         Returns:
             mft_t (float): Critical temperature (K)
-
         """
-
         num_sublattices = len(self.unique_site_ids)
         k_boltzmann = 0.0861733  # meV/K
 
@@ -582,7 +559,6 @@ class HeisenbergMapper:
         Returns:
             igraph (StructureGraph): Exchange interaction graph.
         """
-
         structure = self.ordered_structures[0]
         sgraph = self.sgraphs[0]
 
@@ -598,7 +574,7 @@ class HeisenbergMapper:
             logging.warning(warning_msg)
 
         # J_ij exchange interaction matrix
-        for i, node in enumerate(sgraph.graph.nodes):
+        for i, _node in enumerate(sgraph.graph.nodes):
             connections = sgraph.get_connected_sites(i)
             for c in connections:
                 jimage = c[1]  # relative integer coordinates of atom j
@@ -632,7 +608,6 @@ class HeisenbergMapper:
         Returns:
             j_exc (float): Exchange parameter in meV
         """
-
         # Get unique site identifiers
         for k, v in self.unique_site_ids.items():
             if i in k:
@@ -671,9 +646,7 @@ class HeisenbergMapper:
 
         Returns:
             hmodel (HeisenbergModel): MSONable object.
-
         """
-
         # Original formula unit with nonmagnetic ions
         hm_formula = str(self.ordered_structures_[0].composition.reduced_formula)
 
@@ -733,7 +706,6 @@ class HeisenbergScreener:
             screened_structures (list): Sorted structures.
             screened_energies (list): Sorted energies.
         """
-
         # Cleanup
         structures, energies = self._do_cleanup(structures, energies)
 
@@ -764,9 +736,7 @@ class HeisenbergScreener:
         Returns:
             ordered_structures (list): Sanitized structures.
             ordered_energies (list): Sorted energies.
-
         """
-
         # Get only magnetic ions & give all structures site_properties['magmom']
         # zero threshold so that magnetic ions with small moments
         # are preserved
@@ -801,7 +771,7 @@ class HeisenbergScreener:
         #             remove_list.append(i)
 
         # Remove duplicates
-        if len(remove_list):
+        if len(remove_list) > 0:
             ordered_structures = [s for i, s in enumerate(ordered_structures) if i not in remove_list]
             energies = [e for i, e in enumerate(energies) if i not in remove_list]
 
@@ -824,9 +794,7 @@ class HeisenbergScreener:
         Returns:
             screened_structures (list): Sorted structures.
             screened_energies (list): Sorted energies.
-
         """
-
         magmoms = [s.site_properties["magmom"] for s in structures]
         n_below_1ub = [len([m for m in ms if abs(m) < 1]) for ms in magmoms]
 
@@ -881,7 +849,6 @@ class HeisenbergModel(MSONable):
         igraph=None,
     ):
         """
-
         Args:
             formula (str): Reduced formula of compound.
             structures (list): Structure objects with magmoms.
@@ -893,7 +860,7 @@ class HeisenbergModel(MSONable):
                 identifier.
             wyckoff_ids (dict): Maps unique numerical identifier to wyckoff
                 position.
-            nn_interacations (dict): {i: j} pairs of NN interactions
+            nn_interactions (dict): {i: j} pairs of NN interactions
                 between unique sites.
             dists (dict): NN, NNN, and NNNN interaction distances
             ex_mat (DataFrame): Invertible Heisenberg Hamiltonian for each
@@ -901,9 +868,7 @@ class HeisenbergModel(MSONable):
             ex_params (dict): Exchange parameter values (meV/atom).
             javg (float): <J> exchange param (meV/atom).
             igraph (StructureGraph): Exchange interaction graph.
-
         """
-
         self.formula = formula
         self.structures = structures
         self.energies = energies
@@ -923,10 +888,9 @@ class HeisenbergModel(MSONable):
         """
         Because some dicts have tuple keys, some sanitization is required for json compatibility.
         """
-
         d = {}
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
+        d["@module"] = type(self).__module__
+        d["@class"] = type(self).__name__
         d["@version"] = __version__
         d["formula"] = self.formula
         d["structures"] = [s.as_dict() for s in self.structures]
@@ -1023,9 +987,8 @@ class HeisenbergModel(MSONable):
         Returns:
             j_exc (float): Exchange parameter in meV
         """
-
         # Get unique site identifiers
-        for k in self.unique_site_ids.keys():
+        for k in self.unique_site_ids:
             if i in k:
                 i_index = self.unique_site_ids[k]
             if j in k:
