@@ -1,7 +1,6 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module provides classes to perform fitting of molecule with arbitrary
 atom orders.
@@ -30,11 +29,11 @@ from monty.dev import requires
 from monty.json import MSONable
 
 try:
-    from openbabel import openbabel as ob
+    from openbabel import openbabel
 
     from pymatgen.io.babel import BabelMolAdaptor
 except ImportError:
-    ob = None
+    openbabel = None
 
 from scipy.optimize import linear_sum_assignment
 from scipy.spatial.distance import cdist
@@ -69,7 +68,6 @@ class AbstractMolAtomMapper(MSONable, metaclass=abc.ABCMeta):
             order.
             (None, None) if unform atom is not available.
         """
-        pass
 
     @abc.abstractmethod
     def get_molecule_hash(self, mol):
@@ -83,7 +81,6 @@ class AbstractMolAtomMapper(MSONable, metaclass=abc.ABCMeta):
         Returns:
             A hashable object. Examples can be string formulas, etc.
         """
-        pass
 
     @classmethod
     def from_dict(cls, d):
@@ -106,8 +103,7 @@ class AbstractMolAtomMapper(MSONable, metaclass=abc.ABCMeta):
             )
             if hasattr(mod, d["@class"]):
                 class_proxy = getattr(mod, d["@class"])
-                from_dict_proxy = getattr(class_proxy, "from_dict")
-                return from_dict_proxy(d)
+                return class_proxy.from_dict(d)
         raise ValueError("Invalid Comparator dict")
 
 
@@ -143,16 +139,16 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         if h1 != h2:
             return None, None
 
-        query = ob.CompileMoleculeQuery(obmol1)
-        isomapper = ob.OBIsomorphismMapper.GetInstance(query)
-        isomorph = ob.vvpairUIntUInt()
+        query = openbabel.CompileMoleculeQuery(obmol1)
+        isomapper = openbabel.OBIsomorphismMapper.GetInstance(query)
+        isomorph = openbabel.vvpairUIntUInt()
         isomapper.MapAll(obmol2, isomorph)
 
         sorted_isomorph = [sorted(x, key=lambda morp: morp[0]) for x in isomorph]
         label2_list = tuple(tuple(p[1] + 1 for p in x) for x in sorted_isomorph)
 
         vmol1 = obmol1
-        aligner = ob.OBAlign(True, False)
+        aligner = openbabel.OBAlign(True, False)
         aligner.SetRefMol(vmol1)
         least_rmsd = float("Inf")
         best_label2 = None
@@ -164,7 +160,7 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
             elements2 = InchiMolAtomMapper._get_elements(obmol2, label2)
             if elements1 != elements2:
                 continue
-            vmol2 = ob.OBMol()
+            vmol2 = openbabel.OBMol()
             for i in label2:
                 vmol2.AddAtom(obmol2.GetAtom(i))
             aligner.SetTargetMol(vmol2)
@@ -179,9 +175,9 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         """
         Return inchi as molecular hash
         """
-        obconv = ob.OBConversion()
+        obconv = openbabel.OBConversion()
         obconv.SetOutFormat("inchi")
-        obconv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
+        obconv.AddOption("X", openbabel.OBConversion.OUTOPTIONS, "DoNotAddH")
         inchi_text = obconv.WriteString(mol)
         match = re.search(r"InChI=(?P<inchi>.+)\n", inchi_text)
         return match.group("inchi")
@@ -193,8 +189,8 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         """
         return {
             "version": __version__,
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
         }
 
     @classmethod
@@ -206,7 +202,7 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         Returns:
             IsomorphismMolAtomMapper
         """
-        return IsomorphismMolAtomMapper()
+        return cls()
 
 
 class InchiMolAtomMapper(AbstractMolAtomMapper):
@@ -229,8 +225,8 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         """
         return {
             "version": __version__,
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "angle_tolerance": self._angle_tolerance,
         }
 
@@ -243,7 +239,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         Returns:
             InchiMolAtomMapper
         """
-        return InchiMolAtomMapper(angle_tolerance=d["angle_tolerance"])
+        return cls(angle_tolerance=d["angle_tolerance"])
 
     @staticmethod
     def _inchi_labels(mol):
@@ -258,10 +254,10 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
             original label
             List of equivalent atoms.
         """
-        obconv = ob.OBConversion()
+        obconv = openbabel.OBConversion()
         obconv.SetOutFormat("inchi")
-        obconv.AddOption("a", ob.OBConversion.OUTOPTIONS)
-        obconv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
+        obconv.AddOption("a", openbabel.OBConversion.OUTOPTIONS)
+        obconv.AddOption("X", openbabel.OBConversion.OUTOPTIONS, "DoNotAddH")
         inchi_text = obconv.WriteString(mol)
         match = re.search(
             r"InChI=(?P<inchi>.+)\nAuxInfo=.+" r"/N:(?P<labels>[0-9,;]+)/(E:(?P<eq_atoms>[0-9," r";\(\)]*)/)?",
@@ -317,7 +313,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         Return:
             The virtual molecule
         """
-        vmol = ob.OBMol()
+        vmol = openbabel.OBMol()
 
         non_unique_atoms = {a for g in eq_atoms for a in g}
         all_atoms = set(range(1, len(ilabels) + 1))
@@ -363,12 +359,11 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
                 OBMol object
             ilabel1: inchi label map of the first molecule
             ilabel2: inchi label map of the second molecule
-            eq_atoms: equivalent atom lables
+            eq_atoms: equivalent atom labels
 
         Return:
             corrected inchi labels of heavy atoms of the second molecule
         """
-
         nvirtual = vmol1.NumAtoms()
         nheavy = len(ilabel1)
 
@@ -383,20 +378,20 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
             # used to align, but match by positions
             a2.SetVector(oa2.GetVector())
 
-        aligner = ob.OBAlign(False, False)
+        aligner = openbabel.OBAlign(False, False)
         aligner.SetRefMol(vmol1)
         aligner.SetTargetMol(vmol2)
         aligner.Align()
         aligner.UpdateCoords(vmol2)
 
-        canon_mol1 = ob.OBMol()
+        canon_mol1 = openbabel.OBMol()
         for i in ilabel1:
             oa1 = mol1.GetAtom(i)
             a1 = canon_mol1.NewAtom()
             a1.SetAtomicNum(oa1.GetAtomicNum())
             a1.SetVector(oa1.GetVector())
 
-        aligned_mol2 = ob.OBMol()
+        aligned_mol2 = openbabel.OBMol()
         for i in range(nvirtual + 1, nvirtual + nheavy + 1):
             oa2 = vmol2.GetAtom(i)
             a2 = aligned_mol2.NewAtom()
@@ -450,20 +445,20 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         label1 = heavy_indices1 + tuple(hydrogen_atoms1)
         label2 = heavy_indices2 + tuple(hydrogen_atoms2)
 
-        cmol1 = ob.OBMol()
+        cmol1 = openbabel.OBMol()
         for i in label1:
             oa1 = mol1.GetAtom(i)
             a1 = cmol1.NewAtom()
             a1.SetAtomicNum(oa1.GetAtomicNum())
             a1.SetVector(oa1.GetVector())
-        cmol2 = ob.OBMol()
+        cmol2 = openbabel.OBMol()
         for i in label2:
             oa2 = mol2.GetAtom(i)
             a2 = cmol2.NewAtom()
             a2.SetAtomicNum(oa2.GetAtomicNum())
             a2.SetVector(oa2.GetVector())
 
-        aligner = ob.OBAlign(False, False)
+        aligner = openbabel.OBAlign(False, False)
         aligner.SetRefMol(cmol1)
         aligner.SetTargetMol(cmol2)
         aligner.Align()
@@ -497,7 +492,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
     @staticmethod
     def _get_elements(mol, label):
         """
-        The the elements of the atoms in the specified order
+        The elements of the atoms in the specified order
 
         Args:
             mol: The molecule. OpenBabel OBMol object.
@@ -590,12 +585,12 @@ class MoleculeMatcher(MSONable):
     """
 
     @requires(
-        ob,
+        openbabel,
         "BabelMolAdaptor requires openbabel to be installed with "
         "Python bindings. Please get it at http://openbabel.org "
         "(version >=3.0.0).",
     )
-    def __init__(self, tolerance=0.01, mapper=InchiMolAtomMapper()):
+    def __init__(self, tolerance: float = 0.01, mapper=None) -> None:
         """
         Args:
             tolerance (float): RMSD difference threshold whether two molecules are
@@ -604,7 +599,7 @@ class MoleculeMatcher(MSONable):
                 molecule to uniform order
         """
         self._tolerance = tolerance
-        self._mapper = mapper
+        self._mapper = mapper or InchiMolAtomMapper()
 
     def fit(self, mol1, mol2):
         """
@@ -653,20 +648,20 @@ class MoleculeMatcher(MSONable):
         obmol1 = BabelMolAdaptor(mol1).openbabel_mol
         obmol2 = BabelMolAdaptor(mol2).openbabel_mol
 
-        cmol1 = ob.OBMol()
+        cmol1 = openbabel.OBMol()
         for i in clabel1:
             oa1 = obmol1.GetAtom(i)
             a1 = cmol1.NewAtom()
             a1.SetAtomicNum(oa1.GetAtomicNum())
             a1.SetVector(oa1.GetVector())
-        cmol2 = ob.OBMol()
+        cmol2 = openbabel.OBMol()
         for i in clabel2:
             oa2 = obmol2.GetAtom(i)
             a2 = cmol2.NewAtom()
             a2.SetAtomicNum(oa2.GetAtomicNum())
             a2.SetVector(oa2.GetVector())
 
-        aligner = ob.OBAlign(True, False)
+        aligner = openbabel.OBAlign(True, False)
         aligner.SetRefMol(cmol1)
         aligner.SetTargetMol(cmol2)
         aligner.Align()
@@ -722,8 +717,8 @@ class MoleculeMatcher(MSONable):
         """
         return {
             "version": __version__,
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "tolerance": self._tolerance,
             "mapper": self._mapper.as_dict(),
         }
@@ -737,7 +732,7 @@ class MoleculeMatcher(MSONable):
         Returns:
             MoleculeMatcher
         """
-        return MoleculeMatcher(
+        return cls(
             tolerance=d["tolerance"],
             mapper=AbstractMolAtomMapper.from_dict(d["mapper"]),
         )
@@ -840,7 +835,6 @@ class KabschMatcher(MSONable):
         Returns:
             U: 3x3 rotation matrix
         """
-
         # Computation of the cross-covariance matrix
         C = np.dot(P.T, Q)
 
@@ -884,7 +878,6 @@ class BruteForceOrderMatcher(KabschMatcher):
             V: Translation vector
             rmsd: Root mean squared deviation between P and Q
         """
-
         q = self.target
 
         if sorted(p.atomic_numbers) != sorted(q.atomic_numbers):
@@ -897,8 +890,7 @@ class BruteForceOrderMatcher(KabschMatcher):
 
         if not ignore_warning and total_permutations > 1_000_000:
             raise ValueError(
-                "The number of all possible permutations "
-                "({}) is not feasible to run this method!".format(total_permutations)
+                "The number of all possible permutations " f"({total_permutations}) is not feasible to run this method!"
             )
 
         p_coord, q_coord = p.cart_coords, q.cart_coords
@@ -951,7 +943,6 @@ class BruteForceOrderMatcher(KabschMatcher):
             p_prime: Rotated and translated of the `p` `Molecule` object
             rmsd: Root-mean-square-deviation between `p_prime` and the `target`
         """
-
         inds, U, V, rmsd = self.match(p, ignore_warning=ignore_warning)
 
         p_prime = Molecule.from_sites([p[i] for i in inds])
@@ -963,7 +954,7 @@ class BruteForceOrderMatcher(KabschMatcher):
     @staticmethod
     def permutations(atoms):
         """Generates all the possible permutations of atom order. To achieve better
-        performance all tha cases where the atoms are different has been ignored.
+        performance all the cases where the atoms are different has been ignored.
         """
         element_iterators = [itertools.permutations(np.where(atoms == element)[0]) for element in np.unique(atoms)]
 
@@ -995,7 +986,6 @@ class HungarianOrderMatcher(KabschMatcher):
             V: Translation vector
             rmsd: Root mean squared deviation between P and Q
         """
-
         if sorted(p.atomic_numbers) != sorted(self.target.atomic_numbers):
             raise ValueError("The number of the same species aren't matching!")
 
@@ -1044,7 +1034,6 @@ class HungarianOrderMatcher(KabschMatcher):
             p_prime: Rotated and translated of the `p` `Molecule` object
             rmsd: Root-mean-square-deviation between `p_prime` and the `target`
         """
-
         inds, U, V, rmsd = self.match(p)
 
         # Translate and rotate `mol1` unto `mol2` using Kabsch algorithm.
@@ -1136,7 +1125,6 @@ class HungarianOrderMatcher(KabschMatcher):
         Returns:
             Array of dim 3 containing the principal axis
         """
-
         Ixx = Iyy = Izz = Ixy = Ixz = Iyz = 0.0
 
         for (x, y, z), wt in zip(coords, weights):
@@ -1170,7 +1158,6 @@ class HungarianOrderMatcher(KabschMatcher):
         Returns:
             3x3 rotation matrix
         """
-
         if np.allclose(v1, v2):
             # same direction
             return np.eye(3)
@@ -1285,7 +1272,6 @@ class GeneticOrderMatcher(KabschMatcher):
         Returns:
             Array of index arrays
         """
-
         # caching atomic numbers and coordinates
         p_atoms, q_atoms = p.atomic_numbers, self.target.atomic_numbers
         p_coords, q_coords = p.cart_coords, self.target.cart_coords
@@ -1293,7 +1279,7 @@ class GeneticOrderMatcher(KabschMatcher):
         if sorted(p_atoms) != sorted(q_atoms):
             raise ValueError("The number of the same species aren't matching!")
 
-        # starting maches (only based on element)
+        # starting matches (only based on element)
         partial_matches = [[j] for j in range(self.N) if p_atoms[j] == q_atoms[0]]
 
         for i in range(1, self.N):
