@@ -9,9 +9,10 @@ following work::
     Ceder, The Journal of Chemical Physics 145 (7), 074112
 """
 
+from __future__ import annotations
+
 import logging
 import math
-from abc import ABCMeta
 import warnings
 
 import numpy as np
@@ -80,7 +81,7 @@ class NEBPathfinder:
         The final number of images will still be n_images.
         """
         if self.__mid is not None:
-            # to make arithmatic easier we will do the interpolation in two parts with n images each
+            # to make arithmetic easier we will do the interpolation in two parts with n images each
             # then just take every other image at the end, this results in exactly n images
             images_0 = self.__s1.interpolate(self.__mid, nimages=self.__n_images, interpolate_lattices=False)[:-1]
             images_1 = self.__mid.interpolate(self.__s2, nimages=self.__n_images, interpolate_lattices=False)
@@ -297,7 +298,7 @@ class NEBPathfinder:
     @staticmethod
     def __d2f(disc_coords, v):
         """
-        Converts a point given in discrete coordinates withe respect to the
+        Converts a point given in discrete coordinates with respect to the
         grid in v to fractional coordinates.
         """
         return np.array(
@@ -309,7 +310,7 @@ class NEBPathfinder:
         )
 
 
-class StaticPotential(metaclass=ABCMeta):
+class StaticPotential:
     """
     Defines a general static potential for diffusion calculations. Implements
     grid-rescaling and smearing for the potential grid. Also provides a
@@ -372,7 +373,7 @@ class StaticPotential(metaclass=ABCMeta):
         relatively smooth anyway). The smearing obeys periodic
         boundary conditions at the edges of the cell.
 
-        :param r - Smearing width in cartesian coordinates, in the same units
+        :param r - Smearing width in Cartesian coordinates, in the same units
             as the structure lattice vectors
         """
         # Since scaling factor in fractional coords is not isotropic, have to
