@@ -5,6 +5,8 @@
 This module provides classes that define a chemical reaction.
 """
 
+from __future__ import annotations
+
 import logging
 import re
 from itertools import chain, combinations
@@ -63,7 +65,7 @@ class BalancedReaction(MSONable):
         self._coeffs = []
         self._els = []
         self._all_comp = []
-        for c in set(list(reactants_coeffs.keys()) + list(products_coeffs.keys())):
+        for c in set(list(reactants_coeffs) + list(products_coeffs)):
             coeff = products_coeffs.get(c, 0) - reactants_coeffs.get(c, 0)
 
             if abs(coeff) > self.TOLERANCE:
@@ -180,9 +182,9 @@ class BalancedReaction(MSONable):
         """
         return self.normalized_repr_and_factor()[0]
 
-    def __eq__(self, other):
-        if other is None:
-            return False
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
         for comp in self._all_comp:
             coeff2 = other.get_coeff(comp) if comp in other._all_comp else 0
             if abs(self.get_coeff(comp) - coeff2) > self.TOLERANCE:
@@ -206,7 +208,7 @@ class BalancedReaction(MSONable):
             elif amt > cls.TOLERANCE:
                 product_str.append(f"{amt:.4g} {formula}")
 
-        return " + ".join(reactant_str) + " -> " + " + ".join(product_str)
+        return f"{' + '.join(reactant_str)} -> {' + '.join(product_str)}"
 
     @classmethod
     def _str_from_comp(cls, coeffs, compositions, reduce=False):
@@ -236,7 +238,7 @@ class BalancedReaction(MSONable):
         relevant_comp = [comp * abs(coeff) for coeff, comp in zip(self._coeffs, self._all_comp)]
         comp = sum(relevant_comp, Composition())
         entry = ComputedEntry(0.5 * comp, self.calculate_energy(energies))
-        entry.name = self.__str__()
+        entry.name = str(self)
         return entry
 
     def as_dict(self):
@@ -245,8 +247,8 @@ class BalancedReaction(MSONable):
             A dictionary representation of BalancedReaction.
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "reactants": {str(comp): coeff for comp, coeff in self.reactants_coeffs.items()},
             "products": {str(comp): coeff for comp, coeff in self.products_coeffs.items()},
         }
@@ -300,7 +302,7 @@ class Reaction(BalancedReaction):
     def __init__(self, reactants, products):
         """
         Reactants and products to be specified as list of
-        pymatgen.core.structure.Composition.  e.g., [comp1, comp2]
+        pymatgen.core.structure.Composition. e.g., [comp1, comp2]
 
         Args:
             reactants ([Composition]): List of reactants.
@@ -383,8 +385,8 @@ class Reaction(BalancedReaction):
             A dictionary representation of Reaction.
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "reactants": [comp.as_dict() for comp in self._input_reactants],
             "products": [comp.as_dict() for comp in self._input_products],
         }
@@ -478,7 +480,6 @@ class ComputedReaction(Reaction):
         Calculates the uncertainty in the reaction energy based on the uncertainty in the
         energies of the products and reactants
         """
-
         calc_energies = {}
 
         for entry in self._reactant_entries + self._product_entries:
@@ -494,8 +495,8 @@ class ComputedReaction(Reaction):
             A dictionary representation of ComputedReaction.
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "reactants": [e.as_dict() for e in self._reactant_entries],
             "products": [e.as_dict() for e in self._product_entries],
         }
