@@ -1,4 +1,4 @@
-import unittest as unittest
+import unittest
 import warnings
 
 import numpy as np
@@ -7,7 +7,10 @@ from pandas import DataFrame
 from plotly.graph_objects import Figure as plotly_figure
 from scipy.spatial import ConvexHull
 
-from pymatgen.analysis.interface_reactions import InterfacialReactivity, GrandPotentialInterfacialReactivity
+from pymatgen.analysis.interface_reactions import (
+    GrandPotentialInterfacialReactivity,
+    InterfacialReactivity,
+)
 from pymatgen.analysis.phase_diagram import GrandPotentialPhaseDiagram, PhaseDiagram
 from pymatgen.analysis.reaction_calculator import Reaction
 from pymatgen.core.composition import Composition, Element
@@ -140,13 +143,13 @@ class InterfaceReactionTest(unittest.TestCase):
             use_hull_energy=False,
         )
         with self.assertRaises(Exception) as context1:
-            ir_13 = InterfacialReactivity(Composition("Li2O2"), Composition("Li"), pd=self.gpd, norm=True)
+            _ = InterfacialReactivity(Composition("Li2O2"), Composition("Li"), pd=self.gpd, norm=True)
             self.assertTrue(
                 "Please use the GrandPotentialInterfacialReactivity "
                 "class for interfacial reactions with open elements!" == str(context1.exception)
             )
         with self.assertRaises(Exception) as context2:
-            ir_14 = GrandPotentialInterfacialReactivity(
+            _ = GrandPotentialInterfacialReactivity(
                 Composition("O2"),
                 Composition("Mn"),
                 grand_pd=self.gpd,
@@ -271,17 +274,17 @@ class InterfaceReactionTest(unittest.TestCase):
             f"_convert: conversion gets error! {answer} expected, but gets {result}",
         )
 
-    def test_get_products(self):
-        test1 = sorted(self.ir[0].get_products()) == sorted(["MnO2", "O2", "Mn"])
+    def test_products_property(self):
+        test1 = sorted(self.ir[0].products) == sorted(["MnO2", "O2", "Mn"])
         self.assertTrue(
             test1,
-            "get_products: decomposition products gets error for reaction not involving chempots species!",
+            "decomposition products gets error for reaction not involving chempots species!",
         )
 
-        test2 = sorted(self.ir[3].get_products()) == sorted(["Li", "MnO2", "Mn", "Li2O"])
+        test2 = sorted(self.ir[3].products) == sorted(["Li", "MnO2", "Mn", "Li2O"])
         self.assertTrue(
             test2,
-            "get_decomp: decomposition products gets error for reaction involving chempots species!",
+            "decomposition products gets error for reaction involving chempots species!",
         )
 
     def test_get_kinks(self):
@@ -314,10 +317,8 @@ class InterfaceReactionTest(unittest.TestCase):
             test4 = len(react_kink) == len(react_kink_expect)
             self.assertTrue(
                 test4,
-                "get_kinks: reaction kinks "
-                "gets error for {} and {} reaction!".format(
-                    ir.c1_original.reduced_formula, ir.c2_original.reduced_formula
-                ),
+                f"get_kinks: reaction kinks gets error for {ir.c1_original.reduced_formula} and "
+                f"{ir.c2_original.reduced_formula} reaction!",
             )
 
             test5 = np.allclose(energy_per_rxt_kink, energy_per_rxt_kink_expect)
@@ -421,7 +422,7 @@ class InterfaceReactionTest(unittest.TestCase):
             d_pymg,
             d_test,
             "labels:label does not match for interfacial system "
-            "with {} and {}.".format(self.ir[0].c1_original.reduced_formula, self.ir[0].c2_original.reduced_formula),
+            f"with {self.ir[0].c1_original.reduced_formula} and {self.ir[0].c2_original.reduced_formula}.",
         )
 
     def test_plot(self):
@@ -451,13 +452,8 @@ class InterfaceReactionTest(unittest.TestCase):
         for i, j in zip(self.ir, answer):
             self.assertTrue(
                 np.allclose(i.minimum, j),
-                "minimum: the system with {} and {} "
-                "gets error!{} expected, but gets {}".format(
-                    i.c1_original.reduced_formula,
-                    i.c2_original.reduced_formula,
-                    str(j),
-                    str(i.minimum),
-                ),
+                f"minimum: the system with {i.c1_original.reduced_formula} and {i.c2_original.reduced_formula} "
+                f"gets error!{j} expected, but gets {i.minimum}",
             )
 
     def test_get_no_mixing_energy(self):
@@ -486,7 +482,7 @@ class InterfaceReactionTest(unittest.TestCase):
                 np.allclose(energy_lst(i), energy_lst(j)),
                 "get_no_mixing_energy: "
                 "no_mixing energies get error, "
-                "{} expected but gets {}".format(energy_lst(j), energy_lst(i)),
+                f"{energy_lst(j)} expected but gets {energy_lst(i)}",
             )
 
     def test_get_chempot_correction(self):
