@@ -4,15 +4,13 @@ import os
 import unittest
 import warnings
 from math import pi
+from shutil import which
+from typing import get_args
 
 import numpy as np
 import pytest
-from monty.os.path import which
 
-from pymatgen.core.periodic_table import Element
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Molecule, Structure
-from pymatgen.analysis.graphs import MoleculeGraph
+from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
 from pymatgen.analysis.local_env import (
     BrunnerNN_real,
     BrunnerNN_reciprocal,
@@ -22,6 +20,7 @@ from pymatgen.analysis.local_env import (
     CrystalNN,
     CutOffDictNN,
     EconNN,
+    IsayevNN,
     JmolNN,
     LocalStructOrderParams,
     MinimumDistanceNN,
@@ -32,14 +31,15 @@ from pymatgen.analysis.local_env import (
     ValenceIonicRadiusEvaluator,
     VoronoiNN,
     get_neighbors_of_site_with_index,
+    metal_edge_extender,
+    on_disorder_options,
     site_is_of_motif_type,
     solid_angle,
-    IsayevNN,
-    metal_edge_extender,
 )
+from pymatgen.core import Lattice, Molecule, Structure
+from pymatgen.core.periodic_table import Element
 from pymatgen.util.testing import PymatgenTest
 
-
 test_dir = os.path.join(PymatgenTest.TEST_FILES_DIR, "fragmenter_files")
 
 
@@ -90,8 +90,11 @@ class VoronoiNNTest(PymatgenTest):
         self.assertEqual(len(self.nn.get_voronoi_polyhedra(self.s, 0).items()), 8)
 
     def test_get_cn(self):
-        self.assertAlmostEqual(self.nn.get_cn(self.s, 0, use_weights=True), 5.809265748999465, 7)
-        self.assertAlmostEqual(self.nn_sic.get_cn(self.s_sic, 0, use_weights=True), 4.5381161643940668, 7)
+        site_0_coord_num = self.nn.get_cn(self.s, 0, use_weights=True, on_disorder="take_max_species")
+        self.assertAlmostEqual(site_0_coord_num, 5.809265748999465, 7)
+
+        site_0_coord_num = self.nn_sic.get_cn(self.s_sic, 0, use_weights=True, on_disorder="take_max_species")
+        self.assertAlmostEqual(site_0_coord_num, 4.5381161643940668, 7)
 
     def test_get_coordinated_sites(self):
         self.assertEqual(len(self.nn.get_nn(self.s, 0)), 8)
@@ -169,7 +172,7 @@ class VoronoiNNTest(PymatgenTest):
         neighbors = self.nn.get_voronoi_polyhedra(s, 0)
 
         # Each neighbor has 4 adjacent neighbors, all orthogonal
-        for nn_key, nn_info in neighbors.items():
+        for nn_info in neighbors.values():
             self.assertEqual(4, len(nn_info["adj_neighbors"]))
 
             for adj_key in nn_info["adj_neighbors"]:
@@ -312,8 +315,8 @@ class OpenBabelNNTest(PymatgenTest):
         self.acetylene = Molecule.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "acetylene.xyz"))
 
     def test_nn_orders(self):
-        strat = OpenBabelNN()
-        acetylene = strat.get_nn_info(self.acetylene, 0)
+        strategy = OpenBabelNN()
+        acetylene = strategy.get_nn_info(self.acetylene, 0)
         self.assertEqual(acetylene[0]["weight"], 3)
         self.assertEqual(acetylene[1]["weight"], 1)
 
@@ -322,14 +325,14 @@ class OpenBabelNNTest(PymatgenTest):
         # Instead of searching for aromatic bonds, we check that bonds are
         # detected in the same way from both sides
         self.assertEqual(
-            strat.get_nn_info(self.benzene, 0)[0]["weight"],
-            strat.get_nn_info(self.benzene, 1)[0]["weight"],
+            strategy.get_nn_info(self.benzene, 0)[0]["weight"],
+            strategy.get_nn_info(self.benzene, 1)[0]["weight"],
         )
 
     def test_nn_length(self):
-        strat = OpenBabelNN(order=False)
+        strategy = OpenBabelNN(order=False)
 
-        benzene_bonds = strat.get_nn_info(self.benzene, 0)
+        benzene_bonds = strategy.get_nn_info(self.benzene, 0)
 
         c_bonds = [b for b in benzene_bonds if str(b["site"].specie) == "C"]
         h_bonds = [b for b in benzene_bonds if str(b["site"].specie) == "H"]
@@ -337,7 +340,7 @@ class OpenBabelNNTest(PymatgenTest):
         self.assertAlmostEqual(c_bonds[0]["weight"], 1.41, 2)
         self.assertAlmostEqual(h_bonds[0]["weight"], 1.02, 2)
 
-        self.assertAlmostEqual(strat.get_nn_info(self.acetylene, 0)[0]["weight"], 1.19, 2)
+        self.assertAlmostEqual(strategy.get_nn_info(self.acetylene, 0)[0]["weight"], 1.19, 2)
 
     def tearDown(self):
         del self.benzene
@@ -350,19 +353,19 @@ class CovalentBondNNTest(PymatgenTest):
         self.acetylene = Molecule.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "acetylene.xyz"))
 
     def test_nn_orders(self):
-        strat = CovalentBondNN()
+        strategy = CovalentBondNN()
 
-        acetylene = strat.get_nn_info(self.acetylene, 0)
+        acetylene = strategy.get_nn_info(self.acetylene, 0)
         self.assertEqual(acetylene[0]["weight"], 3)
         self.assertEqual(acetylene[1]["weight"], 1)
 
-        benzene = strat.get_nn_info(self.benzene, 0)
+        benzene = strategy.get_nn_info(self.benzene, 0)
         self.assertAlmostEqual(benzene[0]["weight"], 1.6596, places=4)
 
     def test_nn_length(self):
-        strat = CovalentBondNN(order=False)
+        strategy = CovalentBondNN(order=False)
 
-        benzene_bonds = strat.get_nn_info(self.benzene, 0)
+        benzene_bonds = strategy.get_nn_info(self.benzene, 0)
 
         c_bonds = [b for b in benzene_bonds if str(b["site"].specie) == "C"]
         h_bonds = [b for b in benzene_bonds if str(b["site"].specie) == "H"]
@@ -370,16 +373,16 @@ class CovalentBondNNTest(PymatgenTest):
         self.assertAlmostEqual(c_bonds[0]["weight"], 1.41, 2)
         self.assertAlmostEqual(h_bonds[0]["weight"], 1.02, 2)
 
-        acetylene = strat.get_nn_info(self.acetylene, 0)
+        acetylene = strategy.get_nn_info(self.acetylene, 0)
         self.assertAlmostEqual(acetylene[0]["weight"], 1.19, places=2)
 
     def test_bonded_structure(self):
-        strat = CovalentBondNN()
+        strategy = CovalentBondNN()
 
-        benzene = strat.get_bonded_structure(self.benzene)
+        benzene = strategy.get_bonded_structure(self.benzene)
         self.assertEqual(len(benzene.find_rings()), 1)
 
-        acetylene = strat.get_bonded_structure(self.acetylene)
+        acetylene = strategy.get_bonded_structure(self.acetylene)
         self.assertEqual(len(acetylene.graph.nodes), 4)
 
     def tearDown(self):
@@ -632,6 +635,14 @@ class NearNeighborTest(PymatgenTest):
                 self.assertEqual(nn_info[0]["site_index"], 1)
                 self.assertEqual(nn_info[0]["image"][0], 1)
 
+    def test_on_disorder_options(self):
+        assert get_args(on_disorder_options) == (
+            "take_majority_strict",
+            "take_majority_drop",
+            "take_max_species",
+            "error",
+        )
+
     def tearDown(self):
         del self.diamond
 
@@ -1062,7 +1073,7 @@ class LocalStructOrderParamsTest(PymatgenTest):
         ops_099 = LocalStructOrderParams(op_types, parameters=op_params, cutoff=0.99)
         ops_101 = LocalStructOrderParams(op_types, parameters=op_params, cutoff=1.01)
         ops_501 = LocalStructOrderParams(op_types, parameters=op_params, cutoff=5.01)
-        ops_voro = LocalStructOrderParams(op_types, parameters=op_params)
+        _ = LocalStructOrderParams(op_types, parameters=op_params)
 
         # Single bond.
         op_vals = ops_101.get_order_parameters(self.single_bond, 0)
@@ -1264,6 +1275,13 @@ class CrystalNNTest(PymatgenTest):
         self.prev_warnings = warnings.filters
         warnings.simplefilter("ignore")
 
+        self.disordered_struct = Structure(
+            Lattice.cubic(3), [{"Fe": 0.4, "C": 0.3, "Mn": 0.3}, "O"], [[0, 0, 0], [0.5, 0.5, 0.5]]
+        )
+        self.disordered_struct_with_majority = Structure(
+            Lattice.cubic(3), [{"Fe": 0.6, "C": 0.4}, "O"], [[0, 0, 0], [0.5, 0.5, 0.5]]
+        )
+
     def tearDown(self):
         warnings.filters = self.prev_warnings
 
@@ -1279,36 +1297,7 @@ class CrystalNNTest(PymatgenTest):
     def test_discrete_cn(self):
         cnn = CrystalNN()
         cn_array = []
-        expected_array = [
-            6,
-            6,
-            6,
-            6,
-            6,
-            6,
-            6,
-            6,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-            4,
-        ]
+        expected_array = 8 * [6] + 20 * [4]
         for idx, _ in enumerate(self.lifepo4):
             cn_array.append(cnn.get_cn(self.lifepo4, idx))
 
@@ -1318,36 +1307,13 @@ class CrystalNNTest(PymatgenTest):
         cnn = CrystalNN(weighted_cn=True)
         cn_array = []
 
+        # fmt: off
         expected_array = [
-            5.863,
-            5.8716,
-            5.863,
-            5.8716,
-            5.7182,
-            5.7182,
-            5.719,
-            5.7181,
-            3.991,
-            3.991,
-            3.991,
-            3.9907,
-            3.5997,
-            3.525,
-            3.4133,
-            3.4714,
-            3.4727,
-            3.4133,
-            3.525,
-            3.5997,
-            3.5997,
-            3.525,
-            3.4122,
-            3.4738,
-            3.4728,
-            3.4109,
-            3.5259,
-            3.5997,
+            5.863, 5.8716, 5.863, 5.8716, 5.7182, 5.7182, 5.719, 5.7181, 3.991, 3.991, 3.991,
+            3.9907, 3.5997, 3.525, 3.4133, 3.4714, 3.4727, 3.4133, 3.525, 3.5997, 3.5997, 3.525,
+            3.4122, 3.4738, 3.4728, 3.4109, 3.5259, 3.5997,
         ]
+        # fmt: on
         for idx, _ in enumerate(self.lifepo4):
             cn_array.append(cnn.get_cn(self.lifepo4, idx, use_weights=True))
 
@@ -1356,36 +1322,13 @@ class CrystalNNTest(PymatgenTest):
     def test_weighted_cn_no_oxid(self):
         cnn = CrystalNN(weighted_cn=True)
         cn_array = []
+        # fmt: off
         expected_array = [
-            5.8962,
-            5.8996,
-            5.8962,
-            5.8996,
-            5.7195,
-            5.7195,
-            5.7202,
-            5.7194,
-            4.0012,
-            4.0012,
-            4.0012,
-            4.0009,
-            3.3897,
-            3.2589,
-            3.1218,
-            3.1914,
-            3.1914,
-            3.1218,
-            3.2589,
-            3.3897,
-            3.3897,
-            3.2589,
-            3.1207,
-            3.1924,
-            3.1915,
-            3.1207,
-            3.2598,
-            3.3897,
+            5.8962, 5.8996, 5.8962, 5.8996, 5.7195, 5.7195, 5.7202, 5.7194, 4.0012, 4.0012,
+            4.0012, 4.0009, 3.3897, 3.2589, 3.1218, 3.1914, 3.1914, 3.1218, 3.2589, 3.3897,
+            3.3897, 3.2589, 3.1207, 3.1924, 3.1915, 3.1207, 3.2598, 3.3897,
         ]
+        # fmt: on
         s = self.lifepo4.copy()
         s.remove_oxidation_states()
         for idx, _ in enumerate(s):
@@ -1431,6 +1374,41 @@ class CrystalNNTest(PymatgenTest):
             len(bonded_struct_shifted.get_connected_sites(0)),
         )
 
+    def test_get_cn(self):
+        cnn = CrystalNN()
+
+        site_0_coord_num = cnn.get_cn(self.disordered_struct, 0, on_disorder="take_max_species")
+        site_0_coord_num_strict_majority = cnn.get_cn(
+            self.disordered_struct_with_majority, 0, on_disorder="take_majority_strict"
+        )
+        assert site_0_coord_num == 8
+        assert site_0_coord_num == site_0_coord_num_strict_majority
+
+        self.assertRaises(ValueError, cnn.get_cn, self.disordered_struct, 0, on_disorder="take_majority_strict")
+        self.assertRaises(ValueError, cnn.get_cn, self.disordered_struct, 0, on_disorder="error")
+
+    def test_get_bonded_structure(self):
+        cnn = CrystalNN()
+
+        structure_graph = cnn.get_bonded_structure(self.disordered_struct, on_disorder="take_max_species")
+        structure_graph_strict_majority = cnn.get_bonded_structure(
+            self.disordered_struct_with_majority, on_disorder="take_majority_strict"
+        )
+        structure_graph_drop_majority = cnn.get_bonded_structure(
+            self.disordered_struct_with_majority, on_disorder="take_majority_drop"
+        )
+
+        assert isinstance(structure_graph, StructureGraph)
+        assert len(structure_graph) == 2
+        assert structure_graph == structure_graph_strict_majority == structure_graph_drop_majority
+
+        self.assertRaises(
+            ValueError, cnn.get_bonded_structure, self.disordered_struct, 0, on_disorder="take_majority_strict"
+        )
+        self.assertRaises(ValueError, cnn.get_bonded_structure, self.disordered_struct, 0, on_disorder="error")
+
+        self.assertRaises(ValueError, cnn.get_bonded_structure, self.disordered_struct, 0, on_disorder="error")
+
 
 class CutOffDictNNTest(PymatgenTest):
     def setUp(self):
@@ -1477,16 +1455,14 @@ class Critic2NNTest(PymatgenTest):
         warnings.filters = self.prev_warnings
 
     def test_cn(self):
-        nn = Critic2NN()
+        Critic2NN()
         # self.assertEqual(nn.get_cn(self.diamond, 0), 4)
 
 
 class MetalEdgeExtenderTest(PymatgenTest):
     def setUp(self):
         self.LiEC = Molecule.from_file(os.path.join(test_dir, "LiEC.xyz"))
-
-    def test_metal_edge_extender(self):
-        mol_graph = MoleculeGraph.with_edges(
+        self.LiEC_graph = MoleculeGraph.with_edges(
             molecule=self.LiEC,
             edges={
                 (0, 2): None,
@@ -1502,10 +1478,63 @@ class MetalEdgeExtenderTest(PymatgenTest):
                 (5, 10): None,
             },
         )
-        self.assertEqual(len(mol_graph.graph.edges), 11)
-        extended_mol_graph = metal_edge_extender(mol_graph)
+
+        # potassium + 7 H2O. 4 at ~2.5 Ang and 3 more within 4.25 Ang
+        uncharged_K_cluster = Molecule.from_file(os.path.join(test_dir, "water_cluster_K.xyz"))
+        K_sites = [s.coords for s in uncharged_K_cluster.sites]
+        K_species = [s.species for s in uncharged_K_cluster.sites]
+        charged_K_cluster = Molecule(K_species, K_sites, charge=1)
+        self.water_cluster_K = MoleculeGraph.with_empty_graph(charged_K_cluster)
+        assert len(self.water_cluster_K.graph.edges) == 0
+
+        # Mg + 6 H2O at 1.94 Ang from Mg
+        uncharged_Mg_cluster = Molecule.from_file(os.path.join(test_dir, "water_cluster_Mg.xyz"))
+        Mg_sites = [s.coords for s in uncharged_Mg_cluster.sites]
+        Mg_species = [s.species for s in uncharged_Mg_cluster.sites]
+        charged_Mg_cluster = Molecule(Mg_species, Mg_sites, charge=2)
+        self.water_cluster_Mg = MoleculeGraph.with_empty_graph(charged_Mg_cluster)
+
+    def test_metal_edge_extender(self):
+        self.assertEqual(len(self.LiEC_graph.graph.edges), 11)
+        extended_mol_graph = metal_edge_extender(self.LiEC_graph)
         self.assertEqual(len(extended_mol_graph.graph.edges), 12)
 
+    def test_custom_metals(self):
+        extended_mol_graph = metal_edge_extender(self.LiEC_graph, metals={"K"})
+        self.assertEqual(len(extended_mol_graph.graph.edges), 11)
+
+        # empty metals should exit cleanly with no change to graph
+        mol_graph = metal_edge_extender(self.water_cluster_K, metals={}, cutoff=2.5)
+        self.assertEqual(len(mol_graph.graph.edges), 0)
+
+        mol_graph = metal_edge_extender(self.water_cluster_K, metals={"K"}, cutoff=2.5)
+        self.assertEqual(len(mol_graph.graph.edges), 4)
+
+        extended_graph = metal_edge_extender(self.water_cluster_K, metals={"K"}, cutoff=4.5)
+        self.assertEqual(len(extended_graph.graph.edges), 7)
+
+        # if None, should auto-detect Li
+        extended_mol_graph = metal_edge_extender(self.LiEC_graph, metals=None)
+        self.assertEqual(len(extended_mol_graph.graph.edges), 12)
+
+    def test_custom_coordinators(self):
+        # leave out Oxygen, graph should not change
+        extended_mol_graph = metal_edge_extender(self.LiEC_graph, coordinators={"N", "F", "S", "Cl"})
+        self.assertEqual(len(extended_mol_graph.graph.edges), 11)
+        # empty coordinators should exit cleanly with no change
+        extended_mol_graph = metal_edge_extender(self.LiEC_graph, coordinators={})
+        self.assertEqual(len(extended_mol_graph.graph.edges), 11)
+
+    def test_custom_cutoff(self):
+        short_mol_graph = metal_edge_extender(self.LiEC_graph, cutoff=0.5)
+        self.assertEqual(len(short_mol_graph.graph.edges), 11)
+
+        # with a cutoff of 1.5, no edges should be found.
+        # test that the 2nd pass analysis (auto increasing cutoff to 2.5) picks
+        # up the six coordination bonds
+        short_mol_graph = metal_edge_extender(self.water_cluster_Mg, cutoff=1.5)
+        self.assertEqual(len(short_mol_graph.graph.edges), 6)
+
 
 if __name__ == "__main__":
     unittest.main()
