@@ -25,6 +25,7 @@ import numpy as np
 import plotly.graph_objs as go
 from scipy.spatial import ConvexHull
 
+from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.util.coord import get_angle
 from pymatgen.util.string import unicodeify_spacegroup
@@ -165,7 +166,7 @@ class WulffShape:
 
     """
 
-    def __init__(self, lattice, miller_list, e_surf_list, symprec=1e-5):
+    def __init__(self, lattice: Lattice, miller_list, e_surf_list, symprec=1e-5):
         """
         Args:
             lattice: Lattice object of the conventional unit cell
@@ -173,7 +174,6 @@ class WulffShape:
             e_surf_list ([float]): list of corresponding surface energies
             symprec (float): for recp_operation, default is 1e-5.
         """
-
         if any(se < 0 for se in e_surf_list):
             warnings.warn("Unphysical (negative) surface energy detected.")
 
@@ -301,7 +301,7 @@ class WulffShape:
             plane.outer_lines = [line for line in plane.outer_lines if plane.outer_lines.count(line) != 2]
         return on_wulff, surface_area
 
-    def _get_colors(self, color_set, alpha, off_color, custom_colors={}):
+    def _get_colors(self, color_set, alpha, off_color, custom_colors=None):
         """
         assign colors according to the surface energies of on_wulff facets.
 
@@ -332,7 +332,7 @@ class WulffShape:
 
         for i, e_surf in e_surf_on_wulff:
             color_list[i] = scalar_map.to_rgba(e_surf, alpha=alpha)
-            if tuple(self.miller_list[i]) in custom_colors.keys():
+            if tuple(self.miller_list[i]) in custom_colors:
                 color_list[i] = custom_colors[tuple(self.miller_list[i])]
             color_proxy_on_wulff.append(plt.Rectangle((2, 2), 1, 1, fc=color_list[i], alpha=alpha))
             miller_on_wulff.append(self.input_miller_fig[i])
@@ -348,7 +348,7 @@ class WulffShape:
         )
 
     def show(self, *args, **kwargs):
-        r"""
+        """
         Show the Wulff plot.
 
         Args:
@@ -361,25 +361,24 @@ class WulffShape:
         """
         Returns the sorted pts in a facet used to draw a line
         """
-
         lines = list(facet.outer_lines)
         pt = []
         prev = None
         while len(lines) > 0:
             if prev is None:
-                l = lines.pop(0)
+                line = lines.pop(0)
             else:
-                for i, l in enumerate(lines):
-                    if prev in l:
-                        l = lines.pop(i)
-                        if l[1] == prev:
-                            l.reverse()
+                for i, line in enumerate(lines):
+                    if prev in line:
+                        line = lines.pop(i)
+                        if line[1] == prev:
+                            line.reverse()
                         break
             # make sure the lines are connected one by one.
             # find the way covering all pts and facets
-            pt.append(self.wulff_pt_list[l[0]].tolist())
-            pt.append(self.wulff_pt_list[l[1]].tolist())
-            prev = l[1]
+            pt.append(self.wulff_pt_list[line[0]].tolist())
+            pt.append(self.wulff_pt_list[line[1]].tolist())
+            prev = line[1]
 
         return pt
 
@@ -397,7 +396,7 @@ class WulffShape:
         units_in_JPERM2=True,
         legend_on=True,
         aspect_ratio=(8, 8),
-        custom_colors={},
+        custom_colors=None,
     ):
         """
         Get the Wulff shape plot.
@@ -405,7 +404,7 @@ class WulffShape:
         Args:
             color_set: default is 'PuBu'
             grid_off (bool): default is True
-            axis_off (bool): default is Ture
+            axis_off (bool): default is True
             show_area (bool): default is False
             alpha (float): chosen from 0 to 1 (float), default is 1
             off_color: Default color for facets not present on the Wulff shape.
@@ -435,7 +434,7 @@ class WulffShape:
             color_proxy_on_wulff,
             miller_on_wulff,
             e_surf_on_wulff,
-        ) = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors)
+        ) = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors or {})
 
         if not direction:
             # If direction is not specified, use the miller indices of
@@ -519,7 +518,7 @@ class WulffShape:
                 orientation="vertical",
             )
             units = "$J/m^2$" if units_in_JPERM2 else r"$eV/\AA^2$"
-            cbar.set_label("Surface Energies (%s)" % (units), fontsize=25)
+            cbar.set_label(f"Surface Energies ({units})", fontsize=25)
 
         if grid_off:
             ax.grid("off")
@@ -532,7 +531,7 @@ class WulffShape:
         color_set="PuBu",
         off_color="red",
         alpha=1,
-        custom_colors={},
+        custom_colors=None,
         units_in_JPERM2=True,
     ):
         """
@@ -553,7 +552,6 @@ class WulffShape:
         Return:
             (plotly.graph_objs.Figure)
         """
-
         units = "Jm⁻²" if units_in_JPERM2 else "eVÅ⁻²"
         (
             color_list,
@@ -561,7 +559,7 @@ class WulffShape:
             color_proxy_on_wulff,
             miller_on_wulff,
             e_surf_on_wulff,
-        ) = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors)
+        ) = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors or {})
 
         planes_data, color_scale, ticktext, tickvals = [], [], [], []
         for plane in self.facets:
@@ -590,7 +588,8 @@ class WulffShape:
             tri_indices = np.array(list(itertools.combinations(index_list, 3))).T
             hkl = self.miller_list[plane.index]
             hkl = unicodeify_spacegroup("(" + "%s" * len(hkl) % hkl + ")")
-            color = "rgba(%.5f, %.5f, %.5f, %.5f)" % tuple(np.array(plane_color) * 255)
+            cs = tuple(np.array(plane_color) * 255)
+            color = f"rgba({cs[0]:.5f}, {cs[1]:.5f}, {cs[2]:.5f}, {cs[3]:.5f})"
 
             # note hoverinfo is incompatible with latex, need unicode instead
             planes_data.append(
@@ -601,9 +600,9 @@ class WulffShape:
                     i=tri_indices[0],
                     j=tri_indices[1],
                     k=tri_indices[2],
-                    hovertemplate="<br>%{text}<br>" + "{}={:.3f} {}<br>".format("\u03b3", plane.e_surf, units),
+                    hovertemplate=f"<br>%{{text}}<br>γ={plane.e_surf:.3f} {units}<br>",
                     color=color,
-                    text=[r"Miller index: %s" % hkl] * len(x_pts),
+                    text=[f"Miller index: {hkl}"] * len(x_pts),
                     hoverinfo="name",
                     name="",
                 )
@@ -614,7 +613,7 @@ class WulffShape:
             c = [norm_e, color]
             if c not in color_scale:
                 color_scale.append(c)
-                ticktext.append("%.3f" % plane.e_surf)
+                ticktext.append(f"{plane.e_surf:.3f}")
                 tickvals.append(norm_e)
 
         # Add colorbar
@@ -625,7 +624,7 @@ class WulffShape:
             z=[0],
             colorbar=go.ColorBar(
                 title={
-                    "text": r"Surface energy %s" % units,
+                    "text": f"Surface energy {units}",
                     "side": "right",
                     "font": {"size": 25},
                 },
@@ -796,12 +795,12 @@ class WulffShape:
             pt = self.get_line_in_facet(facet)
 
             lines = []
-            for i, p in enumerate(pt):
-                if i == len(pt) / 2:
+            for idx, _ in enumerate(pt):
+                if idx == len(pt) / 2:
                     break
-                lines.append(tuple(sorted(tuple([tuple(pt[i * 2]), tuple(pt[i * 2 + 1])]))))
+                lines.append(tuple(sorted(tuple([tuple(pt[idx * 2]), tuple(pt[idx * 2 + 1])]))))
 
-            for i, p in enumerate(lines):
+            for p in lines:
                 if p not in all_edges:
                     edges.append(p)
 
