@@ -29,31 +29,34 @@ appropriate (e.g. the two nucleus critical points linked to
 If you use this module, please cite the following:
 
 A. Otero-de-la-Roza, E. R. Johnson and V. Luaña,
-Comput. Phys. Commun. 185, 1007-1018 (2014)
+Comput. Phys. Communications 185, 1007-1018 (2014)
 (https://doi.org/10.1016/j.cpc.2013.10.026)
 
 A. Otero-de-la-Roza, M. A. Blanco, A. Martín Pendás and
-V. Luaña, Comput. Phys. Commun. 180, 157–166 (2009)
+V. Luaña, Comput. Phys. Communications 180, 157-166 (2009)
 (https://doi.org/10.1016/j.cpc.2008.07.018)
 """
 
+from __future__ import annotations
+
+import glob
 import logging
 import os
 import subprocess
 import warnings
 from enum import Enum
+from shutil import which
 
 import numpy as np
 from monty.dev import requires
 from monty.json import MSONable
-from monty.os.path import which
 from monty.serialization import loadfn
 from monty.tempfile import ScratchDir
 from scipy.spatial import KDTree
 
 from pymatgen.analysis.graphs import StructureGraph
-from pymatgen.command_line.bader_caller import get_filepath
 from pymatgen.core.periodic_table import DummySpecies
+from pymatgen.core.structure import Structure
 from pymatgen.io.vasp.inputs import Potcar
 from pymatgen.io.vasp.outputs import Chgcar, VolumetricData
 
@@ -77,7 +80,6 @@ class Critic2Caller:
 
         :param input_script: string defining the critic2 input
         """
-
         # store if examining the input script is useful,
         # not otherwise used
         self._input_script = input_script
@@ -146,7 +148,7 @@ class Critic2Caller:
         * CPEPS, float (Bohr units in crystals), minimum distance between
           critical points for them to be equivalent
         * NUCEPS, same as CPEPS but specifically for nucleus critical
-          points (critic2 default is depedent on grid dimensions)
+          points (critic2 default is dependent on grid dimensions)
         * NUCEPSH, same as NUCEPS but specifically for hydrogen nuclei
           since associated charge density can be significantly displaced
           from hydrogen nucleus
@@ -176,7 +178,6 @@ class Critic2Caller:
         (ZVAL in VASP pseudopotential), with which to properly augment core regions
         and calculate charge transfer. Optional.
         """
-
         settings = {"CPEPS": 0.1, "SEED": ["WS", "PAIR DIST 10"]}
         if user_input_settings:
             settings.update(user_input_settings)
@@ -192,7 +193,7 @@ class Critic2Caller:
         if chgcar:
             input_script += ["load int.CHGCAR id chg_int", "integrable chg_int"]
             if zpsp:
-                zpsp_str = " zpsp " + " ".join([f"{symbol} {int(zval)}" for symbol, zval in zpsp.items()])
+                zpsp_str = " zpsp " + " ".join([f"{symbol} {zval}" for symbol, zval in zpsp.items()])
                 input_script[-2] += zpsp_str
 
         # Command to run automatic analysis
@@ -269,7 +270,6 @@ class Critic2Caller:
         :param zpsp: manually specify ZPSP if POTCAR not present
         :return:
         """
-
         chgcar_path = get_filepath("CHGCAR", "Could not find CHGCAR!", path, suffix)
         chgcar = Chgcar.from_file(chgcar_path)
         chgcar_ref = None
@@ -322,6 +322,29 @@ class CriticalPointType(Enum):
     nnattr = "nnattr"  # (3, -3), non-nuclear attractor
 
 
+def get_filepath(filename, warning, path, suffix):
+    """
+    Args:
+        filename: Filename
+        warning: Warning message
+        path: Path to search
+        suffix: Suffixes to search.
+    """
+    paths = glob.glob(os.path.join(path, filename + suffix + "*"))
+    if not paths:
+        warnings.warn(warning)
+        return None
+    if len(paths) > 1:
+        # using reverse=True because, if multiple files are present,
+        # they likely have suffixes 'static', 'relax', 'relax2', etc.
+        # and this would give 'static' over 'relax2' over 'relax'
+        # however, better to use 'suffix' kwarg to avoid this!
+        paths.sort(reverse=True)
+        warnings.warn(f"Multiple files detected, using {os.path.basename(path)}")
+    path = paths[0]
+    return path
+
+
 class CriticalPoint(MSONable):
     """
     Access information about a critical point and the field values at that point.
@@ -348,8 +371,8 @@ class CriticalPoint(MSONable):
 
         :param index: index of point
         :param type: type of point, given as a string
-        :param coords: Cartesian co-ordinates in Angstroms
-        :param frac_coords: fractional co-ordinates
+        :param coords: Cartesian coordinates in Angstroms
+        :param frac_coords: fractional coordinates
         :param point_group: point group associated with critical point
         :param multiplicity: number of equivalent critical points
         :param field: value of field at point (f)
@@ -402,7 +425,7 @@ class Critic2Analysis(MSONable):
     Class to process the standard output from critic2 into pymatgen-compatible objects.
     """
 
-    def __init__(self, structure, stdout=None, stderr=None, cpreport=None, yt=None, zpsp=None):
+    def __init__(self, structure: Structure, stdout=None, stderr=None, cpreport=None, yt=None, zpsp=None):
         """
         This class is used to store results from the Critic2Caller.
 
@@ -439,7 +462,6 @@ class Critic2Analysis(MSONable):
         (ZVAL in VASP pseudopotential), with which to calculate charge transfer.
         Optional.
         """
-
         self.structure = structure
 
         self._stdout = stdout
@@ -448,8 +470,8 @@ class Critic2Analysis(MSONable):
         self._yt = yt
         self._zpsp = zpsp
 
-        self.nodes = {}
-        self.edges = {}
+        self.nodes: dict[int, dict] = {}
+        self.edges: dict[int, dict] = {}
 
         if yt:
             self.structure = self._annotate_structure_with_yt(yt, structure, zpsp)
@@ -475,7 +497,6 @@ class Critic2Analysis(MSONable):
 
         Returns: a StructureGraph
         """
-
         structure = self.structure.copy()
 
         point_idx_to_struct_idx = {}
@@ -527,13 +548,8 @@ class Critic2Analysis(MSONable):
                                 "interested in rings/cages."
                             )
                             logger.debug(
-                                "Duplicate edge between points {} (unique point {})"
-                                "and {} ({}).".format(
-                                    idx,
-                                    self.nodes[idx]["unique_idx"],
-                                    idx2,
-                                    self.nodes[idx2]["unique_idx"],
-                                )
+                                f"Duplicate edge between points {idx} (unique point {self.nodes[idx]['unique_idx']})"
+                                f"and {idx2} ({self.nodes[idx2]['unique_idx']})."
                             )
         # and remove any duplicate bonds present
         for idx in idx_to_delete:
@@ -588,10 +604,10 @@ class Critic2Analysis(MSONable):
 
         return sg
 
-    def get_critical_point_for_site(self, n):
+    def get_critical_point_for_site(self, n: int):
         """
         Args:
-            n: Site index n
+            n (int): Site index
 
         Returns: A CriticalPoint instance
         """
@@ -643,19 +659,19 @@ class Critic2Analysis(MSONable):
             for p in cpreport["critical_points"]["nonequivalent_cps"]
         ]
 
-        for idx, p in enumerate(cpreport["critical_points"]["cell_cps"]):
+        for point in cpreport["critical_points"]["cell_cps"]:
             self._add_node(
-                idx=p["id"] - 1,
-                unique_idx=p["nonequivalent_id"] - 1,
-                frac_coords=p["fractional_coordinates"],
+                idx=point["id"] - 1,
+                unique_idx=point["nonequivalent_id"] - 1,
+                frac_coords=point["fractional_coordinates"],
             )
-            if "attractors" in p:
+            if "attractors" in point:
                 self._add_edge(
-                    idx=p["id"] - 1,
-                    from_idx=int(p["attractors"][0]["cell_id"]) - 1,
-                    from_lvec=p["attractors"][0]["lvec"],
-                    to_idx=int(p["attractors"][1]["cell_id"]) - 1,
-                    to_lvec=p["attractors"][1]["lvec"],
+                    idx=point["id"] - 1,
+                    from_idx=int(point["attractors"][0]["cell_id"]) - 1,
+                    from_lvec=point["attractors"][0]["lvec"],
+                    to_idx=int(point["attractors"][1]["cell_id"]) - 1,
+                    to_lvec=point["attractors"][1]["lvec"],
                 )
 
     def _remap_indices(self):
@@ -663,7 +679,6 @@ class Critic2Analysis(MSONable):
         Re-maps indices on self.nodes and self.edges such that node indices match
         that of structure, and then sorts self.nodes by index.
         """
-
         # Order of nuclei provided by critic2 doesn't
         # necessarily match order of sites in Structure.
         # This is because critic2 performs a symmetrization step.
@@ -681,8 +696,8 @@ class Critic2Analysis(MSONable):
 
         if len(node_mapping) != len(self.structure):
             warnings.warn(
-                "Check that all sites in input structure ({}) have "
-                "been detected by critic2 ({}).".format(len(self.structure), len(node_mapping))
+                f"Check that all sites in input structure ({len(self.structure)}) have "
+                f"been detected by critic2 ({ len(node_mapping)})."
             )
 
         self.nodes = {node_mapping.get(idx, idx): node for idx, node in self.nodes.items()}
@@ -692,7 +707,7 @@ class Critic2Analysis(MSONable):
             edge["to_idx"] = node_mapping.get(edge["to_idx"], edge["to_idx"])
 
     @staticmethod
-    def _annotate_structure_with_yt(yt, structure, zpsp):
+    def _annotate_structure_with_yt(yt, structure: Structure, zpsp):
 
         volume_idx = None
         charge_idx = None
@@ -719,9 +734,7 @@ class Critic2Analysis(MSONable):
         for idx, site in enumerate(yt["structure"]["cell_atoms"]):
             if not np.allclose(structure[idx].frac_coords, site["fractional_coordinates"]):
                 raise IndexError(
-                    "Site in structure doesn't seem to match site in YT integration:\n{}\n{}".format(
-                        structure[idx], site
-                    )
+                    f"Site in structure doesn't seem to match site in YT integration:\n{structure[idx]}\n{site}"
                 )
             volume, charge = get_volume_and_charge(site["nonequivalent_id"])
             volumes.append(volume)
@@ -731,9 +744,8 @@ class Critic2Analysis(MSONable):
                     charge_transfer.append(charge - zpsp[structure[idx].species_string])
                 else:
                     raise ValueError(
-                        "ZPSP argument does not seem compatible with species in structure ({}): {}".format(
-                            structure[idx].species_string, zpsp
-                        )
+                        f"ZPSP argument does not seem compatible with species in structure "
+                        f"({structure[idx].species_string}): {zpsp}"
                     )
 
         structure = structure.copy()
@@ -866,7 +878,7 @@ class Critic2Analysis(MSONable):
         :param idx: index
         :param unique_idx: index of unique CriticalPoint,
             used to look up more information of point (field etc.)
-        :param frac_coord: fractional co-ordinates of point
+        :param frac_coord: fractional coordinates of point
         :return:
         """
         self.nodes[idx] = {"unique_idx": unique_idx, "frac_coords": frac_coords}
