@@ -1,7 +1,6 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 Interface with command line GULP.
 http://projects.ivec.org
@@ -245,12 +244,12 @@ class GulpIO:
 
     @staticmethod
     def keyword_line(*args):
-        r"""
+        """
         Checks if the input args are proper gulp keywords and
         generates the 1st line of gulp input. Full keywords are expected.
 
         Args:
-            \\*args: 1st line keywords
+            args: 1st line keywords
         """
         # if len(list(filter(lambda x: x in _gulp_kw, args))) != len(args):
         #    raise GulpError("Wrong keywords given")
@@ -260,12 +259,12 @@ class GulpIO:
 
     @staticmethod
     def structure_lines(
-        structure,
-        cell_flg=True,
-        frac_flg=True,
-        anion_shell_flg=True,
-        cation_shell_flg=False,
-        symm_flg=True,
+        structure: Structure,
+        cell_flg: bool = True,
+        frac_flg: bool = True,
+        anion_shell_flg: bool = True,
+        cation_shell_flg: bool = False,
+        symm_flg: bool = True,
     ):
         """
         Generates GULP input string corresponding to pymatgen structure.
@@ -274,10 +273,10 @@ class GulpIO:
             structure: pymatgen Structure object
             cell_flg (default = True): Option to use lattice parameters.
             fractional_flg (default = True): If True, fractional coordinates
-                are used. Else, cartesian coodinates in Angstroms are used.
+                are used. Else, Cartesian coordinates in Angstroms are used.
                 ******
                 GULP convention is to use fractional coordinates for periodic
-                structures and cartesian coordinates for non-periodic
+                structures and Cartesian coordinates for non-periodic
                 structures.
                 ******
             anion_shell_flg (default = True): If True, anions are considered
@@ -293,8 +292,10 @@ class GulpIO:
         gin = ""
         if cell_flg:
             gin += "cell\n"
-            l = structure.lattice
-            lat_str = f"{l.a:6f} {l.b:6f} {l.c:6f} {l.alpha:6f} {l.beta:6f} {l.gamma:6f}"
+            lattice = structure.lattice
+            alpha, beta, gamma = lattice.angles
+            a, b, c = lattice.lengths
+            lat_str = f"{a:6f} {b:6f} {c:6f} {alpha:6f} {beta:6f} {gamma:6f}"
             gin += lat_str + "\n"
 
         if frac_flg:
@@ -321,14 +322,14 @@ class GulpIO:
 
     @staticmethod
     def specie_potential_lines(structure, potential, **kwargs):
-        r"""
+        """
         Generates GULP input specie and potential string for pymatgen
         structure.
 
         Args:
             structure: pymatgen.core.structure.Structure object
             potential: String specifying the type of potential used
-            \\*\\*kwargs: Additional parameters related to potential. For
+            kwargs: Additional parameters related to potential. For
                 potential == "buckingham",
                 anion_shell_flg (default = False):
                 If True, anions are considered polarizable.
@@ -359,7 +360,7 @@ class GulpIO:
         Returns:
             GULP input string specifying library option
         """
-        gulplib_set = "GULP_LIB" in os.environ.keys()
+        gulplib_set = "GULP_LIB" in os.environ
 
         def readable(f):
             return os.path.isfile(f) and os.access(f, os.R_OK)
@@ -380,7 +381,7 @@ class GulpIO:
             return gin + "\n"
         raise GulpError("GULP Library not found")
 
-    def buckingham_input(self, structure, keywords, library=None, uc=True, valence_dict=None):
+    def buckingham_input(self, structure: Structure, keywords, library=None, uc=True, valence_dict=None):
         """
         Gets a GULP input for an oxide structure and buckingham potential
         from library.
@@ -433,10 +434,10 @@ class GulpIO:
         bpb = BuckinghamPotential("bush")
         bpl = BuckinghamPotential("lewis")
         gin = ""
-        for key in val_dict.keys():
+        for key in val_dict:
             use_bush = True
             el = re.sub(r"[1-9,+,\-]", "", key)
-            if el not in bpb.species_dict.keys():
+            if el not in bpb.species_dict:
                 use_bush = False
             elif val_dict[key] != bpb.species_dict[el]["oxi"]:
                 use_bush = False
@@ -453,7 +454,7 @@ class GulpIO:
             # use_lewis = True
             if el != "O":  # For metals the key is "Metal_OxiState+"
                 k = el + "_" + str(int(val_dict[key])) + "+"
-                if k not in bpl.species_dict.keys():
+                if k not in bpl.species_dict:
                     # use_lewis = False
                     raise GulpError(f"Element {k} not in library")
                 gin += "species\n"
@@ -472,7 +473,7 @@ class GulpIO:
                 gin += bpl.spring_dict[key]
         return gin
 
-    def tersoff_input(self, structure, periodic=False, uc=True, *keywords):
+    def tersoff_input(self, structure: Structure, periodic=False, uc=True, *keywords):
         """
         Gets a GULP input with Tersoff potential for an oxide structure
 
@@ -845,7 +846,7 @@ class BuckinghamPotential:
                 elmnt = row.split()[0]
                 if sp_flg:
                     if bush_lewis_flag == "bush":
-                        if elmnt not in species_dict.keys():
+                        if elmnt not in species_dict:
                             species_dict[elmnt] = {"inp_str": "", "oxi": 0}
                         species_dict[elmnt]["inp_str"] += row
                         species_dict[elmnt]["oxi"] += float(row.split()[2])
@@ -878,8 +879,8 @@ class BuckinghamPotential:
 
             if bush_lewis_flag == "bush":
                 # Fill the null keys in spring dict with empty strings
-                for key in pot_dict.keys():
-                    if key not in spring_dict.keys():
+                for key in pot_dict:
+                    if key not in spring_dict:
                         spring_dict[key] = ""
 
             self.species_dict = species_dict
