@@ -6,15 +6,16 @@ This module implements a Composition class to represent compositions,
 and a ChemicalPotential class to represent potentials.
 """
 
+from __future__ import annotations
+
 import collections
-import numbers
 import os
 import re
 import string
 import warnings
 from functools import total_ordering
 from itertools import combinations_with_replacement, product
-from typing import Dict, Generator, List, Tuple, Union
+from typing import Generator, Iterator, Union, cast
 
 from monty.fractions import gcd, gcd_float
 from monty.json import MSONable
@@ -90,8 +91,8 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
 
     oxi_prob = None  # prior probability of oxidation used by oxi_state_guesses
 
-    def __init__(self, *args, strict: bool = False, **kwargs):
-        r"""
+    def __init__(self, *args, strict: bool = False, **kwargs) -> None:
+        """
         Very flexible Composition construction, similar to the built-in Python
         dict(). Also extended to allow simple string init.
 
@@ -117,60 +118,67 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 ambiguity.
         """
         self.allow_negative = kwargs.pop("allow_negative", False)
-        # it's much faster to recognize a composition and use the elmap than
+        # it's much faster to recognize a composition and use the el_map than
         # to pass the composition to {}
         if len(args) == 1 and isinstance(args[0], Composition):
-            elmap = args[0]
+            elem_map = args[0]
         elif len(args) == 1 and isinstance(args[0], str):
-            elmap = self._parse_formula(args[0])  # type: ignore
+            elem_map = self._parse_formula(args[0])  # type: ignore
         else:
-            elmap = dict(*args, **kwargs)  # type: ignore
-        elamt = {}
+            elem_map = dict(*args, **kwargs)  # type: ignore
+        elem_amt = {}
         self._natoms = 0
-        for k, v in elmap.items():
+        for k, v in elem_map.items():
             if v < -Composition.amount_tolerance and not self.allow_negative:
                 raise ValueError("Amounts in Composition cannot be negative!")
             if abs(v) >= Composition.amount_tolerance:
-                elamt[get_el_sp(k)] = v
+                elem_amt[get_el_sp(k)] = v
                 self._natoms += abs(v)
-        self._data = elamt
+        self._data = elem_amt
         if strict and not self.valid:
-            raise ValueError("Composition is not valid, contains: {}".format(", ".join(map(str, self.elements))))
+            raise ValueError(f"Composition is not valid, contains: {', '.join(map(str, self.elements))}")
 
-    def __getitem__(self, item: SpeciesLike):
+    def __getitem__(self, item: SpeciesLike) -> float:
         try:
             sp = get_el_sp(item)
             return self._data.get(sp, 0)
         except ValueError as ex:
             raise TypeError(f"Invalid key {item}, {type(item)} for Composition\nValueError exception:\n{ex}")
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._data)
 
-    def __iter__(self):
-        return self._data.keys().__iter__()
+    def __iter__(self) -> Iterator[Species | Element | DummySpecies]:
+        return self._data.__iter__()
 
-    def __contains__(self, item):
+    def __contains__(self, item) -> bool:
         try:
             sp = get_el_sp(item)
             return sp in self._data
         except ValueError as ex:
             raise TypeError(f"Invalid key {item}, {type(item)} for Composition\nValueError exception:\n{ex}")
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        """Defines == for Compositions."""
+        if not isinstance(other, (Composition, dict)):
+            return NotImplemented
+
         #  elements with amounts < Composition.amount_tolerance don't show up
-        #  in the elmap, so checking len enables us to only check one
-        #  compositions elements
+        #  in the el_map, so checking len enables us to only check one
+        #  composition's elements
         if len(self) != len(other):
             return False
 
-        return all(abs(v - other[el]) <= Composition.amount_tolerance for el, v in self.items())
+        return all(abs(amt - other[el]) <= Composition.amount_tolerance for el, amt in self.items())
 
-    def __ge__(self, other):
+    def __ge__(self, other: object) -> bool:
         """
         Defines >= for Compositions. Should ONLY be used for defining a sort
-        order (the behavior is probably not what you'd expect)
+        order (the behavior is probably not what you'd expect).
         """
+        if not isinstance(other, Composition):
+            return NotImplemented
+
         for el in sorted(set(self.elements + other.elements)):
             if other[el] - self[el] >= Composition.amount_tolerance:
                 return False
@@ -178,21 +186,21 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 return True
         return True
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def __add__(self, other):
+    def __add__(self, other: object) -> Composition:
         """
         Adds two compositions. For example, an Fe2O3 composition + an FeO
         composition gives a Fe3O4 composition.
         """
-        new_el_map = collections.defaultdict(float)
+        if not isinstance(other, (Composition, dict)):
+            return NotImplemented
+
+        new_el_map: dict[SpeciesLike, float] = collections.defaultdict(float)
         new_el_map.update(self)
         for k, v in other.items():
             new_el_map[get_el_sp(k)] += v
         return Composition(new_el_map, allow_negative=self.allow_negative)
 
-    def __sub__(self, other):
+    def __sub__(self, other: object) -> Composition:
         """
         Subtracts two compositions. For example, an Fe2O3 composition - an FeO
         composition gives an FeO2 composition.
@@ -202,35 +210,38 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             original composition in any of its elements, unless allow_negative
             is True
         """
-        new_el_map = collections.defaultdict(float)
+        if not isinstance(other, (Composition, dict)):
+            return NotImplemented
+
+        new_el_map: dict[SpeciesLike, float] = collections.defaultdict(float)
         new_el_map.update(self)
         for k, v in other.items():
             new_el_map[get_el_sp(k)] -= v
         return Composition(new_el_map, allow_negative=self.allow_negative)
 
-    def __mul__(self, other):
+    def __mul__(self, other: object) -> Composition:
         """
         Multiply a Composition by an integer or a float.
         Fe2O3 * 4 -> Fe8O12
         """
-        if not isinstance(other, numbers.Number):
+        if not isinstance(other, (int, float)):
             return NotImplemented
         return Composition({el: self[el] * other for el in self}, allow_negative=self.allow_negative)
 
     __rmul__ = __mul__
 
-    def __truediv__(self, other):
-        if not isinstance(other, numbers.Number):
+    def __truediv__(self, other: object) -> Composition:
+        if not isinstance(other, (int, float)):
             return NotImplemented
         return Composition({el: self[el] / other for el in self}, allow_negative=self.allow_negative)
 
     __div__ = __truediv__
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         """
-        hash based on the chemical system
+        Hash based on the chemical system
         """
-        return hash(frozenset(self._data.keys()))
+        return hash(frozenset(self._data))
 
     @property
     def average_electroneg(self) -> float:
@@ -246,7 +257,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         return sum((el.Z * abs(amt) for el, amt in self.items()))
 
-    def almost_equals(self, other: "Composition", rtol: float = 0.1, atol: float = 1e-8) -> bool:
+    def almost_equals(self, other: Composition, rtol: float = 0.1, atol: float = 1e-8) -> bool:
         """
         Returns true if compositions are equal within a tolerance.
 
@@ -267,11 +278,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     @property
     def is_element(self) -> bool:
         """
-        True if composition is for an element.
+        True if composition is an element.
         """
         return len(self) == 1
 
-    def copy(self) -> "Composition":
+    def copy(self) -> Composition:
         """
         :return: A copy of the composition.
         """
@@ -284,7 +295,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         e.g., Li4 Fe4 P4 O16.
         """
         sym_amt = self.get_el_amt_dict()
-        syms = sorted(sym_amt.keys(), key=lambda sym: get_el_sp(sym).X)
+        syms = sorted(sym_amt, key=lambda sym: get_el_sp(sym).X)
         formula = [s + formula_double_format(sym_amt[s], False) for s in syms]
         return " ".join(formula)
 
@@ -303,17 +314,17 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         electronegativity ordering defined in Table VI of "Nomenclature of
         Inorganic Chemistry (IUPAC Recommendations 2005)". This ordering
         effectively follows the groups and rows of the periodic table, except
-        the Lanthanides, Actanides and hydrogen. Polyanions are still determined
+        the Lanthanides, Actinides and hydrogen. Polyanions are still determined
         based on the true electronegativity of the elements.
         e.g. CH2(SO4)2
         """
         sym_amt = self.get_el_amt_dict()
-        syms = sorted(sym_amt.keys(), key=lambda s: get_el_sp(s).iupac_ordering)
+        syms = sorted(sym_amt, key=lambda s: get_el_sp(s).iupac_ordering)
         formula = [s + formula_double_format(sym_amt[s], False) for s in syms]
         return " ".join(formula)
 
     @property
-    def element_composition(self) -> "Composition":
+    def element_composition(self) -> Composition:
         """
         Returns the composition replacing any species by the corresponding
         element.
@@ -321,26 +332,23 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         return Composition(self.get_el_amt_dict(), allow_negative=self.allow_negative)
 
     @property
-    def fractional_composition(self) -> "Composition":
+    def fractional_composition(self) -> Composition:
         """
-        Returns the normalized composition which the number of species sum to
+        Returns the normalized composition in which the amounts of each species sum to
         1.
-
-        Returns:
-            Normalized composition which the number of species sum to 1.
+        E.g. "Fe2 O3".fractional_composition = "Fe0.4 O0.6".
         """
         return self / self._natoms
 
     @property
-    def reduced_composition(self) -> "Composition":
+    def reduced_composition(self) -> Composition:
         """
-        Returns the reduced composition,i.e. amounts normalized by greatest
-        common denominator. e.g., Composition("FePO4") for
-        Composition("Fe4P4O16").
+        Returns the reduced composition, i.e. amounts normalized by greatest common denominator.
+        E.g. "Fe4 P4 O16".reduced_composition = "Fe P O4".
         """
         return self.get_reduced_composition_and_factor()[0]
 
-    def get_reduced_composition_and_factor(self) -> Tuple["Composition", float]:
+    def get_reduced_composition_and_factor(self) -> tuple[Composition, float]:
         """
         Calculates a reduced composition and factor.
 
@@ -351,7 +359,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         factor = self.get_reduced_formula_and_factor()[1]
         return self / factor, factor
 
-    def get_reduced_formula_and_factor(self, iupac_ordering: bool = False) -> Tuple[str, float]:
+    def get_reduced_formula_and_factor(self, iupac_ordering: bool = False) -> tuple[str, float]:
         """
         Calculates a reduced formula and factor.
 
@@ -361,7 +369,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 Table VI of "Nomenclature of Inorganic Chemistry (IUPAC
                 Recommendations 2005)". This ordering effectively follows
                 the groups and rows of the periodic table, except the
-                Lanthanides, Actanides and hydrogen. Note that polyanions
+                Lanthanides, Actinides and hydrogen. Note that polyanions
                 will still be determined based on the true electronegativity of
                 the elements.
 
@@ -383,7 +391,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
 
     def get_integer_formula_and_factor(
         self, max_denominator: int = 10000, iupac_ordering: bool = False
-    ) -> Tuple[str, float]:
+    ) -> tuple[str, float]:
         """
         Calculates an integer formula and factor.
 
@@ -395,7 +403,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 Table VI of "Nomenclature of Inorganic Chemistry (IUPAC
                 Recommendations 2005)". This ordering effectively follows
                 the groups and rows of the periodic table, except the
-                Lanthanides, Actanides and hydrogen. Note that polyanions
+                Lanthanides, Actinides and hydrogen. Note that polyanions
                 will still be determined based on the true electronegativity of
                 the elements.
 
@@ -434,19 +442,19 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         alphabetically.
         """
         c = self.element_composition
-        elements = sorted(el.symbol for el in c.keys())
+        elements = sorted(el.symbol for el in c)
         if "C" in elements:
             elements = ["C"] + [el for el in elements if el != "C"]
 
-        formula = ["{}{}".format(el, formula_double_format(c[el]) if c[el] != 1 else "") for el in elements]
+        formula = [f"{el}{formula_double_format(c[el]) if c[el] != 1 else ''}" for el in elements]
         return " ".join(formula)
 
     @property
-    def elements(self) -> List[Union[Element, Species, DummySpecies]]:
+    def elements(self) -> list[Element | Species | DummySpecies]:
         """
         Returns view of elements in Composition.
         """
-        return list(self.keys())
+        return list(self)
 
     def __str__(self):
         return " ".join([f"{k}{formula_double_format(v, ignore_ones=False)}" for k, v in self.as_dict().items()])
@@ -456,7 +464,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Returns:
             str: Same as output __str__() but without spaces.
         """
-        return re.sub(r"\s+", "", self.__str__())
+        return re.sub(r"\s+", "", str(self))
 
     @property
     def num_atoms(self) -> float:
@@ -490,12 +498,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Calculate weight fraction of an Element or Species.
 
         Args:
-            el (Element/Species): Element or Species to get fraction for.
+            el (Element | Species): Element or Species to get fraction for.
 
         Returns:
-            Weight fraction for element el in Composition
+            float: Weight fraction for element el in Composition.
         """
-        return get_el_sp(el).atomic_mass * abs(self[el]) / self.weight
+        el_mass = cast(float, get_el_sp(el).atomic_mass)
+        return el_mass * abs(self[el]) / self.weight
 
     def contains_element_type(self, category: str) -> bool:
         """
@@ -510,7 +519,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Returns:
             True if any elements in Composition match category, otherwise False
         """
-
         allowed_categories = (
             "noble_gas",
             "transition_metal",
@@ -532,13 +540,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         )
 
         if category not in allowed_categories:
-            raise ValueError("Please pick a category from: {}".format(", ".join(allowed_categories)))
+            raise ValueError(f"Please pick a category from: {allowed_categories}")
 
         if "block" in category:
             return any(category[0] in el.block for el in self.elements)
         return any(getattr(el, f"is_{category}") for el in self.elements)
 
-    def _parse_formula(self, formula: str) -> Dict[str, float]:
+    def _parse_formula(self, formula: str) -> dict[str, float]:
         """
         Args:
             formula (str): A string formula, e.g. Fe2O3, Li3Fe2(PO4)3
@@ -553,8 +561,8 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         # for Metallofullerene like "Y3N@C80"
         formula = formula.replace("@", "")
 
-        def get_sym_dict(form: str, factor: Union[int, float]) -> Dict[str, float]:
-            sym_dict: Dict[str, float] = collections.defaultdict(float)
+        def get_sym_dict(form: str, factor: int | float) -> dict[str, float]:
+            sym_dict: dict[str, float] = collections.defaultdict(float)
             for m in re.finditer(r"([A-Z][a-z]*)\s*([-*\.e\d]*)", form):
                 el = m.group(1)
                 amt = 1.0
@@ -622,7 +630,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         return "Comp: " + self.formula
 
     @classmethod
-    def from_dict(cls, d) -> "Composition":
+    def from_dict(cls, d) -> Composition:
         """
         Creates a composition from a dict generated by as_dict(). Strictly not
         necessary given that the standard constructor already takes in such an
@@ -635,24 +643,24 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         return cls(d)
 
-    def get_el_amt_dict(self) -> Dict[str, float]:
+    def get_el_amt_dict(self) -> dict[str, float]:
         """
         Returns:
-            Dict with element symbol and (unreduced) amount e.g.,
+            dict[str, float]: element symbol and (unreduced) amount. E.g.
             {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
-        d: Dict[str, float] = collections.defaultdict(float)
-        for e, a in self.items():
-            d[e.symbol] += a
-        return d
+        dic: dict[str, float] = collections.defaultdict(float)
+        for el, amt in self.items():
+            dic[el.symbol] += amt
+        return dic
 
-    def as_dict(self) -> Dict[str, float]:
+    def as_dict(self) -> dict[str, float]:
         """
         Returns:
             dict with species symbol and (unreduced) amount e.g.,
             {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
-        d: Dict[str, float] = collections.defaultdict(float)
+        d: dict[str, float] = collections.defaultdict(float)
         for e, a in self.items():
             d[str(e)] += a
         return d
@@ -678,8 +686,8 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             "reduced_cell_composition": self.get_reduced_composition_and_factor()[0],
             "unit_cell_composition": self.as_dict(),
             "reduced_cell_formula": self.reduced_formula,
-            "elements": list(self.as_dict().keys()),
-            "nelements": len(self.as_dict().keys()),
+            "elements": list(self.as_dict()),
+            "nelements": len(self.as_dict()),
         }
 
     def oxi_state_guesses(
@@ -688,7 +696,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         target_charge: float = 0,
         all_oxi_states: bool = False,
         max_sites: int = None,
-    ) -> List[Dict[str, float]]:
+    ) -> list[dict[str, float]]:
         """
         Checks if the composition is charge-balanced and returns back all
         charge-balanced oxidation state combinations. Composition must have
@@ -721,10 +729,9 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 oxidation state across all sites in that composition. If the
                 composition is not charge balanced, an empty list is returned.
         """
-
         return self._get_oxid_state_guesses(all_oxi_states, max_sites, oxi_states_override, target_charge)[0]
 
-    def replace(self, elem_map: Dict[str, Union[str, Dict[str, Union[int, float]]]]) -> "Composition":
+    def replace(self, elem_map: dict[str, str | dict[str, int | float]]) -> Composition:
         """
         Replace elements in a composition. Returns a new Composition, leaving the old one unchanged.
 
@@ -736,7 +743,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Returns:
             Composition: New object with elements remapped according to elem_map.
         """
-
         # drop inapplicable substitutions
         invalid_elems = [key for key in elem_map if key not in self]
         if invalid_elems:
@@ -747,16 +753,34 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         for elem in invalid_elems:
             elem_map.pop(elem)
 
-        new_comp = self.as_dict()
+        # start with elements that remain unchanged (not in elem_map)
+        new_comp = {elem: amount for elem, amount in self.as_dict().items() if elem not in elem_map}
 
         for old_elem, new_elem in elem_map.items():
-            amount = new_comp.pop(old_elem)
 
+            amount = self[old_elem]
+
+            # build a dictionary of substitutions to be made
+            subs = {}
             if isinstance(new_elem, dict):
                 for el, factor in new_elem.items():
-                    new_comp[el] = factor * amount
+                    subs[el] = factor * amount
             else:
-                new_comp[new_elem] = amount
+                subs = {new_elem: amount}
+
+            # and apply the substitutions to the new composition
+            for el, amt in subs.items():
+                if el in new_comp:
+                    new_comp[el] += amt
+                else:
+                    new_comp[el] = amt
+
+                # check for ambiguous input (see issue #2553)
+                if el in self:
+                    warnings.warn(
+                        f"Same element ({el}) in both the keys and values of the substitution!"
+                        "This can be ambiguous, so be sure to check your result."
+                    )
 
         return Composition(new_comp)
 
@@ -766,13 +790,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         target_charge: float = 0,
         all_oxi_states: bool = False,
         max_sites: int = None,
-    ) -> "Composition":
+    ) -> Composition:
         """
-        Assign oxidation states basedon guessed oxidation states.
+        Assign oxidation states based on guessed oxidation states.
 
         See `oxi_state_guesses` for an explanation of how oxidation states are
         guessed. This operation uses the set of oxidation states for each site
-        that were determined to be most likley from the oxidation state guessing
+        that were determined to be most likely from the oxidation state guessing
         routine.
 
         Args:
@@ -798,7 +822,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             on the results form guessing oxidation states. If no oxidation state
             is possible, returns a Composition where all oxidation states are 0.
         """
-
         _, oxidation_states = self._get_oxid_state_guesses(
             all_oxi_states, max_sites, oxi_states_override, target_charge
         )
@@ -815,7 +838,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         # Return the new object
         return Composition(collections.Counter(species))
 
-    def remove_charges(self) -> "Composition":
+    def remove_charges(self) -> Composition:
         """
         Removes the charges from any species in a Composition object.
 
@@ -823,7 +846,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             Composition object without charge decoration, for example
             {"Fe3+": 2.0, "O2-":3.0} becomes {"Fe": 2.0, "O":3.0}
         """
-        d: Dict[Element, float] = collections.defaultdict(float)
+        d: dict[Element, float] = collections.defaultdict(float)
         for e, a in self.items():
             d[Element(e.symbol)] += a
         return Composition(d)
@@ -861,7 +884,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 oxidation states for each site of that element. For example, Fe3O4 could
                 return a list of [2,2,2,3,3,3] for the oxidation states of If the composition
                 is
-
         """
         comp = self.copy()
         # reduce Composition if necessary
@@ -892,11 +914,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         # for each element, determine all possible sum of oxidations
         # (taking into account nsites for that particular element)
         el_amt = comp.get_el_amt_dict()
-        els = el_amt.keys()
+        elements = list(el_amt)
         el_sums = []  # matrix: dim1= el_idx, dim2=possible sums
         el_sum_scores = collections.defaultdict(set)  # dict of el_idx, sum -> score
         el_best_oxid_combo = {}  # dict of el_idx, sum -> oxid combo with best score
-        for idx, el in enumerate(els):
+        for idx, el in enumerate(elements):
             el_sum_scores[idx] = {}
             el_best_oxid_combo[idx] = {}
             el_sums.append([])
@@ -933,7 +955,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         for x in product(*el_sums):
             # each x is a trial of one possible oxidation sum for each element
             if sum(x) == target_charge:  # charge balance condition
-                el_sum_sol = dict(zip(els, x))  # element->oxid_sum
+                el_sum_sol = dict(zip(elements, x))  # element->oxid_sum
                 # normalize oxid_sum by amount to get avg oxid state
                 sol = {el: v / el_amt[el] for el, v in el_sum_sol.items()}
                 # add the solution to the list of solutions
@@ -946,26 +968,26 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 all_scores.append(score)
 
                 # collect the combination of oxidation states for each site
-                all_oxid_combo.append({e: el_best_oxid_combo[idx][v] for idx, (e, v) in enumerate(zip(els, x))})
+                all_oxid_combo.append({e: el_best_oxid_combo[idx][v] for idx, (e, v) in enumerate(zip(elements, x))})
 
         # sort the solutions by highest to lowest score
         if all_scores:
             all_sols, all_oxid_combo = zip(
-                *[
+                *(
                     (y, x)
                     for (z, y, x) in sorted(
                         zip(all_scores, all_sols, all_oxid_combo),
                         key=lambda pair: pair[0],
                         reverse=True,
                     )
-                ]
+                )
             )
         return all_sols, all_oxid_combo
 
     @staticmethod
     def ranked_compositions_from_indeterminate_formula(
         fuzzy_formula: str, lock_if_strict: bool = True
-    ) -> List["Composition"]:
+    ) -> list[Composition]:
         """
         Takes in a formula where capitalization might not be correctly entered,
         and suggests a ranked list of potential Composition matches.
@@ -982,7 +1004,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Returns:
             A ranked list of potential Composition matches
         """
-
         # if we have an exact match and the user specifies lock_if_strict, just
         # return the exact match!
         if lock_if_strict:
@@ -1005,10 +1026,10 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     @staticmethod
     def _comps_from_fuzzy_formula(
         fuzzy_formula: str,
-        m_dict: Dict[str, float] = None,
+        m_dict: dict[str, float] = None,
         m_points: int = 0,
-        factor: Union[int, float] = 1,
-    ) -> Generator[Tuple["Composition", int], None, None]:
+        factor: int | float = 1,
+    ) -> Generator[tuple[Composition, int], None, None]:
         """
         A recursive helper method for formula parsing that helps in
         interpreting and ranking indeterminate formulas.
@@ -1052,7 +1073,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                 number of points returned for chomping. Returns
                 (None, None, None) if no element could be found...
             """
-
             points = 0
             # Points awarded if the first element of the element is correctly
             # specified as a capital
@@ -1146,7 +1166,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
                         yield match
 
 
-def reduce_formula(sym_amt, iupac_ordering: bool = False) -> Tuple[str, float]:
+def reduce_formula(sym_amt, iupac_ordering: bool = False) -> tuple[str, float]:
     """
     Helper method to reduce a sym_amt dict to a reduced formula and factor.
 
@@ -1164,7 +1184,7 @@ def reduce_formula(sym_amt, iupac_ordering: bool = False) -> Tuple[str, float]:
     Returns:
         (reduced_formula, factor).
     """
-    syms = sorted(sym_amt.keys(), key=lambda x: [get_el_sp(x).X, x])
+    syms = sorted(sym_amt, key=lambda x: [get_el_sp(x).X, x])
 
     syms = list(filter(lambda x: abs(sym_amt[x]) > Composition.amount_tolerance, syms))
 
@@ -1180,7 +1200,7 @@ def reduce_formula(sym_amt, iupac_ordering: bool = False) -> Tuple[str, float]:
         (poly_form, poly_factor) = reduce_formula(poly_sym_amt, iupac_ordering=iupac_ordering)
 
         if poly_factor != 1:
-            polyanion.append(f"({poly_form}){int(poly_factor)}")
+            polyanion.append(f"({poly_form}){poly_factor}")
 
     syms = syms[: len(syms) - 2 if polyanion else len(syms)]
 
@@ -1213,31 +1233,31 @@ class ChemicalPotential(dict, MSONable):
         if len(d) != len(self):
             raise ValueError("Duplicate potential specified")
 
-    def __mul__(self, other):
-        if isinstance(other, numbers.Number):
+    def __mul__(self, other: object) -> ChemicalPotential:
+        if isinstance(other, (int, float)):
             return ChemicalPotential({k: v * other for k, v in self.items()})
-        raise NotImplementedError()
+        return NotImplemented
 
     __rmul__ = __mul__
 
-    def __truediv__(self, other):
-        if isinstance(other, numbers.Number):
+    def __truediv__(self, other: object) -> ChemicalPotential:
+        if isinstance(other, (int, float)):
             return ChemicalPotential({k: v / other for k, v in self.items()})
-        raise NotImplementedError()
+        return NotImplemented
 
     __div__ = __truediv__
 
-    def __sub__(self, other):
+    def __sub__(self, other: object) -> ChemicalPotential:
         if isinstance(other, ChemicalPotential):
-            els = set(self.keys()).union(other.keys())
+            els = set(self).union(other)
             return ChemicalPotential({e: self.get(e, 0) - other.get(e, 0) for e in els})
-        raise NotImplementedError()
+        return NotImplemented
 
-    def __add__(self, other):
+    def __add__(self, other: object) -> ChemicalPotential:
         if isinstance(other, ChemicalPotential):
-            els = set(self.keys()).union(other.keys())
+            els = set(self).union(other)
             return ChemicalPotential({e: self.get(e, 0) + other.get(e, 0) for e in els})
-        raise NotImplementedError()
+        return NotImplemented
 
     def get_energy(self, composition: Composition, strict: bool = True) -> float:
         """
@@ -1247,8 +1267,8 @@ class ChemicalPotential(dict, MSONable):
             composition (Composition): input composition
             strict (bool): Whether all potentials must be specified
         """
-        if strict and set(composition.keys()) > set(self.keys()):
-            s = set(composition.keys()) - set(self.keys())
+        if strict and set(composition) > set(self):
+            s = set(composition) - set(self)
             raise ValueError(f"Potentials not specified for {s}")
         return sum(self.get(k, 0) * v for k, v in composition.items())
 
