@@ -2,16 +2,19 @@
 # Distributed under the terms of the MIT License.
 
 """Module contains classes presenting Element and Species (Element + oxidation state) and PeriodicTable."""
+
+from __future__ import annotations
+
 import ast
+import functools
 import json
 import re
-import sys
 import warnings
 from collections import Counter
 from enum import Enum
 from itertools import combinations, product
 from pathlib import Path
-from typing import Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Literal
 
 import numpy as np
 from monty.json import MSONable
@@ -19,11 +22,6 @@ from monty.json import MSONable
 from pymatgen.core.units import SUPPORTED_UNIT_NAMES, FloatWithUnit, Length, Mass, Unit
 from pymatgen.util.string import Stringify, formula_double_format
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 # Loads element data from json file
 with open(str(Path(__file__).absolute().parent / "periodic_table.json")) as f:
     _pt_data = json.load(f)
@@ -31,6 +29,7 @@ with open(str(Path(__file__).absolute().parent / "periodic_table.json")) as f:
 _pt_row_sizes = (2, 8, 8, 18, 18, 32, 32)
 
 
+@functools.total_ordering
 class ElementBase(Enum):
     """Element class defined without any enum values so it can be subclassed."""
 
@@ -187,7 +186,7 @@ class ElementBase(Enum):
             energy, etc. Note that this is zero-based indexing! So Element.ionization_energies[0] refer to the 1st
             ionization energy. Values are from the NIST Atomic Spectra Database. Missing values are None.
         """
-        self.symbol = "%s" % symbol
+        self.symbol = symbol
         d = _pt_data[symbol]
 
         # Store key variables for quick access
@@ -211,29 +210,37 @@ class ElementBase(Enum):
         if "X" in self._data:
             return self._data["X"]
         warnings.warn(
-            "No electronegativity for %s. Setting to NaN. "
-            "This has no physical meaning, and is mainly done to "
-            "avoid errors caused by the code expecting a float." % self.symbol
+            f"No electronegativity for {self.symbol}. Setting to NaN. This has no physical meaning, "
+            "and is mainly done to avoid errors caused by the code expecting a float."
         )
         return float("NaN")
 
     @property
-    def atomic_radius(self) -> Optional[FloatWithUnit]:
+    def atomic_radius(self) -> FloatWithUnit | None:
         """
         Returns:
-            float | None: The atomic radius of the element in Ångstroms.
+            float | None: The atomic radius of the element in Ångstroms. Can be None for
+                some elements like noble gases.
         """
         return self._atomic_radius
 
     @property
-    def atomic_mass(self) -> Optional[FloatWithUnit]:
+    def atomic_mass(self) -> FloatWithUnit:
         """
         Returns:
-            float | None: The atomic mass of the element in amu.
+            float: The atomic mass of the element in amu.
         """
         return self._atomic_mass
 
-    def __getattr__(self, item):
+    def __getattr__(self, item: str) -> Any:
+        """Key access to available element data.
+
+        Args:
+            item (str): Attribute name.
+
+        Raises:
+            AttributeError: If item not in _pt_data.
+        """
         if item in [
             "mendeleev_no",
             "electrical_resistivity",
@@ -294,16 +301,16 @@ class ElementBase(Enum):
                             else:
                                 unit = toks[1].replace("<sup>", "^").replace("</sup>", "").replace("&Omega;", "ohm")
                                 units = Unit(unit)
-                                if set(units.keys()).issubset(SUPPORTED_UNIT_NAMES):
+                                if set(units).issubset(SUPPORTED_UNIT_NAMES):
                                     val = FloatWithUnit(toks[0], unit)
                         except ValueError:
                             # Ignore error. val will just remain a string.
                             pass
             return val
-        raise AttributeError("Element has no attribute %s!" % item)
+        raise AttributeError(f"Element has no attribute {item}!")
 
     @property
-    def data(self) -> dict:
+    def data(self) -> dict[str, Any]:
         """
         Returns dict of data for element.
         """
@@ -319,7 +326,7 @@ class ElementBase(Enum):
     @property
     def electron_affinity(self) -> float:
         """
-        First ionization energy of element.
+        The amount of energy released when an electron is attached to a neutral atom.
         """
         return self._data["Electron affinity"]
 
@@ -371,10 +378,10 @@ class ElementBase(Enum):
         return FloatWithUnit(0.0, "ang")
 
     @property
-    def ionic_radii(self) -> Dict[int, float]:
+    def ionic_radii(self) -> dict[int, float]:
         """
         All ionic radii of the element as a dict of
-        {oxidation state: ionic radii}. Radii are given in ang.
+        {oxidation state: ionic radii}. Radii are given in angstrom.
         """
         if "Ionic radii" in self._data:
             return {int(k): FloatWithUnit(v, "ang") for k, v in self._data["Ionic radii"].items()}
@@ -382,7 +389,7 @@ class ElementBase(Enum):
 
     @property
     def number(self) -> int:
-        """Alternative attribute for atomic number"""
+        """Alternative attribute for atomic number Z"""
         return self.Z
 
     @property
@@ -400,17 +407,17 @@ class ElementBase(Enum):
         return 0
 
     @property
-    def oxidation_states(self) -> Tuple:
+    def oxidation_states(self) -> tuple[int, ...]:
         """Tuple of all known oxidation states"""
-        return tuple(self._data.get("Oxidation states", []))
+        return tuple(int(x) for x in self._data.get("Oxidation states", []))
 
     @property
-    def common_oxidation_states(self) -> Tuple:
+    def common_oxidation_states(self) -> tuple[int, ...]:
         """Tuple of common oxidation states"""
         return tuple(self._data.get("Common oxidation states", []))
 
     @property
-    def icsd_oxidation_states(self) -> Tuple:
+    def icsd_oxidation_states(self) -> tuple[int, ...]:
         """Tuple of all oxidation states with at least 10 instances in
         ICSD database AND at least 1% of entries for that element"""
         return tuple(self._data.get("ICSD oxidation states", []))
@@ -423,7 +430,7 @@ class ElementBase(Enum):
         return FloatWithUnit(self._data["Metallic radius"], "ang")
 
     @property
-    def full_electronic_structure(self) -> List[Tuple[int, str, int]]:
+    def full_electronic_structure(self) -> list[tuple[int, str, int]]:
         """
         Full electronic structure as tuple.
         E.g., The electronic structure for Fe is represented as:
@@ -442,7 +449,7 @@ class ElementBase(Enum):
         if data[0][0] == "[":
             sym = data[0].replace("[", "").replace("]", "")
             data = list(Element(sym).full_electronic_structure) + data[1:]
-        return data  # type: ignore
+        return data
 
     @property
     def valence(self):
@@ -470,13 +477,10 @@ class ElementBase(Enum):
         return valence[0]
 
     @property
-    def term_symbols(self) -> List[List[str]]:
+    def term_symbols(self) -> list[list[str]]:
         """
-        All possible  Russell-Saunders term symbol of the Element
-        eg. L = 1, n_e = 2 (s2)
-        returns
-           [['1D2'], ['3P0', '3P1', '3P2'], ['1S0']]
-
+        All possible  Russell-Saunders term symbol of the Element.
+        eg. L = 1, n_e = 2 (s2) returns [['1D2'], ['3P0', '3P1', '3P2'], ['1S0']]
         """
         L_symbols = "SPDFGHIKLMNOQRTUVWXYZ"
 
@@ -507,9 +511,6 @@ class ElementBase(Enum):
 
             J = list(np.arange(abs(L - S), abs(L) + abs(S) + 1))
             term_symbols.append([str(int(2 * (abs(S)) + 1)) + L_symbols[abs(L)] + str(j) for j in J])
-            # Without J
-            # term_symbols.append(str(int(2 * (abs(S)) + 1)) \
-            #                     + L_symbols[abs(L)])
 
             # Delete all configurations included in this term
             for ML in range(-L, L - 1, -1):
@@ -526,7 +527,6 @@ class ElementBase(Enum):
         """
         Ground state term symbol
         Selected based on Hund's Rule
-
         """
         L_symbols = "SPDFGHIKLMNOQRTUVWXYZ"
 
@@ -554,12 +554,9 @@ class ElementBase(Enum):
             return J_sorted_terms[0][0]
         return J_sorted_terms[-1][0]
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         return isinstance(other, Element) and self.Z == other.Z
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
     def __hash__(self):
         return self.Z
 
@@ -572,9 +569,11 @@ class ElementBase(Enum):
     def __lt__(self, other):
         """
         Sets a default sort order for atomic species by electronegativity. Very
-        useful for getting correct formulas.  For example, FeO4PLi is
+        useful for getting correct formulas. For example, FeO4PLi is
         automatically sorted into LiFePO4.
         """
+        if not hasattr(other, "X") or not hasattr(other, "symbol"):
+            return NotImplemented
         x1 = float("inf") if self.X != self.X else self.X
         x2 = float("inf") if other.X != other.X else other.X
         if x1 != x2:
@@ -585,36 +584,70 @@ class ElementBase(Enum):
         return self.symbol < other.symbol
 
     @staticmethod
-    def from_Z(z: int) -> "Element":
+    def from_Z(Z: int) -> Element:
         """
         Get an element from an atomic number.
 
         Args:
-            z (int): Atomic number
+            Z (int): Atomic number
 
         Returns:
-            Element with atomic number z.
+            Element with atomic number Z.
         """
         for sym, data in _pt_data.items():
-            if data["Atomic no"] == z:
+            if data["Atomic no"] == Z:
                 return Element(sym)
-        raise ValueError("No element with this atomic number %s" % z)
+        raise ValueError(f"No element with this atomic number {Z}")
 
     @staticmethod
-    def from_row_and_group(row: int, group: int) -> "Element":
+    def from_name(name: str) -> Element:
         """
-        Returns an element from a row and group number.
+        Get an element from its long name.
 
         Args:
-            row (int): Row number
-            group (int): Group number
+            name: Long name of the element, e.g. 'Hydrogen' or
+                  'Iron'. Not case-sensitive.
+        Returns:
+            Element with the name 'name'
+        """
+        for sym, data in _pt_data.items():
+            if data["Name"] == name.capitalize():
+                return Element(sym)
+        raise ValueError(f"No element with the name {name}")
+
+    @staticmethod
+    def from_row_and_group(row: int, group: int) -> Element:
+        """
+        Returns an element from a row and group number.
+        Important Note: For lanthanoids and actinoids, the row number must
+        be 8 and 9, respectively, and the group number must be
+        between 3 (La, Ac) and 17 (Lu, Lr). This is different than the
+        value for Element(symbol).row and Element(symbol).group for these
+        elements.
+
+        Args:
+            row (int): (pseudo) row number. This is the
+                standard row number except for the lanthanoids
+                and actinoids for which it is 8 or 9, respectively.
+            group (int): (pseudo) group number. This is the
+                standard group number except for the lanthanoids
+                and actinoids for which it is 3 (La, Ac) to 17 (Lu, Lr).
 
         .. note::
             The 18 group number system is used, i.e., Noble gases are group 18.
         """
-        for sym in _pt_data.keys():
+        for sym in _pt_data:
             el = Element(sym)
-            if el.row == row and el.group == group:
+            if 57 <= el.Z <= 71:
+                el_pseudorow = 8
+                el_pseudogroup = (el.Z - 54) % 32
+            elif 89 <= el.Z <= 103:
+                el_pseudorow = 9
+                el_pseudogroup = (el.Z - 54) % 32
+            else:
+                el_pseudorow = el.row
+                el_pseudogroup = el.group
+            if el_pseudorow == row and el_pseudogroup == group:
                 return el
         raise ValueError("No element with this row and group!")
 
@@ -636,13 +669,15 @@ class ElementBase(Enum):
     def row(self) -> int:
         """
         Returns the periodic table row of the element.
+        Note: For lanthanoids and actinoids, the row is always 6 or 7,
+        respectively.
         """
         z = self.Z
         total = 0
         if 57 <= z <= 71:
-            return 8
+            return 6
         if 89 <= z <= 103:
-            return 9
+            return 7
         for i, size in enumerate(_pt_row_sizes):
             total += size
             if total >= z:
@@ -653,12 +688,14 @@ class ElementBase(Enum):
     def group(self) -> int:
         """
         Returns the periodic table group of the element.
+        Note: For lanthanoids and actinoids, the group is always 3.
         """
         z = self.Z
         if z == 1:
             return 1
         if z == 2:
             return 18
+
         if 3 <= z <= 18:
             if (z - 2) % 8 == 0:
                 return 18
@@ -671,6 +708,9 @@ class ElementBase(Enum):
                 return 18
             return (z - 18) % 18
 
+        if (57 <= z <= 71) or (89 <= z <= 103):
+            return 3
+
         if (z - 54) % 32 == 0:
             return 18
         if (z - 54) % 32 >= 18:
@@ -731,7 +771,7 @@ class ElementBase(Enum):
     @property
     def is_metal(self) -> bool:
         """
-        :return: True if is a metal.
+        True if is a metal.
         """
         return (
             self.is_alkali
@@ -794,12 +834,12 @@ class ElementBase(Enum):
     @property
     def is_quadrupolar(self) -> bool:
         """
-        Checks if this element can be quadrupolar
+        Checks if this element can be quadrupolar.
         """
         return len(self.data.get("NMR Quadrupole Moment", {})) > 0
 
     @property
-    def nmr_quadrupole_moment(self) -> dict:
+    def nmr_quadrupole_moment(self) -> dict[str, FloatWithUnit]:
         """
         Get a dictionary the nuclear electric quadrupole moment in units of
         e*millibarns for various isotopes
@@ -811,7 +851,7 @@ class ElementBase(Enum):
         """
         Ordering according to Table VI of "Nomenclature of Inorganic Chemistry
         (IUPAC Recommendations 2005)". This ordering effectively follows the
-        groups and rows of the periodic table, except the Lanthanides, Actanides
+        groups and rows of the periodic table, except the Lanthanides, Actinides
         and hydrogen.
         """
         return self._data["IUPAC ordering"]
@@ -820,26 +860,26 @@ class ElementBase(Enum):
         return Element(self.symbol)
 
     @staticmethod
-    def from_dict(d) -> "Element":
+    def from_dict(d) -> Element:
         """
         Makes Element obey the general json interface used in pymatgen for
         easier serialization.
         """
         return Element(d["element"])
 
-    def as_dict(self) -> dict:
+    def as_dict(self) -> dict[Literal["element", "@module", "@class"], str]:
         """
         Makes Element obey the general json interface used in pymatgen for
         easier serialization.
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "element": self.symbol,
         }
 
     @staticmethod
-    def print_periodic_table(filter_function: Optional[Callable] = None):
+    def print_periodic_table(filter_function: Callable | None = None):
         """
         A pretty ASCII printer for the periodic table, based on some
         filter_function.
@@ -856,7 +896,7 @@ class ElementBase(Enum):
                 try:
                     el = Element.from_row_and_group(row, group)
                 except ValueError:
-                    el = None  # type: ignore
+                    el = None
                 if el and ((not filter_function) or filter_function(el)):
                     rowstr.append(f"{el.symbol:3s}")
                 else:
@@ -864,6 +904,7 @@ class ElementBase(Enum):
             print(" ".join(rowstr))
 
 
+@functools.total_ordering
 class Element(ElementBase):
     """Enum representing an element in the periodic table."""
 
@@ -990,6 +1031,7 @@ class Element(ElementBase):
     Og = "Og"
 
 
+@functools.total_ordering
 class Species(MSONable, Stringify):
     """
     An extension of Element with an oxidation state and other optional
@@ -1006,8 +1048,8 @@ class Species(MSONable, Stringify):
     def __init__(
         self,
         symbol: str,
-        oxidation_state: Optional[float] = 0.0,
-        properties: Optional[dict] = None,
+        oxidation_state: float | None = 0.0,
+        properties: dict | None = None,
     ):
         """
         Initializes a Species.
@@ -1033,7 +1075,7 @@ class Species(MSONable, Stringify):
         """
         self._el = Element(symbol)
         self._oxi_state = oxidation_state
-        self._properties = properties if properties else {}
+        self._properties = properties or {}
         for k, _ in self._properties.items():
             if k not in Species.supported_properties:
                 raise ValueError(f"{k} is not a supported property")
@@ -1046,34 +1088,31 @@ class Species(MSONable, Stringify):
             return p[a]
         return getattr(self._el, a)
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         """
-        Species is equal to other only if element and oxidation states are
-        exactly the same.
+        Species is equal to other only if element and oxidation states are exactly the same.
         """
-        return (
-            isinstance(other, Species)
-            and self.symbol == other.symbol
-            and self.oxi_state == other.oxi_state
-            and self._properties == other._properties
-        )
+        if not hasattr(other, "oxi_state") or not hasattr(other, "symbol") or not hasattr(other, "_properties"):
+            return NotImplemented
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
+        return all(getattr(self, attr) == getattr(other, attr) for attr in ["symbol", "oxi_state", "_properties"])
 
     def __hash__(self):
         """
         Equal Species should have the same str representation, hence
-        should hash equally. Unequal Species will have differnt str
+        should hash equally. Unequal Species will have different str
         representations.
         """
-        return self.__str__().__hash__()
+        return hash(str(self))
 
-    def __lt__(self, other):
+    def __lt__(self, other: object) -> bool:
         """
         Sets a default sort order for atomic species by electronegativity,
         followed by oxidation state, followed by spin.
         """
+        if not isinstance(other, type(self)):
+            return NotImplemented
+
         x1 = float("inf") if self.X != self.X else self.X
         x2 = float("inf") if other.X != other.X else other.X
         if x1 != x2:
@@ -1098,34 +1137,33 @@ class Species(MSONable, Stringify):
         return self._el
 
     @property
-    def ionic_radius(self) -> Optional[float]:
+    def ionic_radius(self) -> float | None:
         """
         Ionic radius of specie. Returns None if data is not present.
         """
-
         if self._oxi_state in self.ionic_radii:
             return self.ionic_radii[self._oxi_state]
         if self._oxi_state:
             d = self._el.data
             oxstr = str(int(self._oxi_state))
             if oxstr in d.get("Ionic radii hs", {}):
-                warnings.warn("No default ionic radius for %s. Using hs data." % self)
+                warnings.warn(f"No default ionic radius for {self}. Using hs data.")
                 return d["Ionic radii hs"][oxstr]
             if oxstr in d.get("Ionic radii ls", {}):
-                warnings.warn("No default ionic radius for %s. Using ls data." % self)
+                warnings.warn(f"No default ionic radius for {self}. Using ls data.")
                 return d["Ionic radii ls"][oxstr]
         warnings.warn(f"No ionic radius for {self}!")
         return None
 
     @property
-    def oxi_state(self) -> Optional[float]:
+    def oxi_state(self) -> float | None:
         """
         Oxidation state of Species.
         """
         return self._oxi_state
 
     @staticmethod
-    def from_string(species_string: str) -> "Species":
+    def from_string(species_string: str) -> Species:
         """
         Returns a Species from a string representation.
 
@@ -1137,9 +1175,8 @@ class Species(MSONable, Stringify):
             A Species object.
 
         Raises:
-            ValueError if species_string cannot be intepreted.
+            ValueError if species_string cannot be interpreted.
         """
-
         # e.g. Fe2+,spin=5
         # 1st group: ([A-Z][a-z]*)    --> Fe
         # 2nd group: ([0-9.]*)        --> "2"
@@ -1173,7 +1210,7 @@ class Species(MSONable, Stringify):
         raise ValueError("Invalid Species String")
 
     def __repr__(self):
-        return "Species " + self.__str__()
+        return f"Species {self}"
 
     def __str__(self):
         output = self.symbol
@@ -1198,7 +1235,7 @@ class Species(MSONable, Stringify):
                 output += formula_double_format(-self.oxi_state) + "-"
         return output
 
-    def get_nmr_quadrupole_moment(self, isotope: Optional[str] = None) -> float:
+    def get_nmr_quadrupole_moment(self, isotope: str | None = None) -> float:
         """
         Gets the nuclear electric quadrupole moment in units of
         e*millibarns
@@ -1207,14 +1244,13 @@ class Species(MSONable, Stringify):
             isotope (str): the isotope to get the quadrupole moment for
                 default is None, which gets the lowest mass isotope
         """
-
         quad_mom = self._el.nmr_quadrupole_moment
 
         if not quad_mom:
             return 0.0
 
         if isotope is None:
-            isotopes = list(quad_mom.keys())
+            isotopes = list(quad_mom)
             isotopes.sort(key=lambda x: int(x.split("-")[1]), reverse=False)
             return quad_mom.get(isotopes[0], 0.0)
 
@@ -1246,8 +1282,8 @@ class Species(MSONable, Stringify):
         """
         radii = self._el.data["Shannon radii"]
         radii = radii[str(int(self._oxi_state))][cn]  # type: ignore
-        if len(radii) == 1:  # type: ignore
-            k, data = list(radii.items())[0]  # type: ignore
+        if len(radii) == 1:
+            k, data = list(radii.items())[0]
             if k != spin:
                 warnings.warn(
                     f"Specified spin state of {spin} not consistent with database "
@@ -1255,7 +1291,7 @@ class Species(MSONable, Stringify):
                 )
         else:
             data = radii[spin]
-        return data["%s_radius" % radius_type]
+        return data[f"{radius_type}_radius"]
 
     def get_crystal_field_spin(
         self, coordination: Literal["oct", "tet"] = "oct", spin_config: Literal["low", "high"] = "high"
@@ -1315,8 +1351,8 @@ class Species(MSONable, Stringify):
         :return: Json-able dictionary representation.
         """
         d = {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "element": self.symbol,
             "oxidation_state": self._oxi_state,
         }
@@ -1325,7 +1361,7 @@ class Species(MSONable, Stringify):
         return d
 
     @classmethod
-    def from_dict(cls, d) -> "Species":
+    def from_dict(cls, d) -> Species:
         """
         :param d: Dict representation.
         :return: Species.
@@ -1333,6 +1369,7 @@ class Species(MSONable, Stringify):
         return cls(d["element"], d["oxidation_state"], d.get("properties", None))
 
 
+@functools.total_ordering
 class DummySpecies(Species):
     """
     A special specie for representing non-traditional elements or species. For
@@ -1359,8 +1396,8 @@ class DummySpecies(Species):
     def __init__(
         self,
         symbol: str = "X",
-        oxidation_state: Optional[float] = 0,
-        properties: Optional[dict] = None,
+        oxidation_state: float | None = 0,
+        properties: dict | None = None,
     ):
         """
         Args:
@@ -1385,39 +1422,19 @@ class DummySpecies(Species):
         # most instances.
         self._symbol = symbol
         self._oxi_state = oxidation_state
-        self._properties = properties if properties else {}
+        self._properties = properties or {}
         for k, _ in self._properties.items():
             if k not in Species.supported_properties:
                 raise ValueError(f"{k} is not a supported property")
 
     def __getattr__(self, a):
-        # overriding getattr doens't play nice with pickle, so we
+        # overriding getattr doesn't play nice with pickle, so we
         # can't use self._properties
         p = object.__getattribute__(self, "_properties")
         if a in p:
             return p[a]
         raise AttributeError(a)
 
-    def __hash__(self):
-        return self.symbol.__hash__()
-
-    def __eq__(self, other):
-        """
-        Species is equal to other only if element and oxidation states are
-        exactly the same.
-        """
-        if not isinstance(other, DummySpecies):
-            return False
-        return (
-            isinstance(other, Species)
-            and self.symbol == other.symbol
-            and self.oxi_state == other.oxi_state
-            and self._properties == other._properties
-        )
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
     def __lt__(self, other):
         """
         Sets a default sort order for atomic species by electronegativity,
@@ -1439,10 +1456,10 @@ class DummySpecies(Species):
         the symbol. The expectation is that someone would be an actual dummy
         to use atomic numbers for a Dummy specie.
         """
-        return self.symbol.__hash__()
+        return hash(self.symbol)
 
     @property
-    def oxi_state(self) -> Optional[float]:
+    def oxi_state(self) -> float | None:
         """
         Oxidation state associated with DummySpecies
         """
@@ -1467,7 +1484,7 @@ class DummySpecies(Species):
         return DummySpecies(self.symbol, self._oxi_state)
 
     @staticmethod
-    def from_string(species_string: str) -> "DummySpecies":
+    def from_string(species_string: str) -> DummySpecies:
         """
         Returns a Dummy from a string representation.
 
@@ -1479,7 +1496,7 @@ class DummySpecies(Species):
             A DummySpecies object.
 
         Raises:
-            ValueError if species_string cannot be intepreted.
+            ValueError if species_string cannot be interpreted.
         """
         m = re.search(r"([A-ZAa-z]*)([0-9.]*)([+\-]*)(.*)", species_string)
         if m:
@@ -1501,8 +1518,8 @@ class DummySpecies(Species):
         :return: MSONAble dict representation.
         """
         d = {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "element": self.symbol,
             "oxidation_state": self._oxi_state,
         }
@@ -1511,7 +1528,7 @@ class DummySpecies(Species):
         return d
 
     @classmethod
-    def from_dict(cls, d) -> "DummySpecies":
+    def from_dict(cls, d) -> DummySpecies:
         """
         :param d: Dict representation
         :return: DummySpecies
@@ -1519,7 +1536,7 @@ class DummySpecies(Species):
         return cls(d["element"], d["oxidation_state"], d.get("properties", None))
 
     def __repr__(self):
-        return "DummySpecies " + self.__str__()
+        return f"DummySpecies {self}"
 
     def __str__(self):
         output = self.symbol
@@ -1533,25 +1550,23 @@ class DummySpecies(Species):
         return output
 
 
+@functools.total_ordering
 class Specie(Species):
     """
     This maps the historical grammatically inaccurate Specie to Species
     to maintain backwards compatibility.
     """
 
-    pass
-
 
+@functools.total_ordering
 class DummySpecie(DummySpecies):
     """
     This maps the historical grammatically inaccurate DummySpecie to DummySpecies
     to maintain backwards compatibility.
     """
 
-    pass
 
-
-def get_el_sp(obj) -> Union[Element, Species, DummySpecies]:
+def get_el_sp(obj) -> Element | Species | DummySpecies:
     """
     Utility method to get an Element or Species from an input obj.
     If obj is in itself an element or a specie, it is returned automatically.
@@ -1562,7 +1577,7 @@ def get_el_sp(obj) -> Union[Element, Species, DummySpecies]:
     DummyElement parsing will be attempted.
 
     Args:
-        obj (Element/Species/str/int): An arbitrary object.  Supported objects
+        obj (Element/Species/str/int): An arbitrary object. Supported objects
             are actual Element/Species objects, integers (representing atomic
             numbers) or strings (element symbols or species strings).
 
@@ -1581,7 +1596,7 @@ def get_el_sp(obj) -> Union[Element, Species, DummySpecies]:
         i = int(c)
         i = i if i == c else None  # type: ignore
     except (ValueError, TypeError):
-        i = None  # type: ignore
+        i = None
 
     if i is not None:
         return Element.from_Z(i)
