@@ -4,6 +4,8 @@
 
 import unittest
 
+import pytest
+
 from pymatgen.core.molecular_orbitals import MolecularOrbitals
 from pymatgen.util.testing import PymatgenTest
 
@@ -13,7 +15,7 @@ test_case = MolecularOrbitals("NaCl")
 class MolecularOrbitalTestCase(PymatgenTest):
     def test_max_electronegativity(self):
         test_elec_neg = 2.23
-        self.assertEqual(test_elec_neg, test_case.max_electronegativity())
+        assert test_elec_neg == test_case.max_electronegativity()
 
     def test_aos_as_list(self):
         test_list = [
@@ -27,7 +29,7 @@ class MolecularOrbitalTestCase(PymatgenTest):
             ["Cl", "3p", -0.32038],
             ["Na", "3s", -0.103415],
         ]
-        self.assertEqual(test_list, test_case.aos_as_list())
+        assert test_list == test_case.aos_as_list()
 
     def test_obtain_band_edges(self):
         test_edges = {
@@ -35,12 +37,13 @@ class MolecularOrbitalTestCase(PymatgenTest):
             "LUMO": ["Na", "3s", -0.103415],
             "metal": False,
         }
-        for k in test_edges.keys():
-            self.assertEqual(test_edges[k], test_case.obtain_band_edges()[k])
+        for key, val in test_edges.items():
+            assert val == test_case.obtain_band_edges()[key]
 
     # test for raising ValueError for fractional composition
     def test_fractional_compositions(self):
-        self.assertRaises(ValueError, lambda: MolecularOrbitals("Na0.5Cl0.5"))
+        with pytest.raises(ValueError):
+            MolecularOrbitals("Na0.5Cl0.5")
 
 
 if __name__ == "__main__":
