@@ -10,38 +10,46 @@ import warnings
 from copy import deepcopy
 
 import numpy as np
+import pytest
 
-from pymatgen.core.periodic_table import DummySpecies, Element, Species, get_el_sp
+from pymatgen.core.periodic_table import (
+    DummySpecies,
+    Element,
+    ElementBase,
+    Species,
+    get_el_sp,
+)
 from pymatgen.util.testing import PymatgenTest
 
 
 class ElementTestCase(PymatgenTest):
     def test_init(self):
-        self.assertEqual("Fe", Element("Fe").symbol, "Fe test failed")
+        assert "Fe" == Element("Fe").symbol, "Fe test failed"
 
         fictional_symbols = ["D", "T", "Zebra"]
 
         for sym in fictional_symbols:
-            self.assertRaises(ValueError, Element, sym)
+            with pytest.raises(ValueError):
+                Element(sym)
 
         # Test caching
-        self.assertEqual(id(Element("Fe")), id(Element("Fe")))
+        assert id(Element("Fe")) == id(Element("Fe"))
 
     def test_is_metal(self):
         for metal in ["Fe", "Eu", "Li", "Ca", "In"]:
-            self.assertTrue(Element(metal).is_metal)
+            assert Element(metal).is_metal
         for non_metal in ["Ge", "Si", "O", "He"]:
-            self.assertFalse(Element(non_metal).is_metal)
+            assert not Element(non_metal).is_metal
 
     def test_nan_X(self):
-        self.assertTrue(math.isnan(Element.He.X))
+        assert math.isnan(Element.He.X)
         els = sorted([Element.He, Element.H, Element.F])
-        self.assertEqual(els, [Element.H, Element.F, Element.He])
+        assert els == [Element.H, Element.F, Element.He]
 
     def test_dict(self):
         fe = Element.Fe
         d = fe.as_dict()
-        self.assertEqual(fe, Element.from_dict(d))
+        assert fe == Element.from_dict(d)
 
     def test_block(self):
         testsets = {
@@ -54,7 +62,7 @@ class ElementTestCase(PymatgenTest):
             "Lr": "d",
         }
         for k, v in testsets.items():
-            self.assertEqual(Element(k).block, v)
+            assert Element(k).block == v
 
     def test_full_electronic_structure(self):
         testsets = {
@@ -91,21 +99,86 @@ class ElementTestCase(PymatgenTest):
             ],
         }
         for k, v in testsets.items():
-            self.assertEqual(Element(k).full_electronic_structure, v)
+            assert Element(k).full_electronic_structure == v
 
-        self.assertEqual(Element.Ac.electronic_structure, "[Rn].6d1.7s2")
+        assert Element.Ac.electronic_structure == "[Rn].6d1.7s2"
+
+    def test_group(self):
+        testsets = {
+            "H": 1,
+            "He": 18,
+            "Li": 1,
+            "O": 16,
+            "Fe": 8,
+            "La": 3,
+            "Ce": 3,
+            "Lu": 3,
+            "U": 3,
+            "Lr": 3,
+            "Og": 18,
+        }
+        for k, v in testsets.items():
+            assert Element(k).group == v
+
+    def test_row(self):
+        testsets = {
+            "H": 1,
+            "He": 1,
+            "Li": 2,
+            "O": 2,
+            "Fe": 4,
+            "La": 6,
+            "Ce": 6,
+            "Lu": 6,
+            "U": 7,
+            "Lr": 7,
+            "Og": 7,
+        }
+        for k, v in testsets.items():
+            assert Element(k).row == v
+
+    def test_from_name(self):
+        testsets = {
+            "H": "hydrogen",
+            "He": "Helium",
+            "Li": "lithium",
+            "O": "Oxygen",
+            "Fe": "Iron",
+            "La": "lanthanum",
+            "Ce": "Cerium",
+            "U": "Uranium",
+        }
+        for k, v in testsets.items():
+            assert ElementBase.from_name(v) == Element(k)
+
+    def test_from_row_and_group(self):
+        testsets = {
+            "H": (1, 1),
+            "He": (1, 18),
+            "Li": (2, 1),
+            "O": (2, 16),
+            "Fe": (4, 8),
+            "La": (8, 3),
+            "Ce": (8, 4),
+            "Lu": (8, 17),
+            "U": (9, 6),
+            "Lr": (9, 17),
+            "Og": (7, 18),
+        }
+        for k, v in testsets.items():
+            assert ElementBase.from_row_and_group(v[0], v[1]) == Element(k)
 
     def test_valence(self):
         testsets = {"O": (1, 4), "Fe": (2, 6), "Li": (0, 1), "Be": (0, 2)}
         for k, v in testsets.items():
-            self.assertEqual(Element(k).valence, v)
+            assert Element(k).valence == v
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             Element("U").valence
 
         valence = Element("He").valence
-        self.assertTrue(np.isnan(valence[0]))
-        self.assertEqual(valence[1], 0)
+        assert np.isnan(valence[0])
+        assert valence[1] == 0
 
     def test_term_symbols(self):
         testsets = {
@@ -139,7 +212,7 @@ class ElementTestCase(PymatgenTest):
             ],  # f3
         }
         for k, v in testsets.items():
-            self.assertEqual(Element(k).term_symbols, v)
+            assert Element(k).term_symbols == v
 
     def test_ground_state_term_symbol(self):
         testsets = {
@@ -150,7 +223,7 @@ class ElementTestCase(PymatgenTest):
             "Pr": "4I4.5",
         }  # f3
         for k, v in testsets.items():
-            self.assertEqual(Element(k).ground_state_term_symbol, v)
+            assert Element(k).ground_state_term_symbol == v
 
     def test_attributes(self):
         is_true = {
@@ -167,7 +240,7 @@ class ElementTestCase(PymatgenTest):
 
         for k, v in is_true.items():
             for sym in k:
-                self.assertTrue(getattr(Element(sym), v), sym + " is false")
+                assert getattr(Element(sym), v), sym + " is false"
 
         keys = [
             "mendeleev_no",
@@ -217,63 +290,64 @@ class ElementTestCase(PymatgenTest):
             for k in keys:
                 k_str = k.capitalize().replace("_", " ")
                 if k_str in d and (not str(d[k_str]).startswith("no data")):
-                    self.assertIsNotNone(getattr(el, k))
+                    assert getattr(el, k) is not None
                 elif k == "long_name":
-                    self.assertEqual(getattr(el, "long_name"), d["Name"])
+                    assert el.long_name == d["Name"]
                 elif k == "iupac_ordering":
-                    self.assertTrue("IUPAC ordering" in d)
-                    self.assertIsNotNone(getattr(el, k))
+                    assert "IUPAC ordering" in d
+                    assert getattr(el, k) is not None
             el = Element.from_Z(i)
             if len(el.oxidation_states) > 0:
-                self.assertEqual(max(el.oxidation_states), el.max_oxidation_state)
-                self.assertEqual(min(el.oxidation_states), el.min_oxidation_state)
+                assert max(el.oxidation_states) == el.max_oxidation_state
+                assert min(el.oxidation_states) == el.min_oxidation_state
 
             if el.symbol not in ["He", "Ne", "Ar"]:
-                self.assertTrue(el.X > 0, "No electroneg for %s" % el)
+                assert el.X > 0, f"No electroneg for {el}"
 
-        self.assertRaises(ValueError, Element.from_Z, 1000)
+        with pytest.raises(ValueError):
+            Element.from_Z(1000)
 
     def test_ie_ea(self):
-        self.assertAlmostEqual(Element.Fe.ionization_energies[2], 30.651)
-        self.assertEqual(Element.Fe.ionization_energy, Element.Fe.ionization_energies[0])
-        self.assertAlmostEqual(Element.Br.electron_affinity, 3.3635883)
+        assert round(abs(Element.Fe.ionization_energies[2] - 30.651), 7) == 0
+        assert Element.Fe.ionization_energy == Element.Fe.ionization_energies[0]
+        assert round(abs(Element.Br.electron_affinity - 3.3635883), 7) == 0
 
     def test_oxidation_states(self):
         el = Element.Fe
-        self.assertEqual(el.oxidation_states, (-2, -1, 1, 2, 3, 4, 5, 6))
-        self.assertEqual(el.common_oxidation_states, (2, 3))
-        self.assertEqual(el.icsd_oxidation_states, (2, 3))
+        assert el.oxidation_states == (-2, -1, 1, 2, 3, 4, 5, 6)
+        assert el.common_oxidation_states == (2, 3)
+        assert el.icsd_oxidation_states == (2, 3)
 
     def test_deepcopy(self):
         el1 = Element.Fe
         el2 = Element.Na
         ellist = [el1, el2]
-        self.assertEqual(ellist, deepcopy(ellist), "Deepcopy operation doesn't produce exact copy")
+        assert ellist == deepcopy(ellist), "Deepcopy operation doesn't produce exact copy"
 
     def test_radii(self):
         el = Element.Pd
-        self.assertEqual(el.atomic_radius, 1.40)
-        self.assertEqual(el.atomic_radius_calculated, 1.69)
-        self.assertEqual(el.van_der_waals_radius, 2.10)
+        assert el.atomic_radius == 1.40
+        assert el.atomic_radius_calculated == 1.69
+        assert el.van_der_waals_radius == 2.10
 
     def test_data(self):
-        self.assertEqual(Element.Pd.data["Atomic radius"], 1.4)
+        assert Element.Pd.data["Atomic radius"] == 1.4
         al = Element.Al
         val = al.thermal_conductivity
-        self.assertEqual(val, 235)
-        self.assertEqual(str(val.unit), "W K^-1 m^-1")
+        assert val == 235
+        assert str(val.unit) == "W K^-1 m^-1"
         val = al.electrical_resistivity
-        self.assertEqual(val, 2.7e-08)
-        self.assertEqual(str(val.unit), "m ohm")
+        assert val == 2.7e-08
+        assert str(val.unit) == "m ohm"
 
     def test_sort(self):
         els = [Element.Se, Element.C]
-        self.assertEqual(sorted(els), [Element.C, Element.Se])
+        assert sorted(els) == [Element.C, Element.Se]
 
     def test_pickle(self):
         el1 = Element.Fe
         o = pickle.dumps(el1)
-        self.assertEqual(el1, pickle.loads(o))
+        assert el1 == pickle.loads(o)
 
         # Test all elements up to Uranium
         for i in range(1, 93):
@@ -283,7 +357,7 @@ class ElementTestCase(PymatgenTest):
         Element.print_periodic_table()
 
     def test_is(self):
-        self.assertTrue(Element("Bi").is_post_transition_metal, True)
+        assert Element("Bi").is_post_transition_metal, True
 
 
 class SpecieTestCase(PymatgenTest):
@@ -294,42 +368,39 @@ class SpecieTestCase(PymatgenTest):
         self.specie4 = Species("Fe", 2, {"spin": 5})
 
     def test_init(self):
-        self.assertRaises(ValueError, Species, "Fe", 2, {"magmom": 5})
+        with pytest.raises(ValueError):
+            Species("Fe", 2, {"magmom": 5})
 
     def test_ionic_radius(self):
-        self.assertEqual(self.specie2.ionic_radius, 78.5 / 100)
-        self.assertEqual(self.specie3.ionic_radius, 92 / 100)
-        self.assertAlmostEqual(Species("Mn", 4).ionic_radius, 0.67)
+        assert self.specie2.ionic_radius == 78.5 / 100
+        assert self.specie3.ionic_radius == 92 / 100
+        assert round(abs(Species("Mn", 4).ionic_radius - 0.67), 7) == 0
 
     def test_eq(self):
-        self.assertEqual(
-            self.specie1,
-            self.specie3,
-            "Static and actual constructor gives unequal result!",
-        )
-        self.assertNotEqual(self.specie1, self.specie2, "Fe2+ should not be equal to Fe3+")
-        self.assertNotEqual(self.specie4, self.specie3)
-        self.assertFalse(self.specie1 == Element("Fe"))
-        self.assertFalse(Element("Fe") == self.specie1)
+        assert self.specie1 == self.specie3, "Static and actual constructor gives unequal result!"
+        assert self.specie1 != self.specie2, "Fe2+ should not be equal to Fe3+"
+        assert self.specie4 != self.specie3
+        assert not self.specie1 == Element("Fe")
+        assert not Element("Fe") == self.specie1
 
     def test_cmp(self):
-        self.assertLess(self.specie1, self.specie2, "Fe2+ should be < Fe3+")
-        self.assertLess(Species("C", 1), Species("Se", 1))
+        assert self.specie1 < self.specie2, "Fe2+ should be < Fe3+"
+        assert Species("C", 1) < Species("Se", 1)
 
     def test_attr(self):
-        self.assertEqual(self.specie1.Z, 26, "Z attribute for Fe2+ should be = Element Fe.")
-        self.assertEqual(self.specie4.spin, 5)
+        assert self.specie1.Z == 26, "Z attribute for Fe2+ should be = Element Fe."
+        assert self.specie4.spin == 5
 
     def test_deepcopy(self):
         el1 = Species("Fe", 4)
         el2 = Species("Na", 1)
         ellist = [el1, el2]
-        self.assertEqual(ellist, deepcopy(ellist), "Deepcopy operation doesn't produce exact copy.")
+        assert ellist == deepcopy(ellist), "Deepcopy operation doesn't produce exact copy."
 
     def test_pickle(self):
-        self.assertEqual(self.specie1, pickle.loads(pickle.dumps(self.specie1)))
+        assert self.specie1 == pickle.loads(pickle.dumps(self.specie1))
         for i in range(1, 5):
-            self.serialize_with_pickle(getattr(self, "specie%d" % i), test_eq=True)
+            self.serialize_with_pickle(getattr(self, f"specie{i}"), test_eq=True)
         cs = Species("Cs", 1)
         cl = Species("Cl", 1)
 
@@ -338,67 +409,73 @@ class SpecieTestCase(PymatgenTest):
 
         with open("cscl.pickle", "rb") as f:
             d = pickle.load(f)
-            self.assertEqual(d, (cs, cl))
+            assert d == (cs, cl)
         os.remove("cscl.pickle")
 
     def test_get_crystal_field_spin(self):
-        self.assertEqual(Species("Fe", 2).get_crystal_field_spin(), 4)
-        self.assertEqual(Species("Fe", 3).get_crystal_field_spin(), 5)
-        self.assertEqual(Species("Fe", 4).get_crystal_field_spin(), 4)
-        self.assertEqual(Species("Co", 3).get_crystal_field_spin(spin_config="low"), 0)
-        self.assertEqual(Species("Co", 4).get_crystal_field_spin(spin_config="low"), 1)
-        self.assertEqual(Species("Ni", 3).get_crystal_field_spin(spin_config="low"), 1)
-        self.assertEqual(Species("Ni", 4).get_crystal_field_spin(spin_config="low"), 0)
+        assert Species("Fe", 2).get_crystal_field_spin() == 4
+        assert Species("Fe", 3).get_crystal_field_spin() == 5
+        assert Species("Fe", 4).get_crystal_field_spin() == 4
+        assert Species("Co", 3).get_crystal_field_spin(spin_config="low") == 0
+        assert Species("Co", 4).get_crystal_field_spin(spin_config="low") == 1
+        assert Species("Ni", 3).get_crystal_field_spin(spin_config="low") == 1
+        assert Species("Ni", 4).get_crystal_field_spin(spin_config="low") == 0
 
-        self.assertRaises(AttributeError, Species("Li", 1).get_crystal_field_spin)
-        self.assertRaises(AttributeError, Species("Ge", 4).get_crystal_field_spin)
-        self.assertRaises(AttributeError, Species("H", 1).get_crystal_field_spin)
-        self.assertRaises(AttributeError, Species("Fe", 10).get_crystal_field_spin)
-        self.assertRaises(ValueError, Species("Fe", 2).get_crystal_field_spin, "hex")
+        with pytest.raises(AttributeError):
+            Species("Li", 1).get_crystal_field_spin()
+        with pytest.raises(AttributeError):
+            Species("Ge", 4).get_crystal_field_spin()
+        with pytest.raises(AttributeError):
+            Species("H", 1).get_crystal_field_spin()
+        with pytest.raises(AttributeError):
+            Species("Fe", 10).get_crystal_field_spin()
+        with pytest.raises(ValueError):
+            Species("Fe", 2).get_crystal_field_spin("hex")
 
         s = Species("Co", 3).get_crystal_field_spin("tet", spin_config="low")
-        self.assertEqual(s, 2)
+        assert s == 2
 
     def test_get_nmr_mom(self):
-        self.assertEqual(Species("H").get_nmr_quadrupole_moment(), 2.860)
-        self.assertEqual(Species("Li").get_nmr_quadrupole_moment(), -0.808)
-        self.assertEqual(Species("Li").get_nmr_quadrupole_moment("Li-7"), -40.1)
-        self.assertEqual(Species("Si").get_nmr_quadrupole_moment(), 0.0)
-        self.assertRaises(ValueError, Species("Li").get_nmr_quadrupole_moment, "Li-109")
+        assert Species("H").get_nmr_quadrupole_moment() == 2.860
+        assert Species("Li").get_nmr_quadrupole_moment() == -0.808
+        assert Species("Li").get_nmr_quadrupole_moment("Li-7") == -40.1
+        assert Species("Si").get_nmr_quadrupole_moment() == 0.0
+        with pytest.raises(ValueError):
+            Species("Li").get_nmr_quadrupole_moment("Li-109")
 
     def test_get_shannon_radius(self):
-        self.assertEqual(Species("Li", 1).get_shannon_radius("IV"), 0.59)
+        assert Species("Li", 1).get_shannon_radius("IV") == 0.59
         mn2 = Species("Mn", 2)
-        self.assertEqual(mn2.get_shannon_radius("IV", "High Spin"), 0.66)
-        self.assertEqual(mn2.get_shannon_radius("V", "High Spin"), 0.75)
+        assert mn2.get_shannon_radius("IV", "High Spin") == 0.66
+        assert mn2.get_shannon_radius("V", "High Spin") == 0.75
 
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
             # Trigger a warning.
             r = mn2.get_shannon_radius("V")
             # Verify some things
-            self.assertEqual(len(w), 1)
-            self.assertIs(w[-1].category, UserWarning)
-            self.assertEqual(r, 0.75)
+            assert len(w) == 1
+            assert w[-1].category is UserWarning
+            assert r == 0.75
 
-        self.assertEqual(mn2.get_shannon_radius("VI", "Low Spin"), 0.67)
-        self.assertEqual(mn2.get_shannon_radius("VI", "High Spin"), 0.83)
-        self.assertEqual(mn2.get_shannon_radius("VII", "High Spin"), 0.9)
-        self.assertEqual(mn2.get_shannon_radius("VIII"), 0.96)
+        assert mn2.get_shannon_radius("VI", "Low Spin") == 0.67
+        assert mn2.get_shannon_radius("VI", "High Spin") == 0.83
+        assert mn2.get_shannon_radius("VII", "High Spin") == 0.9
+        assert mn2.get_shannon_radius("VIII") == 0.96
 
     def test_sort(self):
         els = map(get_el_sp, ["N3-", "Si4+", "Si3+"])
-        self.assertEqual(sorted(els), [Species("Si", 3), Species("Si", 4), Species("N", -3)])
+        assert sorted(els) == [Species("Si", 3), Species("Si", 4), Species("N", -3)]
 
     def test_to_from_string(self):
         fe3 = Species("Fe", 3, {"spin": 5})
-        self.assertEqual(str(fe3), "Fe3+,spin=5")
+        assert str(fe3) == "Fe3+,spin=5"
         fe = Species.from_string("Fe3+,spin=5")
-        self.assertEqual(fe.spin, 5)
+        assert fe.spin == 5
         mo0 = Species("Mo", 0, {"spin": 5})
-        self.assertEqual(str(mo0), "Mo0+,spin=5")
+        assert str(mo0) == "Mo0+,spin=5"
         mo = Species.from_string("Mo0+,spin=4")
-        self.assertEqual(mo.spin, 4)
+        assert mo.spin == 4
 
         # Shyue Ping: I don't understand the need for a None for oxidation state. That to me is basically an element.
         # Why make the thing so complicated for a use case that I have never seen???
@@ -408,61 +485,64 @@ class SpecieTestCase(PymatgenTest):
 
     def test_no_oxidation_state(self):
         mo0 = Species("Mo", None, {"spin": 5})
-        self.assertEqual(str(mo0), "Mo,spin=5")
+        assert str(mo0) == "Mo,spin=5"
 
     def test_stringify(self):
-        self.assertEqual(self.specie2.to_latex_string(), "Fe$^{3+}$")
-        self.assertEqual(self.specie2.to_unicode_string(), "Fe³⁺")
-        self.assertEqual(Species("S", -2).to_latex_string(), "S$^{2-}$")
-        self.assertEqual(Species("S", -2).to_unicode_string(), "S²⁻")
+        assert self.specie2.to_latex_string() == "Fe$^{3+}$"
+        assert self.specie2.to_unicode_string() == "Fe³⁺"
+        assert Species("S", -2).to_latex_string() == "S$^{2-}$"
+        assert Species("S", -2).to_unicode_string() == "S²⁻"
 
 
 class DummySpecieTestCase(unittest.TestCase):
     def test_init(self):
         self.specie1 = DummySpecies("X")
-        self.assertRaises(ValueError, DummySpecies, "Xe")
-        self.assertRaises(ValueError, DummySpecies, "Xec")
-        self.assertRaises(ValueError, DummySpecies, "Vac")
+        with pytest.raises(ValueError):
+            DummySpecies("Xe")
+        with pytest.raises(ValueError):
+            DummySpecies("Xec")
+        with pytest.raises(ValueError):
+            DummySpecies("Vac")
         self.specie2 = DummySpecies("X", 2, {"spin": 3})
-        self.assertEqual(self.specie2.spin, 3)
+        assert self.specie2.spin == 3
 
     def test_eq(self):
-        self.assertFalse(DummySpecies("Xg") == DummySpecies("Xh"))
-        self.assertFalse(DummySpecies("Xg") == DummySpecies("Xg", 3))
-        self.assertTrue(DummySpecies("Xg", 3) == DummySpecies("Xg", 3))
+        assert not DummySpecies("Xg") == DummySpecies("Xh")
+        assert not DummySpecies("Xg") == DummySpecies("Xg", 3)
+        assert DummySpecies("Xg", 3) == DummySpecies("Xg", 3)
 
     def test_from_string(self):
         sp = DummySpecies.from_string("X")
-        self.assertEqual(sp.oxi_state, 0)
+        assert sp.oxi_state == 0
         sp = DummySpecies.from_string("X2+")
-        self.assertEqual(sp.oxi_state, 2)
-        self.assertEqual(sp.to_latex_string(), "X$^{2+}$")
+        assert sp.oxi_state == 2
+        assert sp.to_latex_string() == "X$^{2+}$"
         sp = DummySpecies.from_string("X2+spin=5")
-        self.assertEqual(sp.oxi_state, 2)
-        self.assertEqual(sp.spin, 5)
-        self.assertEqual(sp.to_latex_string(), "X$^{2+}$")
-        self.assertEqual(sp.to_html_string(), "X<sup>2+</sup>")
-        self.assertEqual(sp.to_unicode_string(), "X²⁺")
+        assert sp.oxi_state == 2
+        assert sp.spin == 5
+        assert sp.to_latex_string() == "X$^{2+}$"
+        assert sp.to_html_string() == "X<sup>2+</sup>"
+        assert sp.to_unicode_string() == "X²⁺"
 
     def test_pickle(self):
         el1 = DummySpecies("X", 3)
         o = pickle.dumps(el1)
-        self.assertEqual(el1, pickle.loads(o))
+        assert el1 == pickle.loads(o)
 
     def test_sort(self):
         r = sorted([Element.Fe, DummySpecies("X")])
-        self.assertEqual(r, [DummySpecies("X"), Element.Fe])
-        self.assertTrue(DummySpecies("X", 3) < DummySpecies("X", 4))
+        assert r == [DummySpecies("X"), Element.Fe]
+        assert DummySpecies("X", 3) < DummySpecies("X", 4)
 
 
 class FuncTest(unittest.TestCase):
     def test_get_el_sp(self):
-        self.assertEqual(get_el_sp("Fe2+"), Species("Fe", 2))
-        self.assertEqual(get_el_sp("3"), Element.Li)
-        self.assertEqual(get_el_sp("3.0"), Element.Li)
-        self.assertEqual(get_el_sp("U"), Element.U)
-        self.assertEqual(get_el_sp("X2+"), DummySpecies("X", 2))
-        self.assertEqual(get_el_sp("Mn3+"), Species("Mn", 3))
+        assert get_el_sp("Fe2+") == Species("Fe", 2)
+        assert get_el_sp("3") == Element.Li
+        assert get_el_sp("3.0") == Element.Li
+        assert get_el_sp("U") == Element.U
+        assert get_el_sp("X2+") == DummySpecies("X", 2)
+        assert get_el_sp("Mn3+") == Species("Mn", 3)
 
 
 if __name__ == "__main__":
