@@ -21,7 +21,7 @@ References are:
     BoltzTraP. A code for calculating band-structure dependent quantities.
     Computer Physics Communications, 175, 67-71
 
-TODO:
+Todo:
 - DONE: spin polarized bands
 - read first derivative of the eigenvalues from vasprun.xml (mommat)
 - handle magnetic moments (magmom)
@@ -69,11 +69,11 @@ class VasprunBSLoader:
             obj: Either a pmg Vasprun or a BandStructure object.
             structure: Structure object in case is not included in the BandStructure object.
             nelect: number of electrons in case a BandStructure obj is provided.
+
         Example:
             vrun = Vasprun('vasprun.xml')
             data = VasprunBSLoader(vrun)
         """
-
         if isinstance(obj, Vasprun):
             structure = obj.final_structure
             nelect = obj.parameters["NELECT"]
@@ -113,7 +113,7 @@ class VasprunBSLoader:
         self.mommat = None  # not implemented yet
         self.magmom = None  # not implemented yet
         self.fermi = bs_obj.efermi * units.eV
-        self.UCvol = self.structure.volume * units.Angstrom ** 3
+        self.UCvol = self.structure.volume * units.Angstrom**3
 
         if not bs_obj.is_metal():
             self.vbm_idx = max(bs_obj.get_vbm()["band_index"][Spin.up] + bs_obj.get_vbm()["band_index"][Spin.down])
@@ -123,8 +123,8 @@ class VasprunBSLoader:
         else:
             self.vbm_idx = None
             self.cbm_idx = None
-            self.vbm = self.fermi
-            self.cbm = self.fermi
+            self.vbm = self.fermi / units.eV
+            self.cbm = self.fermi / units.eV
 
         if nelect:
             self.nelect_all = nelect
@@ -205,7 +205,6 @@ class BandstructureLoader:
             ne = vrun.parameters['NELECT']
             data = BandstructureLoader(bs,st,ne)
         """
-
         warnings.warn("Deprecated Loader. Use VasprunBSLoader instead.")
 
         self.kpoints = np.array([kp.frac_coords for kp in bs_obj.kpoints])
@@ -236,7 +235,7 @@ class BandstructureLoader:
         self.mommat = mommat  # not implemented yet
         self.magmom = magmom  # not implemented yet
         self.fermi = bs_obj.efermi * units.eV
-        self.UCvol = self.structure.volume * units.Angstrom ** 3
+        self.UCvol = self.structure.volume * units.Angstrom**3
 
         if not bs_obj.is_metal():
             self.vbm_idx = max(bs_obj.get_vbm()["band_index"][Spin.up] + bs_obj.get_vbm()["band_index"][Spin.down])
@@ -326,7 +325,6 @@ class VasprunLoader:
         """
         vrun_obj: Vasprun object.
         """
-
         warnings.warn("Deprecated Loader. Use VasprunBSLoader instead.")
 
         if vrun_obj:
@@ -352,7 +350,7 @@ class VasprunLoader:
             self.spin = None
             self.fermi = vrun_obj.efermi * units.eV
             self.nelect = vrun_obj.parameters["NELECT"]
-            self.UCvol = self.structure.volume * units.Angstrom ** 3
+            self.UCvol = self.structure.volume * units.Angstrom**3
 
             bs_obj = vrun_obj.get_band_structure()
             if not bs_obj.is_metal():
@@ -447,7 +445,7 @@ class BztInterpolator:
                 bands that will be interpolated
                 and taken into account to calculate the transport properties.
             curvature: boolean value to enable/disable the calculation of second
-                derivative related trasport properties (Hall coefficient).
+                derivative related transport properties (Hall coefficient).
             save_bztInterp: Default False. If True coefficients and equivalences are
                 saved in fname file.
             load_bztInterp: Default False. If True the coefficients and equivalences
@@ -530,13 +528,12 @@ class BztInterpolator:
                       'X':np.array(0.5,0.5,0.)}
         density: Number of points in each segment.
         """
-
         if isinstance(kpaths, list) and isinstance(kpoints_lbls_dict, dict):
             kpoints = []
             for kpath in kpaths:
-                for i, k in enumerate(kpath[:-1]):
-                    sta = kpoints_lbls_dict[kpath[i]]
-                    end = kpoints_lbls_dict[kpath[i + 1]]
+                for idx, k_pt in enumerate(kpath[:-1]):
+                    sta = kpoints_lbls_dict[k_pt]
+                    end = kpoints_lbls_dict[kpath[idx + 1]]
                     kpoints.append(np.linspace(sta, end, density))
             kpoints = np.concatenate(kpoints)
         else:
@@ -664,7 +661,7 @@ class BztTransportProperties:
     def __init__(
         self,
         BztInterpolator,
-        temp_r=np.arange(100, 1400, 100),
+        temp_r=None,
         doping=None,
         npts_mu=4000,
         CRTA=1e-14,
@@ -676,17 +673,17 @@ class BztTransportProperties:
         """
         Args:
             BztInterpolator: a BztInterpolator previously generated
-            temp_r: numpy array of temperatures at which to calculate trasport properties
-            doping: doping levels at which to calculate trasport properties. If provided,
+            temp_r: numpy array of temperatures at which to calculate transport properties
+            doping: doping levels at which to calculate transport properties. If provided,
                 transport properties w.r.t. these doping levels are also computed. See
                 compute_properties_doping() method for details.
-            npts_mu: number of energy points at which to calculate trasport properties
+            npts_mu: number of energy points at which to calculate transport properties
             CRTA: constant value of the relaxation time
-            save_bztTranspProps: Default False. If True all computed tranport properties
+            save_bztTranspProps: Default False. If True all computed transport properties
                 will be stored in fname file.
-            load_bztTranspProps: Default False. If True all computed tranport properties
+            load_bztTranspProps: Default False. If True all computed transport properties
                 will be loaded from fname file.
-            fname: File path where to save/load tranport properties.
+            fname: File path where to save/load transport properties.
 
         Upon creation, it contains properties tensors w.r.t. the chemical potential
         of size (len(temp_r),npts_mu,3,3):
@@ -703,6 +700,8 @@ class BztTransportProperties:
         Example:
             bztTransp = BztTransportProperties(bztInterp,temp_r = np.arange(100,1400,100))
         """
+        if temp_r is None:
+            temp_r = np.arange(100, 1400, 100)
 
         self.dosweight = BztInterpolator.data.dosweight
         self.volume = BztInterpolator.data.get_volume()
@@ -771,7 +770,7 @@ class BztTransportProperties:
                         cond_eff_mass[t, i] = (
                             np.linalg.inv(self.Conductivity_mu[t, i])
                             * self.Carrier_conc_mu[t, i]
-                            * units.qe_SI ** 2
+                            * units.qe_SI**2
                             / units.me_SI
                             * 1e6
                         )
@@ -798,7 +797,7 @@ class BztTransportProperties:
         Calculate all the properties w.r.t. the doping levels in input.
 
         Args:
-            doping: numpy array specifing the doping levels
+            doping: numpy array specifying the doping levels
 
         When executed, it add the following variable at the BztTransportProperties
         object:
@@ -808,7 +807,6 @@ class BztTransportProperties:
             Carriers_conc_doping: carriers concentration for each doping level and T.
             mu_doping_eV: the chemical potential corrispondent to each doping level.
         """
-
         if temp_r is None:
             temp_r = self.temp_r
 
@@ -883,7 +881,7 @@ class BztTransportProperties:
             for t in range(len(temp_r)):
                 for i, dop in enumerate(doping):
                     try:
-                        cond_eff_mass[t, i] = np.linalg.inv(cond[t, i]) * dop * units.qe_SI ** 2 / units.me_SI * 1e6
+                        cond_eff_mass[t, i] = np.linalg.inv(cond[t, i]) * dop * units.qe_SI**2 / units.me_SI * 1e6
                     except np.linalg.LinAlgError:
                         pass
 
@@ -914,7 +912,7 @@ class BztTransportProperties:
     #     return epsilon[pos]
 
     def save(self, fname="bztTranspProps.json.gz"):
-        """Save the tranport properties to fname file."""
+        """Save the transport properties to fname file."""
         lst_props = [
             self.temp_r,
             self.CRTA,
@@ -950,7 +948,7 @@ class BztTransportProperties:
         dumpfn(lst_props, fname)
 
     def load(self, fname="bztTranspProps.json.gz"):
-        """Load the tranport properties from fname file."""
+        """Load the transport properties from fname file."""
         d = loadfn(fname)
         (
             self.temp_r,
@@ -1078,7 +1076,6 @@ class BztPlotter:
         more example are provided in the notebook
         "How to use Boltztra2 interface.ipynb".
         """
-
         props = (
             "Conductivity",
             "Seebeck",
