@@ -14,6 +14,7 @@ import warnings
 import numpy as np
 from monty.json import MSONable
 from scipy.interpolate import InterpolatedUnivariateSpline
+
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Orbital, Spin
@@ -53,7 +54,7 @@ class Cohp(MSONable):
         self.icohp = icohp
 
     def __repr__(self):
-        return self.__str__()
+        return str(self)
 
     def __str__(self):
         """
@@ -80,16 +81,16 @@ class Cohp(MSONable):
         formatdata = " ".join(["{:.5f}" for __ in header])
         stringarray = [formatheader.format(*header)]
         for i, __ in enumerate(self.energies):
-            stringarray.append(formatdata.format(*[d[i] for d in data]))
+            stringarray.append(formatdata.format(*(d[i] for d in data)))
         return "\n".join(stringarray)
 
     def as_dict(self):
         """
-        Json-serializable dict representation of COHP.
+        JSON-serializable dict representation of COHP.
         """
         d = {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "are_coops": self.are_coops,
             "are_cobis": self.are_cobis,
             "efermi": self.efermi,
@@ -158,7 +159,6 @@ class Cohp(MSONable):
         Returns dict indicating if there are antibonding states below the Fermi level depending on the spin
             spin: Spin
             limit: -COHP smaller -limit will be considered.
-
         """
         warnings.warn("This method has not been tested on many examples. Check the parameter limit, pls!")
 
@@ -192,7 +192,6 @@ class Cohp(MSONable):
     def from_dict(cls, d):
         """
         Returns a COHP object from a dict representation of the COHP.
-
         """
         if "ICOHP" in d:
             icohp = {Spin(int(key)): np.array(val) for key, val in d["ICOHP"].items()}
@@ -263,7 +262,7 @@ class CompleteCohp(Cohp):
     ):
         """
         Args:
-            structure: Structure assosciated with this COHP.
+            structure: Structure associated with this COHP.
             avg_cohp: The average cohp as a COHP object.
             cohps: A dict of COHP objects for individual bonds of the form
                 {label: COHP}
@@ -273,9 +272,9 @@ class CompleteCohp(Cohp):
                 the bond length, and the number of bonds. If nothing is
                 supplied, it will default to an empty dict.
             are_coops: indicates whether the Cohp objects are COOPs.
-                Defauls to False for COHPs.
+                Defaults to False for COHPs.
             are_cobis: indicates whether the Cohp objects are COBIs.
-                Defauls to False for COHPs.
+                Defaults to False for COHPs.
             orb_res_cohp: Orbital-resolved COHPs.
         """
         if are_coops and are_cobis:
@@ -294,7 +293,7 @@ class CompleteCohp(Cohp):
         self.all_cohps = cohp_dict
         self.orb_res_cohp = orb_res_cohp
         if bonds is None:
-            self.bonds = {label: {} for label in self.all_cohps.keys()}
+            self.bonds = {label: {} for label in self.all_cohps}
         else:
             self.bonds = bonds
 
@@ -307,11 +306,11 @@ class CompleteCohp(Cohp):
 
     def as_dict(self):
         """
-        Json-serializable dict representation of CompleteCohp.
+        JSON-serializable dict representation of CompleteCohp.
         """
         d = {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "are_coops": self.are_coops,
             "are_cobis": self.are_cobis,
             "efermi": self.efermi,
@@ -323,10 +322,10 @@ class CompleteCohp(Cohp):
         if self.icohp is not None:
             d["ICOHP"] = {"average": {str(spin): pops.tolist() for spin, pops in self.icohp.items()}}
 
-        for label in self.all_cohps.keys():
+        for label in self.all_cohps:
             d["COHP"].update({label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].cohp.items()}})
             if self.all_cohps[label].icohp is not None:
-                if "ICOHP" not in d.keys():
+                if "ICOHP" not in d:
                     d["ICOHP"] = {
                         label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].icohp.items()}
                     }
@@ -543,7 +542,7 @@ class CompleteCohp(Cohp):
                 else:
                     raise TypeError("Orbital must be str, int, or Orbital.")
             orb_index = cohp_orbs.index(orbs)
-            orb_label = list(self.orb_res_cohp[label].keys())[orb_index]
+            orb_label = list(self.orb_res_cohp[label])[orb_index]
         elif isinstance(orbitals, str):
             orb_label = orbitals
         else:
@@ -584,7 +583,7 @@ class CompleteCohp(Cohp):
         efermi = d["efermi"]
         energies = d["energies"]
         structure = Structure.from_dict(d["structure"])
-        if "bonds" in d.keys():
+        if "bonds" in d:
             bonds = {
                 bond: {
                     "length": d["bonds"][bond]["length"],
@@ -605,7 +604,7 @@ class CompleteCohp(Cohp):
             else:
                 cohp_dict[label] = Cohp(efermi, energies, cohp, icohp=icohp)
 
-        if "orb_res_cohp" in d.keys():
+        if "orb_res_cohp" in d:
             orb_cohp = {}
             for label in d["orb_res_cohp"]:
                 orb_cohp[label] = {}
@@ -664,7 +663,7 @@ class CompleteCohp(Cohp):
         else:
             orb_cohp = None
 
-        if "average" not in d["COHP"].keys():
+        if "average" not in d["COHP"]:
             # calculate average
             cohp = np.array([np.array(c) for c in d["COHP"].values()]).mean(axis=0)
             try:
@@ -745,7 +744,7 @@ class CompleteCohp(Cohp):
             cohp_file = Cohpcar(filename=filename, are_coops=are_coops, are_cobis=are_cobis)
             orb_res_cohp = cohp_file.orb_res_cohp
         else:
-            raise ValueError("Unknown format %s. Valid formats are LMTO and LOBSTER." % fmt)
+            raise ValueError(f"Unknown format {fmt}. Valid formats are LMTO and LOBSTER.")
 
         structure = Structure.from_file(structure_file)
         efermi = cohp_file.efermi
@@ -1006,7 +1005,6 @@ class IcohpValue(MSONable):
         tells if spin polarized calculation or not
         Returns:
             Boolean
-
         """
         return self._is_spin_polarized
 
@@ -1133,7 +1131,6 @@ class IcohpCollection(MSONable):
         Returns:
             float describing ICOHP/ICOOP value
         """
-
         icohp_here = self._icohplist[label]
         if icohp_here._is_spin_polarized:
             if summed_spin_channels:
@@ -1208,7 +1205,6 @@ class IcohpCollection(MSONable):
         Returns:
              dict of IcohpValues, the keys correspond to the values from the initial list_labels
         """
-
         newicohp_dict = {}
         for key, value in self._icohplist.items():
             atomnumber1 = int(re.split(r"(\d+)", value._atom1)[1]) - 1
