@@ -19,15 +19,15 @@ class ExpEntryTest(unittest.TestCase):
         self.entry = ExpEntry("Fe2O3", thermodata)
 
     def test_energy(self):
-        self.assertAlmostEqual(self.entry.energy, -825.5)
+        assert round(abs(self.entry.energy - -825.5), 7) == 0
 
     def test_to_from_dict(self):
         d = self.entry.as_dict()
         e = ExpEntry.from_dict(d)
-        self.assertAlmostEqual(e.energy, -825.5)
+        assert round(abs(e.energy - -825.5), 7) == 0
 
     def test_str(self):
-        self.assertIsNotNone(str(self.entry))
+        assert str(self.entry) is not None
 
 
 if __name__ == "__main__":
