@@ -4,17 +4,19 @@
 
 import unittest
 import warnings
+from shutil import which
 
 import requests
 
-from monty.os.path import which
-
 from pymatgen.ext.cod import COD
 
-website_is_up = requests.get("https://www.crystallography.net").status_code == 200
+try:
+    website_down = requests.get("https://www.crystallography.net").status_code != 200
+except requests.exceptions.ConnectionError:
+    website_down = True
 
 
-@unittest.skipIf(not website_is_up, "www.crystallography.net is down.")
+@unittest.skipIf(website_down, "www.crystallography.net is down.")
 class CODTest(unittest.TestCase):
     _multiprocess_shared_ = True
 
@@ -27,17 +29,17 @@ class CODTest(unittest.TestCase):
     @unittest.skipIf(not which("mysql"), "No mysql.")
     def test_get_cod_ids(self):
         ids = COD().get_cod_ids("Li2O")
-        self.assertTrue(len(ids) > 15)
+        assert len(ids) > 15
 
     @unittest.skipIf(not which("mysql"), "No mysql.")
     def test_get_structure_by_formula(self):
         data = COD().get_structure_by_formula("Li2O")
-        self.assertTrue(len(data) > 15)
-        self.assertEqual(data[0]["structure"].composition.reduced_formula, "Li2O")
+        assert len(data) > 15
+        assert data[0]["structure"].composition.reduced_formula == "Li2O"
 
     def test_get_structure_by_id(self):
         s = COD().get_structure_by_id(2002926)
-        self.assertEqual(s.formula, "Be8 H64 N16 F32")
+        assert s.formula == "Be8 H64 N16 F32"
 
 
 if __name__ == "__main__":
