@@ -2,7 +2,7 @@
 # Distributed under the terms of the MIT License.
 """
 This module provides objects for extracting timing data from the ABINIT output files
-It also provides tools to analye and to visualize the parallel efficiency.
+It also provides tools to analyze and to visualize the parallel efficiency.
 """
 
 import collections
@@ -46,7 +46,7 @@ class AbinitTimerParser(collections.abc.Iterable):
         parser = AbinitTimerParser()
         parser.parse(list_of_files)
 
-    To analyze all *.abo files withing top, use:
+    To analyze all *.abo files within top, use:
 
         parser, paths, okfiles = AbinitTimerParser.walk(top=".", ext=".abo")
     """
@@ -71,7 +71,7 @@ class AbinitTimerParser(collections.abc.Iterable):
             (okfiles == paths) if all files have been parsed.
         """
         paths = []
-        for root, dirs, files in os.walk(top):
+        for root, _dirs, files in os.walk(top):
             for f in files:
                 if f.endswith(ext):
                     paths.append(os.path.join(root, f))
@@ -87,7 +87,7 @@ class AbinitTimerParser(collections.abc.Iterable):
 
         # timers[filename][mpi_rank]
         # contains the timer extracted from the file filename associated to the MPI rank mpi_rank.
-        self._timers = collections.OrderedDict()
+        self._timers = {}
 
     def __iter__(self):
         return self._timers.__iter__()
@@ -114,7 +114,7 @@ class AbinitTimerParser(collections.abc.Iterable):
             try:
                 fh = open(fname)  # pylint: disable=R1732
             except OSError:
-                logger.warning("Cannot open file %s" % fname)
+                logger.warning(f"Cannot open file {fname}")
                 continue
 
             try:
@@ -122,7 +122,7 @@ class AbinitTimerParser(collections.abc.Iterable):
                 read_ok.append(fname)
 
             except self.Error as e:
-                logger.warning(f"exception while parsing file {fname}:\n{str(e)}")
+                logger.warning(f"exception while parsing file {fname}:\n{e}")
                 continue
 
             finally:
@@ -135,7 +135,7 @@ class AbinitTimerParser(collections.abc.Iterable):
     def _read(self, fh, fname):
         """Parse the TIMER section"""
         if fname in self._timers:
-            raise self.Error("Cannot overwrite timer associated to: %s " % fname)
+            raise self.Error(f"Cannot overwrite timer associated to: {fname} ")
 
         def parse_line(line):
             """Parse single line."""
@@ -150,6 +150,7 @@ class AbinitTimerParser(collections.abc.Iterable):
 
         sections, info, cpu_time, wall_time = None, None, None, None
         data = {}
+        parser_failed = False
         inside, has_timer = 0, False
         for line in fh:
             # print(line.strip())
@@ -168,7 +169,7 @@ class AbinitTimerParser(collections.abc.Iterable):
             elif line.startswith(self.END_TAG):
                 inside = 0
                 timer = AbinitTimer(sections, info, cpu_time, wall_time)
-                mpi_rank = info["mpi_rank"]
+                mpi_rank = info["mpi_rank"]  # pylint: disable=E1136
                 data[mpi_rank] = timer
 
             elif inside:
@@ -195,7 +196,7 @@ class AbinitTimerParser(collections.abc.Iterable):
                         raise self.Error("line should be empty: " + str(inside) + line)
 
         if not has_timer:
-            raise self.Error("%s: No timer section found" % fname)
+            raise self.Error(f"{fname}: No timer section found")
 
         # Add it to the dict
         self._timers[fname] = data
@@ -314,7 +315,7 @@ class AbinitTimerParser(collections.abc.Iterable):
         ]
 
         frame = pd.DataFrame(columns=colnames)
-        for i, timer in enumerate(self.timers()):
+        for timer in self.timers():
             frame = frame.append({k: getattr(timer, k) for k in colnames}, ignore_index=True)
         frame["tot_ncpus"] = frame["mpi_nprocs"] * frame["omp_nthreads"]
 
@@ -397,7 +398,7 @@ class AbinitTimerParser(collections.abc.Iterable):
         ax.grid(True)
 
         # Set xticks and labels.
-        labels = ["MPI=%d, OMP=%d" % (t.mpi_nprocs, t.omp_nthreads) for t in timers]
+        labels = [f"MPI={t.mpi_nprocs}, OMP={t.omp_nthreads}" for t in timers]
         ax.set_xticks(xx)
         ax.set_xticklabels(labels, fontdict=None, minor=False, rotation=15)
 
@@ -439,7 +440,7 @@ class AbinitTimerParser(collections.abc.Iterable):
         Args:
             key: Keyword used to extract data from the timers. Only the first `nmax`
                 sections with largest value are show.
-            mmax: Maximum nuber of sections to show. Other entries are grouped together
+            mmax: Maximum number of sections to show. Other entries are grouped together
                 in the `others` section.
             ax: matplotlib :class:`Axes` or None if a new figure should be created.
 
@@ -464,7 +465,7 @@ class AbinitTimerParser(collections.abc.Iterable):
             else:
                 rest += svals
 
-        names.append("others (nmax=%d)" % nmax)
+        names.append(f"others (nmax={nmax})")
         values.append(rest)
 
         # The dataset is stored in values. Now create the stacked histogram.
@@ -481,10 +482,10 @@ class AbinitTimerParser(collections.abc.Iterable):
             bottom += vals
 
         ax.set_ylabel(key)
-        ax.set_title("Stacked histogram with the %d most important sections" % nmax)
+        ax.set_title(f"Stacked histogram with the {nmax} most important sections")
 
         ticks = ind + width / 2.0
-        labels = ["MPI=%d, OMP=%d" % (t.mpi_nprocs, t.omp_nthreads) for t in timers]
+        labels = [f"MPI={t.mpi_nprocs}, OMP={t.omp_nthreads}" for t in timers]
         ax.set_xticks(ticks)
         ax.set_xticklabels(labels, rotation=15)
 
@@ -562,7 +563,7 @@ class ParallelEfficiency(dict):
             fract = self[sect_name]["wall_fract"]
             vals = alternate(peff, fract)
 
-            table.append([sect_name] + ["%.2f" % val for val in vals])
+            table.append([sect_name] + [f"{val:.2f}" for val in vals])
 
         return table
 
@@ -671,14 +672,10 @@ class AbinitTimer:
         self.fname = info["fname"].strip()
 
     def __str__(self):
-        string = "file=%s, wall_time=%.1f, mpi_nprocs=%d, omp_nthreads=%d" % (
-            self.fname,
-            self.wall_time,
-            self.mpi_nprocs,
-            self.omp_nthreads,
+        return (
+            f"file={self.fname}, wall_time={self.wall_time:.1f}, "
+            f"mpi_nprocs={self.mpi_nprocs}, omp_nthreads={self.omp_nthreads}"
         )
-        # string += ", rank = " + self.mpi_rank
-        return string
 
     @property
     def ncpus(self):
