@@ -4,6 +4,7 @@ IO for ADF files.
 
 import os
 import re
+from typing import Generator
 
 from monty.io import reverse_readline
 from monty.itertools import chunks
@@ -38,20 +39,14 @@ def is_numeric(s):
         return True
 
 
-def iterlines(s):
-    r"""
-    A generator form of s.split('\n') for reducing memory overhead.
+def iterlines(s: str) -> Generator[str, None, None]:
+    r"""A generator form of s.split('\n') for reducing memory overhead.
 
-    Parameters
-    ----------
-    s : str
-        A multi-line string.
-
-    Yields
-    ------
-    line : str
-        A string.
+    Args:
+        s (str): A multi-line string.
 
+    Yields:
+        str: line
     """
     prevnl = -1
     while True:
@@ -68,16 +63,12 @@ class AdfInputError(Exception):
     The default error class for ADF.
     """
 
-    pass
-
 
 class AdfOutputError(Exception):
     """
     The default error class for errors raised by ``AdfOutput``.
     """
 
-    pass
-
 
 class AdfKey(MSONable):
     """
@@ -131,7 +122,6 @@ class AdfKey(MSONable):
         ------
         ValueError
             If elements in ``subkeys`` are not ``AdfKey`` objects.
-
         """
         self.name = name
         self.options = options if options is not None else []
@@ -152,9 +142,9 @@ class AdfKey(MSONable):
             s = ""
             for op in self.options:
                 if self._sized_op:
-                    s += "{:s}={:s} ".format(*map(str, op))
+                    s += f"{op[0]}={op[1]} "
                 else:
-                    s += f"{str(op):s} "
+                    s += f"{op} "
             return s.strip()
         return ""
 
@@ -182,16 +172,18 @@ class AdfKey(MSONable):
         -----
         If this key is 'Atoms' and the coordinates are in Cartesian form, a
         different string format will be used.
-
         """
-        s = f"{self.key:s}"
+        s = f"{self.key}"
         if len(self.options) > 0:
-            s += f" {self._options_string():s}"
+            s += f" {self._options_string()}"
         s += "\n"
         if len(self.subkeys) > 0:
             if self.key.lower() == "atoms":
                 for subkey in self.subkeys:
-                    s += "{:2s}  {: 14.8f}    {: 14.8f}    {: 14.8f}\n".format(subkey.name, *subkey.options)
+                    s += (
+                        f"{subkey.name:2s}  {subkey.options[0]: 14.8f}"
+                        f"    {subkey.options[1]: 14.8f}    {subkey.options[2]: 14.8f}\n"
+                    )
             else:
                 for subkey in self.subkeys:
                     s += str(subkey)
@@ -203,7 +195,7 @@ class AdfKey(MSONable):
             s += "END\n"
         return s
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, AdfKey):
             return False
         return str(self) == str(other)
@@ -221,7 +213,6 @@ class AdfKey(MSONable):
         -------
         has : bool
             True if this key contains the given key. Otherwise False.
-
         """
         if isinstance(subkey, str):
             key = subkey
@@ -246,7 +237,6 @@ class AdfKey(MSONable):
         Notes
         -----
         Duplicate check will not be performed if this is an 'Atoms' block.
-
         """
         if self.key.lower() == "atoms" or not self.has_subkey(subkey):
             self.subkeys.append(subkey)
@@ -259,7 +249,6 @@ class AdfKey(MSONable):
         ----------
         subkey : str or AdfKey
             The subkey to remove.
-
         """
         if len(self.subkeys) > 0:
             key = subkey if isinstance(subkey, str) else subkey.key
@@ -275,14 +264,13 @@ class AdfKey(MSONable):
         Parameters
         ----------
         option : Sized or str or int or float
-            A new option to add. This must have the same format with exsiting
+            A new option to add. This must have the same format with existing
             options.
 
         Raises
         ------
         TypeError
             If the format of the given ``option`` is different.
-
         """
         if len(self.options) == 0:
             self.options.append(option)
@@ -305,7 +293,6 @@ class AdfKey(MSONable):
         ------
         TypeError
             If the option has a wrong type.
-
         """
         if len(self.options) > 0:
             if self._sized_op:
@@ -333,7 +320,6 @@ class AdfKey(MSONable):
         -------
         has : bool
             True if the option can be found. Otherwise False will be returned.
-
         """
         if len(self.options) == 0:
             return False
@@ -344,11 +330,11 @@ class AdfKey(MSONable):
 
     def as_dict(self):
         """
-        A JSON serializable dict representation of self.
+        A JSON-serializable dict representation of self.
         """
         d = {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "name": self.name,
             "options": self.options,
         }
@@ -359,12 +345,6 @@ class AdfKey(MSONable):
             d.update({"subkeys": subkeys})
         return d
 
-    def to_json(self):
-        """
-        Return a json string representation of the MSONable AdfKey object.
-        """
-        return super().to_json()
-
     @classmethod
     def from_dict(cls, d):
         """
@@ -379,7 +359,6 @@ class AdfKey(MSONable):
         -------
         adfkey : AdfKey
             An AdfKey object recovered from the JSON dict ``d``.
-
         """
         key = d.get("name")
         options = d.get("options", None)
@@ -414,7 +393,6 @@ class AdfKey(MSONable):
         Notes
         -----
         Only the first block key will be returned.
-
         """
 
         def is_float(s):
@@ -510,10 +488,9 @@ class AdfTask(MSONable):
             The scf options.
         other_directives : Sized
             User-defined directives.
-
         """
-        if operation not in self.operations.keys():
-            raise AdfInputError(f"Invalid ADF task {operation:s}")
+        if operation not in self.operations:
+            raise AdfInputError(f"Invalid ADF task {operation}")
         self.operation = operation
         self.title = title
         self.basis_set = basis_set if basis_set is not None else self.get_default_basis_set()
@@ -571,7 +548,6 @@ class AdfTask(MSONable):
         -----
         Most of the run types of ADF are specified in the Geometry block except
         the 'AnalyticFreq'.
-
         """
         self.geo = AdfKey("Geometry", subkeys=geo_subkeys)
         if self.operation.lower() == "energy":
@@ -590,33 +566,26 @@ class AdfTask(MSONable):
                 self.geo.remove_subkey("Frequencies")
 
     def __str__(self):
-        s = """TITLE {title}\n
-{units}
-{xc}
-{basis_set}
-{scf}
-{geo}""".format(
-            title=self.title,
-            units=str(self.units),
-            xc=str(self.xc),
-            basis_set=str(self.basis_set),
-            scf=str(self.scf),
-            geo=str(self.geo),
-        )
+        s = f"""TITLE {self.title}\n
+{str(self.units)}
+{str(self.xc)}
+{str(self.basis_set)}
+{str(self.scf)}
+{str(self.geo)}"""
         s += "\n"
         for block_key in self.other_directives:
             if not isinstance(block_key, AdfKey):
-                raise ValueError(f"{str(block_key)} is not an AdfKey!")
+                raise ValueError(f"{block_key} is not an AdfKey!")
             s += str(block_key) + "\n"
         return s
 
     def as_dict(self):
         """
-        A JSON serializable dict representation of self.
+        A JSON-serializable dict representation of self.
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "operation": self.operation,
             "title": self.title,
             "xc": self.xc.as_dict(),
@@ -627,12 +596,6 @@ class AdfTask(MSONable):
             "others": [k.as_dict() for k in self.other_directives],
         }
 
-    def to_json(self):
-        """
-        Return a json string representation of the MSONable AdfTask object.
-        """
-        return super().to_json()
-
     @classmethod
     def from_dict(cls, d):
         """
@@ -647,7 +610,6 @@ class AdfTask(MSONable):
         -------
         task : AdfTask
             An AdfTask object recovered from the JSON dict ``d``.
-
         """
 
         def _from_dict(_d):
@@ -678,7 +640,6 @@ class AdfInput:
         ----------
         task : AdfTask
             An ADF task.
-
         """
         self.task = task
 
@@ -692,9 +653,7 @@ class AdfInput:
             The molecule for this task.
         inpfile : str
             The name where the input file will be saved.
-
         """
-
         mol_blocks = []
         atom_block = AdfKey("Atoms", options=["cartesian"])
         for site in molecule:
@@ -758,7 +717,6 @@ class AdfOutput:
         ----------
         filename : str
             The ADF output file to parse.
-
         """
         self.filename = filename
         self._parse()
@@ -805,7 +763,6 @@ class AdfOutput:
         -------
         mol : Molecule
             A ``Molecule`` object.
-
         """
         return Molecule([site[0] for site in sites], [site[1] for site in sites])
 
@@ -813,7 +770,6 @@ class AdfOutput:
         """
         Parse the formatted logfile.
         """
-
         cycle_patt = re.compile(r"Coordinates\sin\sGeometry\sCycle\s(\d+)")
         coord_patt = re.compile(r"\s+([0-9]+)\.([A-Za-z]+)" + 3 * r"\s+([-\.0-9]+)")
         energy_patt = re.compile(r"<.*>\s<.*>\s+current\senergy\s+([-\.0-9]+)\sHartree")
@@ -982,7 +938,7 @@ class AdfOutput:
                         parse_mode = True
                         parse_freq = False
                         self.frequencies.extend(map(float, el))
-                        for i in range(nnext):
+                        for _ in range(nnext):
                             self.normal_modes.append([])
 
                 elif parse_mode:
