@@ -10,7 +10,7 @@ import os
 import re
 import textwrap
 import warnings
-from collections import OrderedDict, deque
+from collections import deque
 from functools import partial
 from inspect import getfullargspec as getargspec
 from io import StringIO
@@ -19,6 +19,7 @@ from pathlib import Path
 
 import numpy as np
 from monty.io import zopen
+from monty.serialization import loadfn
 from monty.string import remove_non_ascii
 
 from pymatgen.core.composition import Composition
@@ -37,22 +38,18 @@ __author__ = "Shyue Ping Ong, Will Richards, Matthew Horton"
 
 sub_spgrp = partial(re.sub, r"[\s_]", "")
 
-space_groups = {sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"].keys()}  # type: ignore
+space_groups = {sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"]}  # type: ignore
 
-space_groups.update({sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"].keys()})  # type: ignore
+space_groups.update({sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"]})  # type: ignore
 
 _COD_DATA = None
 
 
 def _get_cod_data():
     global _COD_DATA
+
     if _COD_DATA is None:
-        import pymatgen
-
-        with open(os.path.join(pymatgen.symmetry.__path__[0], "symm_ops.json")) as f:
-            import json
-
-            _COD_DATA = json.load(f)
+        _COD_DATA = loadfn(os.path.join(os.path.dirname(os.path.dirname(__file__)), "symmetry", "symm_ops.json"))
 
     return _COD_DATA
 
@@ -70,13 +67,10 @@ class CifBlock:
     def __init__(self, data, loops, header):
         """
         Args:
-            data: dict or OrderedDict of data to go into the cif. Values should
-                    be convertible to string, or lists of these if the key is
-                    in a loop
-            loops: list of lists of keys, grouped by which loop they should
-                    appear in
-            header: name of the block (appears after the data_ on the first
-                line)
+            data: dict of data to go into the cif. Values should be convertible to string,
+                or lists of these if the key is in a loop
+            loops: list of lists of keys, grouped by which loop they should appear in
+            header: name of the block (appears after the data_ on the first line)
         """
         self.loops = loops
         self.data = data
@@ -84,7 +78,9 @@ class CifBlock:
         # get an Exception
         self.header = header[:74]
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, CifBlock):
+            return NotImplemented
         return self.loops == other.loops and self.data == other.data and self.header == other.header
 
     def __getitem__(self, key):
@@ -95,7 +91,7 @@ class CifBlock:
         Returns the cif string for the data block
         """
         s = [f"data_{self.header}"]
-        keys = self.data.keys()
+        keys = list(self.data)
         written = []
         for k in keys:
             if k in written:
@@ -119,7 +115,7 @@ class CifBlock:
         s = "loop_"
         for l in loop:
             s += "\n " + l
-        for fields in zip(*[self.data[k] for k in loop]):
+        for fields in zip(*(self.data[k] for k in loop)):
             line = "\n"
             for val in map(self._format_field, fields):
                 if val[0] == ";":
@@ -134,7 +130,7 @@ class CifBlock:
         return s
 
     def _format_field(self, v):
-        v = v.__str__().strip()
+        v = str(v).strip()
         if len(v) > self.maxlen:
             return ";\n" + textwrap.fill(v, self.maxlen) + "\n;"
         # add quotes if necessary
@@ -197,7 +193,7 @@ class CifBlock:
         """
         q = cls._process_string(string)
         header = q.popleft()[0][5:]
-        data = OrderedDict()
+        data = {}
         loops = []
         while q:
             s = q.popleft()
@@ -229,7 +225,7 @@ class CifBlock:
                 for k, v in zip(columns * n, items):
                     data[k].append(v.strip())
             elif "".join(s).strip() != "":
-                warnings.warn("Possible issue in cif file at line: {}".format("".join(s).strip()))
+                warnings.warn(f"Possible issue in cif file at line: {''.join(s).strip()}")
         return cls(data, loops, header)
 
 
@@ -241,7 +237,7 @@ class CifFile:
     def __init__(self, data, orig_string=None, comment=None):
         """
         Args:
-            data (OrderedDict): Of CifBlock objects.å
+            data (dict): Of CifBlock objects.
             orig_string (str): The original cif string.
             comment (str): Comment string.
         """
@@ -250,7 +246,7 @@ class CifFile:
         self.comment = comment or "# generated using pymatgen"
 
     def __str__(self):
-        s = ["%s" % v for v in self.data.values()]
+        s = [f"{v}" for v in self.data.values()]
         return self.comment + "\n" + "\n".join(s) + "\n"
 
     @classmethod
@@ -261,7 +257,7 @@ class CifFile:
         :param string: String representation.
         :return: CifFile
         """
-        d = OrderedDict()
+        d = {}
         for x in re.split(r"^\s*data_", "x\n" + string, flags=re.MULTILINE | re.DOTALL)[1:]:
 
             # Skip over Cif block that contains powder diffraction data.
@@ -328,7 +324,7 @@ class CifParser:
                 "_space_group_symop_magn",
             ]
             for d in self._cif.data.values():
-                for k in d.data.keys():
+                for k in d.data:
                     for prefix in prefixes:
                         if prefix in k:
                             return True
@@ -342,13 +338,13 @@ class CifParser:
             structure (heuristic).
             """
             # Doesn't seem to be a canonical way to test if magCIF file
-            # describes incommensurate strucure or not, so instead check
+            # describes incommensurate structure or not, so instead check
             # for common datanames
             if not self.feature_flags["magcif"]:
                 return False
             prefixes = ["_cell_modulation_dimension", "_cell_wave_vector"]
             for d in self._cif.data.values():
-                for k in d.data.keys():
+                for k in d.data:
                     for prefix in prefixes:
                         if prefix in k:
                             return True
@@ -356,7 +352,7 @@ class CifParser:
 
         self.feature_flags["magcif_incommensurate"] = is_magcif_incommensurate()
 
-        for k in self._cif.data.keys():
+        for k in self._cif.data:
             # pass individual CifBlocks to _sanitize_data
             self._cif.data[k] = self._sanitize_data(self._cif.data[k])
 
@@ -388,15 +384,13 @@ class CifParser:
         :param data: CifBlock
         :return: data CifBlock
         """
-
         """
         This part of the code deals with handling formats of data as found in
         CIF files extracted from the Springer Materials/Pauling File
         databases, and that are different from standard ICSD formats.
         """
-
         # check for implicit hydrogens, warn if any present
-        if "_atom_site_attached_hydrogens" in data.data.keys():
+        if "_atom_site_attached_hydrogens" in data.data:
             attached_hydrogens = [str2float(x) for x in data.data["_atom_site_attached_hydrogens"] if str2float(x) != 0]
             if len(attached_hydrogens) > 0:
                 self.warnings.append(
@@ -407,7 +401,7 @@ class CifParser:
 
         # Check to see if "_atom_site_type_symbol" exists, as some test CIFs do
         # not contain this key.
-        if "_atom_site_type_symbol" in data.data.keys():
+        if "_atom_site_type_symbol" in data.data:
 
             # Keep a track of which data row needs to be removed.
             # Example of a row: Nb,Zr '0.8Nb + 0.2Zr' .2a .m-3m 0 0 0 1 14
@@ -435,9 +429,7 @@ class CifParser:
                 # Below, we split the strings on ' + ' to
                 # check if the length (or number of elements) in the label and
                 # symbol are equal.
-                if len(data["_atom_site_type_symbol"][idx].split(" + ")) > len(
-                    data["_atom_site_label"][idx].split(" + ")
-                ):
+                if len(data["_atom_site_type_symbol"][idx].split(" + ")) > len(el_row.split(" + ")):
 
                     # Dictionary to hold extracted elements and occupancies
                     els_occu = {}
@@ -492,13 +484,11 @@ class CifParser:
                 data.data["_atom_site_fract_x"] += new_fract_x
                 data.data["_atom_site_fract_y"] += new_fract_y
                 data.data["_atom_site_fract_z"] += new_fract_z
-
         """
         This fixes inconsistencies in naming of several magCIF tags
         as a result of magCIF being in widespread use prior to
         specification being finalized (on advice of Branton Campbell).
         """
-
         if self.feature_flags["magcif"]:
 
             # CIF-1 style has all underscores, interim standard
@@ -517,8 +507,7 @@ class CifParser:
                 "_atom_site_moment_label",
             ]
 
-            # cannot mutate OrderedDict during enumeration,
-            # so store changes we want to make
+            # cannot mutate dict during enumeration, so store changes we want to make
             changes_to_make = {}
 
             for original_key in data.data:
@@ -549,24 +538,24 @@ class CifParser:
             for final_key, interim_key in changes_to_make.items():
                 data.data[final_key] = data.data[interim_key]
 
-        # check for finite precision frac co-ordinates (e.g. 0.6667 instead of 0.6666666...7)
+        # check for finite precision frac coordinates (e.g. 0.6667 instead of 0.6666666...7)
         # this can sometimes cause serious issues when applying symmetry operations
         important_fracs = (1 / 3.0, 2 / 3.0)
         fracs_to_change = {}
         for label in ("_atom_site_fract_x", "_atom_site_fract_y", "_atom_site_fract_z"):
-            if label in data.data.keys():
+            if label in data.data:
                 for idx, frac in enumerate(data.data[label]):
                     try:
                         frac = str2float(frac)
                     except Exception:
-                        # co-ordinate might not be defined e.g. '?'
+                        # coordinate might not be defined e.g. '?'
                         continue
                     for comparison_frac in important_fracs:
                         if abs(1 - frac / comparison_frac) < 1e-4:
                             fracs_to_change[(label, idx)] = str(comparison_frac)
         if fracs_to_change:
             self.warnings.append(
-                "Some fractional co-ordinates rounded to ideal values to avoid issues with finite precision."
+                "Some fractional coordinates rounded to ideal values to avoid issues with finite precision."
             )
             for (label, idx), val in fracs_to_change.items():
                 data.data[label][idx] = val
@@ -623,12 +612,9 @@ class CifParser:
         """
         try:
 
-            lengths = [str2float(data["_cell_length_" + i]) for i in length_strings]
-            angles = [str2float(data["_cell_angle_" + i]) for i in angle_strings]
-            if not lattice_type:
-                return Lattice.from_parameters(*lengths, *angles)
-
-            return getattr(Lattice, lattice_type)(*(lengths + angles))
+            return self.get_lattice_no_exception(
+                data=data, angle_strings=angle_strings, lattice_type=lattice_type, length_strings=length_strings
+            )
 
         except KeyError:
             # Missing Key search for cell setting
@@ -653,6 +639,27 @@ class CifParser:
                     return None
         return None
 
+    @staticmethod
+    def get_lattice_no_exception(
+        data, length_strings=("a", "b", "c"), angle_strings=("alpha", "beta", "gamma"), lattice_type=None
+    ):
+        """
+        Generate the lattice from the provided lattice parameters.
+        Args:
+            data:
+            length_strings:
+            angle_strings:
+            lattice_type:
+
+        Returns:
+
+        """
+        lengths = [str2float(data["_cell_length_" + i]) for i in length_strings]
+        angles = [str2float(data["_cell_angle_" + i]) for i in angle_strings]
+        if not lattice_type:
+            return Lattice.from_parameters(*lengths, *angles)
+        return getattr(Lattice, lattice_type)(*(lengths + angles))
+
     def get_symops(self, data):
         """
         In order to generate symmetry equivalent positions, the symmetry
@@ -695,6 +702,7 @@ class CifParser:
                 "_symmetry_space_group_name_h-m_",
             ]:
                 sg = data.data.get(symmetry_label)
+                msg_template = "No _symmetry_equiv_pos_as_xyz type key found. Spacegroup from {} used."
 
                 if sg:
                     sg = sub_spgrp(sg)
@@ -702,10 +710,7 @@ class CifParser:
                         spg = space_groups.get(sg)
                         if spg:
                             symops = SpaceGroup(spg).symmetry_ops
-                            msg = (
-                                "No _symmetry_equiv_pos_as_xyz type key found. "
-                                "Spacegroup from %s used." % symmetry_label
-                            )
+                            msg = msg_template.format(symmetry_label)
                             warnings.warn(msg)
                             self.warnings.append(msg)
                             break
@@ -718,10 +723,7 @@ class CifParser:
                             if sg == re.sub(r"\s+", "", d["hermann_mauguin"]):
                                 xyz = d["symops"]
                                 symops = [SymmOp.from_xyz_string(s) for s in xyz]
-                                msg = (
-                                    "No _symmetry_equiv_pos_as_xyz type key found. "
-                                    "Spacegroup from %s used." % symmetry_label
-                                )
+                                msg = msg_template.format(symmetry_label)
                                 warnings.warn(msg)
                                 self.warnings.append(msg)
                                 break
@@ -892,7 +894,7 @@ class CifParser:
         # try with special symbols, otherwise check the first two letters,
         # then the first letter alone. If everything fails try extracting the
         # first letters.
-        m_sp = re.match("|".join(special.keys()), sym)
+        m_sp = re.match("|".join(special), sym)
         if m_sp:
             parsed_sym = special[m_sp.group()]
         elif Element.is_valid_symbol(sym[:2].title()):
@@ -904,7 +906,7 @@ class CifParser:
             if m:
                 parsed_sym = m.group()
 
-        if parsed_sym is not None and (m_sp or not re.match(fr"{parsed_sym}\d*", sym)):
+        if parsed_sym is not None and (m_sp or not re.match(rf"{parsed_sym}\d*", sym)):
             msg = f"{sym} parsed as {parsed_sym}"
             warnings.warn(msg)
             self.warnings.append(msg)
@@ -935,18 +937,18 @@ class CifParser:
 
         oxi_states = self.parse_oxi_states(data)
 
-        coord_to_species = OrderedDict()
-        coord_to_magmoms = OrderedDict()
+        coord_to_species = {}
+        coord_to_magmoms = {}
 
         def get_matching_coord(coord):
-            keys = list(coord_to_species.keys())
+            keys = list(coord_to_species)
             coords = np.array(keys)
             for op in self.symmetry_operations:
                 c = op.operate(coord)
                 inds = find_in_coord_list_pbc(coords, c, atol=self._site_tolerance)
-                # cant use if inds, because python is dumb and np.array([0]) evaluates
+                # can't use if inds, because python is dumb and np.array([0]) evaluates
                 # to False
-                if len(inds):
+                if len(inds) > 0:
                     return keys[inds[0]]
             return False
 
@@ -966,7 +968,7 @@ class CifParser:
             if oxi_states is not None:
                 o_s = oxi_states.get(symbol, 0)
                 # use _atom_site_type_symbol if possible for oxidation state
-                if "_atom_site_type_symbol" in data.data.keys():
+                if "_atom_site_type_symbol" in data.data:
                     oxi_symbol = data["_atom_site_type_symbol"][i]
                     o_s = oxi_states.get(oxi_symbol, o_s)
                 try:
@@ -1011,9 +1013,9 @@ class CifParser:
         ]
         if any(o > 1 for o in sum_occu):
             msg = (
-                "Some occupancies ({}) sum to > 1! If they are within "
+                f"Some occupancies ({sum_occu}) sum to > 1! If they are within "
                 "the occupancy_tolerance, they will be rescaled. "
-                "The current occupancy_tolerance is set to: {}".format(sum_occu, self._occupancy_tolerance)
+                f"The current occupancy_tolerance is set to: {self._occupancy_tolerance}"
             )
             warnings.warn(msg)
             self.warnings.append(msg)
@@ -1026,13 +1028,13 @@ class CifParser:
 
         # check to see if magCIF file is disordered
         if self.feature_flags["magcif"]:
-            for k, v in coord_to_magmoms.items():
+            for v in coord_to_magmoms.values():
                 if v is None:
                     # Proposed solution to this is to instead store magnetic
                     # moments as Species 'spin' property, instead of site
                     # property, but this introduces ambiguities for end user
                     # (such as unintended use of `spin` and Species will have
-                    # fictious oxidation state).
+                    # fictitious oxidation state).
                     raise NotImplementedError("Disordered magnetic structures not currently supported.")
 
         if coord_to_species.items():
@@ -1058,7 +1060,7 @@ class CifParser:
                     im_h = 0
                     species = comp
 
-                # The following might be a more natural representation of equivalent indicies,
+                # The following might be a more natural representation of equivalent indices,
                 # but is not in the format expect by SymmetrizedStructure:
                 #   equivalent_indices.append(list(range(len(allcoords), len(coords)+len(allcoords))))
                 # The above gives a list like:
@@ -1076,9 +1078,9 @@ class CifParser:
 
             # rescale occupancies if necessary
             for i, species in enumerate(allspecies):
-                totaloccu = sum(species.values())
-                if 1 < totaloccu <= self._occupancy_tolerance:
-                    allspecies[i] = species / totaloccu
+                total_occu = sum(species.values())
+                if 1 < total_occu <= self._occupancy_tolerance:
+                    allspecies[i] = species / total_occu
 
         if allspecies and len(allspecies) == len(allcoords) and len(allspecies) == len(allmagmoms):
             site_properties = {}
@@ -1138,7 +1140,6 @@ class CifParser:
         Returns:
             List of Structures.
         """
-
         if primitive and symmetrized:
             raise ValueError(
                 "Using both 'primitive' and 'symmetrized' arguments is not currently supported "
@@ -1156,12 +1157,12 @@ class CifParser:
                 # A user reported a problem with cif files produced by Avogadro
                 # in which the atomic coordinates are in Cartesian coords.
                 self.warnings.append(str(exc))
-                warnings.warn("No structure parsed for %d structure in CIF. Section of CIF file below." % (i + 1))
+                warnings.warn(f"No structure parsed for {i + 1} structure in CIF. Section of CIF file below.")
                 warnings.warn(str(d))
-                warnings.warn("Error is %s." % str(exc))
+                warnings.warn(f"Error is {str(exc)}.")
 
         if self.warnings:
-            warnings.warn("Issues encountered while parsing CIF: %s" % "\n".join(self.warnings))
+            warnings.warn("Issues encountered while parsing CIF: " + "\n".join(self.warnings))
         if len(structures) == 0:
             raise ValueError("Invalid cif file with no structures!")
         return structures
@@ -1172,7 +1173,6 @@ class CifParser:
         :param data:
         :return: BibTeX string
         """
-
         try:
             from pybtex.database import BibliographyData, Entry
         except ImportError:
@@ -1227,10 +1227,7 @@ class CifParser:
 
             # convert to bibtex page range format, use empty string if not specified
             if ("page_first" in bibtex_entry) or ("page_last" in bibtex_entry):
-                bibtex_entry["pages"] = "{}--{}".format(
-                    bibtex_entry.get("page_first", ""),
-                    bibtex_entry.get("page_last", ""),
-                )
+                bibtex_entry["pages"] = bibtex_entry.get("page_first", "") + "--" + bibtex_entry.get("page_last", "")
                 bibtex_entry.pop("page_first", None)  # and remove page_first, page_list if present
                 bibtex_entry.pop("page_last", None)
 
@@ -1243,7 +1240,7 @@ class CifParser:
         """
         :return: MSONable dict
         """
-        d = OrderedDict()
+        d = {}
         for k, v in self._cif.data.items():
             d[k] = {}
             for k2, v2 in v.data.items():
@@ -1288,14 +1285,13 @@ class CifWriter:
             refine_struct: Used only if symprec is not None. If True, get_refined_structure
                 is invoked to convert input structure from primitive to conventional.
         """
-
         if write_magmoms and symprec:
             warnings.warn("Magnetic symmetry cannot currently be detected by pymatgen,disabling symmetry detection.")
             symprec = None
 
-        format_str = "{:.%df}" % significant_figures
+        format_str = f"{{:.{significant_figures}f}}"
 
-        block = OrderedDict()
+        block = {}
         loops = []
         spacegroup = ("P 1", 1)
         if symprec is not None:
@@ -1335,18 +1331,18 @@ class CifWriter:
                 symmops.append(SymmOp.from_rotation_and_translation(op.rotation_matrix, v))
 
             ops = [op.as_xyz_string() for op in symmops]
-            block["_symmetry_equiv_pos_site_id"] = ["%d" % i for i in range(1, len(ops) + 1)]
+            block["_symmetry_equiv_pos_site_id"] = [f"{i}" for i in range(1, len(ops) + 1)]
             block["_symmetry_equiv_pos_as_xyz"] = ops
 
         loops.append(["_symmetry_equiv_pos_site_id", "_symmetry_equiv_pos_as_xyz"])
 
         try:
-            symbol_to_oxinum = OrderedDict([(el.__str__(), float(el.oxi_state)) for el in sorted(comp.elements)])
-            block["_atom_type_symbol"] = symbol_to_oxinum.keys()
+            symbol_to_oxinum = {str(el): float(el.oxi_state) for el in sorted(comp.elements)}
+            block["_atom_type_symbol"] = list(symbol_to_oxinum)
             block["_atom_type_oxidation_number"] = symbol_to_oxinum.values()
             loops.append(["_atom_type_symbol", "_atom_type_oxidation_number"])
         except (TypeError, AttributeError):
-            symbol_to_oxinum = OrderedDict([(el.symbol, 0) for el in sorted(comp.elements)])
+            symbol_to_oxinum = {el.symbol: 0 for el in sorted(comp.elements)}
 
         atom_site_type_symbol = []
         atom_site_symmetry_multiplicity = []
@@ -1363,13 +1359,13 @@ class CifWriter:
         if symprec is None:
             for site in struct:
                 for sp, occu in sorted(site.species.items()):
-                    atom_site_type_symbol.append(sp.__str__())
+                    atom_site_type_symbol.append(str(sp))
                     atom_site_symmetry_multiplicity.append("1")
                     atom_site_fract_x.append(format_str.format(site.a))
                     atom_site_fract_y.append(format_str.format(site.b))
                     atom_site_fract_z.append(format_str.format(site.c))
                     atom_site_label.append(f"{sp.symbol}{count}")
-                    atom_site_occupancy.append(occu.__str__())
+                    atom_site_occupancy.append(str(occu))
 
                     magmom = Magmom(site.properties.get("magmom", getattr(sp, "spin", 0)))
                     if write_magmoms and abs(magmom) > 0:
@@ -1400,13 +1396,13 @@ class CifWriter:
                 ),
             ):
                 for sp, occu in site.species.items():
-                    atom_site_type_symbol.append(sp.__str__())
-                    atom_site_symmetry_multiplicity.append("%d" % mult)
+                    atom_site_type_symbol.append(str(sp))
+                    atom_site_symmetry_multiplicity.append(f"{mult}")
                     atom_site_fract_x.append(format_str.format(site.a))
                     atom_site_fract_y.append(format_str.format(site.b))
                     atom_site_fract_z.append(format_str.format(site.c))
                     atom_site_label.append(f"{sp.symbol}{count}")
-                    atom_site_occupancy.append(occu.__str__())
+                    atom_site_occupancy.append(str(occu))
                     count += 1
 
         block["_atom_site_type_symbol"] = atom_site_type_symbol
@@ -1440,7 +1436,7 @@ class CifWriter:
                     "_atom_site_moment_crystalaxis_z",
                 ]
             )
-        d = OrderedDict()
+        d = {}
         d[comp.reduced_formula] = CifBlock(block, loops, comp.reduced_formula)
         self._cf = CifFile(d)
 
@@ -1455,14 +1451,14 @@ class CifWriter:
         """
         Returns the cif as a string.
         """
-        return self._cf.__str__()
+        return str(self._cf)
 
     def write_file(self, filename):
         """
         Write the cif file.
         """
         with zopen(filename, "wt") as f:
-            f.write(self.__str__())
+            f.write(str(self))
 
 
 def str2float(text):
