@@ -1,10 +1,9 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
-This package containes classes to parse input files from the exciting
+This package contains classes to parse input files from the exciting
 code package.
 """
 
-from .inputs import *  # noqa
+from .inputs import ExcitingInput
