@@ -8,6 +8,8 @@ and
 -Localised Basis set reader
 """
 
+from __future__ import annotations
+
 import os
 import re
 import shutil
@@ -41,10 +43,8 @@ class Nwchem2Fiesta(MSONable):
         filename: name of nwchem files read by NWCHEM2FIESTA (filename.nw, filename.nwout and filename.movecs)
         logfile: logfile of NWCHEM2FIESTA
 
-        the run method launchs NWCHEM2FIESTA
-
+        the run method launches NWCHEM2FIESTA
         """
-
         self.folder = folder
         self.filename = filename
         self.log_file = log_file
@@ -58,7 +58,6 @@ class Nwchem2Fiesta(MSONable):
         """
         Performs actual NWCHEM2FIESTA run
         """
-
         init_folder = os.getcwd()
         os.chdir(self.folder)
 
@@ -80,8 +79,8 @@ class Nwchem2Fiesta(MSONable):
         :return: MSONable dict
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "filename": self.filename,
             "folder": self.folder,
         }
@@ -92,7 +91,7 @@ class Nwchem2Fiesta(MSONable):
         :param d: Dict representation.
         :return: Nwchem2Fiesta
         """
-        return Nwchem2Fiesta(folder=d["folder"], filename=d["filename"])
+        return cls(folder=d["folder"], filename=d["filename"])
 
 
 class FiestaRun(MSONable):
@@ -103,14 +102,14 @@ class FiestaRun(MSONable):
         otherwise it breaks
     """
 
-    def __init__(self, folder=os.getcwd(), grid=[2, 2, 2], log_file="log"):
+    def __init__(self, folder: str = None, grid: tuple[int, int, int] = (2, 2, 2), log_file: str = "log") -> None:
         """
         Args:
             folder: Folder to look for runs.
             grid:
             log_file: logfile of Fiesta
         """
-        self.folder = folder
+        self.folder = folder or os.getcwd()
         self.log_file = log_file
         self.grid = grid
 
@@ -131,7 +130,6 @@ class FiestaRun(MSONable):
         """
         Performs FIESTA (gw) run
         """
-
         if self.folder != os.getcwd():
             init_folder = os.getcwd()
             os.chdir(self.folder)
@@ -157,7 +155,6 @@ class FiestaRun(MSONable):
         """
         Performs BSE run
         """
-
         if self.folder != os.getcwd():
             init_folder = os.getcwd()
             os.chdir(self.folder)
@@ -183,8 +180,8 @@ class FiestaRun(MSONable):
         :return: MSONable dict
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "log_file": self.log_file,
             "grid": self.grid,
             "folder": self.folder,
@@ -196,7 +193,7 @@ class FiestaRun(MSONable):
         :param d: Dict representation
         :return: FiestaRun
         """
-        return FiestaRun(folder=d["folder"], grid=d["grid"], log_file=d["log_file"])
+        return cls(folder=d["folder"], grid=d["grid"], log_file=d["log_file"])
 
 
 class BasisSetReader:
@@ -273,7 +270,6 @@ class BasisSetReader:
         """
         :return: the number of nlm orbitals for the basis set
         """
-
         nnlmo = 0
 
         data_tmp = self.data
@@ -295,10 +291,10 @@ class BasisSetReader:
         o.append("=========================================")
         o.append("Reading basis set:")
         o.append("")
-        o.append(f" Basis set for {str(self.filename)} atom ")
-        o.append(" Maximum angular momentum = {}".format(self.data["lmax"]))
-        o.append(" Number of atomics orbitals = {}".format(self.data["n_nlo"]))
-        o.append(" Number of nlm orbitals = {}".format(self.data["n_nlmo"]))
+        o.append(f" Basis set for {self.filename} atom ")
+        o.append(f" Maximum angular momentum = {self.data['lmax']}")
+        o.append(f" Number of atomics orbitals = {self.data['n_nlo']}")
+        o.append(f" Number of nlm orbitals = {self.data['n_nlmo']}")
         o.append("=========================================")
 
         return str(0)
@@ -312,26 +308,11 @@ class FiestaInput(MSONable):
     def __init__(
         self,
         mol,
-        correlation_grid={"dE_grid": "0.500", "n_grid": "14"},
-        Exc_DFT_option={"rdVxcpsi": "1"},
-        COHSEX_options={
-            "eigMethod": "C",
-            "mix_cohsex": "0.500",
-            "nc_cohsex": "0",
-            "nit_cohsex": "0",
-            "nv_cohsex": "0",
-            "resMethod": "V",
-            "scf_cohsex_wf": "0",
-        },
-        GW_options={"nc_corr": "10", "nit_gw": "3", "nv_corr": "10"},
-        BSE_TDDFT_options={
-            "do_bse": "1",
-            "do_tddft": "0",
-            "nc_bse": "382",
-            "nit_bse": "50",
-            "npsi_bse": "1",
-            "nv_bse": "21",
-        },
+        correlation_grid: dict[str, str] = None,
+        Exc_DFT_option: dict[str, str] = None,
+        COHSEX_options: dict[str, str] = None,
+        GW_options: dict[str, str] = None,
+        BSE_TDDFT_options: dict[str, str] = None,
     ):
         """
         :param mol: pymatgen mol
@@ -341,13 +322,27 @@ class FiestaInput(MSONable):
         :param GW_options: dict
         :param BSE_TDDFT_options: dict
         """
-
         self._mol = mol
-        self.correlation_grid = correlation_grid
-        self.Exc_DFT_option = Exc_DFT_option
-        self.COHSEX_options = COHSEX_options
-        self.GW_options = GW_options
-        self.BSE_TDDFT_options = BSE_TDDFT_options
+        self.correlation_grid = correlation_grid or {"dE_grid": "0.500", "n_grid": "14"}
+        self.Exc_DFT_option = Exc_DFT_option or {"rdVxcpsi": "1"}
+        self.COHSEX_options = COHSEX_options or {
+            "eigMethod": "C",
+            "mix_cohsex": "0.500",
+            "nc_cohsex": "0",
+            "nit_cohsex": "0",
+            "nv_cohsex": "0",
+            "resMethod": "V",
+            "scf_cohsex_wf": "0",
+        }
+        self.GW_options = GW_options or {"nc_corr": "10", "nit_gw": "3", "nv_corr": "10"}
+        self.BSE_TDDFT_options = BSE_TDDFT_options or {
+            "do_bse": "1",
+            "do_tddft": "0",
+            "nc_bse": "382",
+            "nit_bse": "50",
+            "npsi_bse": "1",
+            "nv_bse": "21",
+        }
 
     def set_auxiliary_basis_set(self, folder, auxiliary_folder, auxiliary_basis_set_type="aug_cc_pvtz"):
         """
@@ -356,7 +351,6 @@ class FiestaInput(MSONable):
         :param auxiliary_basis_set_type: type of basis set (string to be found in the extension of the file name; must
             be in lower case). ex: C2.ion_aug_cc_pvtz_RI_Weigend find "aug_cc_pvtz"
         """
-
         list_files = os.listdir(auxiliary_folder)
 
         for specie in self._mol.symbol_set:
@@ -372,7 +366,6 @@ class FiestaInput(MSONable):
         :param n_iteration: number of iteration
         :param n_grid and dE_grid:: number of points and spacing in eV for correlation grid
         """
-
         self.GW_options.update(nv_corr=nv_band, nc_corr=nc_band, nit_gw=n_iteration)
         self.correlation_grid.update(dE_grid=dE_grid, n_grid=n_grid)
 
@@ -381,7 +374,6 @@ class FiestaInput(MSONable):
         """
         mkdir "FULL_BSE_Densities" folder (needed for bse run) in the desired folder
         """
-
         if os.path.exists(folder + "/FULL_BSE_Densities"):
             return "FULL_BSE_Densities folder already exists"
 
@@ -403,7 +395,6 @@ class FiestaInput(MSONable):
         :param BSE_dump: boolean
         :return: set the "do_bse" variable to one in cell.in
         """
-
         if BSE_dump:
             self.BSE_TDDFT_options.update(do_bse=1, do_tddft=0)
         else:
@@ -411,7 +402,7 @@ class FiestaInput(MSONable):
 
     def dump_TDDFT_data_in_GW_run(self, TDDFT_dump=True):
         """
-        :param TDDFT_dump: boolen
+        :param TDDFT_dump: boolean
         :return: set the do_tddft variable to one in cell.in
         """
         if TDDFT_dump:
@@ -424,21 +415,17 @@ class FiestaInput(MSONable):
         """
         Returns infos on initial parameters as in the log file of Fiesta
         """
-
         o = []
         o.append("=========================================")
         o.append("Reading infos on system:")
         o.append("")
         o.append(
-            " Number of atoms = {} ; number of species = {}".format(
-                int(self._mol.composition.num_atoms), len(self._mol.symbol_set)
-            )
+            f" Number of atoms = {self._mol.composition.num_atoms} ; number of species = {len(self._mol.symbol_set)}"
         )
         o.append(f" Number of valence bands = {int(self._mol.nelectrons / 2)}")
         o.append(
-            " Sigma grid specs: n_grid = {} ;  dE_grid = {} (eV)".format(
-                self.correlation_grid["n_grid"], self.correlation_grid["dE_grid"]
-            )
+            f" Sigma grid specs: n_grid = {self.correlation_grid['n_grid']} ;  "
+            f"dE_grid = {self.correlation_grid['dE_grid']} (eV)"
         )
         if int(self.Exc_DFT_option["rdVxcpsi"]) == 1:
             o.append(" Exchange and correlation energy read from Vxcpsi.mat")
@@ -447,26 +434,23 @@ class FiestaInput(MSONable):
 
         if self.COHSEX_options["eigMethod"] == "C":
             o.append(
-                " Correcting  {} valence bands and   {} conduction bands at COHSEX level".format(
-                    self.COHSEX_options["nv_cohsex"], self.COHSEX_options["nc_cohsex"]
-                )
+                f" Correcting  {self.COHSEX_options['nv_cohsex']} valence bands and  "
+                f"{self.COHSEX_options['nc_cohsex']} conduction bands at COHSEX level"
             )
-            o.append(" Performing   {} diagonal COHSEX iterations".format(self.COHSEX_options["nit_cohsex"]))
+            o.append(f" Performing   {self.COHSEX_options['nit_cohsex']} diagonal COHSEX iterations")
         elif self.COHSEX_options["eigMethod"] == "HF":
             o.append(
-                " Correcting  {} valence bands and   {} conduction bands at HF level".format(
-                    self.COHSEX_options["nv_cohsex"], self.COHSEX_options["nc_cohsex"]
-                )
+                f" Correcting  {self.COHSEX_options['nv_cohsex']} valence bands and  "
+                f"{self.COHSEX_options['nc_cohsex']} conduction bands at HF level"
             )
-            o.append(" Performing   {} diagonal HF iterations".format(self.COHSEX_options["nit_cohsex"]))
+            o.append(f" Performing   {self.COHSEX_options['nit_cohsex']} diagonal HF iterations")
 
-        o.append(" Using resolution of identity : {}".format(self.COHSEX_options["resMethod"]))
+        o.append(f" Using resolution of identity : {self.COHSEX_options['resMethod']}")
         o.append(
-            " Correcting  {} valence bands and  {} conduction bands at GW level".format(
-                self.GW_options["nv_corr"], self.GW_options["nc_corr"]
-            )
+            f" Correcting  {self.GW_options['nv_corr']} valence bands and "
+            f"{self.GW_options['nc_corr']} conduction bands at GW level"
         )
-        o.append(" Performing   {} GW iterations".format(self.GW_options["nit_gw"]))
+        o.append(f" Performing   {self.GW_options['nit_gw']} GW iterations")
 
         if int(self.BSE_TDDFT_options["do_bse"]) == 1:
             o.append(" Dumping data for BSE treatment")
@@ -522,7 +506,7 @@ class FiestaInput(MSONable):
     $nit_gw
 # dumping for BSE and TDDFT
     $do_bse    $do_tddft
-# number of occp. and virtual bands fo BSE: nocore and up to 40 eVs
+# number of occp. and virtual bands of BSE: nocore and up to 40 eVs
     $nv_bse   $nc_bse
 # number of excitations needed and number of iterations
     $npsi_bse   $nit_bse
@@ -568,7 +552,7 @@ $geometry
         :param filename: Filename
         """
         with zopen(filename, "w") as f:
-            f.write(self.__str__())
+            f.write(str(self))
 
     def as_dict(self):
         """
@@ -589,7 +573,7 @@ $geometry
         :param d: Dict representation
         :return: FiestaInput
         """
-        return FiestaInput(
+        return cls(
             Molecule.from_dict(d["mol"]),
             correlation_grid=d["correlation_grid"],
             Exc_DFT_option=d["Exc_DFT_option"],
@@ -609,7 +593,6 @@ $geometry
         Returns:
             FiestaInput object
         """
-
         correlation_grid = {}
         Exc_DFT_option = {}
         COHSEX_options = {}
@@ -681,7 +664,7 @@ $geometry
         toks = l.split()
         BSE_TDDFT_options["do_bse"] = toks[0]
         BSE_TDDFT_options["do_tddft"] = toks[1]
-        # number of occp. and virtual bands fo BSE: nocore and up to 40 eVs
+        # number of occp. and virtual bands of BSE: nocore and up to 40 eVs
         lines.pop(0)
         l = lines.pop(0).strip()
         toks = l.split()
