@@ -13,14 +13,14 @@ import scipy.constants as cst
 from monty.io import zopen
 
 from pymatgen.core.composition import Composition
+from pymatgen.core.operations import SymmOp
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.structure import Molecule
-from pymatgen.core.operations import SymmOp
 from pymatgen.core.units import Ha_to_eV
 from pymatgen.electronic_structure.core import Spin
 from pymatgen.util.coord import get_angle
 
-__author__ = "Shyue Ping Ong, Germain  Salvato-Vallverdu, Xin Chen"
+__author__ = "Shyue Ping Ong, Germain Salvato-Vallverdu, Xin Chen"
 __copyright__ = "Copyright 2013, The Materials Virtual Lab"
 __version__ = "0.1"
 __maintainer__ = "Shyue Ping Ong"
@@ -110,7 +110,7 @@ class GaussianInput:
         """
         Args:
             mol: Input molecule. It can either be a Molecule object,
-                a string giving the geometry in a format supported by Guassian,
+                a string giving the geometry in a format supported by Gaussian,
                 or ``None``. If the molecule is ``None``, you will need to use
                 read it in from a checkpoint. Consider adding ``CHK`` to the
                 ``link0_parameters``.
@@ -129,7 +129,7 @@ class GaussianInput:
             route_parameters: Additional route parameters as a dict. For example,
                 {'SP':"", "SCF":"Tight"}
             input_parameters: Additional input parameters for run as a dict. Used
-                for example, in PCM calculations.  E.g., {"EPS":12}
+                for example, in PCM calculations. E.g., {"EPS":12}
             link0_parameters: Link0 parameters as a dict. E.g., {"%mem": "1000MW"}
             dieze_tag: # preceding the route line. E.g. "#p"
             gen_basis: allows a user-specified basis set to be used in a Gaussian
@@ -146,27 +146,27 @@ class GaussianInput:
                 self.spin_multiplicity = spin_multiplicity
                 if (nelectrons + spin_multiplicity) % 2 != 1:
                     raise ValueError(
-                        "Charge of {} and spin multiplicity of {} is"
-                        " not possible for this molecule".format(self.charge, spin_multiplicity)
+                        f"Charge of {self.charge} and spin multiplicity of {spin_multiplicity} is"
+                        " not possible for this molecule"
                     )
             else:
                 self.spin_multiplicity = 1 if nelectrons % 2 == 0 else 2
 
             # Get a title from the molecule name
-            self.title = title if title else self._mol.composition.formula
+            self.title = title or self._mol.composition.formula
         else:
             self.charge = charge
             self.spin_multiplicity = spin_multiplicity
 
             # Set a title
-            self.title = title if title else "Restart"
+            self.title = title or "Restart"
 
         # Store the remaining settings
         self.functional = functional
         self.basis_set = basis_set
-        self.link0_parameters = link0_parameters if link0_parameters else {}
-        self.route_parameters = route_parameters if route_parameters else {}
-        self.input_parameters = input_parameters if input_parameters else {}
+        self.link0_parameters = link0_parameters or {}
+        self.route_parameters = route_parameters or {}
+        self.input_parameters = input_parameters or {}
         self.dieze_tag = dieze_tag if dieze_tag[0] == "#" else "#" + dieze_tag
         self.gen_basis = gen_basis
         if gen_basis is not None:
@@ -302,20 +302,20 @@ class GaussianInput:
 
         link0_patt = re.compile(r"^(%.+)\s*=\s*(.+)")
         link0_dict = {}
-        for i, l in enumerate(lines):
-            if link0_patt.match(l):
-                m = link0_patt.match(l)
+        for line in lines:
+            if link0_patt.match(line):
+                m = link0_patt.match(line)
                 link0_dict[m.group(1).strip("=")] = m.group(2)
 
         route_patt = re.compile(r"^#[sSpPnN]*.*")
         route = ""
         route_index = None
-        for i, l in enumerate(lines):
-            if route_patt.match(l):
-                route += " " + l
-                route_index = i
+        for idx, line in enumerate(lines):
+            if route_patt.match(line):
+                route += " " + line
+                route_index = idx
             # This condition allows for route cards spanning multiple lines
-            elif (l == "" or l.isspace()) and route_index:
+            elif (line == "" or line.isspace()) and route_index:
                 break
         functional, basis_set, route_paras, dieze_tag = read_route_line(route)
         ind = 2
@@ -413,14 +413,14 @@ class GaussianInput:
 
     def get_cart_coords(self):
         """
-        Return the cartesian coordinates of the molecule
+        Return the Cartesian coordinates of the molecule
         """
 
         def to_s(x):
-            return "%0.6f" % x
+            return f"{x:0.6f}"
 
         outs = []
-        for i, site in enumerate(self._mol):
+        for site in self._mol:
             outs.append(" ".join([site.species_string, " ".join([to_s(j) for j in site.coords])]))
         return "\n".join(outs)
 
@@ -431,9 +431,8 @@ class GaussianInput:
         """
         Return GaussianInput string
 
-        Option: whe cart_coords sets to True return the cartesian coordinates
+        Option: when cart_coords is set to True return the Cartesian coordinates
                 instead of the z-matrix
-
         """
 
         def para_dict_to_string(para, joiner=" "):
@@ -463,19 +462,13 @@ class GaussianInput:
             # don't use the slash if either or both are set as empty
             func_bset_str = f" {func_str}{bset_str}".rstrip()
 
-        output.append(
-            "{diez}{func_bset} {route}".format(
-                diez=self.dieze_tag,
-                func_bset=func_bset_str,
-                route=para_dict_to_string(self.route_parameters),
-            )
-        )
+        output.append(f"{self.dieze_tag}{func_bset_str} {para_dict_to_string(self.route_parameters)}")
         output.append("")
         output.append(self.title)
         output.append("")
 
-        charge_str = "" if self.charge is None else "%d" % self.charge
-        multip_str = "" if self.spin_multiplicity is None else " %d" % self.spin_multiplicity
+        charge_str = "" if self.charge is None else f"{self.charge:.0f}"
+        multip_str = "" if self.spin_multiplicity is None else f" {self.spin_multiplicity:.0f}"
         output.append(f"{charge_str}{multip_str}")
 
         if isinstance(self._mol, Molecule):
@@ -487,7 +480,7 @@ class GaussianInput:
             output.append(str(self._mol))
         output.append("")
         if self.gen_basis is not None:
-            output.append(f"{self.gen_basis:s}\n")
+            output.append(f"{self.gen_basis}\n")
         output.append(para_dict_to_string(self.input_parameters, "\n"))
         output.append("\n")
         return "\n".join(output)
@@ -506,8 +499,8 @@ class GaussianInput:
         :return: MSONable dict
         """
         return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
             "molecule": self.molecule.as_dict(),
             "functional": self.functional,
             "basis_set": self.basis_set,
@@ -526,7 +519,7 @@ class GaussianInput:
         :param d: dict
         :return: GaussianInput
         """
-        return GaussianInput(
+        return cls(
             mol=Molecule.from_dict(d["molecule"]),
             functional=d["functional"],
             basis_set=d["basis_set"],
@@ -581,7 +574,7 @@ class GaussianOutput:
 
     .. attribute:: cart_forces
 
-        All cartesian forces from the calculation.
+        All Cartesian forces from the calculation.
 
     .. attribute:: frequencies
 
@@ -877,7 +870,7 @@ class GaussianOutput:
                         if m.group(1) == "Zero-point":
                             self.corrections["Zero-point"] = float(m.group(3))
                         else:
-                            key = m.group(2).strip(" to ")
+                            key = m.group(2).replace(" to ", "")
                             self.corrections[key] = float(m.group(3))
 
                     if read_coord:
@@ -992,9 +985,9 @@ class GaussianOutput:
                         self.molecular_orbital = mo
 
                     elif parse_freq:
-                        while line.strip() != "":  #  blank line
+                        while line.strip() != "":  # blank line
                             ifreqs = [int(val) - 1 for val in line.split()]
-                            for ifreq in ifreqs:
+                            for _ in ifreqs:
                                 frequencies.append(
                                     {
                                         "frequency": None,
@@ -1069,7 +1062,7 @@ class GaussianOutput:
                         line = f.readline()
                         nat = len(input_structures[0])
                         matrix = []
-                        for iat in range(nat):
+                        for _ in range(nat):
                             line = f.readline()
                             matrix.append([float(v) for v in line.split()[2:]])
 
@@ -1201,7 +1194,7 @@ class GaussianOutput:
 
     def as_dict(self):
         """
-        Json-serializable dict representation.
+        JSON-serializable dict representation.
         """
         structure = self.final_structure
         d = {
@@ -1216,7 +1209,7 @@ class GaussianOutput:
         d["errors"] = self.errors
         d["Mulliken_charges"] = self.Mulliken_charges
 
-        unique_symbols = sorted(list(d["unit_cell_formula"].keys()))
+        unique_symbols = sorted(list(d["unit_cell_formula"]))
         d["elements"] = unique_symbols
         d["nelements"] = len(unique_symbols)
         d["charge"] = self.charge
@@ -1244,8 +1237,8 @@ class GaussianOutput:
         }
 
         d["output"] = vout
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
+        d["@module"] = type(self).__module__
+        d["@class"] = type(self).__name__
 
         return d
 
@@ -1320,7 +1313,7 @@ class GaussianOutput:
         Get a matplotlib plot of the potential energy surface.
 
         Args:
-            coords: internal coordinate name to use as abcissa.
+            coords: internal coordinate name to use as abscissa.
         """
         from pymatgen.util.plotting import pretty_plot
 
@@ -1364,7 +1357,6 @@ class GaussianOutput:
             A list: A list of tuple for each transition such as
                     [(energie (eV), lambda (nm), oscillatory strength), ... ]
         """
-
         transitions = []
 
         # read in file
@@ -1384,7 +1376,7 @@ class GaussianOutput:
 
     def get_spectre_plot(self, sigma=0.05, step=0.01):
         """
-        Get a matplotlib plot of the UV-visible xas. Transition are plotted
+        Get a matplotlib plot of the UV-visible xas. Transitions are plotted
         as vertical lines and as a sum of normal functions with sigma with. The
         broadening is applied in energy and the xas is plotted as a function
         of the wavelength.
