@@ -5,15 +5,14 @@ import json
 import os
 import random
 import unittest
-from collections import OrderedDict
 
 import numpy as np
 import pandas as pd
-from monty.json import MontyEncoder, MontyDecoder
+from monty.json import MontyDecoder, MontyEncoder
+from ruamel.yaml import YAML
 
-from pymatgen.core import yaml
-from pymatgen.core.periodic_table import Element
 from pymatgen.core.lattice import Lattice
+from pymatgen.core.periodic_table import Element
 from pymatgen.core.structure import Molecule, Structure
 from pymatgen.io.lammps.data import (
     CombinedData,
@@ -22,7 +21,6 @@ from pymatgen.io.lammps.data import (
     LammpsData,
     Topology,
     lattice_2_lmpbox,
-    structure_2_lmpdata,
 )
 from pymatgen.util.testing import PymatgenTest
 
@@ -284,9 +282,9 @@ class LammpsDataTest(unittest.TestCase):
         c2h6 = LammpsData.from_file(filename1)
         pd.testing.assert_frame_equal(c2h6.masses, self.ethane.masses)
         pd.testing.assert_frame_equal(c2h6.atoms, self.ethane.atoms)
-        ff_kw = random.sample(self.ethane.force_field.keys(), 1)[0]
+        ff_kw = random.sample(sorted(self.ethane.force_field), 1)[0]
         pd.testing.assert_frame_equal(c2h6.force_field[ff_kw], self.ethane.force_field[ff_kw], ff_kw)
-        topo_kw = random.sample(self.ethane.topology.keys(), 1)[0]
+        topo_kw = random.sample(sorted(self.ethane.topology), 1)[0]
         pd.testing.assert_frame_equal(c2h6.topology[topo_kw], self.ethane.topology[topo_kw], topo_kw)
         filename2 = "test2.data"
         self.virus.write_file(filename=filename2)
@@ -456,7 +454,7 @@ class LammpsDataTest(unittest.TestCase):
         self.assertEqual(self.tatb.atoms.loc[atom_id].name, atom_id)
 
     def test_from_ff_and_topologies(self):
-        mass = OrderedDict()
+        mass = {}
         mass["H"] = 1.0079401
         mass["O"] = 15.999400
         nonbond_coeffs = [[0.00774378, 0.98], [0.1502629, 3.1169]]
@@ -701,6 +699,7 @@ class ForceFieldTest(unittest.TestCase):
         )
         self.assertEqual(v.masses.at[3, "mass"], 15.9994)
         v_ff = v.force_field
+        assert isinstance(v_ff, dict)
         self.assertNotIn("Pair Coeffs", v_ff)
         self.assertEqual(v_ff["PairIJ Coeffs"].iat[5, 4], 1.93631)
         self.assertEqual(v_ff["Bond Coeffs"].at[2, "coeff2"], 0.855906)
@@ -720,6 +719,7 @@ class ForceFieldTest(unittest.TestCase):
         e = self.ethane
         self.assertEqual(e.masses.at[1, "mass"], 12.01115)
         e_ff = e.force_field
+        assert isinstance(e_ff, dict)
         self.assertNotIn("PairIJ Coeffs", e_ff)
         self.assertEqual(e_ff["Pair Coeffs"].at[1, "coeff2"], 3.854)
         self.assertEqual(e_ff["Bond Coeffs"].at[2, "coeff4"], 844.6)
@@ -757,6 +757,7 @@ class ForceFieldTest(unittest.TestCase):
         filename = "ff_test.yaml"
         v = self.virus
         v.to_file(filename=filename)
+        yaml = YAML()
         with open(filename) as f:
             d = yaml.load(f)
         # self.assertListEqual(d["mass_info"], [list(m) for m in v.mass_info])
@@ -817,54 +818,28 @@ class FuncTest(unittest.TestCase):
             rotop.rotation_matrix,
             [
                 [1, 0, 0],
-                [0, 2 ** 0.5 / 2, 2 ** 0.5 / 2],
-                [0, -(2 ** 0.5) / 2, 2 ** 0.5 / 2],
+                [0, 2**0.5 / 2, 2**0.5 / 2],
+                [0, -(2**0.5) / 2, 2**0.5 / 2],
             ],
         )
 
-    @unittest.skip("The function is deprecated")
-    def test_structure_2_lmpdata(self):
-        matrix = np.diag(np.random.randint(5, 14, size=(3,))) + np.random.rand(3, 3) * 0.2 - 0.1
-        latt = Lattice(matrix)
-        frac_coords = np.random.rand(10, 3)
-        structure = Structure(latt, ["H"] * 10, frac_coords)
-        ld = structure_2_lmpdata(structure=structure)
-        box_tilt = [0.0, 0.0, 0.0] if not ld.box_tilt else ld.box_tilt
-        box_bounds = np.array(ld.box_bounds)
-        np.testing.assert_array_equal(box_bounds[:, 0], np.zeros(3))
-        new_matrix = np.diag(box_bounds[:, 1])
-        new_matrix[1, 0] = box_tilt[0]
-        new_matrix[2, 0] = box_tilt[1]
-        new_matrix[2, 1] = box_tilt[2]
-        new_latt = Lattice(new_matrix)
-        np.testing.assert_array_almost_equal(new_latt.abc, latt.abc)
-        np.testing.assert_array_almost_equal(new_latt.angles, latt.angles)
-        coords = ld.atoms[["x", "y", "z"]].values
-        new_structure = Structure(new_latt, ["H"] * 10, coords, coords_are_cartesian=True)
-        np.testing.assert_array_almost_equal(new_structure.frac_coords, frac_coords)
-        self.assertEqual(len(ld.masses), 1)
-        # test additional elements
-        ld_elements = structure_2_lmpdata(structure=structure, ff_elements=["C", "H"])
-        self.assertEqual(len(ld_elements.masses), 2)
-        np.testing.assert_array_almost_equal(ld_elements.masses["mass"], [1.00794, 12.01070])
-
 
 class CombinedDataTest(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
-        cls.ec = LammpsData.from_file(filename=os.path.join(test_dir, "ec.data"))
-        cls.fec = LammpsData.from_file(filename=os.path.join(test_dir, "fec.data"))
+        cls.ec = LammpsData.from_file(filename=os.path.join(test_dir, "ec.data.gz"))
+        cls.fec = LammpsData.from_file(filename=os.path.join(test_dir, "fec.data.gz"))
         cls.li = LammpsData.from_file(filename=os.path.join(test_dir, "li.data"))
         cls.li_minimal = LammpsData.from_file(filename=os.path.join(test_dir, "li_minimal.data"))
-        cls.coord = CombinedData.parse_xyz(filename=os.path.join(test_dir, "ec_fec.xyz"))
+        cls.coord = CombinedData.parse_xyz(filename=os.path.join(test_dir, "ec_fec.xyz.gz"))
         cls.small_coord = CombinedData.parse_xyz(filename=os.path.join(test_dir, "li_ec.xyz"))
         cls.small_coord_2 = CombinedData.parse_xyz(filename=os.path.join(test_dir, "li_ec_2.xyz"))
         cls.small_coord_3 = CombinedData.parse_xyz(filename=os.path.join(test_dir, "li_2.xyz"))
         cls.ec_fec1 = CombinedData.from_files(
-            os.path.join(test_dir, "ec_fec.xyz"),
+            os.path.join(test_dir, "ec_fec.xyz.gz"),
             [1200, 300],
-            os.path.join(test_dir, "ec.data"),
-            os.path.join(test_dir, "fec.data"),
+            os.path.join(test_dir, "ec.data.gz"),
+            os.path.join(test_dir, "fec.data.gz"),
         )
         cls.ec_fec2 = CombinedData.from_lammpsdata([cls.ec, cls.fec], ["EC", "FEC"], [1200, 300], cls.coord)
         cls.ec_fec_ld = cls.ec_fec1.as_lammpsdata()
