@@ -1,30 +1,30 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module defines utility classes and functions.
 """
 
 import os
 import tempfile
+from shutil import which
 from subprocess import PIPE, Popen
 
 import numpy as np
+from monty.dev import deprecated
+from monty.tempfile import ScratchDir
+
+from pymatgen.core.operations import SymmOp
+from pymatgen.core.structure import Molecule
+from pymatgen.io.babel import BabelMolAdaptor
+from pymatgen.io.packmol import PackmolBoxGen
+from pymatgen.util.coord import get_angle
 
 try:
     from openbabel import pybel as pb
 except ImportError:
     pb = None
 
-from monty.os.path import which
-from monty.tempfile import ScratchDir
-
-from pymatgen.core.structure import Molecule
-from pymatgen.core.operations import SymmOp
-from pymatgen.io.babel import BabelMolAdaptor
-from pymatgen.util.coord import get_angle
-
 __author__ = "Kiran Mathew, Brandon Wood, Michael Humbert"
 __email__ = "kmathew@lbl.gov"
 
@@ -171,6 +171,7 @@ class Polymer:
             self.end += len(self.monomer)
 
 
+@deprecated(PackmolBoxGen, "PackmolRunner is being phased out in favor of the packmol I/O class.")
 class PackmolRunner:
     """
     Wrapper for the Packmol software that can be used to pack various types of
@@ -184,7 +185,7 @@ class PackmolRunner:
         input_file="pack.inp",
         tolerance=2.0,
         filetype="xyz",
-        control_params={"maxit": 20, "nloop": 600},
+        control_params=None,
         auto_box=True,
         output_file="packed.xyz",
         bin="packmol",
@@ -223,13 +224,13 @@ class PackmolRunner:
         self.param_list = param_list
         self.input_file = input_file
         self.boxit = auto_box
-        self.control_params = control_params
+        self.control_params = control_params or {"maxit": 20, "nloop": 600}
         if not self.control_params.get("tolerance"):
             self.control_params["tolerance"] = tolerance
         if not self.control_params.get("filetype"):
             self.control_params["filetype"] = filetype
         if not self.control_params.get("output"):
-            self.control_params["output"] = "{}.{}".format(output_file.split(".")[0], self.control_params["filetype"])
+            self.control_params["output"] = f"{output_file.split('.')[0]}.{self.control_params['filetype']}"
         if self.boxit:
             self._set_box()
 
@@ -256,9 +257,9 @@ class PackmolRunner:
         net_volume = 0.0
         for idx, mol in enumerate(self.mols):
             length = max(np.max(mol.cart_coords[:, i]) - np.min(mol.cart_coords[:, i]) for i in range(3)) + 2.0
-            net_volume += (length ** 3.0) * float(self.param_list[idx]["number"])
+            net_volume += (length**3.0) * float(self.param_list[idx]["number"])
         length = net_volume ** (1.0 / 3.0)
-        for idx, mol in enumerate(self.mols):
+        for idx, _mol in enumerate(self.mols):
             self.param_list[idx]["inside box"] = f"0.0 0.0 0.0 {length} {length} {length}"
 
     def _write_input(self, input_dir="."):
@@ -275,7 +276,7 @@ class PackmolRunner:
             # the molecule id and the corresponding filename in the packmol
             # input file.
             for idx, mol in enumerate(self.mols):
-                filename = os.path.join(input_dir, "{}.{}".format(idx, self.control_params["filetype"]))
+                filename = os.path.join(input_dir, f"{idx}.{self.control_params['filetype']}")
                 # pdb
                 if self.control_params["filetype"] == "pdb":
                     self.write_pdb(mol, filename, num=idx + 1)
@@ -290,12 +291,7 @@ class PackmolRunner:
                     )
 
                 inp.write("\n")
-                inp.write(
-                    "structure {}.{}\n".format(
-                        os.path.join(input_dir, str(idx)),
-                        self.control_params["filetype"],
-                    )
-                )
+                inp.write(f"structure {os.path.join(input_dir, str(idx))}.{self.control_params['filetype']}\n")
                 for k, v in self.param_list[idx].items():
                     inp.write(f"  {k} {self._format_param_val(v)}\n")
                 inp.write("end structure\n")
@@ -307,7 +303,7 @@ class PackmolRunner:
 
         Args:
             site_property (str): if set then the specified site property
-                for the the final packed molecule will be restored.
+                for the final packed molecule will be restored.
 
         Returns:
                 Molecule object
@@ -321,7 +317,7 @@ class PackmolRunner:
             if os.path.isfile(output_file):
                 packed_mol = BabelMolAdaptor.from_file(output_file, self.control_params["filetype"])
                 packed_mol = packed_mol.pymatgen_mol
-                print("packed molecule written to {}".format(self.control_params["output"]))
+                print(f"packed molecule written to {self.control_params['output']}")
                 if site_property:
                     packed_mol = self.restore_site_properties(site_property=site_property, filename=output_file)
                 return packed_mol
@@ -332,7 +328,6 @@ class PackmolRunner:
         """
         dump the molecule into pdb file with custom residue name and number.
         """
-
         # ugly hack to get around the openbabel issues with inconsistent
         # residue labelling.
         scratch = tempfile.gettempdir()
@@ -345,7 +340,7 @@ class PackmolRunner:
 
         # bma = BabelMolAdaptor(mol)
         pbm = pb.Molecule(bma._obmol)
-        for i, x in enumerate(pbm.residues):
+        for x in pbm.residues:
             x.OBResidue.SetName(name)
             x.OBResidue.SetNum(num)
 
@@ -376,7 +371,6 @@ class PackmolRunner:
         Returns:
             Molecule object
         """
-
         restore_site_props = residue_name is not None
 
         if restore_site_props and not hasattr(self, "map_residue_to_mol"):
@@ -420,7 +414,6 @@ class PackmolRunner:
         Returns:
             Molecule
         """
-
         # only for pdb
         if not self.control_params["filetype"] == "pdb":
             raise ValueError()
@@ -459,10 +452,10 @@ class LammpsRunner:
         self.lammps_bin = bin.split()
         if not which(self.lammps_bin[-1]):
             raise RuntimeError(
-                "LammpsRunner requires the executable {} to be in the path. "
+                f"LammpsRunner requires the executable {self.lammps_bin[-1]} to be in the path. "
                 "Please download and install LAMMPS from "
-                "http://lammps.sandia.gov. "
-                "Don't forget to add the binary to your path".format(self.lammps_bin[-1])
+                "https://www.lammps.org/. "
+                "Don't forget to add the binary to your path"
             )
         self.input_filename = input_filename
 
@@ -471,7 +464,7 @@ class LammpsRunner:
         Write the input/data files and run LAMMPS.
         """
         lammps_cmd = self.lammps_bin + ["-in", self.input_filename]
-        print("Running: {}".format(" ".join(lammps_cmd)))
+        print(f"Running: {' '.join(lammps_cmd)}")
         with Popen(lammps_cmd, stdout=PIPE, stderr=PIPE) as p:
             (stdout, stderr) = p.communicate()
         return stdout, stderr
