@@ -2,6 +2,7 @@ import os
 import unittest
 
 import numpy as np
+
 from pymatgen.analysis.graphs import StructureGraph
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.cohp import Cohp
@@ -26,113 +27,122 @@ class TestLobsterNeighbors(unittest.TestCase):
 
         self.chemenvlobster1 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=1,
         )
 
         # all bonds
         self.chemenvlobster0 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=0,
         )
 
         # only cation cation, anion anion bonds
         self.chemenvlobster5 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=5,
         )
 
         # only cation cation bonds
         self.chemenvlobster6 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=6,
         )
 
         # 2,3,4 are not tested so far
         self.chemenvlobster2 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=2,
         )
 
         self.chemenvlobster3 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=3,
         )
 
         self.chemenvlobster4 = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=4,
         )
 
         # search for other testcase where 2,3,4 arrive at different results
         self.chemenvlobster0_second = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=0,
         )
         self.chemenvlobster1_second = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=1,
         )
 
         self.chemenvlobster2_second = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=2,
         )
 
         self.chemenvlobster5_second = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=5,
         )
 
         self.chemenvlobster5_second_percentage = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=5,
             perc_strength_ICOHP=1.0,
         )
 
         self.chemenvlobster6_second = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             additional_condition=6,
         )
 
         # TODO: use charge instead of valence
         self.chemenvlobster1_charges = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=1,
         )
+        self.chemenvlobster1_charges_loewdin = LobsterNeighbors(
+            are_coops=False,
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+            valences_from_charges=True,
+            filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
+            additional_condition=1,
+            which_charge="Loewdin",
+        )
         self.chemenvlobster6_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=6,
@@ -140,8 +150,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
         self.chemenvlobster5_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=5,
@@ -149,8 +159,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
         self.chemenvlobster4_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=4,
@@ -158,8 +168,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
         self.chemenvlobster3_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=3,
@@ -167,8 +177,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
         self.chemenvlobster2_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=2,
@@ -176,8 +186,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
         self.chemenvlobster1_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=1,
@@ -186,31 +196,67 @@ class TestLobsterNeighbors(unittest.TestCase):
 
         self.chemenvlobster0_charges_additional_condition = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=0,
             adapt_extremum_to_add_cond=True,
         )
+        self.chemenvlobster0_NaSi = LobsterNeighbors(
+            are_coops=False,
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaSi.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.NaSi.gz")),
+            valences_from_charges=True,
+            filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.NaSi.gz"),
+            additional_condition=0,
+            adapt_extremum_to_add_cond=True,
+        )
 
     def test_use_of_coop(self):
         with self.assertRaises(ValueError):
-            test = LobsterNeighbors(
+            _ = LobsterNeighbors(
                 are_coops=True,
-                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                 valences_from_charges=True,
                 filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
                 additional_condition=1,
             )
 
+    def test_cation_anion_mode_without_ions(self):
+        with self.assertRaises(ValueError) as err:
+            _ = LobsterNeighbors(
+                are_coops=False,
+                filename_ICOHP=os.path.join(test_dir_env, "../ICOHPLIST.lobster"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "../POSCAR")),
+                valences_from_charges=False,
+                additional_condition=1,
+            )
+        self.assertEqual(
+            str(err.exception),
+            "Valences cannot be assigned, additional_conditions 1 and 3 and 5 and 6 will not work",
+        )
+        with self.assertRaises(ValueError) as err:
+            _ = LobsterNeighbors(
+                are_coops=False,
+                filename_ICOHP=os.path.join(test_dir_env, "../ICOHPLIST.lobster"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "../POSCAR")),
+                valences_from_charges=False,
+                additional_condition=1,
+                valences=[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
+            )
+        self.assertEqual(
+            str(err.exception),
+            "All valences are equal to 0, additional_conditions 1 and 3 and 5 and 6 will not work",
+        )
+
     def test_wrong_additional_correction(self):
         with self.assertRaises(ValueError):
-            test = LobsterNeighbors(
+            _ = LobsterNeighbors(
                 are_coops=False,
-                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                 valences_from_charges=True,
                 filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
                 additional_condition=10,
@@ -219,8 +265,8 @@ class TestLobsterNeighbors(unittest.TestCase):
     def test_set_limits(self):
         test = LobsterNeighbors(
             are_coops=False,
-            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")),
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
             valences_from_charges=True,
             filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.mp-353.gz"),
             additional_condition=1,
@@ -245,7 +291,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster0.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -253,7 +300,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster0.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             2,
@@ -262,7 +310,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster1.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -270,7 +319,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster1.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             2,
@@ -279,7 +329,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster2.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -287,7 +338,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster2.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             2,
@@ -296,7 +348,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster3.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -304,7 +357,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster3.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             2,
@@ -313,7 +367,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster4.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -321,7 +376,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster4.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             2,
@@ -330,7 +386,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster5.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             0,
@@ -338,7 +395,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster5.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             0,
@@ -347,7 +405,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster6.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=0,
                 )
             ),
             0,
@@ -356,7 +415,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster6.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")), n=1
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
+                    n=1,
                 )
             ),
             0,
@@ -368,7 +428,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster0_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             8,
@@ -378,7 +439,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster1_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             2,
@@ -388,7 +450,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster2_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             2,
@@ -396,7 +459,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster2_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=4
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=4,
                 )
             ),
             4,
@@ -406,7 +470,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster5_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -414,7 +479,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster5_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=4
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=4,
                 )
             ),
             0,
@@ -423,7 +489,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster6_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             6,
@@ -431,7 +498,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster6_second.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=4
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=4,
                 )
             ),
             0,
@@ -440,7 +508,8 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertEqual(
             len(
                 self.chemenvlobster5_second_percentage.get_nn(
-                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                    structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                    n=0,
                 )
             ),
             0,
@@ -448,14 +517,72 @@ class TestLobsterNeighbors(unittest.TestCase):
 
     def test_structure_graph(self):
         sg = self.chemenvlobster1_second.get_bonded_structure(
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353"))
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz"))
         )
         self.assertEqual(type(sg), StructureGraph)
 
+    def test_extended_structure_graph(self):
+        self.chemenvlobsterNaCl = LobsterNeighbors(
+            are_coops=False,
+            filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaCl.gz"),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.NaCl.gz")),
+            valences_from_charges=True,
+            filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.NaCl.gz"),
+            filename_blist_sg1=os.path.join(test_dir_env, "ICOBILIST.lobster.NaCl.gz"),
+            filename_blist_sg2=os.path.join(test_dir_env, "ICOOPLIST.lobster.NaCl.gz"),
+            add_additional_data_sg=True,
+            id_blist_sg1="icobi",
+            id_blist_sg2="icoop",
+            additional_condition=1,
+        )
+        sg = self.chemenvlobsterNaCl.get_bonded_structure(
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.NaCl.gz")),
+            decorate=True,
+            edge_properties=True,
+            weights=True,
+        )
+        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOHP"], -0.56541)
+        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOBI"], 0.08484)
+        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOOP"], 0.02826)
+        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["bond_label"], "21")
+        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[5]["bond_label"], "30")
+        self.assertEqual(type(sg), StructureGraph)
+
+    def test_raises_extended_structure_graph(self):
+        with self.assertRaises(ValueError):
+            self.chemenvlobsterNaCl = LobsterNeighbors(
+                are_coops=False,
+                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaCl.gz"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.NaCl.gz")),
+                valences_from_charges=True,
+                filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.NaCl.gz"),
+                filename_blist_sg1=os.path.join(test_dir_env, "ICOBILIST.lobster.NaCl.gz"),
+                filename_blist_sg2=os.path.join(test_dir_env, "ICOOPLIST.lobster.NaCl.gz"),
+                add_additional_data_sg=True,
+                id_blist_sg1="icopppp",
+                id_blist_sg2="icoop",
+                additional_condition=1,
+            )
+        with self.assertRaises(ValueError):
+            self.chemenvlobsterNaCl = LobsterNeighbors(
+                are_coops=False,
+                filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaCl.gz"),
+                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.NaCl.gz")),
+                valences_from_charges=True,
+                filename_CHARGE=os.path.join(test_dir_env, "CHARGE.lobster.NaCl.gz"),
+                filename_blist_sg1=os.path.join(test_dir_env, "ICOBILIST.lobster.NaCl.gz"),
+                filename_blist_sg2=os.path.join(test_dir_env, "ICOOPLIST.lobster.NaCl.gz"),
+                add_additional_data_sg=True,
+                id_blist_sg1="icopppp",
+                id_blist_sg2="icoop",
+                additional_condition=1,
+            )
+
     def test_order_parameter(self):
         self.assertAlmostEqual(
             self.chemenvlobster1_second.get_local_order_parameters(
-                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353")), n=0
+                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+                n=0,
             )["linear"],
             1.0,
         )
@@ -482,21 +609,32 @@ class TestLobsterNeighbors(unittest.TestCase):
         self.assertAlmostEqual(results[2], 6)
         self.assertAlmostEqual(results[3], ["27", "30", "48", "49", "64", "73"])
 
-        results2 = self.chemenvlobster1.get_info_icohps_to_neighbors(isites=[])
+        results2 = self.chemenvlobster1.get_info_icohps_to_neighbors(isites=None)
         self.assertAlmostEqual(results2[0], -33.26058)
         for bond in results2[1]:
             self.assertAlmostEqual(bond, -5.54345, 3)
         self.assertAlmostEqual(results2[2], 6)
         self.assertAlmostEqual(results2[3], ["27", "30", "48", "49", "64", "73"])
         self.assertAlmostEqual(
-            results2[4], [["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Re1", "O4"]]
+            results2[4],
+            [
+                ["Re1", "O2"],
+                ["Re1", "O2"],
+                ["Re1", "O3"],
+                ["Re1", "O3"],
+                ["Re1", "O4"],
+                ["Re1", "O4"],
+            ],
         )
 
     def test_get_sum_icohps_between_neighbors_of_atom(self):
         # will only look at icohps between cations or anions
         self.chemenvlobster1.get_info_icohps_to_neighbors(isites=[1])
         self.assertEqual(self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[2], 1)
-        self.assertAlmostEqual(self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[0], -0.05507)
+        self.assertAlmostEqual(
+            self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[0],
+            -0.05507,
+        )
         self.assertEqual(self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[0])[2], 15)
         # use an example where this is easier to test (e.g., linear environment?)
 
@@ -511,14 +649,28 @@ class TestLobsterNeighbors(unittest.TestCase):
     def test_get_plot_label(self):
         self.assertEqual(
             self.chemenvlobster1._get_plot_label(
-                atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Re1", "O4"]],
+                atoms=[
+                    ["Re1", "O2"],
+                    ["Re1", "O2"],
+                    ["Re1", "O3"],
+                    ["Re1", "O3"],
+                    ["Re1", "O4"],
+                    ["Re1", "O4"],
+                ],
                 per_bond=False,
             ),
             "6 x O-Re",
         )
         self.assertEqual(
             self.chemenvlobster1._get_plot_label(
-                atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Si1", "O4"]],
+                atoms=[
+                    ["Re1", "O2"],
+                    ["Re1", "O2"],
+                    ["Re1", "O3"],
+                    ["Re1", "O3"],
+                    ["Re1", "O4"],
+                    ["Si1", "O4"],
+                ],
                 per_bond=False,
             ),
             "5 x O-Re, 1 x O-Si",
@@ -526,7 +678,14 @@ class TestLobsterNeighbors(unittest.TestCase):
 
         self.assertEqual(
             self.chemenvlobster1._get_plot_label(
-                atoms=[["Si1", "O2"], ["Si1", "O2"], ["Si1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Si1", "O4"]],
+                atoms=[
+                    ["Si1", "O2"],
+                    ["Si1", "O2"],
+                    ["Si1", "O3"],
+                    ["Re1", "O3"],
+                    ["Re1", "O4"],
+                    ["Si1", "O4"],
+                ],
                 per_bond=False,
             ),
             "4 x O-Si, 2 x O-Re",
@@ -534,7 +693,14 @@ class TestLobsterNeighbors(unittest.TestCase):
 
         self.assertEqual(
             self.chemenvlobster1._get_plot_label(
-                atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Re1", "O4"]],
+                atoms=[
+                    ["Re1", "O2"],
+                    ["Re1", "O2"],
+                    ["Re1", "O3"],
+                    ["Re1", "O3"],
+                    ["Re1", "O4"],
+                    ["Re1", "O4"],
+                ],
                 per_bond=True,
             ),
             "6 x O-Re (per bond)",
@@ -544,12 +710,14 @@ class TestLobsterNeighbors(unittest.TestCase):
         chemenvlobster1 = LobsterNeighbors(
             are_coops=False,
             filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_190_2.gz"),
-            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190")),
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=1,
         )
         self.assertEqual(
             chemenvlobster1.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"), isites=[0], only_bonds_to=["O"]
+                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+                isites=[0],
+                only_bonds_to=["O"],
             )[0],
             "6 x O-Re (per bond)",
         )
@@ -584,7 +752,8 @@ class TestLobsterNeighbors(unittest.TestCase):
             summed_spin_channels=True,
         )[1]
         self.assertAlmostEqual(
-            cophthing.icohp[Spin.up][300], chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0]
+            cophthing.icohp[Spin.up][300],
+            chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0],
         )
 
         self.assertEqual(
@@ -605,6 +774,25 @@ class TestLobsterNeighbors(unittest.TestCase):
             None,
         )
 
+        self.assertEqual(
+            self.chemenvlobster0_NaSi.get_info_cohps_to_neighbors(
+                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.NaSi.gz"),
+                isites=[8],
+                onlycation_isites=False,
+                only_bonds_to=["Na"],
+            )[0],
+            "1 x Na-Si (per bond)",
+        )
+        self.assertEqual(
+            self.chemenvlobster0_NaSi.get_info_cohps_to_neighbors(
+                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.NaSi.gz"),
+                isites=[8],
+                onlycation_isites=False,
+                only_bonds_to=["Si"],
+            )[0],
+            "3 x Si-Si (per bond)",
+        )
+
         chemenvlobster1.plot_cohps_of_neighbors(
             path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
             isites=[0],
