@@ -4,7 +4,8 @@
 """
 Module for interfacing with phonopy, see https://atztogo.github.io/phonopy/
 """
-from typing import Dict, List, Any
+
+from __future__ import annotations
 
 import numpy as np
 from monty.dev import requires
@@ -17,7 +18,11 @@ from pymatgen.phonon.bandstructure import (
     PhononBandStructureSymmLine,
 )
 from pymatgen.phonon.dos import CompletePhononDos, PhononDos
-from pymatgen.phonon.gruneisen import GruneisenParameter, GruneisenPhononBandStructureSymmLine
+from pymatgen.phonon.gruneisen import (
+    GruneisenParameter,
+    GruneisenPhononBandStructureSymmLine,
+)
+from pymatgen.phonon.thermal_displacements import ThermalDisplacementMatrices
 from pymatgen.symmetry.bandstructure import HighSymmKpath
 
 try:
@@ -30,22 +35,19 @@ except ImportError:
     PhonopyAtoms = None
 
 
-@requires(Phonopy, "phonopy not installed!")  # type: ignore
-def get_pmg_structure(phonopy_structure):
+@requires(Phonopy, "phonopy not installed!")
+def get_pmg_structure(phonopy_structure: PhonopyAtoms) -> Structure:
     """
     Convert a PhonopyAtoms object to pymatgen Structure object.
 
     Args:
         phonopy_structure (PhonopyAtoms): A phonopy structure object.
-
     """
-
-    lattice = phonopy_structure.get_cell()
-    frac_coords = phonopy_structure.get_scaled_positions()
-    symbols = phonopy_structure.get_chemical_symbols()
-    masses = phonopy_structure.get_masses()
-    mms = phonopy_structure.get_magnetic_moments()
-    mms = mms or [0] * len(symbols)
+    lattice = phonopy_structure.cell
+    frac_coords = phonopy_structure.scaled_positions
+    symbols = phonopy_structure.symbols
+    masses = phonopy_structure.masses
+    mms = getattr(phonopy_structure, "magnetic_moments", None) or [0] * len(symbols)
 
     return Structure(
         lattice,
@@ -55,16 +57,14 @@ def get_pmg_structure(phonopy_structure):
     )
 
 
-@requires(Phonopy, "phonopy not installed!")  # type: ignore
-def get_phonopy_structure(pmg_structure):
+@requires(Phonopy, "phonopy not installed!")
+def get_phonopy_structure(pmg_structure: Structure) -> PhonopyAtoms:
     """
     Convert a pymatgen Structure object to a PhonopyAtoms object.
 
     Args:
         pmg_structure (pymatgen Structure): A Pymatgen structure object.
-
     """
-
     symbols = [site.specie.symbol for site in pmg_structure]
 
     return PhonopyAtoms(
@@ -473,7 +473,7 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
         else:
             m = 1
         multiplicities.append(m)
-        bands, gruneisenband = ([] for _ in range(2))
+        bands, gruneisenband = [], []
         for b in p["band"]:
             bands.append(b["frequency"])
             if "gruneisen" in b:
@@ -535,8 +535,8 @@ def get_gs_ph_bs_symm_line_from_dict(
         except ValueError:
             raise ValueError("\nPlease provide a structure.\n")
 
-    qpts, frequencies, gruneisenparameters = ([] for _ in range(3))
-    phonopy_labels_dict = {}  # type: Dict[Any,Any]
+    q_points, frequencies, gruneisen_params = [], [], []
+    phonopy_labels_dict: dict[str, dict[str, str]] = {}
 
     if fit:
         for pa in gruneisen_dict["path"]:
@@ -545,61 +545,62 @@ def get_gs_ph_bs_symm_line_from_dict(
             end = pa["phonon"][-1]
 
             if start["q-position"] == [0, 0, 0]:  # Gamma at start of band
-                qpts_temp, frequencies_temp, gruneisen_temp, distance = (
-                    [] for _ in range(4)
-                )  # type: List[Any],List[Any],List[Any],List[Any]
+                qpts_temp, frequencies_temp = [], []
+                gruneisen_temp: list[list[float]] = []
+                distance: list[float] = []
                 for i in range(pa["nqpoint"]):
-                    bands, gruneisenband = ([] for _ in range(2))  # type: List[Any], List[Any]
+                    bands = []
+                    gruneisen_band: list[float] = []
                     for b in phonon[pa["nqpoint"] - i - 1]["band"]:
                         bands.append(b["frequency"])
                         # Fraction of leftover points in current band
-                        gruen = _extrapolate_grun(b, distance, gruneisen_temp, gruneisenband, i, pa)
-                        gruneisenband.append(gruen)
+                        gruen = _extrapolate_grun(b, distance, gruneisen_temp, gruneisen_band, i, pa)
+                        gruneisen_band.append(gruen)
                     q = phonon[pa["nqpoint"] - i - 1]["q-position"]
                     qpts_temp.append(q)
                     d = phonon[pa["nqpoint"] - i - 1]["distance"]
                     distance.append(d)
                     frequencies_temp.append(bands)
-                    gruneisen_temp.append(gruneisenband)
+                    gruneisen_temp.append(gruneisen_band)
                     if "label" in phonon[pa["nqpoint"] - i - 1]:
                         phonopy_labels_dict[phonon[pa["nqpoint"] - i - 1]]["label"] = phonon[pa["nqpoint"] - i - 1][
                             "q-position"
                         ]
 
-                qpts.extend(list(reversed(qpts_temp)))
+                q_points.extend(list(reversed(qpts_temp)))
                 frequencies.extend(list(reversed(frequencies_temp)))
-                gruneisenparameters.extend(list(reversed(gruneisen_temp)))
+                gruneisen_params.extend(list(reversed(gruneisen_temp)))
 
             elif end["q-position"] == [0, 0, 0]:  # Gamma at end of band
                 distance = []
                 for i in range(pa["nqpoint"]):
-                    bands, gruneisenband = ([] for _ in range(2))
+                    bands, gruneisen_band = [], []
                     for b in phonon[i]["band"]:
                         bands.append(b["frequency"])
-                        gruen = _extrapolate_grun(b, distance, gruneisenparameters, gruneisenband, i, pa)
-                        gruneisenband.append(gruen)
+                        gruen = _extrapolate_grun(b, distance, gruneisen_params, gruneisen_band, i, pa)
+                        gruneisen_band.append(gruen)
                     q = phonon[i]["q-position"]
-                    qpts.append(q)
+                    q_points.append(q)
                     d = phonon[i]["distance"]
                     distance.append(d)
                     frequencies.append(bands)
-                    gruneisenparameters.append(gruneisenband)
+                    gruneisen_params.append(gruneisen_band)
                     if "label" in phonon[i]:
                         phonopy_labels_dict[phonon[i]["label"]] = phonon[i]["q-position"]
 
             else:  # No Gamma in band
                 distance = []
                 for i in range(pa["nqpoint"]):
-                    bands, gruneisenband = ([] for _ in range(2))
+                    bands, gruneisen_band = [], []
                     for b in phonon[i]["band"]:
                         bands.append(b["frequency"])
-                        gruneisenband.append(b["gruneisen"])
+                        gruneisen_band.append(b["gruneisen"])
                     q = phonon[i]["q-position"]
-                    qpts.append(q)
+                    q_points.append(q)
                     d = phonon[i]["distance"]
                     distance.append(d)
                     frequencies.append(bands)
-                    gruneisenparameters.append(gruneisenband)
+                    gruneisen_params.append(gruneisen_band)
                     if "label" in phonon[i]:
                         phonopy_labels_dict[phonon[i]["label"]] = phonon[i]["q-position"]
 
@@ -607,27 +608,23 @@ def get_gs_ph_bs_symm_line_from_dict(
         for pa in gruneisen_dict["path"]:
             for p in pa["phonon"]:
                 q = p["q-position"]
-                qpts.append(q)
-                bands, gruneisen_bands = ([] for _ in range(2))
+                q_points.append(q)
+                bands, gruneisen_bands = [], []
                 for b in p["band"]:
                     bands.append(b["frequency"])
                     gruneisen_bands.append(b["gruneisen"])
                 frequencies.append(bands)
-                gruneisenparameters.append(gruneisen_bands)
+                gruneisen_params.append(gruneisen_bands)
                 if "label" in p:
                     phonopy_labels_dict[p["label"]] = p["q-position"]
 
-    qpts_np = np.array(qpts)
-    # transpose to match the convention in PhononBandStructure
-    frequencies_np = np.transpose(frequencies)
-    gruneisenparameters_np = np.transpose(gruneisenparameters)
-
     rec_latt = structure.lattice.reciprocal_lattice
     labels_dict = labels_dict or phonopy_labels_dict
     return GruneisenPhononBandStructureSymmLine(
-        qpoints=qpts_np,
-        frequencies=frequencies_np,
-        gruneisenparameters=gruneisenparameters_np,
+        qpoints=np.array(q_points),
+        # transpose to match the convention in PhononBandStructure
+        frequencies=np.transpose(frequencies),
+        gruneisenparameters=np.transpose(gruneisen_params),
         lattice=rec_latt,
         labels_dict=labels_dict,
         structure=structure,
@@ -677,3 +674,37 @@ def get_gruneisen_ph_bs_symm_line(gruneisen_path, structure=None, structure_path
             (and therefore numerical inaccuracies) close to gamma.
     """
     return get_gs_ph_bs_symm_line_from_dict(loadfn(gruneisen_path), structure, structure_path, labels_dict, fit)
+
+
+def get_thermal_displacement_matrices(
+    thermal_displacements_yaml="thermal_displacement_matrices.yaml", structure_path="POSCAR"
+):
+    """
+    Function to read "thermal_displacement_matrices.yaml" from phonopy and return a list of
+    ThermalDisplacementMatrices objects
+    Args:
+        thermal_displacements_yaml: path to thermal_displacement_matrices.yaml
+        structure_path: path to POSCAR
+
+    Returns:
+
+    """
+    thermal_displacements_dict = loadfn(thermal_displacements_yaml)
+
+    if structure_path:
+        structure = Structure.from_file(structure_path)
+    else:
+        raise ValueError("\nPlease provide a structure.\n")
+
+    thermal_displacement_objects_list = []
+    for matrix in thermal_displacements_dict["thermal_displacement_matrices"]:
+        thermal_displacement_objects_list.append(
+            ThermalDisplacementMatrices(
+                thermal_displacement_matrix_cart=matrix["displacement_matrices"],
+                temperature=matrix["temperature"],
+                structure=structure,
+                thermal_displacement_matrix_cif=matrix["displacement_matrices_cif"],
+            )
+        )
+
+    return thermal_displacement_objects_list
