@@ -1,7 +1,6 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module implements input and output processing from PWSCF.
 """
@@ -73,11 +72,11 @@ class PWInput:
                 try:
                     site.properties["pseudo"]
                 except KeyError:
-                    raise PWInputError("Missing %s in pseudo specification!" % site)
+                    raise PWInputError(f"Missing {site} in pseudo specification!")
         else:
-            for species in self.structure.composition.keys():
+            for species in self.structure.composition:
                 if str(species) not in pseudo:
-                    raise PWInputError("Missing %s in pseudo specification!" % species)
+                    raise PWInputError(f"Missing {species} in pseudo specification!")
         self.pseudo = pseudo
 
         self.sections = sections
@@ -106,9 +105,9 @@ class PWInput:
 
         def to_str(v):
             if isinstance(v, str):
-                return "'%s'" % v
+                return f"'{v}'"
             if isinstance(v, float):
-                return "%s" % str(v).replace("e", "d")
+                return f"{str(v).replace('e', 'd')}"
             if isinstance(v, bool):
                 if v:
                     return ".TRUE."
@@ -117,13 +116,13 @@ class PWInput:
 
         for k1 in ["control", "system", "electrons", "ions", "cell"]:
             v1 = self.sections[k1]
-            out.append("&%s" % k1.upper())
+            out.append(f"&{k1.upper()}")
             sub = []
-            for k2 in sorted(v1.keys()):
+            for k2 in sorted(v1):
                 if isinstance(v1[k2], list):
                     n = 1
-                    for l in v1[k2][: len(site_descriptions)]:
-                        sub.append("  %s(%d) = %s" % (k2, n, to_str(v1[k2][n - 1])))
+                    for _ in v1[k2][: len(site_descriptions)]:
+                        sub.append(f"  {k2}({n}) = {to_str(v1[k2][n - 1])}")
                         n += 1
                 else:
                     sub.append(f"  {k2} = {to_str(v1[k2])}")
@@ -131,9 +130,9 @@ class PWInput:
                 if "ibrav" not in self.sections[k1]:
                     sub.append("  ibrav = 0")
                 if "nat" not in self.sections[k1]:
-                    sub.append("  nat = %d" % len(self.structure))
+                    sub.append(f"  nat = {len(self.structure)}")
                 if "ntyp" not in self.sections[k1]:
-                    sub.append("  ntyp = %d" % len(site_descriptions))
+                    sub.append(f"  ntyp = {len(site_descriptions)}")
             sub.append("/")
             out.append(",\n".join(sub))
 
@@ -158,10 +157,19 @@ class PWInput:
                         name = k
                 out.append(f"  {name} {site.a:.6f} {site.b:.6f} {site.c:.6f}")
 
-        out.append("K_POINTS %s" % self.kpoints_mode)
-        kpt_str = ["%s" % i for i in self.kpoints_grid]
-        kpt_str.extend(["%s" % i for i in self.kpoints_shift])
-        out.append("  %s" % " ".join(kpt_str))
+        out.append(f"K_POINTS {self.kpoints_mode}")
+        if self.kpoints_mode == "automatic":
+            kpt_str = [f"{i}" for i in self.kpoints_grid]
+            kpt_str.extend([f"{i}" for i in self.kpoints_shift])
+            out.append(f"  {' '.join(kpt_str)}")
+        elif self.kpoints_mode == "crystal_b":
+            out.append(f" {str(len(self.kpoints_grid))}")
+            for i in range(len(self.kpoints_grid)):
+                kpt_str = [f"{entry:.4f}" for entry in self.kpoints_grid[i]]
+                out.append(f" {' '.join(kpt_str)}")
+        elif self.kpoints_mode == "gamma":
+            pass
+
         out.append("CELL_PARAMETERS angstrom")
         for vec in self.structure.lattice.matrix:
             out.append(f"  {vec[0]:f} {vec[1]:f} {vec[2]:f}")
@@ -217,7 +225,7 @@ class PWInput:
             filename (str): The string filename to output to.
         """
         with open(filename, "w") as f:
-            f.write(self.__str__())
+            f.write(str(self))
 
     @staticmethod
     def from_file(filename):
@@ -252,9 +260,11 @@ class PWInput:
             if "ATOMIC_SPECIES" in line:
                 return ("pseudo",)
             if "K_POINTS" in line:
-                return "kpoints", line.split("{")[1][:-1]
+                return "kpoints", line.split()[1]
+            if "OCCUPATIONS" in line:
+                return "occupations"
             if "CELL_PARAMETERS" in line or "ATOMIC_POSITIONS" in line:
-                return "structure", line.split("{")[1][:-1]
+                return "structure", line.split()[1]
             if line == "/":
                 return None
             return mode
@@ -267,7 +277,6 @@ class PWInput:
             "cell": {},
         }
         pseudo = {}
-        pseudo_index = 0
         lattice = []
         species = []
         coords = []
@@ -300,10 +309,7 @@ class PWInput:
             elif mode[0] == "pseudo":
                 m = re.match(r"(\w+)\s+(\d*.\d*)\s+(.*)", line)
                 if m:
-                    pseudo[m.group(1).strip()] = {}
-                    pseudo[m.group(1).strip()]["index"] = pseudo_index
-                    pseudo[m.group(1).strip()]["pseudopot"] = m.group(3).strip()
-                    pseudo_index += 1
+                    pseudo[m.group(1).strip()] = m.group(3).strip()
             elif mode[0] == "kpoints":
                 m = re.match(r"(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)", line)
                 if m:
@@ -311,6 +317,9 @@ class PWInput:
                     kpoints_shift = (int(m.group(4)), int(m.group(5)), int(m.group(6)))
                 else:
                     kpoints_mode = mode[1]
+                    kpoints_grid = (1, 1, 1)
+                    kpoints_shift = (0, 0, 0)
+
             elif mode[0] == "structure":
                 m_l = re.match(r"(-?\d+\.?\d*)\s+(-?\d+\.?\d*)\s+(-?\d+\.?\d*)", line)
                 m_p = re.match(r"(\w+)\s+(-?\d+\.\d*)\s+(-?\d+\.?\d*)\s+(-?\d+\.?\d*)", line)
@@ -321,18 +330,14 @@ class PWInput:
                         float(m_l.group(3)),
                     ]
                 elif m_p:
-                    site_properties["pseudo"].append(pseudo[m_p.group(1)]["pseudopot"])
-                    species += [pseudo[m_p.group(1)]["pseudopot"].split(".")[0]]
+                    site_properties["pseudo"].append(pseudo[m_p.group(1)])
+                    species.append(m_p.group(1))
                     coords += [[float(m_p.group(2)), float(m_p.group(3)), float(m_p.group(4))]]
 
-                    for k, v in site_properties.items():
-                        if k != "pseudo":
-                            v.append(sections["system"][k][pseudo[m_p.group(1)]["index"]])
-                if mode[1] == "angstrom":
-                    coords_are_cartesian = True
-                elif mode[1] == "crystal":
-                    coords_are_cartesian = False
-
+                    if mode[1] == "angstrom":
+                        coords_are_cartesian = True
+                    elif mode[1] == "crystal":
+                        coords_are_cartesian = False
         structure = Structure(
             Lattice(lattice),
             species,
@@ -343,6 +348,7 @@ class PWInput:
         return PWInput(
             structure=structure,
             control=sections["control"],
+            pseudo=pseudo,
             system=sections["system"],
             electrons=sections["electrons"],
             ions=sections["ions"],
@@ -499,8 +505,6 @@ class PWInputError(BaseException):
     Error for PWInput
     """
 
-    pass
-
 
 class PWOutput:
     """
@@ -569,15 +573,15 @@ class PWOutput:
         )
         self.data.update(matches)
 
-    def get_celldm(self, i):
+    def get_celldm(self, idx: int):
         """
         Args:
-            i (int): index
+            idx (int): index
 
         Returns:
             Cell dimension along index
         """
-        return self.data["celldm%d" % i]
+        return self.data[f"celldm{idx}"]
 
     @property
     def final_energy(self):
