@@ -4,22 +4,20 @@
 """
 Classes for reading/manipulating/writing QChem input files.
 """
+
+from __future__ import annotations
+
 import logging
-import sys
-from typing import Dict, List, Optional, Tuple, Union
+from pathlib import Path
+from typing import Literal
 
 from monty.io import zopen
-from monty.json import MSONable
 
 from pymatgen.core import Molecule
+from pymatgen.io.core import InputFile
 
 from .utils import lower_and_check_unique, read_pattern, read_table_pattern
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 __author__ = "Brandon Wood, Samuel Blau, Shyam Dwaraknath, Julian Self, Evan Spotte-Smith"
 __copyright__ = "Copyright 2018, The Materials Project"
 __version__ = "0.1"
@@ -29,7 +27,7 @@ __credits__ = "Xiaohui Qu"
 logger = logging.getLogger(__name__)
 
 
-class QCInput(MSONable):
+class QCInput(InputFile):
     """
     An object representing a QChem input file. QCInput attributes represent different sections of a QChem input file.
     To add a new section one needs to modify __init__, __str__, from_sting and add staticmethods
@@ -40,17 +38,18 @@ class QCInput(MSONable):
 
     def __init__(
         self,
-        molecule: Union[Molecule, Literal["read"]],
-        rem: Dict,
-        opt: Optional[Dict[str, List]] = None,
-        pcm: Optional[Dict] = None,
-        solvent: Optional[Dict] = None,
-        smx: Optional[Dict] = None,
-        scan: Optional[Dict[str, List]] = None,
-        van_der_waals: Optional[Dict[str, float]] = None,
+        molecule: Molecule | Literal["read"],
+        rem: dict,
+        opt: dict[str, list] | None = None,
+        pcm: dict | None = None,
+        solvent: dict | None = None,
+        smx: dict | None = None,
+        scan: dict[str, list] | None = None,
+        van_der_waals: dict[str, float] | None = None,
         vdw_mode: str = "atomic",
-        plots: Optional[Dict] = None,
-        nbo: Optional[Dict] = None,
+        plots: dict | None = None,
+        nbo: dict | None = None,
+        geom_opt: dict | None = None,
     ):
         """
         Args:
@@ -63,7 +62,7 @@ class QCInput(MSONable):
                 Ex. rem = {'method': 'rimp2', 'basis': '6-31*G++' ... }
             opt (dict of lists):
                 A dictionary of opt sections, where each opt section is a key and the corresponding
-                values are a list of strings. Stings must be formatted as instructed by the QChem manual.
+                values are a list of strings. Strings must be formatted as instructed by the QChem manual.
                 The different opt sections are: CONSTRAINT, FIXED, DUMMY, and CONNECT
                 Ex. opt = {"CONSTRAINT": ["tors 2 3 4 5 25.0", "tors 2 5 7 9 80.0"], "FIXED": ["2 XY"]}
             pcm (dict):
@@ -84,7 +83,7 @@ class QCInput(MSONable):
                 more than two.
                 Ex. scan = {"stre": ["3 6 1.5 1.9 0.1"], "tors": ["1 2 3 4 -180 180 15"]}
             van_der_waals (dict):
-                A dictionary of custom van der Waals radii to be used when construcing cavities for the PCM
+                A dictionary of custom van der Waals radii to be used when constructing cavities for the PCM
                 model or when computing, e.g. Mulliken charges. They keys are strs whose meaning depends on
                 the value of vdw_mode, and the values are the custom radii in angstroms.
             vdw_mode (str): Method of specifying custom van der Waals radii - 'atomic' or 'sequential'.
@@ -95,7 +94,9 @@ class QCInput(MSONable):
                     A dictionary of all the input parameters for the plots section of QChem input file.
             nbo (dict):
                     A dictionary of all the input parameters for the nbo section of QChem input file.
-
+            geom_opt (dict):
+                    A dictionary of input parameters for the geom_opt section of the QChem input file.
+                    This section is required when using the new libopt3 geometry optimizer.
         """
         self.molecule = molecule
         self.rem = lower_and_check_unique(rem)
@@ -108,6 +109,7 @@ class QCInput(MSONable):
         self.vdw_mode = vdw_mode
         self.plots = lower_and_check_unique(plots)
         self.nbo = lower_and_check_unique(nbo)
+        self.geom_opt = lower_and_check_unique(geom_opt)
 
         # Make sure rem is valid:
         #   - Has a basis
@@ -143,6 +145,12 @@ class QCInput(MSONable):
         #   - Validity checks specific to job type?
         #   - Check OPT and PCM sections?
 
+    def get_string(self):
+        """
+        Return a string representation of an entire input file.
+        """
+        return str(self)
+
     def __str__(self):
         combined_list = []
         # molecule section
@@ -182,10 +190,14 @@ class QCInput(MSONable):
         if self.nbo is not None:
             combined_list.append(self.nbo_template(self.nbo))
             combined_list.append("")
+        # geom_opt section
+        if self.geom_opt is not None:
+            combined_list.append(self.geom_opt_template(self.geom_opt))
+            combined_list.append("")
         return "\n".join(combined_list)
 
     @staticmethod
-    def multi_job_string(job_list: List["QCInput"]) -> str:
+    def multi_job_string(job_list: list[QCInput]) -> str:
         """
         Args:
             job_list (): List of jobs
@@ -196,13 +208,13 @@ class QCInput(MSONable):
         multi_job_string = ""
         for i, job_i in enumerate(job_list):
             if i < len(job_list) - 1:
-                multi_job_string += job_i.__str__() + "\n@@@\n\n"
+                multi_job_string += str(job_i) + "\n@@@\n\n"
             else:
-                multi_job_string += job_i.__str__()
+                multi_job_string += str(job_i)
         return multi_job_string
 
     @classmethod
-    def from_string(cls, string: str) -> "QCInput":
+    def from_string(cls, string: str) -> QCInput:
         """
         Read QcInput from string.
 
@@ -225,6 +237,7 @@ class QCInput(MSONable):
         vdw_mode = "atomic"
         plots = None
         nbo = None
+        geom_opt = None
         if "opt" in sections:
             opt = cls.read_opt(string)
         if "pcm" in sections:
@@ -241,6 +254,8 @@ class QCInput(MSONable):
             plots = cls.read_plots(string)
         if "nbo" in sections:
             nbo = cls.read_nbo(string)
+        if "geom_opt" in sections:
+            geom_opt = cls.read_geom_opt(string)
         return cls(
             molecule,
             rem,
@@ -253,20 +268,11 @@ class QCInput(MSONable):
             vdw_mode=vdw_mode,
             plots=plots,
             nbo=nbo,
+            geom_opt=geom_opt,
         )
 
-    def write_file(self, filename: str):
-        """
-        Write QcInput to file.
-
-        Args:
-            filename (str): Filename
-        """
-        with zopen(filename, "wt") as f:
-            f.write(self.__str__())
-
     @staticmethod
-    def write_multi_job_file(job_list: List["QCInput"], filename: str):
+    def write_multi_job_file(job_list: list[QCInput], filename: str):
         """
         Write a multijob file.
 
@@ -278,7 +284,7 @@ class QCInput(MSONable):
             f.write(QCInput.multi_job_string(job_list))
 
     @staticmethod
-    def from_file(filename: str) -> "QCInput":
+    def from_file(filename: str | Path) -> QCInput:
         """
         Create QcInput from file.
         Args:
@@ -291,7 +297,7 @@ class QCInput(MSONable):
             return QCInput.from_string(f.read())
 
     @classmethod
-    def from_multi_jobs_file(cls, filename: str) -> List["QCInput"]:
+    def from_multi_jobs_file(cls, filename: str) -> list[QCInput]:
         """
         Create list of QcInput from a file.
         Args:
@@ -308,7 +314,7 @@ class QCInput(MSONable):
             return input_list
 
     @staticmethod
-    def molecule_template(molecule: Union[Molecule, Literal["read"]]) -> str:
+    def molecule_template(molecule: Molecule | Literal["read"]) -> str:
         """
         Args:
             molecule (Molecule): molecule
@@ -327,16 +333,12 @@ class QCInput(MSONable):
         else:
             mol_list.append(f" {int(molecule.charge)} {molecule.spin_multiplicity}")
             for site in molecule.sites:
-                mol_list.append(
-                    " {atom}     {x: .10f}     {y: .10f}     {z: .10f}".format(
-                        atom=site.species_string, x=site.x, y=site.y, z=site.z
-                    )
-                )
+                mol_list.append(f" {site.species_string}     {site.x: .10f}     {site.y: .10f}     {site.z: .10f}")
         mol_list.append("$end")
         return "\n".join(mol_list)
 
     @staticmethod
-    def rem_template(rem: Dict) -> str:
+    def rem_template(rem: dict) -> str:
         """
         Args:
             rem ():
@@ -352,7 +354,7 @@ class QCInput(MSONable):
         return "\n".join(rem_list)
 
     @staticmethod
-    def opt_template(opt: Dict[str, List]) -> str:
+    def opt_template(opt: dict[str, list]) -> str:
         """
         Optimization template.
 
@@ -378,7 +380,7 @@ class QCInput(MSONable):
         return "\n".join(opt_list)
 
     @staticmethod
-    def pcm_template(pcm: Dict) -> str:
+    def pcm_template(pcm: dict) -> str:
         """
         Pcm run template.
 
@@ -396,7 +398,7 @@ class QCInput(MSONable):
         return "\n".join(pcm_list)
 
     @staticmethod
-    def solvent_template(solvent: Dict) -> str:
+    def solvent_template(solvent: dict) -> str:
         """
         Solvent template.
 
@@ -414,7 +416,7 @@ class QCInput(MSONable):
         return "\n".join(solvent_list)
 
     @staticmethod
-    def smx_template(smx: Dict) -> str:
+    def smx_template(smx: dict) -> str:
         """
         Args:
             smx ():
@@ -426,14 +428,14 @@ class QCInput(MSONable):
         smx_list.append("$smx")
         for key, value in smx.items():
             if value == "tetrahydrofuran":
-                smx_list.append("   {key} {value}".format(key=key, value="thf"))
+                smx_list.append(f"   {key} thf")
             else:
                 smx_list.append(f"   {key} {value}")
         smx_list.append("$end")
         return "\n".join(smx_list)
 
     @staticmethod
-    def scan_template(scan: Dict[str, List]) -> str:
+    def scan_template(scan: dict[str, list]) -> str:
         """
         Args:
             scan (dict): Dictionary with scan section information.
@@ -455,7 +457,7 @@ class QCInput(MSONable):
         return "\n".join(scan_list)
 
     @staticmethod
-    def van_der_waals_template(radii: Dict[str, float], mode: str = "atomic") -> str:
+    def van_der_waals_template(radii: dict[str, float], mode: str = "atomic") -> str:
         """
         Args:
             radii (dict): Dictionary with custom van der Waals radii, in
@@ -486,7 +488,7 @@ class QCInput(MSONable):
         return "\n".join(vdw_list)
 
     @staticmethod
-    def plots_template(plots: Dict) -> str:
+    def plots_template(plots: dict) -> str:
         """
         Args:
             plots ():
@@ -502,7 +504,7 @@ class QCInput(MSONable):
         return "\n".join(plots_list)
 
     @staticmethod
-    def nbo_template(nbo: Dict) -> str:
+    def nbo_template(nbo: dict) -> str:
         """
         Args:
             nbo ():
@@ -518,7 +520,23 @@ class QCInput(MSONable):
         return "\n".join(nbo_list)
 
     @staticmethod
-    def find_sections(string: str) -> List:
+    def geom_opt_template(geom_opt: dict) -> str:
+        """
+        Args:
+            geom_opt ():
+
+        Returns:
+            (str)
+        """
+        geom_opt_list = []
+        geom_opt_list.append("$geom_opt")
+        for key, value in geom_opt.items():
+            geom_opt_list.append(f"   {key} = {value}")
+        geom_opt_list.append("$end")
+        return "\n".join(geom_opt_list)
+
+    @staticmethod
+    def find_sections(string: str) -> list:
         """
         Find sections in the string.
 
@@ -535,7 +553,7 @@ class QCInput(MSONable):
         # remove end from sections
         sections = [sec for sec in sections if sec != "end"]
         # this error should be replaced by a multi job read function when it is added
-        if "multiple_jobs" in matches.keys():
+        if "multiple_jobs" in matches:
             raise ValueError("Output file contains multiple qchem jobs please parse separately")
         if "molecule" not in sections:
             raise ValueError("Output file does not contain a molecule section")
@@ -544,7 +562,7 @@ class QCInput(MSONable):
         return sections
 
     @staticmethod
-    def read_molecule(string: str) -> Union[Molecule, Literal["read"]]:
+    def read_molecule(string: str) -> Molecule | Literal["read"]:
         """
         Read molecule from string.
 
@@ -562,11 +580,11 @@ class QCInput(MSONable):
             "spin_mult": r"^\s*\$molecule\n\s(?:\-)*\d+\s*(\d)",
         }
         matches = read_pattern(string, patterns)
-        if "read" in matches.keys():
+        if "read" in matches:
             return "read"
-        if "charge" in matches.keys():
+        if "charge" in matches:
             charge = float(matches["charge"][0][0])
-        if "spin_mult" in matches.keys():
+        if "spin_mult" in matches:
             spin_mult = int(matches["spin_mult"][0][0])
         header = r"^\s*\$molecule\n\s*(?:\-)*\d+\s*\d"
         row = r"\s*((?i)[a-z]+)\s+([\d\-\.]+)\s+([\d\-\.]+)\s+([\d\-\.]+)"
@@ -581,7 +599,7 @@ class QCInput(MSONable):
         return mol
 
     @staticmethod
-    def read_rem(string: str) -> Dict:
+    def read_rem(string: str) -> dict:
         """
         Parse rem from string.
 
@@ -592,13 +610,13 @@ class QCInput(MSONable):
             (dict) rem
         """
         header = r"^\s*\$rem"
-        row = r"\s*([a-zA-Z\_]+)\s*=?\s*(\S+)"
+        row = r"\s*([a-zA-Z\_\d]+)\s*=?\s*(\S+)"
         footer = r"^\s*\$end"
         rem_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         return dict(rem_table[0])
 
     @staticmethod
-    def read_opt(string: str) -> Dict[str, List]:
+    def read_opt(string: str) -> dict[str, list]:
         """
         Read opt section from string.
 
@@ -615,7 +633,7 @@ class QCInput(MSONable):
             "CONNECT": r"^\s*CONNECT",
         }
         opt_matches = read_pattern(string, patterns)
-        opt_sections = list(opt_matches.keys())
+        opt_sections = list(opt_matches)
         opt = {}
         if "CONSTRAINT" in opt_sections:
             c_header = r"^\s*CONSTRAINT\n"
@@ -659,7 +677,7 @@ class QCInput(MSONable):
         return opt
 
     @staticmethod
-    def read_pcm(string: str) -> Dict:
+    def read_pcm(string: str) -> dict:
         """
         Read pcm parameters from string.
 
@@ -674,13 +692,13 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         pcm_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if not pcm_table:
-            print("No valid PCM inputs found. Note that there should be no '=' chracters in PCM input lines.")
+            print("No valid PCM inputs found. Note that there should be no '=' characters in PCM input lines.")
             return {}
 
         return dict(pcm_table[0])
 
     @staticmethod
-    def read_vdw(string: str) -> Tuple[str, Dict]:
+    def read_vdw(string: str) -> tuple[str, dict]:
         """
         Read van der Waals parameters from string.
 
@@ -695,7 +713,7 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         vdw_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if not vdw_table:
-            print("No valid vdW inputs found. Note that there should be no '=' chracters in vdW input lines.")
+            print("No valid vdW inputs found. Note that there should be no '=' characters in vdW input lines.")
             return "", {}
 
         if vdw_table[0][0][0] == 2:
@@ -706,7 +724,7 @@ class QCInput(MSONable):
         return mode, dict(vdw_table[0][1:])
 
     @staticmethod
-    def read_solvent(string: str) -> Dict:
+    def read_solvent(string: str) -> dict:
         """
         Read solvent parameters from string.
 
@@ -721,13 +739,13 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         solvent_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if not solvent_table:
-            print("No valid solvent inputs found. Note that there should be no '=' chracters in solvent input lines.")
+            print("No valid solvent inputs found. Note that there should be no '=' characters in solvent input lines.")
             return {}
 
         return dict(solvent_table[0])
 
     @staticmethod
-    def read_smx(string: str) -> Dict:
+    def read_smx(string: str) -> dict:
         """
         Read smx parameters from string.
 
@@ -742,7 +760,7 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         smx_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if not smx_table:
-            print("No valid smx inputs found. Note that there should be no '=' chracters in smx input lines.")
+            print("No valid smx inputs found. Note that there should be no '=' characters in smx input lines.")
             return {}
         smx = {}
         for key, val in smx_table[0]:
@@ -752,7 +770,7 @@ class QCInput(MSONable):
         return smx
 
     @staticmethod
-    def read_scan(string: str) -> Dict[str, List]:
+    def read_scan(string: str) -> dict[str, list]:
         """
         Read scan section from a string.
 
@@ -767,7 +785,7 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         scan_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if scan_table == []:
-            print("No valid scan inputs found. Note that there should be no '=' chracters in scan input lines.")
+            print("No valid scan inputs found. Note that there should be no '=' characters in scan input lines.")
             return {}
 
         stre = []
@@ -787,7 +805,7 @@ class QCInput(MSONable):
         return {"stre": stre, "bend": bend, "tors": tors}
 
     @staticmethod
-    def read_plots(string: str) -> Dict:
+    def read_plots(string: str) -> dict:
         """
         Read plots parameters from string.
 
@@ -802,7 +820,7 @@ class QCInput(MSONable):
         footer = r"^\s*\$end"
         plots_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if plots_table == []:
-            print("No valid plots inputs found. Note that there should be no '=' chracters in plots input lines.")
+            print("No valid plots inputs found. Note that there should be no '=' characters in plots input lines.")
             return {}
         plots = {}
         for key, val in plots_table[0]:
@@ -810,7 +828,7 @@ class QCInput(MSONable):
         return plots
 
     @staticmethod
-    def read_nbo(string: str) -> Dict:
+    def read_nbo(string: str) -> dict:
         """
         Read nbo parameters from string.
 
@@ -831,3 +849,26 @@ class QCInput(MSONable):
         for key, val in nbo_table[0]:
             nbo[key] = val
         return nbo
+
+    @staticmethod
+    def read_geom_opt(string: str) -> dict:
+        """
+        Read geom_opt parameters from string.
+
+        Args:
+            string (str): String
+
+        Returns:
+            (dict) geom_opt parameters.
+        """
+        header = r"^\s*\$geom_opt"
+        row = r"\s*([a-zA-Z\_]+)\s*=?\s*(\S+)"
+        footer = r"^\s*\$end"
+        geom_opt_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
+        if geom_opt_table == []:
+            print("No valid geom_opt inputs found.")
+            return {}
+        geom_opt = {}
+        for key, val in geom_opt_table[0]:
+            geom_opt[key] = val
+        return geom_opt
