@@ -5,10 +5,11 @@
 Input sets for Qchem
 """
 
+from __future__ import annotations
+
 import logging
 import os
-import sys
-from typing import Dict, List, Optional
+from typing import Literal
 
 from monty.io import zopen
 
@@ -16,11 +17,6 @@ from pymatgen.core.structure import Molecule
 from pymatgen.io.qchem.inputs import QCInput
 from pymatgen.io.qchem.utils import lower_and_check_unique
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 __author__ = "Samuel Blau, Brandon Wood, Shyam Dwaraknath, Evan Spotte-Smith, Ryan Kingsbury"
 __copyright__ = "Copyright 2018-2021, The Materials Project"
 __version__ = "0.1"
@@ -40,17 +36,19 @@ class QChemDictSet(QCInput):
         basis_set: str,
         scf_algorithm: str,
         dft_rung: int = 4,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        opt_variables: Optional[Dict[str, List]] = None,
-        scan_variables: Optional[Dict[str, List]] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        opt_variables: dict[str, list] | None = None,
+        scan_variables: dict[str, list] | None = None,
+        max_scf_cycles: int = 100,
         geom_opt_max_cycles: int = 200,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        overwrite_inputs: Optional[Dict] = None,
+        nbo_params: dict | None = None,
+        new_geom_opt: dict | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
+        extra_scf_print: bool = False,
     ):
         """
         Args:
@@ -70,7 +68,7 @@ class QChemDictSet(QCInput):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -84,7 +82,7 @@ class QChemDictSet(QCInput):
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
             opt_variables (dict): A dictionary of opt sections, where each opt section is a key
-                and the corresponding values are a list of strings. Stings must be formatted
+                and the corresponding values are a list of strings. Strings must be formatted
                 as instructed by the QChem manual. The different opt sections are: CONSTRAINT, FIXED,
                 DUMMY, and CONNECT.
 
@@ -95,11 +93,18 @@ class QChemDictSet(QCInput):
                 Note that the total number of variable (sum of lengths of all lists) CANNOT be more than two.
 
                 Ex. scan_variables = {"stre": ["3 6 1.5 1.9 0.1"], "tors": ["1 2 3 4 -180 180 15"]}
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
-            nbo_params (list): A list of strings for the desired NBO params. If an empty list is passed,
-                default NBO analysis will be performed. (Default: False)
+            nbo_params (dict): A dict containing the desired NBO params. Note that a key:value pair of
+                "version":7 will trigger NBO7 analysis. Otherwise, NBO5 analysis will be performed,
+                including if an empty dict is passed. Besides a key of "version", all other key:value
+                pairs will be written into the $nbo section of the QChem input file. (Default: False)
+            new_geom_opt (dict): A dict containing parameters for the $geom_opt section of the QChem
+                input file, which control the new geometry optimizer available starting in version 5.4.2.
+                Note that the new optimizer remains under development and not officially released.
+                Further note that even passig an empty dictionary will trigger the new optimizer.
+                (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
                 The currently available sections (keys) are rem, pcm,
                 solvent, smx, opt, scan, van_der_waals, and plots. The value of each key is a
@@ -120,6 +125,9 @@ class QChemDictSet(QCInput):
                 In 'atomic' mode (default), dict keys represent the atomic number associated with each
                 radius (e.g., '12' = carbon). In 'sequential' mode, dict keys represent the sequential
                 position of a single specific atom in the input structure.
+            extra_scf_print (bool): Whether to store extra information generated from the SCF
+                cycle. If switched on, the Fock Matrix, coefficients of MO and the density matrix
+                will be stored.
         """
         self.molecule = molecule
         self.job_type = job_type
@@ -135,8 +143,10 @@ class QChemDictSet(QCInput):
         self.geom_opt_max_cycles = geom_opt_max_cycles
         self.plot_cubes = plot_cubes
         self.nbo_params = nbo_params
+        self.new_geom_opt = new_geom_opt
         self.overwrite_inputs = overwrite_inputs
         self.vdw_mode = vdw_mode
+        self.extra_scf_print = extra_scf_print
 
         pcm_defaults = {
             "heavypoints": "194",
@@ -169,6 +179,8 @@ class QChemDictSet(QCInput):
         myrem["max_scf_cycles"] = str(self.max_scf_cycles)
         myrem["gen_scfman"] = "true"
         myrem["xc_grid"] = "3"
+        myrem["thresh"] = "14"
+        myrem["s2thresh"] = "16"
         myrem["scf_algorithm"] = self.scf_algorithm
         myrem["resp_charges"] = "true"
         myrem["symmetry"] = "false"
@@ -220,8 +232,30 @@ class QChemDictSet(QCInput):
             myrem["plots"] = "true"
             myrem["make_cube_files"] = "true"
 
+        mynbo = self.nbo_params
         if self.nbo_params is not None:
             myrem["nbo"] = "true"
+            if "version" in self.nbo_params:
+                if self.nbo_params["version"] == 7:
+                    myrem["nbo_external"] = "true"
+                else:
+                    raise RuntimeError("nbo params version should only be set to 7! Exiting...")
+            mynbo = {}
+            for key in self.nbo_params:
+                if key != "version":
+                    mynbo[key] = self.nbo_params[key]
+
+        my_geom_opt = self.new_geom_opt
+        if self.new_geom_opt is not None:
+            myrem["geom_opt2"] = "3"
+            if "maxiter" in self.new_geom_opt:
+                if self.new_geom_opt["maxiter"] != str(self.geom_opt_max_cycles):
+                    raise RuntimeError("Max # of optimization cycles must be the same! Exiting...")
+            else:
+                self.new_geom_opt["maxiter"] = str(self.geom_opt_max_cycles)
+            my_geom_opt = {}
+            for key in self.new_geom_opt:
+                my_geom_opt[key] = self.new_geom_opt[key]
 
         if self.overwrite_inputs:
             for sec, sec_dict in self.overwrite_inputs.items():
@@ -256,14 +290,35 @@ class QChemDictSet(QCInput):
                     for k, v in temp_plots.items():
                         myplots[k] = v
                 if sec == "nbo":
-                    temp_plots = lower_and_check_unique(sec_dict)
-                    for k, v in temp_plots.items():
-                        myplots[k] = v
+                    if mynbo is None:
+                        raise RuntimeError("Can't overwrite nbo params when NBO is not being run! Exiting...")
+                    temp_nbo = lower_and_check_unique(sec_dict)
+                    for k, v in temp_nbo.items():
+                        mynbo[k] = v
+                if sec == "geom_opt":
+                    if my_geom_opt is None:
+                        raise RuntimeError(
+                            "Can't overwrite geom_opt params when not using the new optimizer! Exiting..."
+                        )
+                    temp_geomopt = lower_and_check_unique(sec_dict)
+                    for k, v in temp_geomopt.items():
+                        my_geom_opt[k] = v
                 if sec == "opt":
                     temp_opts = lower_and_check_unique(sec_dict)
                     for k, v in temp_opts.items():
                         myopt[k] = v
 
+        if extra_scf_print:
+            # Allow for the printing of the Fock matrix and the eigenvales
+            myrem["scf_final_print"] = "3"
+            # If extra_scf_print is specified, make sure that the convergence of the
+            # SCF cycle is at least 1e-8. Anything less than that might not be appropriate
+            # for printing out the Fock Matrix and coefficients of the MO.
+            if "scf_convergence" not in myrem:
+                myrem["scf_convergence"] = "8"
+            elif int(myrem["scf_convergence"]) < 8:
+                myrem["scf_convergence"] = "8"
+
         super().__init__(
             self.molecule,
             rem=myrem,
@@ -275,7 +330,8 @@ class QChemDictSet(QCInput):
             van_der_waals=myvdw,
             vdw_mode=self.vdw_mode,
             plots=myplots,
-            nbo=self.nbo_params,
+            nbo=mynbo,
+            geom_opt=my_geom_opt,
         )
 
     def write(self, input_file: str):
@@ -300,14 +356,15 @@ class SinglePointSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        overwrite_inputs: Optional[Dict] = None,
+        nbo_params: dict | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
+        extra_scf_print: bool = False,
     ):
         """
         Args:
@@ -328,7 +385,7 @@ class SinglePointSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -341,7 +398,7 @@ class SinglePointSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
                 The currently available sections (keys) are rem, pcm,
@@ -363,6 +420,9 @@ class SinglePointSet(QChemDictSet):
                 In 'atomic' mode (default), dict keys represent the atomic number associated with each
                 radius (e.g., '12' = carbon). In 'sequential' mode, dict keys represent the sequential
                 position of a single specific atom in the input structure.
+            extra_scf_print (bool): Whether to store extra information generated from the SCF
+                cycle. If switched on, the Fock Matrix, coefficients of MO and the density matrix
+                will be stored.
         """
         self.basis_set = basis_set
         self.scf_algorithm = scf_algorithm
@@ -381,6 +441,7 @@ class SinglePointSet(QChemDictSet):
             nbo_params=nbo_params,
             overwrite_inputs=overwrite_inputs,
             vdw_mode=vdw_mode,
+            extra_scf_print=extra_scf_print,
         )
 
 
@@ -395,15 +456,16 @@ class OptSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        opt_variables: Optional[Dict[str, List]] = None,
+        nbo_params: dict | None = None,
+        opt_variables: dict[str, list] | None = None,
         geom_opt_max_cycles: int = 200,
-        overwrite_inputs: Optional[Dict] = None,
+        new_geom_opt: dict | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
     ):
         """
@@ -425,7 +487,7 @@ class OptSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -438,7 +500,7 @@ class OptSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
@@ -480,6 +542,7 @@ class OptSet(QChemDictSet):
             geom_opt_max_cycles=self.geom_opt_max_cycles,
             plot_cubes=plot_cubes,
             nbo_params=nbo_params,
+            new_geom_opt=new_geom_opt,
             overwrite_inputs=overwrite_inputs,
             vdw_mode=vdw_mode,
         )
@@ -496,15 +559,15 @@ class TransitionStateSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        opt_variables: Optional[Dict[str, List]] = None,
+        nbo_params: dict | None = None,
+        opt_variables: dict[str, list] | None = None,
         geom_opt_max_cycles: int = 200,
-        overwrite_inputs: Optional[Dict] = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode="atomic",
     ):
         """
@@ -523,7 +586,7 @@ class TransitionStateSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -536,7 +599,7 @@ class TransitionStateSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
@@ -594,13 +657,13 @@ class ForceSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        overwrite_inputs: Optional[Dict] = None,
+        nbo_params: dict | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
     ):
         """
@@ -619,7 +682,7 @@ class ForceSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -632,7 +695,7 @@ class ForceSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
@@ -687,13 +750,13 @@ class FreqSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        overwrite_inputs: Optional[Dict] = None,
+        nbo_params: dict | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
     ):
         """
@@ -712,7 +775,7 @@ class FreqSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -725,7 +788,7 @@ class FreqSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
@@ -786,22 +849,22 @@ class PESScanSet(QChemDictSet):
         basis_set: str = "def2-tzvppd",
         scf_algorithm: str = "diis",
         dft_rung: int = 3,
-        pcm_dielectric: Optional[float] = None,
-        smd_solvent: Optional[str] = None,
-        custom_smd: Optional[str] = None,
-        max_scf_cycles: int = 200,
+        pcm_dielectric: float | None = None,
+        smd_solvent: str | None = None,
+        custom_smd: str | None = None,
+        max_scf_cycles: int = 100,
         plot_cubes: bool = False,
-        nbo_params: Optional[Dict] = None,
-        opt_variables: Optional[Dict[str, List]] = None,
-        scan_variables: Optional[Dict[str, List]] = None,
-        overwrite_inputs: Optional[Dict] = None,
+        nbo_params: dict | None = None,
+        opt_variables: dict[str, list] | None = None,
+        scan_variables: dict[str, list] | None = None,
+        overwrite_inputs: dict | None = None,
         vdw_mode: Literal["atomic", "sequential"] = "atomic",
     ):
         """
         Args:
             molecule (Pymatgen Molecule object)
             opt_variables (dict): A dictionary of opt sections, where each opt section is a key
-                and the corresponding values are a list of strings. Stings must be formatted
+                and the corresponding values are a list of strings. Strings must be formatted
                 as instructed by the QChem manual. The different opt sections are: CONSTRAINT, FIXED,
                 DUMMY, and CONNECT.
 
@@ -825,7 +888,7 @@ class PESScanSet(QChemDictSet):
                 argument to {"method":"<NAME OF FUNCTIONAL>"}
 
                 **Note that the "rungs" in this argument do NOT correspond to rungs on "Jacob's
-                Ladder of Density Functional Approxmations"**
+                Ladder of Density Functional Approximations"**
             pcm_dielectric (float): Dielectric constant to use for PCM implicit solvation model. (Default: None)
             smd_solvent (str): Solvent to use for SMD implicit solvation model. (Default: None)
                 Examples include "water", "ethanol", "methanol", and "acetonitrile". Refer to the QChem
@@ -838,7 +901,7 @@ class PESScanSet(QChemDictSet):
                 "dielectric, refractive index, acidity, basicity, surface tension, aromaticity,
                 electronegative halogenicity"
                 Refer to the QChem manual for further details.
-            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 200)
+            max_scf_cycles (int): Maximum number of SCF iterations. (Default: 100)
             geom_opt_max_cycles (int): Maximum number of geometry optimization iterations. (Default: 200)
             plot_cubes (bool): Whether to write CUBE files of the electron density. (Default: False)
             overwrite_inputs (dict): Dictionary of QChem input sections to add or overwrite variables.
