@@ -129,7 +129,7 @@ $end"""
 
         bad_scan = {"stre": ["1 2 1.0 2.0 0.05", "3 4 1.5 2.0 0.05"], "bend": ["7 8 9 90 120 10"]}
         with self.assertRaises(ValueError):
-            bad_scan_test = QCInput.scan_template(bad_scan)
+            QCInput.scan_template(bad_scan)
 
     def test_van_der_waals_template(self):
         vdw_params = {1: 1.20, 12: 1.72}
@@ -149,8 +149,8 @@ $end"""
 $end"""
         self.assertEqual(vdw_test_sequential, vdw_actual_sequential)
 
-        with self.assertRaises(ValueError):
-            bad_vdw_test = QCInput.van_der_waals_template(vdw_params, mode="mymode")
+        with self.assertRaises(ValueError):  # bad vdw test
+            QCInput.van_der_waals_template(vdw_params, mode="mymode")
 
     def test_find_sections(self):
         str_single_job_input = """$molecule
@@ -312,7 +312,7 @@ $end"""
             "max_scf_cycles": "300",
             "gen_scfman": "true",
         }
-        str_test = QCInput(molecule=molecule, rem=rem).__str__().split("\n")
+        str_test = str(QCInput(molecule=molecule, rem=rem)).split("\n")
         str_actual_list = [
             "$molecule",
             " 0 1",
@@ -707,7 +707,7 @@ $end"""
 
     def test_read_scan(self):
         str_scan = """Once more, I'm trying to break you!
-        
+
 $scan
    stre 1 2 1.1 1.4 0.03
    bend 3 4 5 60 90 5
@@ -721,7 +721,7 @@ $end"""
         str_scan_1 = """Once more, I"m trying to break you!
 $scan
    boo 1 4 1.2 1.5 0.02
-   tors = 3 6 1.5 1.9 0.01        
+   tors = 3 6 1.5 1.9 0.01
 $end
 """
         scan_test_1 = QCInput.read_scan(str_scan_1)
@@ -729,7 +729,7 @@ $end
         self.assertDictEqual(scan_test_1, scan_actual_1)
 
         str_scan_2 = """Once more, I'm trying to break you!
-        
+
 $scan
    stre 1 2 1.1 1.4 0.03
    bend 3 4 5 60 90 5
@@ -737,7 +737,7 @@ $scan
 $end"""
 
         with self.assertRaises(ValueError):
-            scan_test_2 = QCInput.read_scan(str_scan_2)
+            QCInput.read_scan(str_scan_2)
 
     def test_read_negative(self):
         str_molecule = """$molecule
@@ -944,6 +944,20 @@ $end
         ref_file.close()
         os.remove(os.path.join(os.path.dirname(__file__), "test_vdw.qin"))
 
+    def test_read_write_nbo7(self):
+        qcinp = QCInput.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "molecules", "new_qchem_files", "nbo7.qin"))
+        qcinp.write_file(os.path.join(os.path.dirname(__file__), "test_nbo7.qin"))
+        test_file = open(os.path.join(PymatgenTest.TEST_FILES_DIR, "molecules", "new_qchem_files", "nbo7.qin"))
+        ref_file = open(os.path.join(os.path.dirname(__file__), "test_nbo7.qin"))
+
+        for l_test, l_ref in zip(test_file, ref_file):
+            # By default, if this statement fails the offending line will be printed
+            assert l_test == l_ref
+
+        test_file.close()
+        ref_file.close()
+        os.remove(os.path.join(os.path.dirname(__file__), "test_nbo7.qin"))
+
 
 if __name__ == "__main__":
     unittest.main()
