@@ -5,7 +5,16 @@
 import os
 import unittest
 
-from pymatgen.io.qchem.sets import *
+from pymatgen.io.qchem.sets import (
+    ForceSet,
+    FreqSet,
+    OptSet,
+    PESScanSet,
+    QChemDictSet,
+    QCInput,
+    SinglePointSet,
+    TransitionStateSet,
+)
 from pymatgen.util.testing import PymatgenTest
 
 __author__ = "Samuel Blau, Brandon Wood, Shyam Dwaraknath, Evan Spotte-Smith"
@@ -31,10 +40,12 @@ class QChemDictSetTest(PymatgenTest):
                 "job_type": "opt",
                 "gen_scfman": "true",
                 "basis": "6-31g*",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xv",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "geom_opt_max_cycles": "200",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -69,6 +80,8 @@ class QChemDictSetTest(PymatgenTest):
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -108,6 +121,8 @@ class QChemDictSetTest(PymatgenTest):
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
@@ -123,7 +138,8 @@ class QChemDictSetTest(PymatgenTest):
             "rem": {
                 "method": "b3lyp",
                 "basis": "6-31g*",
-                "thresh": 10,
+                "thresh": "10",
+                "s2thresh": "12",
                 "xc_grid": "000150000302",
             }
         }
@@ -132,12 +148,13 @@ class QChemDictSetTest(PymatgenTest):
             "job_type": "opt",
             "gen_scfman": "true",
             "basis": "6-31g*",
-            "max_scf_cycles": "200",
+            "max_scf_cycles": "100",
             "method": "b3lyp",
             "scf_algorithm": "diis",
             "xc_grid": "000150000302",
             "geom_opt_max_cycles": "200",
-            "thresh": 10,
+            "thresh": "10",
+            "s2thresh": "12",
             "symmetry": "false",
             "sym_ignore": "true",
             "resp_charges": "true",
@@ -187,6 +204,8 @@ class QChemDictSetTest(PymatgenTest):
             "gen_scfman": "true",
             "scf_algorithm": "diis",
             "xc_grid": "3",
+            "thresh": "14",
+            "s2thresh": "16",
             "solvent_method": "pcm",
             "symmetry": "false",
             "sym_ignore": "true",
@@ -226,6 +245,8 @@ class QChemDictSetTest(PymatgenTest):
             "gen_scfman": "true",
             "scf_algorithm": "diis",
             "xc_grid": "3",
+            "thresh": "14",
+            "s2thresh": "16",
             "solvent_method": "smd",
             "ideriv": "1",
             "symmetry": "false",
@@ -260,6 +281,8 @@ class QChemDictSetTest(PymatgenTest):
             "gen_scfman": "true",
             "scf_algorithm": "diis",
             "xc_grid": "3",
+            "thresh": "14",
+            "s2thresh": "16",
             "solvent_method": "smd",
             "ideriv": "1",
             "symmetry": "false",
@@ -286,10 +309,12 @@ class SinglePointSetTest(PymatgenTest):
                 "job_type": "sp",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "symmetry": "false",
                 "sym_ignore": "true",
                 "resp_charges": "true",
@@ -299,6 +324,32 @@ class SinglePointSetTest(PymatgenTest):
         self.assertEqual(test_SPSet.solvent, {})
         self.assertEqual(test_SPSet.molecule, test_molecule)
 
+    def test_scf_extra_print(self):
+        test_molecule = QCInput.from_file(os.path.join(test_dir, "new_qchem_files/pcm.qin")).molecule
+        test_SPSet = SinglePointSet(molecule=test_molecule, extra_scf_print=True)
+        self.assertEqual(
+            test_SPSet.rem,
+            {
+                "job_type": "sp",
+                "gen_scfman": "true",
+                "basis": "def2-tzvppd",
+                "max_scf_cycles": "100",
+                "method": "wb97xd",
+                "scf_algorithm": "diis",
+                "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
+                "symmetry": "false",
+                "sym_ignore": "true",
+                "resp_charges": "true",
+                "scf_convergence": "8",
+                "scf_final_print": "3",
+            },
+        )
+        self.assertEqual(test_SPSet.pcm, {})
+        self.assertEqual(test_SPSet.solvent, {})
+        self.assertEqual(test_SPSet.molecule, test_molecule)
+
     def test_pcm_init(self):
         test_molecule = QCInput.from_file(os.path.join(test_dir, "new_qchem_files/pcm.qin")).molecule
         test_SPSet = SinglePointSet(molecule=test_molecule, pcm_dielectric=10.0)
@@ -308,10 +359,12 @@ class SinglePointSetTest(PymatgenTest):
                 "job_type": "sp",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -340,10 +393,12 @@ class SinglePointSetTest(PymatgenTest):
                 "job_type": "sp",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
@@ -363,10 +418,12 @@ class SinglePointSetTest(PymatgenTest):
                 "job_type": "sp",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
@@ -391,10 +448,12 @@ class OptSetTest(PymatgenTest):
                 "job_type": "opt",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "geom_opt_max_cycles": "200",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -415,11 +474,13 @@ class OptSetTest(PymatgenTest):
                 "job_type": "opt",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -448,11 +509,13 @@ class OptSetTest(PymatgenTest):
                 "job_type": "opt",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
@@ -480,10 +543,12 @@ class OptSetTest(PymatgenTest):
                 "gen_scfman": "true",
                 "geom_opt_max_cycles": "200",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "symmetry": "false",
                 "sym_ignore": "true",
                 "resp_charges": "true",
@@ -504,10 +569,12 @@ class TransitionStateSetTest(PymatgenTest):
                 "job_type": "ts",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "geom_opt_max_cycles": "200",
                 "resp_charges": "true",
                 "sym_ignore": "true",
@@ -528,11 +595,13 @@ class TransitionStateSetTest(PymatgenTest):
                 "job_type": "ts",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "resp_charges": "true",
                 "sym_ignore": "true",
@@ -555,11 +624,13 @@ class TransitionStateSetTest(PymatgenTest):
                 "job_type": "ts",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "geom_opt_max_cycles": "200",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "resp_charges": "true",
@@ -581,10 +652,12 @@ class ForceSetTest(PymatgenTest):
                 "job_type": "force",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "symmetry": "false",
                 "sym_ignore": "true",
                 "resp_charges": "true",
@@ -603,10 +676,12 @@ class ForceSetTest(PymatgenTest):
                 "job_type": "force",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -629,10 +704,12 @@ class ForceSetTest(PymatgenTest):
                 "job_type": "force",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
@@ -655,11 +732,13 @@ class PESScanSetTest(PymatgenTest):
                 "job_type": "pes_scan",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "geom_opt_max_cycles": "200",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "resp_charges": "true",
                 "sym_ignore": "true",
                 "symmetry": "false",
@@ -682,11 +761,13 @@ class PESScanSetTest(PymatgenTest):
                 "job_type": "pes_scan",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "geom_opt_max_cycles": "200",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "resp_charges": "true",
                 "sym_ignore": "true",
@@ -712,11 +793,13 @@ class PESScanSetTest(PymatgenTest):
                 "job_type": "pes_scan",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "geom_opt_max_cycles": "200",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "resp_charges": "true",
@@ -739,10 +822,12 @@ class FreqSetTest(PymatgenTest):
                 "job_type": "freq",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "symmetry": "false",
                 "sym_ignore": "true",
                 "resp_charges": "true",
@@ -761,10 +846,12 @@ class FreqSetTest(PymatgenTest):
                 "job_type": "freq",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "pcm",
                 "symmetry": "false",
                 "sym_ignore": "true",
@@ -793,10 +880,12 @@ class FreqSetTest(PymatgenTest):
                 "job_type": "freq",
                 "gen_scfman": "true",
                 "basis": "def2-tzvppd",
-                "max_scf_cycles": "200",
+                "max_scf_cycles": "100",
                 "method": "wb97xd",
                 "scf_algorithm": "diis",
                 "xc_grid": "3",
+                "thresh": "14",
+                "s2thresh": "16",
                 "solvent_method": "smd",
                 "ideriv": "1",
                 "symmetry": "false",
