@@ -416,7 +416,6 @@ loop_
         Test the _parse_symbol function with several potentially
         problematic examples of symbols and labels.
         """
-
         test_cases = {
             "MgT": "Mg",
             "MgT1": "Mg",
@@ -476,7 +475,7 @@ loop_
         filepath = self.TEST_FILES_DIR / "POSCAR"
         poscar = Poscar.from_file(filepath)
         writer = CifWriter(poscar.structure, symprec=0.01)
-        ans = """# generated using pymatgen
+        answer = """# generated using pymatgen
 data_FePO4
 _symmetry_space_group_name_H-M   Pnma
 _cell_length_a   10.41176687
@@ -494,13 +493,21 @@ loop_
  _symmetry_equiv_pos_site_id
  _symmetry_equiv_pos_as_xyz
   1  'x, y, z'
-  2  '-x, -y, -z'
-  3  '-x+1/2, -y, z+1/2'
-  4  'x+1/2, y, -z+1/2'
-  5  'x+1/2, -y+1/2, -z+1/2'
-  6  '-x+1/2, y+1/2, z+1/2'
-  7  '-x, y+1/2, -z'
-  8  'x, -y+1/2, z'
+  2  'x, y, z'
+  3  '-x, -y, -z'
+  4  '-x, -y, -z'
+  5  '-x+1/2, -y, z+1/2'
+  6  '-x+1/2, -y, z+1/2'
+  7  'x+1/2, y, -z+1/2'
+  8  'x+1/2, y, -z+1/2'
+  9  'x+1/2, -y+1/2, -z+1/2'
+  10  'x+1/2, -y+1/2, -z+1/2'
+  11  '-x+1/2, y+1/2, z+1/2'
+  12  '-x+1/2, y+1/2, z+1/2'
+  13  '-x, y+1/2, -z'
+  14  '-x, y+1/2, -z'
+  15  'x, -y+1/2, z'
+  16  'x, -y+1/2, z'
 loop_
  _atom_site_type_symbol
  _atom_site_label
@@ -514,7 +521,7 @@ loop_
   O  O2  8  0.16570974  0.04607233  0.28538394  1
   O  O3  4  0.04337231  0.75000000  0.70713767  1
   O  O4  4  0.09664244  0.25000000  0.74132035  1"""
-        for l1, l2 in zip(str(writer).split("\n"), ans.split("\n")):
+        for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
             self.assertEqual(l1.strip(), l2.strip())
 
     def test_symmetrized(self):
@@ -527,7 +534,7 @@ loop_
 
         self.assertTrue(m.fit(cif.get_structures()[0], poscar.structure))
 
-        # for l1, l2 in zip(str(writer).split("\n"), ans.split("\n")):
+        # for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
         #     self.assertEqual(l1.strip(), l2.strip())
 
         s = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
@@ -568,7 +575,7 @@ loop_
         )
         struct = Structure(lattice, [si, {si: 0.5, n: 0.5}], coords)
         writer = CifWriter(struct)
-        ans = """# generated using pymatgen
+        answer = """# generated using pymatgen
 data_Si1.5N0.5
 _symmetry_space_group_name_H-M   'P 1'
 _cell_length_a   3.84019793
@@ -598,7 +605,7 @@ loop_
   Si  Si1  1  0.75000000  0.50000000  0.75000000  0.5
   N  N2  1  0.75000000  0.50000000  0.75000000  0.5"""
 
-        for l1, l2 in zip(str(writer).split("\n"), ans.split("\n")):
+        for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
             self.assertEqual(l1.strip(), l2.strip())
 
     def test_cifwrite_without_refinement(self):
@@ -628,7 +635,7 @@ loop_
         )
         struct = Structure(lattice, [n, {si3: 0.5, n: 0.5}, si4], coords)
         writer = CifWriter(struct)
-        ans = """# generated using pymatgen
+        answer = """# generated using pymatgen
 data_X1.5Si1.5
 _symmetry_space_group_name_H-M   'P 1'
 _cell_length_a   3.84019793
@@ -665,11 +672,11 @@ loop_
   Si3+  Si2  1  0.75000000  0.50000000  0.75000000  0.5
   Si4+  Si3  1  0.00000000  0.00000000  0.00000000  1
 """
-        for l1, l2 in zip(str(writer).split("\n"), ans.split("\n")):
+        for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
             self.assertEqual(l1.strip(), l2.strip())
 
         # test that mixed valence works properly
-        s2 = Structure.from_str(ans, "cif")
+        s2 = Structure.from_str(answer, "cif")
         self.assertEqual(struct.composition, s2.composition)
 
     def test_primes(self):
@@ -837,7 +844,7 @@ loop_
             s = p.get_structures()[0]
             self.assertEqual(str(s.composition), "N5+24")
             self.assertIn(
-                "Some fractional co-ordinates rounded to ideal values to avoid issues with finite precision.",
+                "Some fractional coordinates rounded to ideal values to avoid issues with finite precision.",
                 p.warnings,
             )
 
@@ -1043,7 +1050,7 @@ loop_
         s_ncl = self.mcif_ncl.get_structures(primitive=False)[0]
 
         cw = CifWriter(s_ncl, write_magmoms=True)
-        self.assertEqual(cw.__str__(), cw_ref_string)
+        self.assertEqual(str(cw), cw_ref_string)
 
         # from list-type magmoms
         list_magmoms = [list(m) for m in s_ncl.site_properties["magmom"]]
@@ -1053,7 +1060,7 @@ loop_
 
         s_ncl.add_site_property("magmom", list_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
-        self.assertEqual(cw.__str__(), cw_ref_string)
+        self.assertEqual(str(cw), cw_ref_string)
 
         s_ncl.add_site_property("magmom", float_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
@@ -1114,7 +1121,7 @@ loop_
   Gd2  0.00000000  0.00000000  -7.14177849
   Gd3  0.00000000  0.00000000  -7.14177849
 """
-        self.assertEqual(cw.__str__().strip(), cw_ref_string_magnitudes.strip())
+        self.assertEqual(str(cw).strip(), cw_ref_string_magnitudes.strip())
         # test we're getting correct magmoms in ncl case
         s_ncl2 = self.mcif_ncl2.get_structures()[0]
         list_magmoms = [list(m) for m in s_ncl2.site_properties["magmom"]]
@@ -1170,7 +1177,7 @@ loop_
 """
         s_manual.add_oxidation_state_by_site([1, 1])
         cw = CifWriter(s_manual, write_magmoms=True)
-        self.assertEqual(cw.__str__(), cw_manual_oxi_string)
+        self.assertEqual(str(cw), cw_manual_oxi_string)
 
     @unittest.skipIf(pybtex is None, "pybtex not present")
     def test_bibtex(self):
