@@ -1,27 +1,65 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
+import glob
 import hashlib
+import os
+import shutil
 import tempfile
 import unittest
+import warnings
+from pathlib import Path
+from zipfile import ZipFile
 
-import pytest  # type: ignore
-from _pytest.monkeypatch import MonkeyPatch  # type: ignore
+import numpy as np
+import pytest
+from _pytest.monkeypatch import MonkeyPatch
 from monty.json import MontyDecoder
+from monty.serialization import loadfn
 
-from pymatgen.core import SETTINGS
-from pymatgen.core import Lattice, Species, Structure
+from pymatgen.analysis.structure_matcher import StructureMatcher
+from pymatgen.core import SETTINGS, Lattice, Species, Structure
 from pymatgen.core.surface import SlabGenerator
+from pymatgen.core.units import FloatWithUnit
 from pymatgen.io.vasp.inputs import Kpoints, Poscar
 from pymatgen.io.vasp.outputs import Vasprun
-from pymatgen.io.vasp.sets import *
+from pymatgen.io.vasp.sets import (
+    BadInputSetWarning,
+    LobsterSet,
+    MITMDSet,
+    MITNEBSet,
+    MITRelaxSet,
+    MPAbsorptionSet,
+    MPHSEBSSet,
+    MPMetalRelaxSet,
+    MPNMRSet,
+    MPNonSCFSet,
+    MPRelaxSet,
+    MPScanRelaxSet,
+    MPScanStaticSet,
+    MPSOCSet,
+    MPStaticSet,
+    MVLElasticSet,
+    MVLGBSet,
+    MVLGWSet,
+    MVLNPTMDSet,
+    MVLRelax52Set,
+    MVLScanRelaxSet,
+    MVLSlabSet,
+    batch_write_input,
+    get_structure_from_prev_run,
+    get_valid_magmom_struct,
+)
+from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.testing import PymatgenTest
 
 MODULE_DIR = Path(__file__).resolve().parent
 
 dec = MontyDecoder()
 
+if SETTINGS.get("PMG_VASP_PSP_DIR") is None:
+    raise unittest.SkipTest(f"PMG_VASP_PSP_DIR is not set. Skipping tests in {__file__}.")
+
 
 class SetChangeCheckTest(PymatgenTest):
     def test_sets_changed(self):
@@ -45,7 +83,8 @@ class SetChangeCheckTest(PymatgenTest):
             "MPSCANRelaxSet.yaml": "dfa9fee19178cb38c6a121ce6096db40693478e8",
             "MPRelaxSet.yaml": "4ea97d776fbdc7e168036f73e9176012a56c0a45",
             "MITRelaxSet.yaml": "1a0970f8cad9417ec810f7ab349dc854eaa67010",
-            "vdW_parameters.yaml": "66541f58b221c8966109156f4f651b2ca8aa76da",
+            "vdW_parameters.yaml": "04bb09bb563d159565bcceac6a11e8bdf0152b79",
+            "MPAbsorptionSet.yaml": "e86e405a014a7af41490cc7b99609f99f2ddd5b0",
         }
 
         self.assertDictEqual(
@@ -95,7 +134,7 @@ class MITMPRelaxSetTest(PymatgenTest):
             warnings.simplefilter("always")
             # Trigger a warning.
             vis = MITRelaxSet(structure)
-            incar = vis.incar
+            _ = vis.incar
             # Verify some things
             self.assertIn("ISMEAR", str(w[-1].message))
 
@@ -223,6 +262,13 @@ class MITMPRelaxSetTest(PymatgenTest):
         incar = MITRelaxSet(struct).incar
         self.assertEqual(incar["LDAUU"], [4.0, 0])
 
+        # This seems counterintuitive at first, but even if the prior INCAR has a MAGMOM flag,
+        # because the structure has no site properties, the default MAGMOM is assigned from the
+        # config dictionary.
+        struct = Structure(lattice, ["Fe", "F"], coords)
+        incar = MPStaticSet(struct, prev_incar=os.path.join(self.TEST_FILES_DIR, "INCAR")).incar
+        self.assertEqual(incar["MAGMOM"], [5, 0.6])
+
         # Make sure this works with species.
         struct = Structure(lattice, ["Fe2+", "O2-"], coords)
         incar = MPRelaxSet(struct).incar
@@ -284,7 +330,7 @@ class MITMPRelaxSetTest(PymatgenTest):
         incar = MITRelaxSet(s, user_incar_settings={"LDAU": True}).incar
         self.assertFalse("LDAUU" in incar)  # LDAU = False
 
-        # User set a compound to be sulfide by specifing values of "LDAUL" etc.
+        # User set a compound to be sulfide by specifying values of "LDAUL" etc.
         s = Structure(lattice, ["Fe", "Cl", "S"], coords)
         incar = MITRelaxSet(
             s,
@@ -326,7 +372,7 @@ class MITMPRelaxSetTest(PymatgenTest):
         # test that NELECT does not get set when use_structure_charge = False
         mpr = MPRelaxSet(struct, use_structure_charge=False)
         self.assertFalse(
-            "NELECT" in mpr.incar.keys(),
+            "NELECT" in mpr.incar,
             "NELECT should not be set when use_structure_charge is False",
         )
 
@@ -488,16 +534,6 @@ class MITMPRelaxSetTest(PymatgenTest):
             )
             vis.incar.items()
 
-        # Test the behavior of passing in the wrong type of MAGMOM to user_incar_settings
-        struct = self.structure.copy()
-        with pytest.raises(TypeError, match=r"MAGMOM must be supplied"):
-            vis = MPRelaxSet(
-                struct,
-                user_incar_settings={"MAGMOM": [5.0, 5.0]},
-                user_potcar_settings={"Fe": "Fe"},
-            )
-            vis.incar.items()
-
 
 class MPStaticSetTest(PymatgenTest):
     def setUp(self):
@@ -520,20 +556,6 @@ class MPStaticSetTest(PymatgenTest):
         self.assertEqual(vis.incar["ENCUT"], 600)
         self.assertEqual(vis.kpoints.style, Kpoints.supported_modes.Monkhorst)
 
-        # Check warning if LASPH is set to False for meta-GGAs/hybrids/+U/vdW
-        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
-            vis = MPStaticSet(vis.structure, user_incar_settings={"METAGGA": "M06L", "LASPH": False})
-            vis.incar.items()
-        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
-            vis = MPStaticSet(vis.structure, user_incar_settings={"LHFCALC": True, "LASPH": False})
-            vis.incar.items()
-        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
-            vis = MPStaticSet(vis.structure, user_incar_settings={"LDAU": True, "LASPH": False})
-            vis.incar.items()
-        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
-            vis = MPStaticSet(vis.structure, user_incar_settings={"LUSE_VDW": True, "LASPH": False})
-            vis.incar.items()
-
         non_prev_vis = MPStaticSet(vis.structure, user_incar_settings={"LORBIT": 12, "LWAVE": True})
         self.assertEqual(non_prev_vis.incar["NSW"], 0)
         # Check that the ENCUT and Kpoints style has NOT been inherited.
@@ -560,6 +582,25 @@ class MPStaticSetTest(PymatgenTest):
         lcalcpol_vis = MPStaticSet.from_prev_calc(prev_calc_dir=prev_run, lcalcpol=True)
         self.assertTrue(lcalcpol_vis.incar["LCALCPOL"])
 
+        # Check warning if LASPH is set to False for meta-GGAs/hybrids/+U/vdW
+        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
+            vis = MPStaticSet(vis.structure, user_incar_settings={"METAGGA": "M06L", "LASPH": False})
+            vis.incar.items()
+        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
+            vis = MPStaticSet(vis.structure, user_incar_settings={"LHFCALC": True, "LASPH": False})
+            vis.incar.items()
+        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
+            vis = MPStaticSet(vis.structure, user_incar_settings={"LUSE_VDW": True, "LASPH": False})
+            vis.incar.items()
+        with pytest.warns(BadInputSetWarning, match=r"LASPH"):
+            dummy_struc = Structure(
+                lattice=[[0, 2, 2], [2, 0, 2], [2, 2, 0]],
+                species=["Fe", "O"],
+                coords=[[0, 0, 0], [0.5, 0.5, 0.5]],
+            )
+            vis = MPStaticSet(dummy_struc, user_incar_settings={"LDAU": True, "LASPH": False})
+            vis.incar.items()
+
     def test_user_incar_kspacing(self):
         # Make sure user KSPACING settings properly overrides KPOINTS.
         si = self.get_structure("Si")
@@ -612,7 +653,6 @@ class MPStaticSetTest(PymatgenTest):
         self.assertTrue(os.path.exists("MPStaticSet.zip"))
         with ZipFile("MPStaticSet.zip", "r") as zip:
             contents = zip.namelist()
-            print(contents)
             self.assertTrue(set(contents).issuperset({"INCAR", "POSCAR", "POTCAR.spec", "KPOINTS"}))
             spec = zip.open("POTCAR.spec", "r").read().decode()
             self.assertEqual(spec, "Si")
@@ -622,7 +662,7 @@ class MPStaticSetTest(PymatgenTest):
     def test_conflicting_arguments(self):
         with pytest.raises(ValueError, match="deprecated"):
             si = self.get_structure("Si")
-            vis = MPStaticSet(si, potcar_functional="PBE", user_potcar_functional="PBE")
+            MPStaticSet(si, potcar_functional="PBE", user_potcar_functional="PBE")
 
     def test_grid_size_from_struct(self):
         # TODO grab a bunch_of_calculations store as a list of tuples
@@ -892,7 +932,7 @@ class MVLNPTMDSetTest(PymatgenTest):
         self.assertEqual(incar["LANGEVIN_GAMMA"], [10, 10, 10])
         enmax = max(npt_set.potcar[i].keywords["ENMAX"] for i in range(self.struct.ntypesp))
         self.assertAlmostEqual(incar["ENCUT"], 1.5 * enmax)
-        self.assertEqual(incar["IALGO"], 48)
+        self.assertEqual(incar["ALGO"], "Fast")
         self.assertEqual(incar["ISIF"], 3)
         self.assertEqual(incar["MDALGO"], 3)
         self.assertEqual(incar["SMASS"], 0)
@@ -1020,6 +1060,9 @@ class MPNMRSetTest(PymatgenTest):
         vis = MPNMRSet(structure, mode="efg")
         self.assertFalse(vis.incar.get("LCHIMAG", None))
         self.assertEqual(vis.incar.get("QUAD_EFG", None), [-0.808])
+        for q in vis.incar["QUAD_EFG"]:
+            self.assertTrue(isinstance(q, float))
+            self.assertFalse(isinstance(q, FloatWithUnit))
 
         vis = MPNMRSet(structure, mode="efg", isotopes=["Li-7"])
         self.assertFalse(vis.incar.get("LCHIMAG", None))
@@ -1096,7 +1139,7 @@ class MVLSlabSetTest(PymatgenTest):
 
     def test_as_dict(self):
         vis_dict = self.vis.as_dict()
-        new = MVLSlabSet.from_dict(vis_dict)
+        MVLSlabSet.from_dict(vis_dict)
 
 
 class MVLElasticSetTest(PymatgenTest):
@@ -1490,7 +1533,7 @@ class MPScanStaticSetTest(PymatgenTest):
     def test_conflicting_arguments(self):
         with pytest.raises(ValueError, match="deprecated"):
             si = self.get_structure("Si")
-            vis = MPScanStaticSet(si, potcar_functional="PBE", user_potcar_functional="PBE")
+            MPScanStaticSet(si, potcar_functional="PBE", user_potcar_functional="PBE")
 
     def tearDown(self):
         shutil.rmtree(self.tmp)
@@ -1569,7 +1612,7 @@ class MVLRelax52SetTest(PymatgenTest):
 
     def test_potcar_functional_warning(self):
         with pytest.warns(FutureWarning, match="argument is deprecated"):
-            test_potcar_set_1 = MVLRelax52Set(self.struct, potcar_functional="PBE_52")
+            MVLRelax52Set(self.struct, potcar_functional="PBE_52")
 
     def test_as_from_dict(self):
         d = self.mvl_rlx_set.as_dict()
@@ -1610,6 +1653,9 @@ class LobsterSetTest(PymatgenTest):
         with pytest.warns(BadInputSetWarning, match="Overriding the POTCAR"):
             self.lobsterset6 = LobsterSet(self.struct)
 
+        # test W_sw
+        self.lobsterset8 = LobsterSet(Structure.from_file(os.path.join(self.TEST_FILES_DIR, "cohp", "POSCAR.W")))
+
     def test_incar(self):
         incar1 = self.lobsterset1.incar
         self.assertIn("NBANDS", incar1)
@@ -1655,6 +1701,58 @@ class LobsterSetTest(PymatgenTest):
         self.assertEqual(lobsterset_new.potcar_functional, "PBE_54")
 
 
+class MPAbsorptionSetTest(PymatgenTest):
+    def setUp(self):
+        self.tmp = tempfile.mkdtemp()
+        file_path = self.TEST_FILES_DIR / "absorption/static/POSCAR"
+        poscar = Poscar.from_file(file_path)
+        self.structure = poscar.structure
+        warnings.simplefilter("ignore")
+
+    def tearDown(self):
+        warnings.simplefilter("default")
+        shutil.rmtree(self.tmp)
+
+    def test_ipa(self):
+        prev_run = self.TEST_FILES_DIR / "absorption/static"
+        absorptionipa = MPAbsorptionSet.from_prev_calc(prev_calc_dir=prev_run, copy_wavecar=True, mode="IPA")
+        absorptionipa.write_input(self.tmp)
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVECAR")))
+        self.assertEqual(absorptionipa.incar["NBANDS"], 32)
+        self.assertEqual(absorptionipa.incar["ALGO"], "Exact")
+        self.assertTrue(absorptionipa.incar["LOPTICS"])
+
+        # test override_from_prev_calc
+        absorptionipa = MPAbsorptionSet(_dummy_structure, copy_wavecar=True, mode="IPA")
+        absorptionipa.override_from_prev_calc(prev_calc_dir=prev_run)
+        absorptionipa.write_input(self.tmp)
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVECAR")))
+        self.assertEqual(absorptionipa.incar["NBANDS"], 32)
+        self.assertEqual(absorptionipa.incar["ALGO"], "Exact")
+        self.assertTrue(absorptionipa.incar["LOPTICS"])
+
+    def test_rpa(self):
+        prev_run = self.TEST_FILES_DIR / "absorption/ipa"
+        absorptionrpa = MPAbsorptionSet.from_prev_calc(prev_run, copy_wavecar=True, mode="RPA")
+        absorptionrpa.write_input(self.tmp)
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVECAR")))
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVEDER")))
+        self.assertEqual(absorptionrpa.incar["NOMEGA"], 1000)
+        self.assertEqual(absorptionrpa.incar["NBANDS"], 48)
+        self.assertEqual(absorptionrpa.incar["ALGO"], "CHI")
+
+        # test override_from_prev_calc
+        prev_run = self.TEST_FILES_DIR / "absorption/ipa"
+        absorptionrpa = MPAbsorptionSet(_dummy_structure, copy_wavecar=True, mode="RPA")
+        absorptionrpa.override_from_prev_calc(prev_calc_dir=prev_run)
+        absorptionrpa.write_input(self.tmp)
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVECAR")))
+        self.assertTrue(os.path.exists(os.path.join(self.tmp, "WAVEDER")))
+        self.assertEqual(absorptionrpa.incar["NOMEGA"], 1000)
+        self.assertEqual(absorptionrpa.incar["NBANDS"], 48)
+        self.assertEqual(absorptionrpa.incar["ALGO"], "CHI")
+
+
 _dummy_structure = Structure(
     [1, 0, 0, 0, 1, 0, 0, 0, 1],
     ["I"],
