@@ -5,9 +5,12 @@
 This module implements plotter for DOS and band structure.
 """
 
-import logging
-from collections import OrderedDict, namedtuple
+from __future__ import annotations
 
+import logging
+from collections import namedtuple
+
+import matplotlib.pyplot as plt
 import numpy as np
 import scipy.constants as const
 from monty.json import jsanitize
@@ -29,7 +32,7 @@ def freq_units(units):
         units: str, accepted values: thz, ev, mev, ha, cm-1, cm^-1
 
     Returns:
-        Returns conversion factor from THz to the requred units and the label in the form of a namedtuple
+        Returns conversion factor from THz to the required units and the label in the form of a namedtuple
 
     """
 
@@ -53,7 +56,7 @@ def freq_units(units):
     try:
         return d[units.lower().strip()]
     except KeyError:
-        raise KeyError(f"Value for units `{units}` unknown\nPossible values are:\n {list(d.keys())}")
+        raise KeyError(f"Value for units `{units}` unknown\nPossible values are:\n {list(d)}")
 
 
 class PhononDosPlotter:
@@ -76,7 +79,6 @@ class PhononDosPlotter:
 
     def __init__(self, stack=False, sigma=None):
         """
-
         Args:
             stack: Whether to plot the DOS as a stacked area graph
             sigma: A float specifying a standard deviation for Gaussian smearing
@@ -85,7 +87,7 @@ class PhononDosPlotter:
         """
         self.stack = stack
         self.sigma = sigma
-        self._doses = OrderedDict()
+        self._doses = {}
 
     def add_dos(self, label, dos):
         """
@@ -97,7 +99,6 @@ class PhononDosPlotter:
             dos:
                 PhononDos object
         """
-
         densities = dos.get_smeared_densities(self.sigma) if self.sigma else dos.densities
         self._doses[label] = {"frequencies": dos.frequencies, "densities": densities}
 
@@ -111,9 +112,9 @@ class PhononDosPlotter:
             key_sort_func: function used to sort the dos_dict keys.
         """
         if key_sort_func:
-            keys = sorted(dos_dict.keys(), key=key_sort_func)
+            keys = sorted(dos_dict, key=key_sort_func)
         else:
-            keys = dos_dict.keys()
+            keys = list(dos_dict)
         for label in keys:
             self.add_dos(label, dos_dict[label])
 
@@ -139,7 +140,6 @@ class PhononDosPlotter:
             ylim: Specifies the y-axis limits.
             units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
         """
-
         u = freq_units(units)
 
         ncolors = max(3, len(self._doses))
@@ -156,7 +156,7 @@ class PhononDosPlotter:
 
         # Note that this complicated processing of frequencies is to allow for
         # stacked plots in matplotlib.
-        for key, dos in self._doses.items():
+        for dos in self._doses.values():
             frequencies = dos["frequencies"] * u.factor
             densities = dos["densities"]
             if y is None:
@@ -169,7 +169,7 @@ class PhononDosPlotter:
             allfrequencies.append(frequencies)
             alldensities.append(newdens)
 
-        keys = list(self._doses.keys())
+        keys = list(self._doses)
         keys.reverse()
         alldensities.reverse()
         allfrequencies.reverse()
@@ -199,7 +199,7 @@ class PhononDosPlotter:
         ylim = plt.ylim()
         plt.plot([0, 0], ylim, "k--", linewidth=2)
 
-        plt.xlabel(fr"$\mathrm{{Frequencies\ ({u.label})}}$")
+        plt.xlabel(rf"$\mathrm{{Frequencies\ ({u.label})}}$")
         plt.ylabel(r"$\mathrm{Density\ of\ states}$")
 
         plt.legend()
@@ -242,8 +242,6 @@ class PhononDosPlotter:
 class PhononBSPlotter:
     """
     Class to plot or get data to facilitate the plot of band structure objects.
-
-
     """
 
     def __init__(self, bs):
@@ -282,7 +280,7 @@ class PhononBSPlotter:
                     uniq_d.append(tt[0])
                     uniq_l.append(tt[1])
 
-        logger.debug("Unique labels are %s" % list(zip(uniq_d, uniq_l)))
+        logger.debug(f"Unique labels are {list(zip(uniq_d, uniq_l))}")
         plt.gca().set_xticks(uniq_d)
         plt.gca().set_xticklabels(uniq_l)
 
@@ -291,16 +289,12 @@ class PhononBSPlotter:
                 # don't print the same label twice
                 if i != 0:
                     if ticks["label"][i] == ticks["label"][i - 1]:
-                        logger.debug("already print label... skipping label {i}".format(i=ticks["label"][i]))
+                        logger.debug(f"already print label... skipping label {ticks['label'][i]}")
                     else:
-                        logger.debug(
-                            "Adding a line at {d} for label {l}".format(d=ticks["distance"][i], l=ticks["label"][i])
-                        )
+                        logger.debug(f"Adding a line at {ticks['distance'][i]} for label {ticks['label'][i]}")
                         plt.axvline(ticks["distance"][i], color="k")
                 else:
-                    logger.debug(
-                        "Adding a line at {d} for label {l}".format(d=ticks["distance"][i], l=ticks["label"][i])
-                    )
+                    logger.debug(f"Adding a line at {ticks['distance'][i]} for label {ticks['label'][i]}")
                     plt.axvline(ticks["distance"][i], color="k")
         return plt
 
@@ -346,7 +340,6 @@ class PhononBSPlotter:
                 the code choose.
             units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
         """
-
         u = freq_units(units)
 
         plt = pretty_plot(12, 8)
@@ -370,7 +363,7 @@ class PhononBSPlotter:
 
         # Main X and Y Labels
         plt.xlabel(r"$\mathrm{Wave\ Vector}$", fontsize=30)
-        ylabel = fr"$\mathrm{{Frequencies\ ({u.label})}}$"
+        ylabel = rf"$\mathrm{{Frequencies\ ({u.label})}}$"
         plt.ylabel(ylabel, fontsize=30)
 
         # X range (K)
@@ -385,6 +378,145 @@ class PhononBSPlotter:
 
         return plt
 
+    def _get_weight(self, vec: np.ndarray, indices: list[list[int]]) -> np.ndarray:
+        """
+        compute the weight for each combination of sites according to the
+        eigenvector
+        """
+        num_atom = int(self._nb_bands / 3)
+        new_vec = np.zeros(num_atom)
+        for i in range(num_atom):
+            new_vec[i] = np.linalg.norm(vec[i * 3 : i * 3 + 3])
+        # get the projectors for each group
+        gw = []
+        norm_f = 0
+        for comb in indices:
+            projector = np.zeros(len(new_vec))
+            l = len(projector)
+            for j in range(l):
+                if j in comb:
+                    projector[j] = 1
+            group_weight = np.dot(projector, new_vec)
+            gw.append(group_weight)
+            norm_f += group_weight
+        return np.array(gw, dtype=float) / norm_f
+
+    @staticmethod
+    def _make_color(colors: list[int]) -> list[int]:
+        """
+        convert the eigendisplacements to rgb colors
+
+        """
+        # if there are two groups, use red and blue
+        if len(colors) == 2:
+            return [colors[0], 0, colors[1]]
+        elif len(colors) == 3:
+            return colors
+        # if there are four groups, use cyan, magenta, yellow and black
+        elif len(colors) == 4:
+            r = (1 - colors[0]) * (1 - colors[3])
+            g = (1 - colors[1]) * (1 - colors[3])
+            b = (1 - colors[2]) * (1 - colors[3])
+            return [r, g, b]
+        raise ValueError(f"Expected 2, 3 or 4 colors, got {len(colors)}")
+
+    def get_proj_plot(
+        self,
+        site_comb: str | list[list[int]] = "element",
+        ylim: tuple[None | float, None | float] = None,
+        units: str = "thz",
+        rgb_labels: tuple[None | str] = None,
+    ) -> plt.Axes:
+        """
+        Get a matplotlib object for the bandstructure plot projected along atomic
+        sites.
+
+        Args:
+            site_comb: a list of list, for example, [[0],[1],[2,3,4]];
+                the numbers in each sublist represents the indices of atoms;
+                the atoms in a same sublist will be plotted in a same color；
+                if not specified, unique elements are automatically grouped.
+            ylim: Specify the y-axis (frequency) limits; by default None let
+                the code choose.
+            units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
+        """
+        from matplotlib.collections import LineCollection
+
+        from pymatgen.electronic_structure.plotter import BSDOSPlotter
+
+        elements = [e.symbol for e in self._bs.structure.composition.elements]
+        if site_comb == "element":
+            assert 2 <= len(elements) <= 4, "the compound must have 2, 3 or 4 unique elements"
+            indices: list[list[int]] = [[] for _ in range(len(elements))]
+            for i, ele in enumerate(self._bs.structure.species):
+                for j, unique_species in enumerate(self._bs.structure.composition.elements):
+                    if ele == unique_species:
+                        indices[j].append(i)
+        else:
+            assert isinstance(site_comb, list)
+            assert 2 <= len(site_comb) <= 4, "the length of site_comb must be 2, 3 or 4"
+            all_sites = self._bs.structure.sites
+            all_indices = {*range(len(all_sites))}
+            for comb in site_comb:
+                for idx in comb:
+                    assert 0 <= idx < len(all_sites), "one or more indices in site_comb does not exist"
+                    all_indices.remove(idx)
+            if len(all_indices) != 0:
+                raise Exception(f"not all {len(all_sites)} indices are included in site_comb")
+            indices = site_comb  # type: ignore[assignment]
+        assert rgb_labels is None or len(rgb_labels) == len(indices), "wrong number of rgb_labels"
+
+        u = freq_units(units)
+        fig, ax = plt.subplots(figsize=(12, 8), dpi=300)
+        self._maketicks(plt)
+
+        data = self.bs_plot_data()
+        k_dist = np.array(data["distances"]).flatten()
+        for d in range(1, len(k_dist)):
+            # consider 2 k points each time so they connect
+            colors = []
+            for idx in range(self._nb_bands):
+                eigenvec_1 = self._bs.eigendisplacements[idx][d - 1].flatten()
+                eigenvec_2 = self._bs.eigendisplacements[idx][d].flatten()
+                colors1 = self._get_weight(eigenvec_1, indices)
+                colors2 = self._get_weight(eigenvec_2, indices)
+                colors.append(self._make_color((colors1 + colors2) / 2))
+            seg = np.zeros((self._nb_bands, 2, 2))
+            seg[:, :, 1] = self._bs.bands[:, d - 1 : d + 1] * u.factor
+            seg[:, 0, 0] = k_dist[d - 1]
+            seg[:, 1, 0] = k_dist[d]
+            ls = LineCollection(seg, colors=colors, linestyles="-", linewidths=2.5)
+            ax.add_collection(ls)
+        if ylim is None:
+            y_max: float = max(max(b) for b in self._bs.bands) * u.factor
+            y_min: float = min(min(b) for b in self._bs.bands) * u.factor
+            y_margin = (y_max - y_min) * 0.05
+            ylim = (y_min - y_margin, y_max + y_margin)
+        ax.set_ylim(ylim)
+        xlim = [min(k_dist), max(k_dist)]
+        ax.set_xlim(xlim)
+        ax.set_xlabel(r"$\mathrm{Wave\ Vector}$", fontsize=28)
+        ylabel = rf"$\mathrm{{Frequencies\ ({u.label})}}$"
+        ax.set_ylabel(ylabel, fontsize=28)
+        ax.tick_params(labelsize=28)
+        # make color legend
+        labels: list[str]
+        if rgb_labels is not None:
+            labels = rgb_labels  # type: ignore[assignment]
+        else:
+            if site_comb == "element":
+                labels = [e.symbol for e in self._bs.structure.composition.elements]
+            else:
+                labels = [f"{i}" for i in range(len(site_comb))]
+        if len(indices) == 2:
+            BSDOSPlotter._rb_line(ax, labels[0], labels[1], "best")
+        elif len(indices) == 3:
+            BSDOSPlotter._rgb_triangle(ax, labels[0], labels[1], labels[2], "best")
+        else:
+            # for 4 combinations, build a color square?
+            pass
+        return ax
+
     def show(self, ylim=None, units="thz"):
         """
         Show the plot using matplotlib.
@@ -411,6 +543,24 @@ class PhononBSPlotter:
         plt.savefig(filename, format=img_format)
         plt.close()
 
+    def show_proj(
+        self,
+        site_comb: str | list[list[int]] = "element",
+        ylim: tuple[None | float, None | float] = None,
+        units: str = "thz",
+        rgb_labels: tuple[str] = None,
+    ):
+        """
+        Show the projected plot using matplotlib.
+
+        Args:
+            ylim: Specify the y-axis (frequency) limits; by default None let
+                the code choose.
+            units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
+        """
+        self.get_proj_plot(site_comb=site_comb, ylim=ylim, units=units, rgb_labels=rgb_labels)
+        plt.show()
+
     def get_ticks(self):
         """
         Get all ticks and labels for a band structure plot.
@@ -463,7 +613,6 @@ class PhononBSPlotter:
         Returns:
             a matplotlib object with both band structures
         """
-
         u = freq_units(units)
 
         data_orig = self.bs_plot_data()
@@ -489,7 +638,6 @@ class PhononBSPlotter:
         """
         plot the Brillouin zone
         """
-
         # get labels and lines
         labels = {}
         for q in self._bs.qpoints:
@@ -511,7 +659,7 @@ class PhononBSPlotter:
 class ThermoPlotter:
     """
     Plotter for thermodynamic properties obtained from phonon DOS.
-    If the structure corresponding to the DOS, it will be used to extract the forumla unit and provide
+    If the structure corresponding to the DOS, it will be used to extract the formula unit and provide
     the plots in units of mol instead of mole-cell
     """
 
@@ -541,7 +689,6 @@ class ThermoPlotter:
         Returns:
             matplotlib figure
         """
-
         ax, fig, plt = get_ax_fig_plt(ax)
 
         values = []
@@ -690,11 +837,11 @@ class ThermoPlotter:
             temperatures,
             ylabel="Thermodynamic properties",
             ylim=ylim,
-            label=fr"$C_v$ (J/K/mol{mol})",
+            label=rf"$C_v$ (J/K/mol{mol})",
             **kwargs,
         )
         self._plot_thermo(
-            self.dos.entropy, temperatures, ylim=ylim, ax=fig.axes[0], label=fr"$S$ (J/K/mol{mol})", **kwargs
+            self.dos.entropy, temperatures, ylim=ylim, ax=fig.axes[0], label=rf"$S$ (J/K/mol{mol})", **kwargs
         )
         self._plot_thermo(
             self.dos.internal_energy,
@@ -702,7 +849,7 @@ class ThermoPlotter:
             ylim=ylim,
             ax=fig.axes[0],
             factor=1e-3,
-            label=fr"$\Delta E$ (kJ/mol{mol})",
+            label=rf"$\Delta E$ (kJ/mol{mol})",
             **kwargs,
         )
         self._plot_thermo(
@@ -711,7 +858,7 @@ class ThermoPlotter:
             ylim=ylim,
             ax=fig.axes[0],
             factor=1e-3,
-            label=fr"$\Delta F$ (kJ/mol{mol})",
+            label=rf"$\Delta F$ (kJ/mol{mol})",
             **kwargs,
         )
 
@@ -731,7 +878,6 @@ class GruneisenPlotter:
         Args:
             gruneisen: GruneisenParameter Object
         """
-
         self._gruneisen = gruneisen
 
     def get_plot(self, marker="o", markersize=None, units="thz"):
@@ -743,21 +889,19 @@ class GruneisenPlotter:
             units: unit for the plots, accepted units: thz, ev, mev, ha, cm-1, cm^-1
 
         Returns: plot
-
         """
-
         u = freq_units(units)
 
-        x = self._gruneisen.frequencies.flatten() * u.factor
-        y = self._gruneisen.gruneisen.flatten()
+        xs = self._gruneisen.frequencies.flatten() * u.factor
+        ys = self._gruneisen.gruneisen.flatten()
 
         plt = pretty_plot(12, 8)
 
-        plt.xlabel(fr"$\mathrm{{Frequency\ ({u.label})}}$")
+        plt.xlabel(rf"$\mathrm{{Frequency\ ({u.label})}}$")
         plt.ylabel(r"$\mathrm{Grüneisen\ parameter}$")
 
-        n = len(y) - 1
-        for i, (y, x) in enumerate(zip(y, x)):
+        n = len(ys) - 1
+        for i, (x, y) in enumerate(zip(xs, ys)):
             color = (1.0 / n * i, 0, 1.0 / n * (n - i))
 
             if markersize:
@@ -776,9 +920,7 @@ class GruneisenPlotter:
             units: units for the plot, accepted units: thz, ev, mev, ha, cm-1, cm^-1
 
         Returns: plot
-
         """
-
         plt = self.get_plot(units=units)
         plt.show()
 
@@ -791,9 +933,7 @@ class GruneisenPlotter:
             units: accepted units: thz, ev, mev, ha, cm-1, cm^-1
 
         Returns:
-
         """
-
         plt = self.get_plot(units=units)
         plt.savefig(filename, format=img_format)
         plt.close()
@@ -802,8 +942,6 @@ class GruneisenPlotter:
 class GruneisenPhononBSPlotter(PhononBSPlotter):
     """
     Class to plot or get data to facilitate the plot of band structure objects.
-
-
     """
 
     def __init__(self, bs):
@@ -820,7 +958,6 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
         super().__init__(bs)
 
     def bs_plot_data(self):
-
         """
         Get the data nicely formatted for a plot
 
@@ -864,7 +1001,6 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
             ylim: Specify the y-axis (gruneisen) limits; by default None let
                 the code choose.
         """
-
         plt = pretty_plot(12, 8)
 
         # band_linewidth = 1
@@ -938,9 +1074,7 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
 
         Returns:
             a matplotlib object with both band structures
-
         """
-
         data_orig = self.bs_plot_data()
         data = other_plotter.bs_plot_data()
 
