@@ -7,19 +7,38 @@ import os
 import random
 import unittest
 import warnings
+from shutil import which
 
 from monty.json import MontyDecoder
-from monty.os.path import which
 
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.io.vasp.inputs import Poscar
 from pymatgen.symmetry.structure import SymmetrizedStructure
-from pymatgen.transformations.standard_transformations import *
+from pymatgen.transformations.standard_transformations import (
+    AutoOxiStateDecorationTransformation,
+    ChargedCellTransformation,
+    ConventionalCellTransformation,
+    DeformStructureTransformation,
+    DiscretizeOccupanciesTransformation,
+    EwaldSummation,
+    Fraction,
+    OrderDisorderedStructureTransformation,
+    OxidationStateDecorationTransformation,
+    OxidationStateRemovalTransformation,
+    PartialRemoveSpecieTransformation,
+    PerturbStructureTransformation,
+    PrimitiveCellTransformation,
+    RemoveSpeciesTransformation,
+    RotationTransformation,
+    ScaleToRelaxedTransformation,
+    Structure,
+    SubstitutionTransformation,
+    SupercellTransformation,
+)
 from pymatgen.util.testing import PymatgenTest
 
-
 enumlib_present = which("enum.x") and which("makestr.x")
 
 
