@@ -4,18 +4,13 @@
 Utilities for generating nicer plots.
 """
 import math
-import sys
-from matplotlib import colors, cm
+from typing import Literal
 
 import numpy as np
+from matplotlib import cm, colors
 
 from pymatgen.core.periodic_table import Element
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 
 def pretty_plot(width=8, height=None, plt=None, dpi=None, color_cycle=("qualitative", "Set1_9")):
     """
@@ -46,7 +41,7 @@ def pretty_plot(width=8, height=None, plt=None, dpi=None, color_cycle=("qualitat
 
         import matplotlib.pyplot as plt
 
-        mod = importlib.import_module("palettable.colorbrewer.%s" % color_cycle[0])
+        mod = importlib.import_module(f"palettable.colorbrewer.{color_cycle[0]}")
         colors = getattr(mod, color_cycle[1]).mpl_colors
         from cycler import cycler
 
@@ -153,7 +148,7 @@ def pretty_plot_two_axis(
 
 
 def pretty_polyfit_plot(x, y, deg=1, xlabel=None, ylabel=None, **kwargs):
-    r"""
+    """
     Convenience method to plot data with trend lines based on polynomial fit.
 
     Args:
@@ -162,7 +157,7 @@ def pretty_polyfit_plot(x, y, deg=1, xlabel=None, ylabel=None, **kwargs):
         deg (int): Degree of polynomial. Defaults to 1.
         xlabel (str): Label for x-axis.
         ylabel (str): Label for y-axis.
-        \\*\\*kwargs: Keyword args passed to pretty_plot.
+        kwargs: Keyword args passed to pretty_plot.
 
     Returns:
         matplotlib.pyplot object.
@@ -202,7 +197,7 @@ def periodic_table_heatmap(
     readable_fontcolor=False,
 ):
     """
-    A static method that generates a heat map overlayed on a periodic table.
+    A static method that generates a heat map overlaid on a periodic table.
 
     Args:
          elemental_data (dict): A dictionary with the element as a key and a
@@ -212,7 +207,7 @@ def periodic_table_heatmap(
          cbar_label (string): Label of the colorbar. Default is "".
          cbar_label_size (float): Font size for the colorbar label. Default is 14.
          cmap_range (tuple): Minimum and maximum value of the colormap scale.
-            If None, the colormap will autotmatically scale to the range of the
+            If None, the colormap will automatically scale to the range of the
             data.
          show_plot (bool): Whether to show the heatmap. Default is False.
          value_format (str): Formatting string to show values. If None, no value
@@ -227,7 +222,9 @@ def periodic_table_heatmap(
             periodic table. Default is "white".
          max_row (integer): Maximum number of rows of the periodic table to be
             shown. Default is 9, which means the periodic table heat map covers
-            the first 9 rows of elements.
+            the standard 7 rows of the periodic table + 2 rows for the lanthanides
+            and actinides. Use a value of max_row = 7 to exclude the lanthanides and
+            actinides.
          readable_fontcolor (bool): Whether to use readable fontcolor depending
             on background color. Default is False.
     """
@@ -249,10 +246,19 @@ def periodic_table_heatmap(
     blank_value = min_val - 0.01
 
     for el in Element:
-        if el.row > max_row:
-            continue
         value = elemental_data.get(el.symbol, blank_value)
-        value_table[el.row - 1, el.group - 1] = value
+        if 57 <= el.Z <= 71:
+            plot_row = 8
+            plot_group = (el.Z - 54) % 32
+        elif 89 <= el.Z <= 103:
+            plot_row = 9
+            plot_group = (el.Z - 54) % 32
+        else:
+            plot_row = el.row
+            plot_group = el.group
+        if plot_row > max_row:
+            continue
+        value_table[plot_row - 1, plot_group - 1] = value
 
     # Initialize the plt object
     import matplotlib.pyplot as plt
@@ -348,7 +354,7 @@ def format_formula(formula):
                 number_format = ""
             formatted_formula += s
 
-    return r"$%s$" % (formatted_formula)
+    return f"${formatted_formula}$"
 
 
 def van_arkel_triangle(list_of_materials, annotate=True):
@@ -360,13 +366,13 @@ def van_arkel_triangle(list_of_materials, annotate=True):
             A.E. van Arkel, Molecules and Crystals in Inorganic Chemistry,
                 Interscience, New York (1956)
         and
-            J.A.A Ketelaar, Chemical Constitution (2nd edn.), An Introduction
+            J.A.A Ketelaar, Chemical Constitution (2nd edition), An Introduction
                 to the Theory of the Chemical Bond, Elsevier, New York (1958)
 
     Args:
          list_of_materials (list): A list of computed entries of binary
             materials or a list of lists containing two elements (str).
-         annotate (bool): Whether or not to lable the points on the
+         annotate (bool): Whether or not to label the points on the
             triangle with reduced formula (if list of entries) or pair
             of elements (if list of list of str).
     """
@@ -472,9 +478,10 @@ def van_arkel_triangle(list_of_materials, annotate=True):
     for entry in list_of_materials:
         if type(entry).__name__ not in ["ComputedEntry", "ComputedStructureEntry"]:
             X_pair = [Element(el).X for el in entry]
-            formatted_formula = "%s-%s" % tuple(entry)
+            el_1, el_2 = entry
+            formatted_formula = f"{el_1}-{el_2}"
         else:
-            X_pair = [Element(el).X for el in entry.composition.as_dict().keys()]
+            X_pair = [Element(el).X for el in entry.composition.as_dict()]
             formatted_formula = format_formula(entry.composition.reduced_formula)
         plt.scatter(np.mean(X_pair), abs(X_pair[0] - X_pair[1]), c="b", s=100)
         if annotate:
@@ -506,7 +513,7 @@ def get_ax_fig_plt(ax=None, **kwargs):
 
     if ax is None:
         fig = plt.figure(**kwargs)
-        ax = fig.add_subplot(1, 1, 1)
+        ax = fig.gca()
     else:
         fig = plt.gcf()
 
@@ -624,7 +631,7 @@ def add_fig_kwargs(func):
             if len(fig.axes) > len(tags):
                 tags = (1 + len(ascii_letters) // len(fig.axes)) * ascii_letters
             for ax, tag in zip(fig.axes, tags):
-                ax.annotate("(%s)" % tag, xy=(0.05, 0.95), xycoords="axes fraction")
+                ax.annotate(f"({tag})", xy=(0.05, 0.95), xycoords="axes fraction")
 
         if tight_layout:
             try:
