@@ -1,7 +1,6 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module contains classes to wrap Python VTK to make nice molecular plots.
 """
@@ -11,6 +10,7 @@ import math
 import os
 import subprocess
 import time
+from typing import Sequence
 
 import numpy as np
 
@@ -56,7 +56,7 @@ class StructureVis:
             element_color_mapping: Optional color mapping for the elements,
                 as a dict of {symbol: rgb tuple}. For example, {"Fe": (255,
                 123,0), ....} If None is specified, a default based on
-                Jmol"s color scheme is used.
+                Jmol's color scheme is used.
             show_unit_cell: Set to False to not show the unit cell
                 boundaries. Defaults to True.
             show_bonds: Set to True to show bonds. Defaults to True.
@@ -107,7 +107,7 @@ class StructureVis:
         self.show_bonds = show_bonds
         self.show_polyhedron = show_polyhedron
         self.poly_radii_tol_factor = poly_radii_tol_factor
-        self.excluded_bonding_elements = excluded_bonding_elements if excluded_bonding_elements else []
+        self.excluded_bonding_elements = excluded_bonding_elements or []
         self.show_help = True
         self.supercell = [[1, 0, 0], [0, 1, 0], [0, 0, 1]]
         self.redraw()
@@ -138,12 +138,9 @@ class StructureVis:
         Save render window to an image.
 
         Arguments:
-            filename:
-                filename to save to. Defaults to image.png.
-            magnification:
-                magnification. Use it to render high res images.
-            image_format:
-                choose between jpeg, png.  Png is the default.
+            filename: file to save to. Defaults to image.png.
+            magnification: Use it to render high res images.
+            image_format: choose between jpeg, png. Defaults to 'png'.
         """
         render_large = vtk.vtkRenderLargeImage()
         render_large.SetInput(self.ren)
@@ -167,7 +164,7 @@ class StructureVis:
 
         Args:
             reset_camera: Set to True to reset the camera to a
-                pre-determined default for each structure.  Defaults to False.
+                pre-determined default for each structure. Defaults to False.
         """
         self.ren.RemoveAllViewProps()
         self.picker = None
@@ -211,7 +208,7 @@ class StructureVis:
         self.helptxt_actor.SetPosition(10, 10)
         self.helptxt_actor.VisibilityOn()
 
-    def set_structure(self, structure, reset_camera=True, to_unit_cell=True):
+    def set_structure(self, structure: Structure, reset_camera=True, to_unit_cell=True):
         """
         Add a structure to the visualizer.
 
@@ -260,7 +257,7 @@ class StructureVis:
             anion = elements[-1]
 
             def contains_anion(site):
-                for sp in site.species.keys():
+                for sp in site.species:
                     if sp.symbol == anion.symbol:
                         return True
                 return False
@@ -289,7 +286,7 @@ class StructureVis:
                     if self.show_bonds:
                         self.add_bonds(nn_sites, site)
                     if self.show_polyhedron:
-                        color = [i / 255 for i in color]
+                        color = np.array([i / 255 for i in color])
                         self.add_polyhedron(nn_sites, site, color)
 
         if self.show_help:
@@ -465,7 +462,7 @@ class StructureVis:
         color,
         opacity=1.0,
         draw_edges=False,
-        edges_color=[0.0, 0.0, 0.0],
+        edges_color=(0.0, 0.0, 0.0),
         edges_linewidth=2,
     ):
         """
@@ -528,14 +525,14 @@ class StructureVis:
         center=None,
         opacity=0.4,
         draw_edges=False,
-        edges_color=[0.0, 0.0, 0.0],
+        edges_color=(0.0, 0.0, 0.0),
         edges_linewidth=2,
     ):
         """
         Adds a triangular surface between three atoms.
 
         Args:
-            atoms: Atoms between which a triangle will be drawn.
+            neighbors: Atoms between which a triangle will be drawn.
             color: Color for triangle as RGB.
             center: The "central atom" of the triangle
             opacity: opacity of the triangle
@@ -650,7 +647,7 @@ class StructureVis:
             else:
                 raise ValueError("Number of points for a face should be >= 3")
 
-    def add_edges(self, edges, type="line", linewidth=2, color=[0.0, 0.0, 0.0]):
+    def add_edges(self, edges, type="line", linewidth=2, color=(0.0, 0.0, 0.0)):
         """
         Args:
             edges (): List of edges
@@ -899,7 +896,7 @@ class StructureInteractorStyle(vtkInteractorStyleTrackballCamera):
 
 
 def make_movie(structures, output_filename="movie.mp4", zoom=1.0, fps=20, bitrate="10000k", quality=1, **kwargs):
-    r"""
+    """
     Generate a movie from a sequence of structures using vtk and ffmpeg.
 
     Args:
@@ -908,10 +905,10 @@ def make_movie(structures, output_filename="movie.mp4", zoom=1.0, fps=20, bitrat
             movie.mp4
         zoom (float): A zoom to be applied to the visualizer. Defaults to 1.0.
         fps (int): Frames per second for the movie. Defaults to 20.
-        bitrate (str): Video bitate.  Defaults to "10000k" (fairly high
+        bitrate (str): Video bitate. Defaults to "10000k" (fairly high
             quality).
         quality (int): A quality scale. Defaults to 1.
-        \\*\\*kwargs: Any kwargs supported by StructureVis to modify the images
+        kwargs: Any kwargs supported by StructureVis to modify the images
             generated.
     """
     vis = StructureVis(**kwargs)
@@ -968,7 +965,7 @@ class MultiStructuresVis(StructureVis):
             element_color_mapping: Optional color mapping for the elements,
                 as a dict of {symbol: rgb tuple}. For example, {"Fe": (255,
                 123,0), ....} If None is specified, a default based on
-                Jmol"s color scheme is used.
+                Jmol's color scheme is used.
             show_unit_cell: Set to False to not show the unit cell
                 boundaries. Defaults to True.
             show_bonds: Set to True to show bonds. Defaults to True.
@@ -1002,12 +999,12 @@ class MultiStructuresVis(StructureVis):
         self.current_structure = None
         self.set_animated_movie_options(animated_movie_options=animated_movie_options)
 
-    def set_structures(self, structures, tags=None):
+    def set_structures(self, structures: Sequence[Structure], tags=None):
         """
         Add list of structures to the visualizer.
 
         Args:
-            structures (List of Structures):
+            structures (list[Structures]): structures to be visualized.
             tags (): List of tags.
         """
         self.structures = structures
@@ -1034,7 +1031,7 @@ class MultiStructuresVis(StructureVis):
             self.all_vis_radii.append(struct_vis_radii)
         self.set_structure(self.current_structure, reset_camera=True, to_unit_cell=False)
 
-    def set_structure(self, structure, reset_camera=True, to_unit_cell=False):
+    def set_structure(self, structure: Structure, reset_camera=True, to_unit_cell=False):
         """
         Add a structure to the visualizer.
 
@@ -1062,7 +1059,7 @@ class MultiStructuresVis(StructureVis):
             opacity = tag.get("opacity", 0.5)
             if site_index == "unit_cell_all":
                 struct_radii = self.all_vis_radii[self.istruct]
-                for isite, site in enumerate(self.current_structure):
+                for isite, _site in enumerate(self.current_structure):
                     vis_radius = 1.5 * tag.get("radius", struct_radii[isite])
                     tags[(isite, (0, 0, 0))] = {
                         "radius": vis_radius,
@@ -1121,7 +1118,7 @@ class MultiStructuresVis(StructureVis):
         else:
             self.animated_movie_options = self.DEFAULT_ANIMATED_MOVIE_OPTIONS.copy()
             for key in animated_movie_options:
-                if key not in self.DEFAULT_ANIMATED_MOVIE_OPTIONS.keys():
+                if key not in self.DEFAULT_ANIMATED_MOVIE_OPTIONS:
                     raise ValueError("Wrong option for animated movie")
             self.animated_movie_options.update(animated_movie_options)
 
@@ -1269,8 +1266,8 @@ class MultiStructuresInteractorStyle(StructureInteractorStyle):
                     parent.current_structure = parent.structures[parent.istruct]
                     parent.set_structure(parent.current_structure, reset_camera=False, to_unit_cell=False)
                     parent.display_info(
-                        "Animated movie : structure {:d}/{:d} "
-                        "(loop {:d}/{:d})".format(istruct + 1, len(parent.structures), iloop + 1, nloops)
+                        f"Animated movie : structure {istruct + 1}/{len(parent.structures)} "
+                        f"(loop {iloop + 1}/{nloops})"
                     )
                     parent.ren_win.Render()
                 time.sleep(tloops)
